@@ -39,7 +39,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit BankSkroogoid(QObject* parent, const QVariantList& args);
+    explicit BankSkroogoid(QObject* iParent, const QVariantList& args);
 
     /**
     * Default Destructor
