@@ -28,7 +28,8 @@
 #include <QGraphicsGridLayout>
 #include <kmessagebox.h>
 
-HighlightedOperationSkroogoid::HighlightedOperationSkroogoid(QObject* parent, const QVariantList& args) : Applet(parent, args)
+HighlightedOperationSkroogoid::HighlightedOperationSkroogoid(QObject* iParent, const QVariantList& args) :
+    Applet(iParent, args), widgetLayout(NULL)
 {}
 
 HighlightedOperationSkroogoid::~HighlightedOperationSkroogoid()
@@ -37,11 +38,13 @@ HighlightedOperationSkroogoid::~HighlightedOperationSkroogoid()
 void HighlightedOperationSkroogoid::init()
 {
     // This is the layout for the whole widget
-    widgetLayout = new QGraphicsLinearLayout(Qt::Vertical);
-    setLayout(widgetLayout);
+    if (widgetLayout == NULL) {
+        widgetLayout = new QGraphicsLinearLayout(Qt::Vertical);
+        setLayout(widgetLayout);
 
-    Plasma::DataEngine* engine = dataEngine("skgdataengine");
-    if (engine->isValid())  engine->connectSource("Highlighted Operations", this);
+        Plasma::DataEngine* engine = dataEngine("skgdataengine");
+        if (engine->isValid())  engine->connectSource("Highlighted Operations", this);
+    }
 }
 
 void HighlightedOperationSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData)
@@ -94,10 +97,10 @@ void HighlightedOperationSkroogoid::dataUpdated(const QString& sourceName, const
         QGraphicsLinearLayout* lineLayout = new QGraphicsLinearLayout(Qt::Horizontal);
         widgetLayout->addItem(lineLayout);
 
-        KLocale* locale = KGlobal::locale();
+        KLocale* loc = KGlobal::locale();
         Plasma::Label* dateLabel = new Plasma::Label();
         lineLayout->addItem(dateLabel);
-        dateLabel->setText(locale->formatDate(SKGServices::stringToTime(date).date() , KLocale::FancyShortDate));
+        dateLabel->setText(loc->formatDate(SKGServices::stringToTime(date).date() , KLocale::FancyShortDate));
         dateLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
 
         lineLayout->addStretch(10);
