@@ -38,7 +38,7 @@ public:
     /**
      * Standard constructor
      */
-    IncomeExpenditureWidget(QObject* parent, const QVariantList& args);
+    IncomeExpenditureWidget(QObject* iParent, const QVariantList& args);
 
     /**
      * Default destructor
