@@ -29,8 +29,8 @@
 #include <kmessagebox.h>
 #include <Plasma/Frame>
 
-ScheduledOperationSkroogoid::ScheduledOperationSkroogoid(QObject* parent, const QVariantList& args)
-    : Plasma::Applet(parent, args)
+ScheduledOperationSkroogoid::ScheduledOperationSkroogoid(QObject* iParent, const QVariantList& args)
+    : Plasma::Applet(iParent, args), widgetLayout(NULL)
 {}
 
 ScheduledOperationSkroogoid::~ScheduledOperationSkroogoid()
@@ -39,13 +39,13 @@ ScheduledOperationSkroogoid::~ScheduledOperationSkroogoid()
 void ScheduledOperationSkroogoid::init()
 {
     // This is the layout for the whole widget
-    widgetLayout = new QGraphicsLinearLayout(Qt::Vertical);
-    setLayout(widgetLayout);
-
-    Plasma::DataEngine* engine = dataEngine("skgdataengine");
-    if (engine->isValid())  engine->connectSource("Scheduled Operations", this);
-
+    if (widgetLayout == NULL) {
+        widgetLayout = new QGraphicsLinearLayout(Qt::Vertical);
+        setLayout(widgetLayout);
 
+        Plasma::DataEngine* engine = dataEngine("skgdataengine");
+        if (engine->isValid())  engine->connectSource("Scheduled Operations", this);
+    }
 }
 
 void ScheduledOperationSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& engineData)
@@ -140,9 +140,9 @@ Plasma::Frame* ScheduledOperationSkroogoid::createFrame(const QString date)
     QGraphicsLinearLayout* frameLayout = new QGraphicsLinearLayout(Qt::Vertical);
     dateFrame->setLayout(frameLayout);
 
-    KLocale* locale = KGlobal::locale();
+    KLocale* loc = KGlobal::locale();
     Plasma::Label* dateLabel = new Plasma::Label();
-    dateLabel->setText(locale->formatDate(SKGServices::stringToTime(date).date(), KLocale::FancyShortDate));
+    dateLabel->setText(loc->formatDate(SKGServices::stringToTime(date).date(), KLocale::FancyShortDate));
     dateLabel->setAlignment(Qt::AlignLeft);
     QFont dateFont = dateLabel->font();
     dateFont.setBold(true);
