@@ -40,7 +40,7 @@ public:
     /**
     * Default Constructor
     */
-    explicit ScheduledOperationSkroogoid(QObject* parent, const QVariantList& args);
+    explicit ScheduledOperationSkroogoid(QObject* iParent, const QVariantList& args);
 
     /**
      * Reimplemented from Plasma::Applet
