@@ -34,7 +34,7 @@ public:
     /**
      * Reimplemented from Plasma::DataEngine
      */
-    SKGAdviceDataEngine(QObject* parent, const QVariantList& args);
+    SKGAdviceDataEngine(QObject* iParent, const QVariantList& args);
 
 
     /**
