@@ -73,15 +73,13 @@ QString SKGAdvicePlugin::getDashboardWidgetTitle(int iIndex)
 {
     SKGTRACEIN(1, "SKGAdvicePlugin::getDashboardWidgetTitle");
     if (iIndex == 0) return i18nc("Noun, a list of items", "Advice");
-    else if (iIndex == 1) return i18nc("Noun, a list of items", "Tip of the day");
-    return "";
+    else return i18nc("Noun, a list of items", "Tip of the day");
 }
 
 SKGBoardWidget* SKGAdvicePlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGAdviceBoardWidget(currentDocument);
-    else if (iIndex == 1) return new SKGTipOfDayBoardWidget(currentDocument);
-    return NULL;
+    else return new SKGTipOfDayBoardWidget(currentDocument);
 }
 
 
