@@ -41,7 +41,7 @@ SKGTipOfDayBoardWidget::SKGTipOfDayBoardWidget(SKGDocument* iDocument)
     connect(ui.kIcon, SIGNAL(clicked(bool)), this, SLOT(onModified()));
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(onModified()), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(onModified()), Qt::QueuedConnection);
 
 }
 
