@@ -47,7 +47,7 @@ K_PLUGIN_FACTORY(SKGBookmarkPluginFactory, registerPlugin<SKGBookmarkPlugin>();)
 K_EXPORT_PLUGIN(SKGBookmarkPluginFactory("skg_bookmark", "skg_bookmark"))
 
 SKGBookmarkPlugin::SKGBookmarkPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& iArg) :
-    SKGInterfacePlugin(iParent), m_dockWidget(NULL)
+    SKGInterfacePlugin(iParent), m_currentDocument(NULL), m_dockWidget(NULL), m_importStdBookmarkAction(NULL), m_bookmarkAction(NULL), m_bookmarkMenu(NULL)
 {
     Q_UNUSED(iArg);
     SKGTRACEIN(10, "SKGBookmarkPlugin::SKGBookmarkPlugin");
@@ -227,15 +227,15 @@ void SKGBookmarkPlugin::importStandardBookmarks()
         if (line.count() == 4) {
             SKGNodeObject node;
             err = SKGNodeObject::createPathNode(m_currentDocument, line.at(0), node);
-            if (!err) err = node.setAutoStart(line.at(1) == "Y");
-            if (!err) err = node.setIcon(line.at(2));
-            if (!err) err = node.setData(line.at(3));
-            if (!err) err = node.save();
+            IFOKDO(err, node.setAutoStart(line.at(1) == "Y"))
+            IFOKDO(err, node.setIcon(line.at(2)))
+            IFOKDO(err, node.setData(line.at(3)))
+            IFOKDO(err, node.save())
         }
     }
 
     //status
-    if (!err)  err = SKGError(0, i18nc("Successful message after an user action", "Standard bookmarks imported."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Standard bookmarks imported.")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Import standard bookmarks failed"));
 
     //Display error
@@ -286,7 +286,7 @@ void SKGBookmarkPlugin::onAddBookmark()
         err =  SKGBookmarkPluginDockWidget::createNodeFromPage(SKGMainPanel::getMainPanel()->currentPage(), parentNode, node);
     }
     //status bar
-    if (!err) {
+    IFOK(err) {
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
     }
     SKGMainPanel::displayErrorMessage(err);
