@@ -39,13 +39,13 @@ class SKGMainPanel;
 class SKGBookmarkPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGBookmarkPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGBookmarkPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -111,11 +111,12 @@ private Q_SLOTS:
     void importStandardBookmarks();
     void goHome();
 
-    void actionOpenBookmark(Qt::MouseButtons iMouse = Qt::LeftButton, Qt::KeyboardModifiers iKeyboard = Qt::NoModifier);
+    void onOpenBookmark(Qt::MouseButtons iMouse = Qt::LeftButton, Qt::KeyboardModifiers iKeyboard = Qt::NoModifier);
+    void onAddBookmark();
     void onShowBookmarkMenu();
 
 private:
-    Q_DISABLE_COPY(SKGBookmarkPlugin);
+    Q_DISABLE_COPY(SKGBookmarkPlugin)
 
     SKGDocument* m_currentDocument;
     QDockWidget* m_dockWidget;
