@@ -98,7 +98,7 @@ SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
     m_modelview = NULL;
 }
 
-QWidget* SKGBookmarkPluginDockWidget::mainWidget() const
+QWidget* SKGBookmarkPluginDockWidget::mainWidget()
 {
     return ui.kBookmarksList;
 }
@@ -184,13 +184,13 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
         for (int i = 0 ; !err && i < nb  ; ++i) {
             SKGNodeObject bookmark(selectedBookmarks.at(i));
             err = bookmark.setAttribute("t_autostart", value);
-            if (!err)  err = bookmark.save();
-            if (!err)  err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, bookmark.save())
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, value == "Y" ? i18nc("Successful message after an user action", "Autostart bookmarks") : i18nc("Successful message after an user action", "Do not Autostart bookmarks"));
+    IFOKDO(err, SKGError(0, value == "Y" ? i18nc("Successful message after an user action", "Autostart bookmarks") : i18nc("Successful message after an user action", "Do not Autostart bookmarks")))
     SKGMainPanel::displayErrorMessage(err);
 
 }
@@ -254,8 +254,8 @@ void SKGBookmarkPluginDockWidget::onBeforeOpenBookmark()
 void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex& index)
 {
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onOpenBookmark");
-    QSortFilterProxyModel* proxyModel = (QSortFilterProxyModel*) ui.kBookmarksList->model();
-    SKGObjectModelBase* model = (SKGObjectModelBase*) proxyModel->sourceModel();
+    QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
+    SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
     if (model) {
         SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
         if (!node.isFolder()) openBookmark(node);
@@ -265,8 +265,8 @@ void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex& index)
 void SKGBookmarkPluginDockWidget::onOpenBookmarkFolder(const QModelIndex& index)
 {
     SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onOpenBookmarkFolder");
-    QSortFilterProxyModel* proxyModel = (QSortFilterProxyModel*) ui.kBookmarksList->model();
-    SKGObjectModelBase* model = (SKGObjectModelBase*) proxyModel->sourceModel();
+    QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
+    SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
     if (model) {
         SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
         if (node.isFolder()) openBookmark(node);
@@ -303,7 +303,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
     }
 
     //status bar
-    if (!err) {
+    IFOK(err) {
         ui.kBookmarksList->selectObject(node.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmark group created"));
     }
@@ -345,7 +345,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarks()
     }
 
     //status bar
-    if (!err) {
+    IFOK(err) {
         ui.kBookmarksList->selectObject(rootNode.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmarks created"));
     }
@@ -369,7 +369,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
         err = createNodeFromPage(SKGMainPanel::getMainPanel()->currentPage(), parentNode, node);
     }
     //status bar
-    if (!err) {
+    IFOK(err) {
         ui.kBookmarksList->selectObject(node.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
     }
@@ -410,14 +410,14 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
         //Create bookmark
         SKGBEGINTRANSACTION(*iParentNode.getDocument(), i18nc("Noun, name of the user action", "Bookmark creation '%1'", name), err);
         err = SKGNodeObject::createPathNode(iParentNode.getDocument(), name, oCreatedNode, true);
-        if (!err) {
+        IFOK(err) {
             QString value = SKGServices::stringToCsv(iPage->objectName()) % ';' %
                             SKGServices::stringToCsv(defaultName) % ';' %
                             SKGServices::stringToCsv(iPage->getState());
 
             err = oCreatedNode.setData(value);
-            if (!err) err = oCreatedNode.setIcon(defaultIcon);
-            if (!err) err = oCreatedNode.save();
+            IFOKDO(err, oCreatedNode.setIcon(defaultIcon))
+            IFOKDO(err, oCreatedNode.save())
         }
     }
     return err;
@@ -429,9 +429,9 @@ void SKGBookmarkPluginDockWidget::onRenameBookmark()
 
     SKGObjectBase::SKGListSKGObjectBase selection;
     QItemSelectionModel* selModel = ui.kBookmarksList->selectionModel();
-    QSortFilterProxyModel* proxyModel = (QSortFilterProxyModel*) ui.kBookmarksList->model();
+    QSortFilterProxyModel* proxyModel = qobject_cast< QSortFilterProxyModel* >(ui.kBookmarksList->model());
     if (proxyModel && selModel) {
-        SKGObjectModelBase* model = (SKGObjectModelBase*) proxyModel->sourceModel();
+        SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
         if (model) {
             QModelIndexList indexes = selModel->selectedRows();
             if (indexes.count() == 1) {
@@ -455,11 +455,11 @@ void SKGBookmarkPluginDockWidget::onChangeIconBookmark()
             {
                 SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark icon change"), err);
                 err = node.setIcon(icon);
-                if (!err) err = node.save();
+                IFOKDO(err, node.save())
 
             }
             //status bar
-            if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Bookmark icon changed"));
+            IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Bookmark icon changed")))
             SKGMainPanel::displayErrorMessage(err);
         }
     }
@@ -482,7 +482,7 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Bookmark deleted"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Bookmark deleted")))
     SKGMainPanel::displayErrorMessage(err);
 }
 
