@@ -50,7 +50,7 @@ public:
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() const;
+    virtual QWidget* mainWidget();
 
     /**
      * Open a bookmark
