@@ -77,7 +77,7 @@ QString SKGDashboardPlugin::title() const
 
 QString SKGDashboardPlugin::icon() const
 {
-    return "view-bank";
+    return "dashboard-show";
 }
 
 QString SKGDashboardPlugin::toolTip() const
