@@ -118,9 +118,11 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
     }
 
     //Plug buttons with menus
-    ui.kAddWidget->setIcon(m_addMenu->icon());
-    ui.kAddWidget->setMenu(m_addMenu);
-    ui.kAddWidget->setPopupMode(QToolButton::InstantPopup);
+    if (m_addMenu && ui.kAddWidget) {
+        ui.kAddWidget->setIcon(m_addMenu->icon());
+        ui.kAddWidget->setMenu(m_addMenu);
+        ui.kAddWidget->setPopupMode(QToolButton::InstantPopup);
+    }
 }
 
 SKGDashboardPluginWidget::~SKGDashboardPluginWidget()
@@ -230,7 +232,7 @@ void SKGDashboardPluginWidget::refresh()
     SKGTRACEIN(1, "SKGDashboardPluginWidget::refresh");
 }
 
-QWidget* SKGDashboardPluginWidget::zoomableWidget() const
+QWidget* SKGDashboardPluginWidget::zoomableWidget()
 {
     if (PLASMA) return NULL;
     return SKGTabPage::zoomableWidget();
@@ -269,21 +271,21 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
 
             if (event->type() == QEvent::MouseButtonPress) {
                 //Drag
-                QMouseEvent* mevent = (QMouseEvent*) event;
+                QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
                 if (mevent->button() == Qt::LeftButton) {
                     m_clickedPoint = mevent->pos();
                     m_timer.stop();
                 }
             } else if (event->type() == QEvent::MouseButtonRelease) {
                 //Drag
-                QMouseEvent* mevent = (QMouseEvent*) event;
+                QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
                 if (mevent->button() == Qt::LeftButton) {
                     m_clickedPoint = QPoint(-1, -1);
                 }
             } else if (event->type() == QEvent::MouseMove) {
                 //Drag
                 if (m_clickedPoint != QPoint(-1, -1) && toMoveIndex != -1) {
-                    QMouseEvent* mevent = (QMouseEvent*) event;
+                    QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
                     int distance = (mevent->pos() - m_clickedPoint).manhattanLength();
                     if (distance >= QApplication::startDragDistance()) {
                         QMimeData* mimeData = new QMimeData;
@@ -298,7 +300,7 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
                 }
             } else if (event->type() == QEvent::DragEnter) {
                 //Drop move
-                QDragEnterEvent* devent = (QDragEnterEvent*) event;
+                QDragEnterEvent* devent = static_cast<QDragEnterEvent*>(event);
                 if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
                     devent->accept();
 
@@ -306,7 +308,7 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
                 }
             } else if (event->type() == QEvent::DragMove) {
                 //Drop move
-                QDragMoveEvent* devent = (QDragMoveEvent*) event;
+                QDragMoveEvent* devent = static_cast<QDragMoveEvent*>(event);
                 if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
                     int oldPos = SKGServices::stringToInt(devent->mimeData()->data("application/x-skgdashboardpluginwidget"));
                     if (oldPos != toMoveIndex) devent->accept();
@@ -316,7 +318,7 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
                 }
             } else if (event->type() == QEvent::Drop) {
                 //Drop
-                QDropEvent* devent = (QDropEvent*) event;
+                QDropEvent* devent = static_cast<QDropEvent*>(event);
                 if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
                     int oldPos = SKGServices::stringToInt(devent->mimeData()->data("application/x-skgdashboardpluginwidget"));
 
@@ -355,10 +357,9 @@ void SKGDashboardPluginWidget::onAddWidget()
 void SKGDashboardPluginWidget::onMoveWidget(int iMove)
 {
     //Get current position
-    int pos = -1;
     QWidget* sender = qobject_cast<QWidget*>(this->sender());
     if (sender) {
-        pos = m_itemsPointers.indexOf(parentBoardWidget(sender));
+        int pos = m_itemsPointers.indexOf(parentBoardWidget(sender));
         int newPos = pos + iMove;
         if (newPos < 0) newPos = 0;
         else if (newPos > m_items.count() - 1) newPos = m_items.count() - 1;
@@ -400,8 +401,8 @@ SKGBoardWidget* SKGDashboardPluginWidget::parentBoardWidget(QWidget* iWidget)
 {
     SKGBoardWidget* output = qobject_cast< SKGBoardWidget* >(iWidget);
     if (!output && iWidget) {
-        QWidget* parent = iWidget->parentWidget();
-        if (parent)  output = SKGDashboardPluginWidget::parentBoardWidget(parent);
+        QWidget* iParent = iWidget->parentWidget();
+        if (iParent)  output = SKGDashboardPluginWidget::parentBoardWidget(iParent);
     }
 
     return output;
