@@ -43,7 +43,8 @@ K_PLUGIN_FACTORY(SKGDeletePluginFactory, registerPlugin<SKGDeletePlugin>();)
  */
 K_EXPORT_PLUGIN(SKGDeletePluginFactory("skg_delete", "skg_delete"))
 
-SKGDeletePlugin::SKGDeletePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGDeletePlugin::SKGDeletePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent), m_deleteAction(NULL), m_currentDocument(NULL)
 {
     SKGTRACEIN(10, "SKGDeletePlugin::SKGDeletePlugin");
 }
@@ -112,7 +113,7 @@ void SKGDeletePlugin::onDelete()
                     QApplication::restoreOverrideCursor();
                     if (rc == KMessageBox::Yes) err = selection[i].remove(true, true);
                 }
-                if (!err) err = m_currentDocument->stepForward(i + 1);
+                IFOKDO(err, m_currentDocument->stepForward(i + 1))
             }
         }
 
@@ -120,7 +121,7 @@ void SKGDeletePlugin::onDelete()
         KMessageBox::enableMessage("forcedelete");
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Objects deleted."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Objects deleted.")))
     }
 
     //Display error
