@@ -52,7 +52,9 @@ K_PLUGIN_FACTORY(SKGFilePluginFactory, registerPlugin<SKGFilePlugin>();)
  */
 K_EXPORT_PLUGIN(SKGFilePluginFactory("skg_file", "skg_file"))
 
-SKGFilePlugin::SKGFilePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_recentFiles(NULL)
+SKGFilePlugin::SKGFilePlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent),
+    m_saveAction(NULL), m_saveAsAction(NULL), m_passwordAction(NULL), m_recentFiles(NULL), m_currentDocument(NULL)
 {
     SKGTRACEIN(10, "SKGFilePlugin::SKGFilePlugin");
 
@@ -263,12 +265,12 @@ void SKGFilePlugin::onNew()
 
         err = m_currentDocument->initialize();
 
-        KLocale* locale = KGlobal::locale();
-        if (!err) err = m_currentDocument->setLanguage(locale->language());
+        KLocale* loc = KGlobal::locale();
+        IFOKDO(err, m_currentDocument->setLanguage(loc->language()))
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after creating a document", "Document successfully created."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after creating a document", "Document successfully created.")))
         else err.addError(ERR_FAIL, i18nc("Error message: Could not create a document",  "Document creation failed."));
 
         //Display error
@@ -291,7 +293,7 @@ void SKGFilePlugin::onSave()
             SKGMainPanel::getMainPanel()->refresh();
 
             //status bar
-            if (!err) err = SKGError(0, i18nc("Successfully saved a file", "File successfully saved."));
+            IFOKDO(err, SKGError(0, i18nc("Successfully saved a file", "File successfully saved.")))
             else err.addError(ERR_FAIL, i18nc("Error message: Could not save a file",  "Cannot save file"));
 
             //Display error
@@ -318,7 +320,7 @@ void SKGFilePlugin::onSaveAs()
         SKGMainPanel::getMainPanel()->refresh();
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successfully saved a file", "File '%1' saved.", fileName));
             //Add in recentFiles
             if (m_recentFiles) {
@@ -428,7 +430,7 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
 
                         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                         err = m_currentDocument->load(fileName, pwd, restoreTmpFile);
-                        if (err) {
+                        IFKO(err) {
                             if (err.getReturnCode() == ERR_ENCRYPTION) {
                                 additionalMessage = i18nc("The user did not provide the correct password", "<b>Wrong password.</b>\n");
                                 useKWallet = false;
@@ -445,11 +447,11 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                 } while (err);
             }
 
-            KLocale* locale = KGlobal::locale();
-            if (!err) err = m_currentDocument->setLanguage(locale->language());
+            KLocale* loc = KGlobal::locale();
+            IFOKDO(err, m_currentDocument->setLanguage(loc->language()))
 
             //status bar
-            if (!err) {
+            IFOK(err) {
                 err = SKGError(0, i18nc("Successfully opened a file", "File '%1' opened.", fileName));
                 //Add in recentFiles
                 if (m_recentFiles) {
@@ -502,7 +504,7 @@ void SKGFilePlugin::onChangePassword()
             err = m_currentDocument->changePassword(dlg->password());
 
             //status
-            if (!err)  err = SKGError(0, i18nc("Successfully changed the document password", "Password changed."));
+            IFOKDO(err, SKGError(0, i18nc("Successfully changed the document password", "Password changed.")))
             else err.addError(ERR_FAIL, i18nc("Error message: Could not change the document password",  "Failed to change password."));
         }
         delete dlg;
