@@ -55,7 +55,7 @@ SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGDocument* iDocument)
     ui.kGetNewHotStuff->setIcon(KIcon("get-hot-new-stuff"));
     ui.kDeleteTemplate->setIcon(KIcon("edit-delete"));
 
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 
     QStringList overlays;
     overlays.push_back("list-add");
@@ -120,7 +120,7 @@ QString SKGMonthlyPluginWidget::getDefaultStateAttribute()
     return "SKGMONTHLY_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGMonthlyPluginWidget::mainWidget() const
+QWidget* SKGMonthlyPluginWidget::mainWidget()
 {
     return ui.kWebView;
 }
@@ -181,7 +181,7 @@ void SKGMonthlyPluginWidget::onDeleteTemplate()
         QFile file(templatFileName);
         if (!file.remove()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Deletion of '%1' failed", templatFileName));
 
-        if (!err) ui.kTemplate->removeItem(ui.kTemplate->findText(templat));
+        IFOK(err) ui.kTemplate->removeItem(ui.kTemplate->findText(templat));
 
         //Display error
         SKGMainPanel::displayErrorMessage(err);
@@ -338,7 +338,7 @@ QString SKGMonthlyPluginWidget::getReport()
     QApplication::restoreOverrideCursor();
 
     //status bar
-    if (err) html += err.getFullMessageWithHistorical();
+    IFKO(err) html += err.getFullMessageWithHistorical();
     return html;
 }
 
