@@ -43,7 +43,9 @@ K_PLUGIN_FACTORY(SKGPrintPluginFactory, registerPlugin<SKGPrintPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGPrintPluginFactory("skg_print", "skg_print"))
 
-SKGPrintPlugin::SKGPrintPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGPrintPlugin::SKGPrintPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent),
+    m_currentDocument(NULL), m_printAction(NULL), m_printPreviewAction(NULL)
 {
     SKGTRACEIN(10, "SKGPrintPlugin::SKGPrintPlugin");
 }
@@ -163,7 +165,7 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
             int nbtabs = tabs ? tabs->count() : 0;
             for (int i = 0; i < nbtabs; ++i) {
                 //Yes, get the widget
-                SKGTabPage* page = (SKGTabPage*) tabs->widget(i);
+                SKGTabPage* page = static_cast<SKGTabPage*>(tabs->widget(i));
                 if (page) pages += page->printableWidgets();
             }
             int nbpages = pages.count();
@@ -226,7 +228,7 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
         }
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Print successfully done."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Print successfully done.")))
         else err.addError(ERR_FAIL, i18nc("Error message", "Print failed"));
 
         //Display error
