@@ -43,7 +43,8 @@ K_PLUGIN_FACTORY(SKGPropertiesPluginFactory, registerPlugin<SKGPropertiesPlugin>
 K_EXPORT_PLUGIN(SKGPropertiesPluginFactory("skg_properties", "skg_properties"))
 
 SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_dockWidget(NULL), m_dockContent(NULL)
+    SKGInterfacePlugin(iParent),
+    m_currentDocument(NULL), m_dockWidget(NULL), m_dockContent(NULL), m_addPropertyAction(NULL), m_addPropertyMenu(NULL)
 {
     SKGTRACEIN(10, "SKGPropertiesPlugin::SKGPropertiesPlugin");
 }
@@ -113,19 +114,19 @@ void SKGPropertiesPlugin::onAddProperty()
         QString value = list.at(1);
 
         //Create properties
-        if (!err) {
+        IFOK(err) {
             SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
             int nb = selection.count();
             SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Create a user defined property", "Property creation"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
                 err = selection[i].setProperty(name, value);
-                if (!err)  err = m_currentDocument->stepForward(i + 1);
+                IFOKDO(err, m_currentDocument->stepForward(i + 1))
             }
         }
     }
 
     //status bar
-    if (!err) {
+    IFOK(err) {
         err = SKGError(0, i18nc("The user defined property was successfully created", "Property created"));
     }
     SKGMainPanel::displayErrorMessage(err);
