@@ -85,9 +85,9 @@ void SKGPropertiesPluginDockWidget::refresh()
     SKGTRACEIN(1, "SKGPropertiesPluginDockWidget::refresh");
 
     //Change filter
-    SKGObjectModelBase* model = (SKGObjectModelBase*) ui.kView->model();
+    SKGObjectModelBase* model = qobject_cast<SKGObjectModelBase*>(ui.kView->model());
     QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(model);
-    if (proxyModel) model = (SKGObjectModelBase*) proxyModel->sourceModel();
+    if (proxyModel) model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
 
     if (model) {
         QString filter ;
@@ -265,7 +265,7 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
             if (mode == KMessageBox::Cancel) return;
             if (mode == KMessageBox::Yes) {
                 //Value is a file name ==> blob
-                if (!file.open(QIODevice::ReadOnly)) {
+                if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) {
                     err = SKGError(ERR_INVALIDARG, i18nc("Error message: could not open the requested file", "Open file '%1' failed", value));
                 } else {
                     QByteArray blob_bytes = file.readAll();
@@ -283,7 +283,7 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
         }
 
         //Create properties
-        if (!err) {
+        IFOK(err) {
             SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
             int nb = selection.count();
             SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Create a user defined property", "Property creation"), err, nb);
@@ -291,7 +291,7 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
                 SKGPropertyObject prop;
                 err = selection[i].setProperty(name, value, blob, &prop);
 
-                if (!err) {
+                IFOK(err) {
                     listUUID.push_back(prop.getUniqueID());
                     err = getDocument()->stepForward(i + 1);
                 }
@@ -300,7 +300,7 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
     }
 
     //status bar
-    if (!err) {
+    IFOK(err) {
         err = SKGError(0, i18nc("The user defined property was successfully created", "Property created"));
         ui.kView->selectObjects(listUUID, true);
     }
@@ -323,12 +323,12 @@ void SKGPropertiesPluginDockWidget::onRemoveProperty()
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Verb, delete an item", "Delete"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
             err = selection[i].remove();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("The user defined property was successfully deleted", "Properties deleted."));
+    IFOKDO(err, SKGError(0, i18nc("The user defined property was successfully deleted", "Properties deleted.")))
     else err.addError(ERR_FAIL, i18nc("Error message: Could not delete an item", "Delete failed"));
 
     //Display error
@@ -343,7 +343,7 @@ void SKGPropertiesPluginDockWidget::cleanEditor()
     }
 }
 
-QWidget* SKGPropertiesPluginDockWidget::mainWidget() const
+QWidget* SKGPropertiesPluginDockWidget::mainWidget()
 {
     return ui.kView;
 }
