@@ -40,7 +40,9 @@ K_PLUGIN_FACTORY(SKGSelectAllPluginFactory, registerPlugin<SKGSelectAllPlugin>()
  */
 K_EXPORT_PLUGIN(SKGSelectAllPluginFactory("skg_selectall", "skg_selectall"))
 
-SKGSelectAllPlugin::SKGSelectAllPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGSelectAllPlugin::SKGSelectAllPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent),
+    m_currentDocument(NULL), m_selectAllAction(NULL)
 {
     SKGTRACEIN(10, "SKGSelectAllPlugin::SKGSelectAllPlugin");
 }
