@@ -44,7 +44,9 @@ K_PLUGIN_FACTORY(SKGUndoRedoPluginFactory, registerPlugin<SKGUndoRedoPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGUndoRedoPluginFactory("skg_undoredo", "skg_undoredo"))
 
-SKGUndoRedoPlugin::SKGUndoRedoPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_dockWidget(NULL)
+SKGUndoRedoPlugin::SKGUndoRedoPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent),
+    m_undoSaveAction(NULL), m_undoAction(NULL), m_redoAction(NULL), m_undoMenu(NULL), m_redoMenu(NULL), m_currentDocument(NULL), m_dockWidget(NULL)
 {
     SKGTRACEIN(10, "SKGUndoRedoPlugin::SKGUndoRedoPlugin");
 }
@@ -258,7 +260,7 @@ void SKGUndoRedoPlugin::onClearHistory()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Message for successful user action", "Clear history successfully done."));
+        IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Clear history successfully done.")))
         else err.addError(ERR_FAIL, i18nc("Error message", "Clear history failed"));
 
         //Display error
@@ -276,7 +278,7 @@ void SKGUndoRedoPlugin::onUndoSave()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Undo successfully done."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Undo successfully done.")))
         else err.addError(ERR_FAIL, i18nc("Error message",  "Undo failed"));
 
         //Display error
@@ -290,13 +292,13 @@ void SKGUndoRedoPlugin::onUndo()
     SKGTRACEINRC(10, "SKGUndoRedoPlugin::onUndo", err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        int pos = ((QAction*) sender())->data().toInt();
+        int pos = static_cast<QAction*>(sender())->data().toInt();
         for (int i = 1 ; !err && i <= pos; ++i)
             err = m_currentDocument->undoRedoTransaction(SKGDocument::UNDO);
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Undo successfully done."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Undo successfully done.")))
         else err.addError(ERR_FAIL, i18nc("Error message",  "Undo failed"));
 
         //Display error
@@ -328,13 +330,13 @@ void SKGUndoRedoPlugin::onRedo()
     SKGTRACEINRC(10, "SKGUndoRedoPlugin::onRedo", err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        int pos = ((QAction*) sender())->data().toInt();
+        int pos = static_cast<QAction*>(sender())->data().toInt();
         for (int i = 1 ; !err && i <= pos; ++i)
             err = m_currentDocument->undoRedoTransaction(SKGDocument::REDO);
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Redo successfully done."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Redo successfully done.")))
         else err.addError(ERR_FAIL, i18nc("Error message",  "Redo failed"));
 
         //Display error
