@@ -53,7 +53,7 @@ SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(SKGDocument* iDocument)
     ui.kTransactionList->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_UNDOREDO");
 
     connect(ui.kTransactionList, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onUndoRedo(QModelIndex)));
-    connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), ui.kTransactionList, SLOT(resizeColumnsToContentsDelayed()), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), ui.kTransactionList, SLOT(resizeColumnsToContentsDelayed()), Qt::QueuedConnection);
 
     ui.kTransactionList->setTextResizable(false);
 }
@@ -71,7 +71,7 @@ void SKGUndoRedoPluginDockWidget::onClearHistory()
     QApplication::restoreOverrideCursor();
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Message for successful user action", "Clear history successfully done."));
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Clear history successfully done.")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Clear history failed"));
 
     //Display error
@@ -86,7 +86,7 @@ void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
     //Get Selection
     SKGError err;
     SKGDocument::UndoRedoMode mode;
-    SKGObjectModelBase* model = (SKGObjectModelBase*) ui.kTransactionList->model();
+    SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(ui.kTransactionList->model());
     if (model) {
         SKGObjectBase obj = model->getObject(index);
         int id = obj.getID();
@@ -100,7 +100,7 @@ void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
     QApplication::restoreOverrideCursor();
 
     //status bar
-    if (!err) err = SKGError(0, mode == SKGDocument::UNDO ? i18nc("Message for successful user action", "Undo successfully done.") : i18nc("Message for successful user action", "Redo successfully done."));
+    IFOKDO(err, SKGError(0, mode == SKGDocument::UNDO ? i18nc("Message for successful user action", "Undo successfully done.") : i18nc("Message for successful user action", "Redo successfully done.")))
     else err.addError(ERR_FAIL, mode == SKGDocument::UNDO ? i18nc("Error message", "Undo failed") : i18nc("Error message", "Redo failed"));
 
     //Display error
