@@ -85,9 +85,9 @@ SKGError SKGImportPluginAFB120::importFile()
 
     //Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "AFB120"), 2);
-    if (!err) {
+    IFOK(err) {
         //Open file
-        if (!err) {
+        IFOK(err) {
             QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
             else {
@@ -107,7 +107,7 @@ SKGError SKGImportPluginAFB120::importFile()
                 file.close();
 
                 //Step 1 done
-                if (!err) err = m_importer->getDocument()->stepForward(1);
+                IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
                 //Read lines
                 SKGAccountObject account;
@@ -116,7 +116,7 @@ SKGError SKGImportPluginAFB120::importFile()
                 QString inititalAmount;
 
                 int nb = lines.count();
-                if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+                IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb))
                 for (int i = 0; i < nb && !err; ++i) {
                     //Read line
                     QString line = lines.at(i);
@@ -128,7 +128,7 @@ SKGError SKGImportPluginAFB120::importFile()
 
                             SKGObjectBase::SKGListSKGObjectBase listAccount;
                             err = m_importer->getDocument()->getObjects("v_account", "t_number='" % accountNumber % '\'', listAccount);
-                            if (!err) {
+                            IFOK(err) {
                                 if (listAccount.count() == 1) {
                                     //Yes ! Only one account found
                                     account = listAccount.at(0);
@@ -137,15 +137,15 @@ SKGError SKGImportPluginAFB120::importFile()
                                     if (listAccount.count() > 1) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "More than one possible account found."));
 
                                     SKGBankObject bank(m_importer->getDocument());
-                                    if (!err) err = bank.setName(bankName);
-                                    if (!err) err = bank.setNumber(bankName);
+                                    IFOKDO(err, bank.setName(bankName))
+                                    IFOKDO(err, bank.setNumber(bankName))
                                     if (!err && bank.load().isFailed()) err = bank.save();
-                                    if (!err) err = bank.addAccount(account);
-                                    if (!err) err = account.setName(accountNumber);
-                                    if (!err) err = account.setNumber(accountNumber);
-                                    if (!err) err = account.setType(SKGAccountObject::CURRENT);
+                                    IFOKDO(err, bank.addAccount(account))
+                                    IFOKDO(err, account.setName(accountNumber))
+                                    IFOKDO(err, account.setNumber(accountNumber))
+                                    IFOKDO(err, account.setType(SKGAccountObject::CURRENT))
                                     if (!err && account.load().isFailed()) err = account.save();
-                                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Default account '%1' created for import", accountNumber));
+                                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Default account '%1' created for import", accountNumber)))
                                 }
                             }
                         } else if (line.startsWith(QLatin1String("04"))) {
@@ -161,42 +161,42 @@ SKGError SKGImportPluginAFB120::importFile()
                             if (unit.getID() == 0) {
                                 err = SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), unitCode, unit);
                                 if (account.getNbOperation() > 1) {
-                                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", account.getName()), SKGDocument::Warning);
+                                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", account.getName()), SKGDocument::Warning))
                                 } else {
                                     //Set initial balance
-                                    if (!err) err = account.setInitialBalance(toAmount(inititalAmount, SKGServices::stringToInt(nbDecimal)), unit);
-                                    if (!err) err = account.save();
-                                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set with AFB120 file content", account.getName()));
+                                    IFOKDO(err, account.setInitialBalance(toAmount(inititalAmount, SKGServices::stringToInt(nbDecimal)), unit))
+                                    IFOKDO(err, account.save())
+                                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set with AFB120 file content", account.getName())))
                                 }
                             }
 
                             SKGOperationObject operation;
                             err = account.addOperation(operation, true);
-                            if (!err) err = operation.setDate(SKGServices::stringToTime(SKGServices::dateToSqlString(dateJJMMAA, "DDMMYYYY")).date());
-                            if (!err) err = operation.setUnit(unit);
-                            if (!err) err = operation.setAttribute("t_imported", "T");
-                            if (!err) err = operation.setComment(comment);
+                            IFOKDO(err, operation.setDate(SKGServices::stringToTime(SKGServices::dateToSqlString(dateJJMMAA, "DDMMYYYY")).date()))
+                            IFOKDO(err, operation.setUnit(unit))
+                            IFOKDO(err, operation.setAttribute("t_imported", "T"))
+                            IFOKDO(err, operation.setComment(comment))
                             QByteArray hash = QCryptographicHash::hash(line.toUtf8(), QCryptographicHash::Md5);
-                            if (!err) err = operation.setImportID(QString("AFB120-") % hash.toHex());
-                            if (!err) err = operation.save(false);
+                            IFOKDO(err, operation.setImportID(QString("AFB120-") % hash.toHex()))
+                            IFOKDO(err, operation.save(false))
 
                             SKGSubOperationObject subop;
                             err = operation.addSubOperation(subop);
-                            if (!err) err = subop.setComment(comment);
-                            if (!err) err = subop.setQuantity(toAmount(amount, SKGServices::stringToInt(nbDecimal)));
-                            if (!err) err = subop.save(false, false);
+                            IFOKDO(err, subop.setComment(comment))
+                            IFOKDO(err, subop.setQuantity(toAmount(amount, SKGServices::stringToInt(nbDecimal))))
+                            IFOKDO(err, subop.save(false, false))
                         }
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
                 //Step 2 done
-                if (!err) err = m_importer->getDocument()->stepForward(2);
+                IFOKDO(err, m_importer->getDocument()->stepForward(2))
             }
         }
     }
-    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+    SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
     return err;
 }
