@@ -158,7 +158,7 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
         //Automatic build
         //Open file
         QFile file(m_importer->getLocalFileName());
-        if (!file.open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
         else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -180,7 +180,7 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
         m_csvMapping = *iCSVMapping;
     }
 
-    if (!err) {
+    IFOK(err) {
         //Check if mandatory attributes have been found
         if (!m_csvMapping.contains("date") || !m_csvMapping.contains("amount"))
             err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns date and amount not found. Set import parameters in settings."));
@@ -204,7 +204,7 @@ SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
         //Automatic build
         //Open file
         QFile file(m_importer->getLocalFileName());
-        if (!file.open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
         else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
@@ -252,7 +252,7 @@ SKGError SKGImportPluginCsv::importFile()
     SKGTRACEINRC(2, "SKGImportPluginCsv::importFile", err);
     //Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "CSV"), 3);
-    if (!err) {
+    IFOK(err) {
         //Initialize some variables
         QDateTime now = QDateTime::currentDateTime();
         QString postFix = SKGServices::dateToSqlString(now);
@@ -260,15 +260,15 @@ SKGError SKGImportPluginCsv::importFile()
         //Default mapping
         if (getCSVMapping().count() == 0) {
             err = setCSVMapping(NULL);
-            if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns"));
+            IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns")))
         }
-        if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Mapping used: %1", getCSVMapping().join("|")));
+        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Mapping used: %1", getCSVMapping().join("|"))))
 
         //Step 1 done
-        if (!err) err = m_importer->getDocument()->stepForward(1);
+        IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
         //Open file
-        if (!err) {
+        IFOK(err) {
             QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
             else {
@@ -293,7 +293,7 @@ SKGError SKGImportPluginCsv::importFile()
                 QStringList dates;
                 QStringList lines;
                 bool modeAutoCreditDebit = (!getCSVMapping().contains("sign") && nbAmount == 2);
-                if (!err) {
+                IFOK(err) {
                     int posdate = getCSVMapping().indexOf("date");
                     if (posdate != -1) {
                         QString currentLine;
@@ -333,15 +333,15 @@ SKGError SKGImportPluginCsv::importFile()
                 QString dateFormat = m_parameters["date_format"];
                 if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates); //Automatic detection
                 if (!err && dateFormat.isEmpty())err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
-                if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
+                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat)))
 
                 //Step 2 done
-                if (!err) err = m_importer->getDocument()->stepForward(2);
+                IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
                 //Treat all lines
-                if (!err) {
-                    int nb = lines.size();
-                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+                IFOK(err) {
+                    int nb2 = lines.size();
+                    err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb2);
 
                     //Save last mapping used in a settings
                     QString mappingDesc;
@@ -350,7 +350,7 @@ SKGError SKGImportPluginCsv::importFile()
                         if (i) mappingDesc += '|';
                         mappingDesc += getCSVMapping().at(i);
                     }
-                    if (!err) err = m_importer->getDocument()->setParameter("SKG_LAST_CSV_MAPPING_USED", mappingDesc);
+                    IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_CSV_MAPPING_USED", mappingDesc))
 
                     SKGUnitObject defUnit;
                     SKGAccountObject defAccount;
@@ -360,19 +360,19 @@ SKGError SKGImportPluginCsv::importFile()
                     bool noAccountColumn = (getCSVMapping().indexOf("account") == -1);
                     bool emptyAccount = false;
 
-                    for (int i = 0; !err && i < nb; ++i) {
+                    for (int i = 0; !err && i < nb2; ++i) {
                         QString currentCategory;
                         SKGOperationObject currentOperation(m_importer->getDocument());
                         SKGSubOperationObject currentSubOperation(m_importer->getDocument());
 
                         //Valuate mandatory attribute with default value
                         if (noUnitColumn && i == 0) err = m_importer->getDefaultUnit(defUnit);
-                        if (!err) err = currentOperation.setUnit(defUnit);
+                        IFOKDO(err, currentOperation.setUnit(defUnit))
 
                         if (!err && noAccountColumn) {
                             err = m_importer->getDefaultAccount(defAccount);
                             if (i == 0) emptyAccount = (defAccount.getNbOperation() == 0);
-                            if (!err) err = currentOperation.setParentAccount(defAccount);
+                            IFOKDO(err, currentOperation.setParentAccount(defAccount))
                         }
 
                         QString line = lines.at(i);
@@ -414,13 +414,13 @@ SKGError SKGImportPluginCsv::importFile()
                                 } else if (col == "payee") {
                                     SKGPayeeObject payeeObj;
                                     err = SKGPayeeObject::createPayee(m_importer->getDocument(), val, payeeObj);
-                                    if (!err) err = currentOperation.setPayee(payeeObj);
+                                    IFOKDO(err, currentOperation.setPayee(payeeObj))
                                 } else if (col == "comment") {
                                     QString comment = currentOperation.getComment();
                                     if (!comment.isEmpty()) comment += ' ';
                                     comment += val;
                                     err = currentOperation.setComment(comment);
-                                    if (!err) err = currentSubOperation.setComment(comment);
+                                    IFOKDO(err, currentSubOperation.setComment(comment))
                                 } else if (col == "status") {
                                     err = currentOperation.setStatus(val == "C" || val == "Y" ?  SKGOperationObject::CHECKED : val == "P" ?  SKGOperationObject::POINTED : SKGOperationObject::NONE);
                                 } else if (col == "bookmarked") {
@@ -453,7 +453,7 @@ SKGError SKGImportPluginCsv::importFile()
                                     SKGUnitObject unit(m_importer->getDocument());
                                     if (val != defUnit.getName()) { //For performance
                                         err = unit.setName(val);
-                                        if (!err) err = unit.setSymbol(val);
+                                        IFOKDO(err, unit.setSymbol(val))
                                         if (!err && unit.load().isFailed())  err = unit.save(false);    //Save only
 
                                         //This unit is now the default one, it's better for performance
@@ -463,8 +463,8 @@ SKGError SKGImportPluginCsv::importFile()
                                     }
 
                                     SKGUnitValueObject unitval;
-                                    if (!err) err = unit.addUnitValue(unitval);
-                                    if (!err) {
+                                    IFOKDO(err, unit.addUnitValue(unitval))
+                                    IFOK(err) {
                                         int posAmount = getCSVMapping().indexOf("amount");
                                         int posQuantity = getCSVMapping().indexOf("quantity");
                                         if (posAmount != -1 && posQuantity != -1) {
@@ -473,33 +473,33 @@ SKGError SKGImportPluginCsv::importFile()
                                             err = unitval.setQuantity(1);
                                         }
                                     }
-                                    if (!err) err = unitval.setDate(now.date());
-                                    if (!err) err = unitval.save();
-                                    if (!err) err = currentOperation.setUnit(unit);
+                                    IFOKDO(err, unitval.setDate(now.date()))
+                                    IFOKDO(err, unitval.save())
+                                    IFOKDO(err, currentOperation.setUnit(unit))
                                 } else if (col == "account") {
                                     //Looking for account
                                     if (val != defAccount.getName()) { //For performance
                                         SKGAccountObject account(m_importer->getDocument());
                                         account.setName(val);
                                         err = account.load();
-                                        if (err) {
+                                        IFKO(err) {
                                             //Not found, we have to create one
                                             SKGBankObject bank(m_importer->getDocument());
                                             QString name = i18nc("Noun",  "Bank for import %1", postFix);
                                             err = bank.setName(name);
                                             if (!err && bank.load().isFailed()) {
                                                 err = bank.save(false);   //Save only
-                                                if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Default bank '%1' created for import", name));
+                                                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Default bank '%1' created for import", name)))
                                             }
-                                            if (!err) err = bank.addAccount(account);
-                                            if (!err) err = account.setName(val);
+                                            IFOKDO(err, bank.addAccount(account))
+                                            IFOKDO(err, account.setName(val))
                                             if (!err && account.load().isFailed())  err = account.save(false);     //Save only
                                         }
 
                                         //This account is now the default one, it's better for performance
                                         defAccount = account;
                                     }
-                                    if (!err) err = currentOperation.setParentAccount(defAccount);
+                                    IFOKDO(err, currentOperation.setParentAccount(defAccount))
                                 } else if (col == "category") {
                                     //Set Category
                                     if (!val.isEmpty()) {
@@ -515,7 +515,7 @@ SKGError SKGImportPluginCsv::importFile()
                                         //Create and set category
                                         SKGCategoryObject Category;
                                         err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), val, Category);
-                                        if (!err)  err = currentSubOperation.setCategory(Category);
+                                        IFOKDO(err, currentSubOperation.setCategory(Category))
                                     }
                                 } else {
                                     //A property
@@ -528,10 +528,10 @@ SKGError SKGImportPluginCsv::importFile()
                         if (!err && initialBalance) {
                             //Specific values for initial balance
                             err = currentOperation.setStatus(SKGOperationObject::CHECKED);
-                            if (!err) err = currentOperation.setAttribute("d_date", "0000-00-00");
+                            IFOKDO(err, currentOperation.setAttribute("d_date", "0000-00-00"))
                         }
-                        if (!err) err = currentOperation.setImportID(hash.toHex());
-                        if (!err) {
+                        IFOKDO(err, currentOperation.setImportID(hash.toHex()))
+                        IFOK(err) {
                             if (idtransaction != 0) {
                                 if (mapOperation.contains(idtransaction)) {
                                     currentOperation = mapOperation[idtransaction];
@@ -547,13 +547,13 @@ SKGError SKGImportPluginCsv::importFile()
                         if (!err && idgroup != 0) {
                             if (mapGroup.contains(idgroup)) {
                                 err = currentOperation.setGroupOperation(mapGroup[idgroup]);
-                                if (!err) err = currentOperation.save();
+                                IFOKDO(err, currentOperation.save())
                             }
                             mapGroup[idgroup] = currentOperation;
                         }
 
-                        if (!err) err = currentSubOperation.setParentOperation(currentOperation);
-                        if (!err) err = currentSubOperation.save(false, false);     //Save only without reload
+                        IFOKDO(err, currentSubOperation.setParentOperation(currentOperation))
+                        IFOKDO(err, currentSubOperation.save(false, false))
 
                         //209705 vvvv
                         if (!err && !skg_op_original_amount.isEmpty()) {
@@ -568,11 +568,11 @@ SKGError SKGImportPluginCsv::importFile()
                         }
 
                         if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
 
-                    if (!err) {
+                    IFOK(err) {
                         QString balance = m_parameters["balance"];
                         if (!balance.isEmpty()) {
                             if (emptyAccount) {
@@ -580,23 +580,23 @@ SKGError SKGImportPluginCsv::importFile()
                                 double currentAmount = defAccount.getAmount(QDate::currentDate());
 
                                 //Update account
-                                if (!err) err = defAccount.setInitialBalance(SKGServices::stringToDouble(balance) - currentAmount, defUnit);
-                                if (!err) err = defAccount.save();
-                                if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", defAccount.getName()), SKGDocument::Warning);
+                                IFOKDO(err, defAccount.setInitialBalance(SKGServices::stringToDouble(balance) - currentAmount, defUnit))
+                                IFOKDO(err, defAccount.save())
+                                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", defAccount.getName()), SKGDocument::Warning))
 
                             } else m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", defAccount.getName()));
                         }
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
                     //Lines treated
-                    if (!err) err = m_importer->getDocument()->stepForward(3);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(3))
                 }
             }
         }
     }
-    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+    SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
     return err;
 }
@@ -648,7 +648,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
     if (m_importer->getDocument()) {
         //Begin transaction
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), 3);
-        if (!err) {
+        IFOK(err) {
             //File name is the name of the unit
             QFileInfo fInfo(m_importer->getFileName().path());
             QString unitName = fInfo.baseName();
@@ -656,14 +656,14 @@ SKGError SKGImportPluginCsv::importCSVUnit()
             //Default mapping
             if (getCSVMapping().count() == 0) {
                 err = setCSVMapping(NULL);
-                if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns"));
+                IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns")))
             }
 
             //Step 1 done
-            if (!err) err = m_importer->getDocument()->stepForward(1);
+            IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
             //Open file
-            if (!err) {
+            IFOK(err) {
                 QFile file(m_importer->getLocalFileName());
                 if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
                 else {
@@ -699,13 +699,13 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                     //Select dateformat
                     QString dateFormat = SKGServices::getDateFormat(dates);
                     if (dateFormat.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
-                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
+                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat)))
 
                     //Step 2 done
-                    if (!err) err = m_importer->getDocument()->stepForward(2);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
                     //Treat all lines
-                    if (!err) {
+                    IFOK(err) {
                         int nb = lines.size();
                         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
 
@@ -716,30 +716,30 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                             if (i) mappingDesc += '|';
                             mappingDesc += m_csvMapping.at(i);
                         }
-                        if (!err) err = m_importer->getDocument()->setParameter("SKG_LAST_CSV_UNIT_MAPPING_USED", mappingDesc);
+                        IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_CSV_UNIT_MAPPING_USED", mappingDesc))
 
-                        int posdate = m_csvMapping.indexOf("date");
+                        int posdate2 = m_csvMapping.indexOf("date");
                         int posvalue = m_csvMapping.indexOf("amount");
-                        if (posdate != -1 && posvalue != -1) {
+                        if (posdate2 != -1 && posvalue != -1) {
                             for (int i = 0; !err && i < nb; ++i) {
                                 QStringList atts = SKGServices::splitCSVLine(lines.at(i));
                                 err = m_importer->getDocument()->addOrModifyUnitValue(unitName,
-                                        SKGServices::stringToTime(SKGServices::dateToSqlString(atts.at(posdate), dateFormat)).date(),
+                                        SKGServices::stringToTime(SKGServices::dateToSqlString(atts.at(posdate2), dateFormat)).date(),
                                         SKGServices::stringToDouble(atts.at(posvalue)));
 
-                                if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                                IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                             }
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                        SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
                         //Lines treated
-                        if (!err) err = m_importer->getDocument()->stepForward(3);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(3))
                     }
                 }
             }
         }
-        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+        SKGENDTRANSACTION(m_importer->getDocument(),  err);
     }
     return err;
 }
