@@ -105,7 +105,7 @@ SKGError SKGImportPluginGnc::importFile()
             } else {
                 QMap<QString, SKGUnitObject> mapUnitIdUnit;
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GNC"), 6);
-                if (!err) {
+                IFOK(err) {
                     //Step 1-Get units
                     SKGUnitObject defaultUnit;
                     {
@@ -126,9 +126,9 @@ SKGError SKGImportPluginGnc::importFile()
                                 if (!err && !unitObj.exist()) {
                                     //Creation of unit
                                     err = unitObj.setName(unitName.text());
-                                    if (!err) err = unitObj.setSymbol(unitName.text());
-                                    if (!err) err = unitObj.setType(SKGUnitObject::SHARE);
-                                    if (!err) err = unitObj.save();
+                                    IFOKDO(err, unitObj.setSymbol(unitName.text()))
+                                    IFOKDO(err, unitObj.setType(SKGUnitObject::SHARE))
+                                    IFOKDO(err, unitObj.save())
                                 }
 
                                 if (!err && !defaultUnit.exist()) defaultUnit = unitObj;
@@ -136,12 +136,12 @@ SKGError SKGImportPluginGnc::importFile()
                                 mapUnitIdUnit[unitName.text()] = unitObj;
                             }
 
-                            if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                            IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                        SKGENDTRANSACTION(m_importer->getDocument(),  err);
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
                     //Step 2-Get accounts and categories
                     SKGAccountObject gnucashTemporaryAccount(m_importer->getDocument());
@@ -153,21 +153,21 @@ SKGError SKGImportPluginGnc::importFile()
 
                     //Create bank and temporary account for gnucash import
                     SKGBankObject bank(m_importer->getDocument());
-                    if (!err) err = m_importer->getDocument()->addOrModifyAccount("GNUCASH-TEMPORARY-ACCOUNT", "", "GNUCASH");
-                    if (!err) err = bank.setName("GNUCASH");
-                    if (!err) err = bank.load();
-                    if (!err) err = gnucashTemporaryAccount.setName("GNUCASH-TEMPORARY-ACCOUNT");
-                    if (!err) err = gnucashTemporaryAccount.load();
+                    IFOKDO(err, m_importer->getDocument()->addOrModifyAccount("GNUCASH-TEMPORARY-ACCOUNT", "", "GNUCASH"))
+                    IFOKDO(err, bank.setName("GNUCASH"))
+                    IFOKDO(err, bank.load())
+                    IFOKDO(err, gnucashTemporaryAccount.setName("GNUCASH-TEMPORARY-ACCOUNT"))
+                    IFOKDO(err, gnucashTemporaryAccount.load())
 
                     {
                         //Create accounts
                         QDomNodeList accountList = book.elementsByTagName("gnc:account");
                         int nbAccount = accountList.count();
-                        if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nbAccount);
+                        IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nbAccount))
                         for (int i = 0; !err && i < nbAccount; ++i) {
                             QDomElement account = accountList.at(i).toElement();
-                            QDomElement parent = account.parentNode().toElement();
-                            if (parent.tagName() != "gnc:template-transactions") {
+                            QDomElement parentNode = account.parentNode().toElement();
+                            if (parentNode.tagName() != "gnc:template-transactions") {
                                 QDomElement accountId = account.firstChildElement("act:id");
                                 QDomElement accountName = account.firstChildElement("act:name");
                                 QDomElement accountType = account.firstChildElement("act:type");
@@ -194,7 +194,7 @@ SKGError SKGImportPluginGnc::importFile()
                                         //It is a real account
                                         SKGAccountObject act(m_importer->getDocument());
                                         err = bank.addAccount(act);
-                                        if (!err) err = act.setName(realAccountName);
+                                        IFOKDO(err, act.setName(realAccountName))
                                         int index = 1;
                                         while (!err && act.exist()) {
                                             index++;
@@ -202,8 +202,8 @@ SKGError SKGImportPluginGnc::importFile()
                                             err = act.setName(realAccountName);
                                         }
                                         if (!err && accountCode.isNull()) err = act.setNumber(accountCode.text());
-                                        if (!err) err = act.setType(type == "ASSET" ? SKGAccountObject::ASSETS : type == "STOCK" ? SKGAccountObject::INVESTMENT : type == "CASH" ? SKGAccountObject::WALLET : type == "LIABILITY" ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT);
-                                        if (!err) err = act.save();
+                                        IFOKDO(err, act.setType(type == "ASSET" ? SKGAccountObject::ASSETS : type == "STOCK" ? SKGAccountObject::INVESTMENT : type == "CASH" ? SKGAccountObject::WALLET : type == "LIABILITY" ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT))
+                                        IFOKDO(err, act.save())
 
                                         mapIdAccount[accountId.text()] = act;
                                         mapIdType[accountId.text()] = 'A'; //Memorize an account
@@ -221,19 +221,19 @@ SKGError SKGImportPluginGnc::importFile()
                                 }
                             }
 
-                            if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                            IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                        SKGENDTRANSACTION(m_importer->getDocument(),  err);
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(2);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
                     //Step 3- Get operations
                     QMap<QString, SKGOperationObject> mapIdScheduledOperation;
                     {
                         QDomNodeList operationsList = book.elementsByTagName("gnc:transaction");
                         int nbOperations = operationsList.count();
-                        if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nbOperations);
+                        IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nbOperations))
                         for (int i = 0; !err && i < nbOperations; ++i) {
                             QDomElement operation = operationsList.at(i).toElement();
 
@@ -253,15 +253,15 @@ SKGError SKGImportPluginGnc::importFile()
                             if (!err && !operationPayee.isNull()) {
                                 SKGPayeeObject payeeObject;
                                 err = SKGPayeeObject::createPayee(m_importer->getDocument(), operationPayee.text(), payeeObject);
-                                if (!err) err = operationObj.setPayee(payeeObject);
+                                IFOKDO(err, operationObj.setPayee(payeeObject))
                             }
-                            if (!err) err = operationObj.setImported(true);
-                            if (!err) err = operationObj.setImportID("GNC-" % operationId.text());
-                            if (!err) err = operationObj.setUnit(defaultUnit);
+                            IFOKDO(err, operationObj.setImported(true))
+                            IFOKDO(err, operationObj.setImportID("GNC-" % operationId.text()))
+                            IFOKDO(err, operationObj.setUnit(defaultUnit))
 
-                            if (!err) {
-                                QDomElement parent = operation.parentNode().toElement();
-                                err = operationObj.setTemplate(parent.tagName() == "gnc:template-transactions");
+                            IFOK(err) {
+                                QDomElement parentNode = operation.parentNode().toElement();
+                                err = operationObj.setTemplate(parentNode.tagName() == "gnc:template-transactions");
                             }
                             if (!operationSlots.isNull()) {
                                 QDomNodeList slotList = operationSlots.elementsByTagName("slot");
@@ -278,7 +278,7 @@ SKGError SKGImportPluginGnc::importFile()
                                     }
                                 }
                             }
-                            if (!err) err = operationObj.save();
+                            IFOKDO(err, operationObj.save())
 
                             //Get splits
                             bool parentSet = false;
@@ -316,22 +316,22 @@ SKGError SKGImportPluginGnc::importFile()
                                                     QDomNodeList scheduledSlotList = value.elementsByTagName("slot");
                                                     int nbscheduledSlotList = scheduledSlotList.count();
                                                     for (int k2 = 0; !err && k2 < nbscheduledSlotList; ++k2) {
-                                                        QDomElement slot = scheduledSlotList.at(k2).toElement();
+                                                        QDomElement slot2 = scheduledSlotList.at(k2).toElement();
 
-                                                        QDomElement key = slot.firstChildElement("slot:key");
-                                                        QDomElement value = slot.firstChildElement("slot:value");
-                                                        if (!key.isNull() && !value.isNull()) {
-                                                            if (key.text() == "account") {
+                                                        QDomElement key2 = slot2.firstChildElement("slot:key");
+                                                        QDomElement value2 = slot2.firstChildElement("slot:value");
+                                                        if (!key2.isNull() && !value2.isNull()) {
+                                                            if (key2.text() == "account") {
                                                                 mapIdScheduledOperation[info.account.text()] = operationObj;
-                                                                info.account = value;
-                                                            } else if (key.text() == "debit-formula" && !value.text().isEmpty()) {
-                                                                QStringList vals = SKGServices::splitCSVLine(value.text(), '/');
-                                                                if (vals.count() == 1) info.value = SKGServices::stringToDouble(vals.at(0));
-                                                                else if (vals.count() == 2) info.value = SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
-                                                            } else if (key.text() == "credit-formula" && !value.text().isEmpty()) {
-                                                                QStringList vals = SKGServices::splitCSVLine(value.text(), '/');
-                                                                if (vals.count() == 1) info.value = -SKGServices::stringToDouble(vals.at(0));
-                                                                else if (vals.count() == 2) info.value = -SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
+                                                                info.account = value2;
+                                                            } else if (key2.text() == "debit-formula" && !value2.text().isEmpty()) {
+                                                                QStringList vals2 = SKGServices::splitCSVLine(value2.text(), '/');
+                                                                if (vals2.count() == 1) info.value = SKGServices::stringToDouble(vals2.at(0));
+                                                                else if (vals2.count() == 2) info.value = SKGServices::stringToDouble(vals2.at(0)) / SKGServices::stringToDouble(vals2.at(1));
+                                                            } else if (key2.text() == "credit-formula" && !value2.text().isEmpty()) {
+                                                                QStringList vals2 = SKGServices::splitCSVLine(value2.text(), '/');
+                                                                if (vals2.count() == 1) info.value = -SKGServices::stringToDouble(vals2.at(0));
+                                                                else if (vals2.count() == 2) info.value = -SKGServices::stringToDouble(vals2.at(0)) / SKGServices::stringToDouble(vals2.at(1));
                                                             }
                                                         }
                                                     }
@@ -365,11 +365,11 @@ SKGError SKGImportPluginGnc::importFile()
                                 //Set operation attribute
                                 if (!suboperationReconciled.isNull() && operationObj.getStatus() == SKGOperationObject::NONE) {
                                     QString val = suboperationReconciled.text();
-                                    if (!err) err = operationObj.setStatus(val == "c" ? SKGOperationObject::POINTED : val == "y" ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
+                                    IFOKDO(err, operationObj.setStatus(val == "c" ? SKGOperationObject::POINTED : val == "y" ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
                                 }
                                 if (!err && !suboperationMemo.isNull() && operationObj.getComment().isEmpty()) err = operationObj.setComment(suboperationMemo.text());
                                 if (!err && !suboperationAction.isNull() && operationObj.getMode().isEmpty()) err = operationObj.setMode(suboperationAction.text());
-                                if (!err) err = operationObj.save();
+                                IFOKDO(err, operationObj.save())
 
                                 QChar accountType = mapIdType[suboperationInfo.account.text()];
                                 if (accountType == 'C') {
@@ -378,20 +378,20 @@ SKGError SKGImportPluginGnc::importFile()
 
                                     double q = -suboperationInfo.value;
                                     if (!err && (!suboperationObj.exist() || suboperationObj.getQuantity() != q)) err = operationObj.addSubOperation(suboperationObj);
-                                    if (!err) err = suboperationObj.setQuantity(q);
-                                    if (!err) err = suboperationObj.setCategory(cat);
+                                    IFOKDO(err, suboperationObj.setQuantity(q))
+                                    IFOKDO(err, suboperationObj.setCategory(cat))
                                     if (!err && !suboperationMemo.isNull()) err = suboperationObj.setComment(suboperationMemo.text());
-                                    if (!err) err = suboperationObj.save();
+                                    IFOKDO(err, suboperationObj.save())
                                 } else if (accountType == 'E') {
                                     //Set as initial balance
-                                    if (!err) err = operationObj.setAttribute("d_date", "0000-00-00");
-                                    if (!err) err = operationObj.setStatus(SKGOperationObject::CHECKED);
-                                    if (!err) err = operationObj.save();
+                                    IFOKDO(err, operationObj.setAttribute("d_date", "0000-00-00"))
+                                    IFOKDO(err, operationObj.setStatus(SKGOperationObject::CHECKED))
+                                    IFOKDO(err, operationObj.save())
                                 } else if (accountType == 'A') {
                                     //It is a transfer of account
                                     SKGAccountObject act(m_importer->getDocument());
-                                    if (!err) err = act.setName(mapIdName[suboperationInfo.account.text()]);
-                                    if (!err) err = act.load();
+                                    IFOKDO(err, act.setName(mapIdName[suboperationInfo.account.text()]))
+                                    IFOKDO(err, act.load())
 
                                     //Set Unit
                                     SKGUnitObject unitName = mapIdUnit[suboperationInfo.account.text()];
@@ -399,41 +399,41 @@ SKGError SKGImportPluginGnc::importFile()
                                     if (parentSet) {
                                         //If the parent is already set, it means that is a transfer
                                         SKGOperationObject operationObj2;
-                                        if (!err) err = act.addOperation(operationObj2, true);
-                                        if (!err) err = operationObj2.setDate(operationObj.getDate());
-                                        if (!err) err = operationObj2.setNumber(operationObj.getNumber());
-                                        if (!err) err = operationObj2.setMode(operationObj.getMode());
+                                        IFOKDO(err, act.addOperation(operationObj2, true))
+                                        IFOKDO(err, operationObj2.setDate(operationObj.getDate()))
+                                        IFOKDO(err, operationObj2.setNumber(operationObj.getNumber()))
+                                        IFOKDO(err, operationObj2.setMode(operationObj.getMode()))
                                         if (!err && !suboperationMemo.isNull()) err = operationObj2.setComment(suboperationMemo.text());
                                         SKGPayeeObject payeeObject;
                                         operationObj.getPayee(payeeObject);
-                                        if (!err) err = operationObj2.setPayee(payeeObject);
-                                        if (!err) {
+                                        IFOKDO(err, operationObj2.setPayee(payeeObject))
+                                        IFOK(err) {
                                             QString val = suboperationReconciled.text();
                                             err = operationObj2.setStatus(val == "c" ? SKGOperationObject::POINTED : val == "y" ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
                                         }
-                                        if (!err) err = operationObj2.setImported(true);
-                                        if (!err) err = operationObj2.setImportID(operationObj.getImportID());
-                                        if (!err) err = operationObj2.setTemplate(operationObj.isTemplate());
+                                        IFOKDO(err, operationObj2.setImported(true))
+                                        IFOKDO(err, operationObj2.setImportID(operationObj.getImportID()))
+                                        IFOKDO(err, operationObj2.setTemplate(operationObj.isTemplate()))
                                         if (!err && unitName.exist()) err = operationObj2.setUnit(unitName);
-                                        if (!err) err = operationObj2.save();
-                                        if (!err) err = operationObj2.setGroupOperation(operationObj);
-                                        if (!err) err = operationObj2.save();
+                                        IFOKDO(err, operationObj2.save())
+                                        IFOKDO(err, operationObj2.setGroupOperation(operationObj))
+                                        IFOKDO(err, operationObj2.save())
 
                                         //Create sub operation on operationObj2
                                         SKGSubOperationObject suboperationObj2;
-                                        if (!err) err = operationObj2.addSubOperation(suboperationObj2);
-                                        if (!err) {
+                                        IFOKDO(err, operationObj2.addSubOperation(suboperationObj2))
+                                        IFOK(err) {
                                             //We must take the quality of the split having an action
                                             quantity = suboperationInfo.value;
                                             err = suboperationObj2.setQuantity(suboperationInfo.value);
                                         }
                                         if (!err && !suboperationMemo.isNull()) err = suboperationObj2.setComment(suboperationMemo.text());
-                                        if (!err) err = suboperationObj2.save();
+                                        IFOKDO(err, suboperationObj2.save())
                                     } else {
                                         //We set the parent
-                                        if (!err) err = operationObj.setParentAccount(act);
+                                        IFOKDO(err, operationObj.setParentAccount(act))
                                         if (!err && unitName.exist()) err = operationObj.setUnit(unitName);
-                                        if (!err) err = operationObj.save();
+                                        IFOKDO(err, operationObj.save())
 
                                         //Compute quantity
                                         quantity = suboperationInfo.value;
@@ -441,10 +441,10 @@ SKGError SKGImportPluginGnc::importFile()
                                         //Create sub operation on operationObj
                                         quantity -= SKGServices::stringToDouble(operationObj.getAttribute("f_QUANTITY"));
                                         if (fabs(quantity) > 10e-9) {
-                                            if (!err) err = operationObj.addSubOperation(suboperationObj);
-                                            if (!err) err = suboperationObj.setQuantity(quantity);
+                                            IFOKDO(err, operationObj.addSubOperation(suboperationObj))
+                                            IFOKDO(err, suboperationObj.setQuantity(quantity))
                                             if (!err && !suboperationMemo.isNull()) err = suboperationObj.setComment(suboperationMemo.text());
-                                            if (!err) err = suboperationObj.save();
+                                            IFOKDO(err, suboperationObj.save())
                                         }
 
                                         parentSet = true;
@@ -454,19 +454,19 @@ SKGError SKGImportPluginGnc::importFile()
 
                             if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
 
-                            if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                            IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                        SKGENDTRANSACTION(m_importer->getDocument(),  err);
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(3);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
                     //Step 4-Get scheduled
                     {
                         //Create scheduled
                         QDomNodeList scheduleList = book.elementsByTagName("gnc:schedxaction");
                         int nbSchedule = scheduleList.count();
-                        if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nbSchedule);
+                        IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nbSchedule))
                         for (int i = 0; !err && i < nbSchedule; ++i) {
                             QDomElement schedule = scheduleList.at(i).toElement();
                             QDomElement scheduleAutoCreate = schedule.firstChildElement("sx:autoCreate");
@@ -497,7 +497,7 @@ SKGError SKGImportPluginGnc::importFile()
                                 err = operation.addRecurrentOperation(recuOperation);
                                 if (!err && !scheduleOccur.isNull()) {
                                     err = recuOperation.timeLimit(true);
-                                    if (!err) err = recuOperation.setTimeLimit(SKGServices::stringToInt(scheduleOccur.text()));
+                                    IFOKDO(err, recuOperation.setTimeLimit(SKGServices::stringToInt(scheduleOccur.text())))
                                 }
                                 if (!err && !scheduleAutoCreate.isNull()) err = recuOperation.autoWriteEnabled(scheduleAutoCreate.text() == "y");
                                 if (!err && !scheduleAdvanceCreateDays.isNull()) err = recuOperation.setAutoWriteDays(SKGServices::stringToInt(scheduleAdvanceCreateDays.text()));
@@ -511,25 +511,25 @@ SKGError SKGImportPluginGnc::importFile()
                                     else if (schedulePeriod.text() == "week") punit = SKGRecurrentOperationObject::WEEK;
 
                                     err = recuOperation.setPeriodIncrement(p);
-                                    if (!err) err = recuOperation.setPeriodUnit(punit);
+                                    IFOKDO(err, recuOperation.setPeriodUnit(punit))
                                 }
 
                                 if (!err && !scheduleDate.isNull()) err = recuOperation.setDate(QDate::fromString(scheduleDate.text().left(10), "yyyy-MM-dd"));
-                                if (!err) err = recuOperation.setDate(recuOperation.getNextDate());
+                                IFOKDO(err, recuOperation.setDate(recuOperation.getNextDate()))
                                 if (!err && !scheduleEnable.isNull() && scheduleEnable.text() == "n") {
                                     err = recuOperation.autoWriteEnabled(false);
-                                    if (!err) err = recuOperation.setWarnDays(false);
+                                    IFOKDO(err, recuOperation.setWarnDays(false))
                                 }
 
-                                if (!err) err = recuOperation.save();
+                                IFOKDO(err, recuOperation.save())
                             }
 
-                            if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                            IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                         }
 
-                        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                        SKGENDTRANSACTION(m_importer->getDocument(),  err);
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(4);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
                     //Step 5-Get unit values
                     {
@@ -538,7 +538,7 @@ SKGError SKGImportPluginGnc::importFile()
                         if (!pricedb.isNull()) {
                             QDomNodeList priceList = pricedb.elementsByTagName("price");
                             int nbPrice = priceList.count();
-                            if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nbPrice);
+                            IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nbPrice))
                             for (int i = 0; !err && i < nbPrice; ++i) {
                                 QDomElement price = priceList.at(i).toElement();
 
@@ -559,26 +559,26 @@ SKGError SKGImportPluginGnc::importFile()
 
                                 }
 
-                                if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                                IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                             }
 
-                            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                            SKGENDTRANSACTION(m_importer->getDocument(),  err);
                         }
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(5);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
                     //Step 6-Remove useless account and temporary account
                     {
-                        if (!err) err = gnucashTemporaryAccount.remove(false, true);
+                        IFOKDO(err, gnucashTemporaryAccount.remove(false, true))
 
-                        if (!err) err = m_importer->getDocument()->executeSqliteOrder("DELETE FROM account WHERE rd_bank_id=" % SKGServices::intToString(bank.getID()) % " AND (SELECT COUNT(1) FROM operation WHERE operation.rd_account_id=account.id)=0");
-                        if (!err) err = m_importer->getDocument()->stepForward(6);
+                        IFOKDO(err, m_importer->getDocument()->executeSqliteOrder("DELETE FROM account WHERE rd_bank_id=" % SKGServices::intToString(bank.getID()) % " AND (SELECT COUNT(1) FROM operation WHERE operation.rd_account_id=account.id)=0"))
+                        IFOKDO(err, m_importer->getDocument()->stepForward(6))
                     }
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder("ANALYZE"))
         }
     }
 
