@@ -94,7 +94,7 @@ SKGError SKGImportPluginGsb::importFile()
 
         if (!contentOK) err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
         else {
-            err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GSB"), 9);
+            err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GSB"), 10);
 
             QMap<QString, SKGUnitObject> mapIdUnit;
             QMap<QString, SKGBankObject> mapIdBank;
@@ -103,11 +103,12 @@ SKGError SKGImportPluginGsb::importFile()
             QMap<QString, SKGOperationObject> mapIdOperation;
             QMap<QString, SKGPayeeObject> mapIdPayee;
             QMap<QString, QString> mapIdMode;
+            QMap<QString, QString> mapIdBudgetCat;
 
             //Specifications: http://wiki.grisbi.org/doku.php?id=docs:dev:format_gsb
 
             //Step 1-Create units
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList currencyList = docElem.elementsByTagName("Currency");
                 int nb = currencyList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
@@ -117,22 +118,22 @@ SKGError SKGImportPluginGsb::importFile()
 
                     //Creation of the units
                     SKGUnitObject unitObj(m_importer->getDocument());
-                    if (!err) err = unitObj.setName(getAttribute(currency,  "Na"));
-                    if (!err) err = unitObj.setSymbol(getAttribute(currency,  "Co"));
-                    if (!err) err = unitObj.setNumberDecimal(SKGServices::stringToInt(getAttribute(currency,  "Fl")));
-                    if (!err) err = unitObj.save();
+                    IFOKDO(err, unitObj.setName(getAttribute(currency,  "Na")))
+                    IFOKDO(err, unitObj.setSymbol(getAttribute(currency,  "Co")))
+                    IFOKDO(err, unitObj.setNumberDecimal(SKGServices::stringToInt(getAttribute(currency,  "Fl"))))
+                    IFOKDO(err, unitObj.save())
 
                     mapIdUnit[getAttribute(currency,  "Nb")] = unitObj;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(1);
+            IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
             //Step 2-Create banks
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList bankList = docElem.elementsByTagName("Bank");
                 int nb = bankList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks"), nb);
@@ -142,24 +143,24 @@ SKGError SKGImportPluginGsb::importFile()
 
                     //Creation of the banks
                     SKGBankObject bankObj(m_importer->getDocument());
-                    if (!err) err = bankObj.setName(getAttribute(bank,  "Na"));
-                    if (!err) err = bankObj.setNumber(getAttribute(bank,  "BIC"));
-                    if (!err) err = bankObj.save();
+                    IFOKDO(err, bankObj.setName(getAttribute(bank,  "Na")))
+                    IFOKDO(err, bankObj.setNumber(getAttribute(bank,  "BIC")))
+                    IFOKDO(err, bankObj.save())
 
                     mapIdBank[getAttribute(bank,  "Nb")] = bankObj;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(2);
+            IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
             //Step 3-Create accounts
             SKGBankObject bankDefault(m_importer->getDocument());
-            if (!err) err = bankDefault.setName("GRISBI");
-            if (!err) err = bankDefault.save();
-            if (!err) {
+            IFOKDO(err, bankDefault.setName("GRISBI"))
+            IFOKDO(err, bankDefault.save())
+            IFOK(err) {
                 QDomNodeList accountList = docElem.elementsByTagName("Account");
                 int nb = accountList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
@@ -171,26 +172,28 @@ SKGError SKGImportPluginGsb::importFile()
                     SKGAccountObject accountObj;
                     SKGBankObject bank = mapIdBank[getAttribute(account,  "Bank")];
                     if (!bank.exist()) bank = bankDefault;
-                    if (!err) err = bank.addAccount(accountObj);
-                    if (!err) err = accountObj.setName(getAttribute(account,  "Name"));
-                    if (!err) err = accountObj.setNumber(getAttribute(account,  "Bank_account_number"));
-                    if (!err) err = accountObj.setComment(getAttribute(account,  "Comment"));
-                    if (!err) err = accountObj.setAgencyAddress(getAttribute(account,  "Owner_address"));
-                    if (!err) err = accountObj.setClosed(getAttribute(account,  "Closed_account") != "0");
-                    if (!err) err = accountObj.save();
-                    if (!err) err = accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "Initial_balance")), mapIdUnit[getAttribute(account,  "Currency")]);
+                    IFOKDO(err, bank.addAccount(accountObj))
+                    IFOKDO(err, accountObj.setName(getAttribute(account,  "Name")))
+                    IFOKDO(err, accountObj.setNumber(getAttribute(account,  "Bank_account_number")))
+                    IFOKDO(err, accountObj.setComment(getAttribute(account,  "Comment")))
+                    IFOKDO(err, accountObj.setAgencyAddress(getAttribute(account,  "Owner_address")))
+                    IFOKDO(err, accountObj.setMinLimitAmount(SKGServices::stringToDouble(getAttribute(account,  "Minimum_authorised_balance"))))
+                    IFOKDO(err, accountObj.minLimitAmountEnabled(accountObj.getMinLimitAmount() != 0.0))
+                    IFOKDO(err, accountObj.setClosed(getAttribute(account,  "Closed_account") != "0"))
+                    IFOKDO(err, accountObj.save())
+                    IFOKDO(err, accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "Initial_balance")), mapIdUnit[getAttribute(account,  "Currency")]))
 
                     mapIdAccount[getAttribute(account,  "Number")] = accountObj;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(3);
+            IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
             //Step 4-Get payees
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList partyList = docElem.elementsByTagName("Party");
                 int nb = partyList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
@@ -201,15 +204,15 @@ SKGError SKGImportPluginGsb::importFile()
                     err = SKGPayeeObject::createPayee(m_importer->getDocument(), getAttribute(party,  "Na"), payeeObject);
                     mapIdPayee[getAttribute(party,  "Nb")] = payeeObject;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(4);
+            IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
             //Step 5-Get payement mode
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList paymentList = docElem.elementsByTagName("Payment");
                 int nb = paymentList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payment mode"), nb);
@@ -218,15 +221,15 @@ SKGError SKGImportPluginGsb::importFile()
                     QDomElement payment = paymentList.at(i).toElement();
                     mapIdMode[getAttribute(payment,  "Number")] = getAttribute(payment,  "Name");
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(5);
+            IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
             //Step 6-Create categories
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList categoryList = docElem.elementsByTagName("Category");
                 int nb = categoryList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
@@ -236,20 +239,21 @@ SKGError SKGImportPluginGsb::importFile()
 
                     //Creation of the categories
                     SKGCategoryObject catObj(m_importer->getDocument());
-                    if (!err) err = catObj.setName(getAttribute(category,  "Na"));
-                    if (!err) err = catObj.save();
+                    IFOKDO(err, catObj.setName(getAttribute(category,  "Na")))
+                    IFOKDO(err, catObj.save())
 
-                    mapIdCategory[getAttribute(category,  "Nb")] = catObj;
+                    QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(category,  "Nb")));
+                    mapIdCategory[id] = catObj;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(6);
+            IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
             //Step 7-Create subcategories
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList categoryList = docElem.elementsByTagName("Sub_category");
                 int nb = categoryList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
@@ -258,24 +262,48 @@ SKGError SKGImportPluginGsb::importFile()
                     QDomElement category = categoryList.at(i).toElement();
 
                     //Creation of the subcategories
-                    SKGCategoryObject catParentObj = mapIdCategory[getAttribute(category,  "Nbc")];
+                    SKGCategoryObject catParentObj = mapIdCategory[SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(category,  "Nbc")))];
                     SKGCategoryObject catObj;
-                    if (!err) err = catParentObj.addCategory(catObj);
-                    if (!err) err = catObj.setName(getAttribute(category,  "Na"));
-                    if (!err) err = catObj.save();
+                    IFOKDO(err, catParentObj.addCategory(catObj))
+                    IFOKDO(err, catObj.setName(getAttribute(category,  "Na")))
+                    IFOKDO(err, catObj.save())
 
                     QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(category,  "Nbc")) + SKGServices::stringToInt(getAttribute(category,  "Nb")));
                     mapIdCategory[id] = catObj;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(7);
+            IFOKDO(err, m_importer->getDocument()->stepForward(7))
 
-            //Step 8-Create transaction
-            if (!err) {
+            //Step 8-Index of budget categories
+            IFOK(err) {
+                QDomNodeList budgetaryList = docElem.elementsByTagName("Budgetary");
+                int nb = budgetaryList.count();
+                for (int i = 0; !err && i < nb; ++i) {
+                    //Get account object
+                    QDomElement budgetary = budgetaryList.at(i).toElement();
+                    QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(budgetary,  "Nb")));
+                    mapIdBudgetCat[id] = getAttribute(budgetary,  "Na");
+                }
+            }
+            IFOK(err) {
+                QDomNodeList budgetaryList = docElem.elementsByTagName("Sub_budgetary");
+                int nb = budgetaryList.count();
+                for (int i = 0; !err && i < nb; ++i) {
+                    //Get account object
+                    QDomElement budgetary = budgetaryList.at(i).toElement();
+                    QString id1 = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(budgetary,  "Nb")));
+                    QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(budgetary,  "Nbb")) + SKGServices::stringToInt(getAttribute(budgetary,  "Nb")));
+                    mapIdBudgetCat[id] = mapIdBudgetCat[id1] % OBJECTSEPARATOR % getAttribute(budgetary,  "Na");
+                }
+            }
+            IFOKDO(err, m_importer->getDocument()->stepForward(8))
+
+            //Step 9-Create transaction
+            IFOK(err) {
                 QDomNodeList transactionList = docElem.elementsByTagName("Transaction");
                 int nb = transactionList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
@@ -288,44 +316,64 @@ SKGError SKGImportPluginGsb::importFile()
                     QString parentOpId = getAttribute(transaction,  "Mo");
                     if (parentOpId == "0") {
                         SKGAccountObject account = mapIdAccount[getAttribute(transaction,  "Ac")];
-                        if (!err) err = account.addOperation(opObj, true);
-                        if (!err) err = opObj.setDate(QDate::fromString(getAttribute(transaction,  "Dt"), "MM/dd/yyyy"));
-                        if (!err) err = opObj.setUnit(mapIdUnit[ getAttribute(transaction,  "Cu")]);
-                        if (!err) err = opObj.setPayee(mapIdPayee[ getAttribute(transaction,  "Pa")]);
-                        if (!err) err = opObj.setMode(mapIdMode[getAttribute(transaction,  "Pn")]);
-                        if (!err) err = opObj.setNumber(SKGServices::stringToInt(getAttribute(transaction,  "Pc")));
-                        if (!err) err = opObj.setComment(getAttribute(transaction,  "No"));
-                        if (!err) err = opObj.setImported(true);
-                        if (!err) err = opObj.setImportID("GSB-" % getAttribute(transaction,  "Nb"));
-                        if (!err) err = opObj.setStatus(getAttribute(transaction,  "Re") == "0" ? SKGOperationObject::NONE : SKGOperationObject::CHECKED);
-                        if (!err) err = opObj.setGroupOperation(mapIdOperation[getAttribute(transaction,  "Trt")]);
-                        if (!err) err = opObj.save();
+                        IFOKDO(err, account.addOperation(opObj, true))
+                        IFOKDO(err, opObj.setDate(QDate::fromString(getAttribute(transaction,  "Dt"), "MM/dd/yyyy")))
+                        IFOKDO(err, opObj.setUnit(mapIdUnit[ getAttribute(transaction,  "Cu")]))
+                        IFOKDO(err, opObj.setPayee(mapIdPayee[ getAttribute(transaction,  "Pa")]))
+                        IFOKDO(err, opObj.setMode(mapIdMode[getAttribute(transaction,  "Pn")]))
+                        IFOKDO(err, opObj.setNumber(SKGServices::stringToInt(getAttribute(transaction,  "Pc"))))
+                        IFOKDO(err, opObj.setComment(getAttribute(transaction,  "No")))
+                        IFOKDO(err, opObj.setImported(true))
+                        IFOKDO(err, opObj.setImportID("GSB-" % getAttribute(transaction,  "Nb")))
+                        IFOKDO(err, opObj.setStatus(getAttribute(transaction,  "Re") == "0" ? SKGOperationObject::NONE : SKGOperationObject::CHECKED))
+                        IFOKDO(err, opObj.setGroupOperation(mapIdOperation[getAttribute(transaction,  "Trt")]))
+                        IFOKDO(err, opObj.save())
                     } else {
                         opObj = mapIdOperation[parentOpId];
                     }
 
+                    //Budgetary allocation
+                    IFOK(err) {
+                        int sbu = SKGServices::stringToInt(getAttribute(transaction,  "Sbu"));
+                        QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(transaction,  "Bu")) + qMax(sbu, 0));
+                        QString buCat = mapIdBudgetCat[id];
+                        if (!buCat.isEmpty()) {
+                            err = opObj.setProperty(i18nc("Noun", "Budgetary allocation"), buCat);
+                            IFOKDO(err, opObj.save())
+                        }
+                    }
+
+                    //Fiscal year
+                    IFOK(err) {
+                        QString fiscalYear = getAttribute(transaction,  "Vo");
+                        if (!fiscalYear.isEmpty()) {
+                            err = opObj.setProperty(i18nc("Noun", "Fiscal year"), fiscalYear);
+                            IFOKDO(err, opObj.save())
+                        }
+                    }
+
                     if (getAttribute(transaction,  "Br") == "0") {
                         SKGSubOperationObject subObj;
-                        if (!err) err = opObj.addSubOperation(subObj);
+                        IFOKDO(err, opObj.addSubOperation(subObj))
                         QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(transaction,  "Ca")) + SKGServices::stringToInt(getAttribute(transaction,  "Sca")));
-                        if (!err) err = subObj.setCategory(mapIdCategory[id]);
-                        if (!err) err = subObj.setComment(getAttribute(transaction,  "No"));
-                        if (!err) err = subObj.setQuantity(SKGServices::stringToDouble(getAttribute(transaction,  "Am")));
-                        if (!err) err = subObj.save();
+                        IFOKDO(err, subObj.setCategory(mapIdCategory[id]))
+                        IFOKDO(err, subObj.setComment(getAttribute(transaction,  "No")))
+                        IFOKDO(err, subObj.setQuantity(SKGServices::stringToDouble(getAttribute(transaction,  "Am"))))
+                        IFOKDO(err, subObj.save())
                     }
 
                     mapIdOperation[getAttribute(transaction,  "Nb")] = opObj;
 
                     if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(8);
+            IFOKDO(err, m_importer->getDocument()->stepForward(9))
 
-            //Step 9-Create scheduled transaction
-            if (!err) {
+            //Step 10-Create scheduled transaction
+            IFOK(err) {
                 QDomNodeList scheduledList = docElem.elementsByTagName("Scheduled");
                 int nb = scheduledList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nb);
@@ -336,63 +384,63 @@ SKGError SKGImportPluginGsb::importFile()
                     //Creation of the operation
                     SKGAccountObject account = mapIdAccount[getAttribute(transaction,  "Ac")];
                     SKGOperationObject opObj;
-                    if (!err) err = account.addOperation(opObj, true);
+                    IFOKDO(err, account.addOperation(opObj, true))
                     QDate firstDate = QDate::fromString(getAttribute(transaction,  "Dt"), "MM/dd/yyyy");
-                    if (!err) err = opObj.setDate(firstDate);
-                    if (!err) err = opObj.setUnit(mapIdUnit[ getAttribute(transaction,  "Cu")]);
-                    if (!err) err = opObj.setPayee(mapIdPayee[ getAttribute(transaction,  "Pa")]);
-                    if (!err) err = opObj.setMode(mapIdMode[getAttribute(transaction,  "Pn")]);
-                    if (!err) err = opObj.setNumber(SKGServices::stringToInt(getAttribute(transaction,  "Pc")));
-                    if (!err) err = opObj.setComment(getAttribute(transaction,  "No"));
-                    if (!err) err = opObj.setImported(true);
-                    if (!err) err = opObj.setImportID("GSB-" % getAttribute(transaction,  "Nb"));
-                    if (!err) err = opObj.setTemplate(true);
-                    if (!err) err = opObj.save();
+                    IFOKDO(err, opObj.setDate(firstDate))
+                    IFOKDO(err, opObj.setUnit(mapIdUnit[ getAttribute(transaction,  "Cu")]))
+                    IFOKDO(err, opObj.setPayee(mapIdPayee[ getAttribute(transaction,  "Pa")]))
+                    IFOKDO(err, opObj.setMode(mapIdMode[getAttribute(transaction,  "Pn")]))
+                    IFOKDO(err, opObj.setNumber(SKGServices::stringToInt(getAttribute(transaction,  "Pc"))))
+                    IFOKDO(err, opObj.setComment(getAttribute(transaction,  "No")))
+                    IFOKDO(err, opObj.setImported(true))
+                    IFOKDO(err, opObj.setImportID("GSB-" % getAttribute(transaction,  "Nb")))
+                    IFOKDO(err, opObj.setTemplate(true))
+                    IFOKDO(err, opObj.save())
 
                     SKGSubOperationObject subObj;
-                    if (!err) err = opObj.addSubOperation(subObj);
+                    IFOKDO(err, opObj.addSubOperation(subObj))
                     QString id = SKGServices::intToString(10000 * SKGServices::stringToInt(getAttribute(transaction,  "Ca")) + SKGServices::stringToInt(getAttribute(transaction,  "Sca")));
-                    if (!err) err = subObj.setCategory(mapIdCategory[id]);
-                    if (!err) err = subObj.setComment(getAttribute(transaction,  "No"));
-                    if (!err) err = subObj.setQuantity(SKGServices::stringToDouble(getAttribute(transaction,  "Am")));
-                    if (!err) err = subObj.save();
+                    IFOKDO(err, subObj.setCategory(mapIdCategory[id]))
+                    IFOKDO(err, subObj.setComment(getAttribute(transaction,  "No")))
+                    IFOKDO(err, subObj.setQuantity(SKGServices::stringToDouble(getAttribute(transaction,  "Am"))))
+                    IFOKDO(err, subObj.save())
 
                     QString Tra = getAttribute(transaction,  "Tra");
                     if (Tra != "0") {
                         //This is a transfer
                         SKGOperationObject opObj2;
-                        if (!err) err = opObj.duplicate(opObj2, opObj.getDate(), true);
-                        if (!err) err = opObj2.setImported(true);
-                        if (!err) err = opObj2.setImportID("GSB-" % getAttribute(transaction,  "Nb") % "_TR");
-                        if (!err) err = opObj2.save();
+                        IFOKDO(err, opObj.duplicate(opObj2, opObj.getDate(), true))
+                        IFOKDO(err, opObj2.setImported(true))
+                        IFOKDO(err, opObj2.setImportID("GSB-" % getAttribute(transaction,  "Nb") % "_TR"))
+                        IFOKDO(err, opObj2.save())
 
                         SKGObjectBase::SKGListSKGObjectBase subObjs2;
-                        if (!err) err = opObj2.getSubOperations(subObjs2);
+                        IFOKDO(err, opObj2.getSubOperations(subObjs2))
                         if (!err && subObjs2.count()) {
                             SKGSubOperationObject subObj2(subObjs2.at(0));
                             err = subObj2.setQuantity(-subObj.getQuantity());
-                            err = subObj2.save();
+                            IFOKDO(err, subObj2.save())
                         }
 
                         //Group operations
-                        if (!err) err = opObj.setGroupOperation(opObj2);
-                        if (!err) err = opObj.save();
+                        IFOKDO(err, opObj.setGroupOperation(opObj2))
+                        IFOKDO(err, opObj.save())
                     }
 
                     //Create the schedule
                     SKGRecurrentOperationObject recuObj;
-                    if (!err) err = opObj.addRecurrentOperation(recuObj);
-                    if (!err) err = recuObj.setAutoWriteDays(0);
-                    if (!err) err = recuObj.autoWriteEnabled(getAttribute(transaction,  "Au") != "0");
-                    if (!err) {
+                    IFOKDO(err, opObj.addRecurrentOperation(recuObj))
+                    IFOKDO(err, recuObj.setAutoWriteDays(0))
+                    IFOKDO(err, recuObj.autoWriteEnabled(getAttribute(transaction,  "Au") != "0"))
+                    IFOK(err) {
                         //text_frequency [] = { _("Once"), _("Weekly"), _("Monthly"), _("two months"), ("trimester"), _("Yearly"), _("Custom"), NULL };
                         int occu = 1;
                         SKGRecurrentOperationObject::PeriodUnit period = SKGRecurrentOperationObject::DAY;
                         QString Pe = getAttribute(transaction,  "Pe");
                         if (Pe == "0") {
                             period = SKGRecurrentOperationObject::MONTH;
-                            if (!err) err = recuObj.timeLimit(true);
-                            if (!err) err = recuObj.setTimeLimit(1);
+                            IFOKDO(err, recuObj.timeLimit(true))
+                            IFOKDO(err, recuObj.setTimeLimit(1))
 
                         } else if (Pe == "1") {
                             period = SKGRecurrentOperationObject::WEEK;
@@ -416,28 +464,28 @@ SKGError SKGImportPluginGsb::importFile()
                             else period = SKGRecurrentOperationObject::YEAR;
                         }
 
-                        if (!err) err = recuObj.setPeriodUnit(period);
-                        if (!err) err = recuObj.setPeriodIncrement(occu);
+                        IFOKDO(err, recuObj.setPeriodUnit(period))
+                        IFOKDO(err, recuObj.setPeriodIncrement(occu))
 
                         QString Dtl = getAttribute(transaction,  "Dtl");
                         if (!err && !Dtl.isEmpty()) {
-                            if (!err) err = recuObj.timeLimit(true);
-                            if (!err) err = recuObj.setTimeLimit(QDate::fromString(Dtl, "MM/dd/yyyy"));
+                            IFOKDO(err, recuObj.timeLimit(true))
+                            IFOKDO(err, recuObj.setTimeLimit(QDate::fromString(Dtl, "MM/dd/yyyy")))
                         }
                     }
-                    if (!err) err = recuObj.save();
+                    IFOKDO(err, recuObj.save())
 
                     if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(9);
+            IFOKDO(err, m_importer->getDocument()->stepForward(10))
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+            SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
-            if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder("ANALYZE"))
         }
     }
 
