@@ -61,7 +61,7 @@ SKGError SKGImportPluginJson::exportFile()
     SKGError err;
     QString doc;
     err = m_importer->getDocument()->copyToJson(doc);
-    if (!err) {
+    IFOK(err) {
         KSaveFile file(m_importer->getLocalFileName(false));
         if (!file.open())err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
         else {
