@@ -94,6 +94,24 @@ bool SKGImportPluginMny::isImportPossible()
     return (extension == "MNY");
 }
 
+SKGError SKGImportPluginMny::readJsonFile(const QString& iFileName, QVariant& oVariant)
+{
+    SKGError err;
+    SKGTRACEINRC(2, "SKGImportPluginMny::readJsonFile", err);
+    QJson::Parser parser;
+    bool ok = false;
+    QFile file(iFileName);
+    if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", iFileName));
+    } else {
+        QByteArray json = file.readAll();
+        file.close();
+        oVariant = parser.parse(json, &ok);
+        if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
+    }
+    return err;
+}
+
 SKGError SKGImportPluginMny::importFile()
 {
     if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
@@ -113,7 +131,7 @@ SKGError SKGImportPluginMny::importFile()
         if (m_parameters["install_sunriise"] == "Y") {
             QDir::home().mkdir(".skrooge");
             err = SKGServices::upload(KUrl("http://skrooge.org/files/sunriise.jar"), KUrl(sunriise_jar));
-            if (err) return err;
+            IFKO(err) return err;
         } else {
             err.setReturnCode(ERR_INSTALL).setMessage(i18nc("Error message",  "The sunriise application is needed for Microsoft Money import but is not installed in '%1'", sunriise_jar));
             err.setProperty("application", "sunriise");
@@ -144,7 +162,7 @@ SKGError SKGImportPluginMny::importFile()
         //Import
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MNY"), 6);
         //Step 1-Import categories
-        if (!err) {
+        IFOK(err) {
             /*[ {
             "id" : 137,
             "parentId" : 130,
@@ -152,15 +170,10 @@ SKGError SKGImportPluginMny::importFile()
             "classificationId" : 0,
             "level" : 1
             },*/
-            QJson::Parser parser;
-            bool ok = false;
-            QFile file(temporaryPath % "/categories.json");
-            file.open(QIODevice::ReadOnly);
-            QByteArray json = file.readAll();
-            file.close();
-            QVariantList list = parser.parse(json, &ok).toList();
-            if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-            else {
+            QVariant var;
+            err = readJsonFile(temporaryPath % "/categories.json", var);
+            QVariantList list = var.toList();
+            IFOK(err) {
                 SKGTRACEINRC(10, "SKGImportPluginMny::importFile-CATEGORY", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
@@ -179,32 +192,27 @@ SKGError SKGImportPluginMny::importFile()
                             SKGCategoryObject catObject(m_importer->getDocument());
                             err = catObject.setName(name);
                             if (!err && !parentId.isEmpty()) err = catObject.setParentCategory(m_mapIdCategory[parentId]);
-                            if (!err) err = catObject.save();
+                            IFOKDO(err, catObject.save())
 
                             m_mapIdCategory[id] = catObject;
 
                             ++index;
-                            if (!err) err = m_importer->getDocument()->stepForward(index);
+                            IFOKDO(err, m_importer->getDocument()->stepForward(index))
                         }
                     }
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(1);
+            IFOKDO(err, m_importer->getDocument()->stepForward(1))
         }
 
         //Step 2-Import payees
-        if (!err) {
-            QJson::Parser parser;
-            bool ok = false;
-            QFile file(temporaryPath % "/payees.json");
-            file.open(QIODevice::ReadOnly);
-            QByteArray json = file.readAll();
-            file.close();
-            QVariantList list = parser.parse(json, &ok).toList();
-            if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-            else {
+        IFOK(err) {
+            QVariant var;
+            err = readJsonFile(temporaryPath % "/payees.json", var);
+            QVariantList list = var.toList();
+            IFOK(err) {
                 SKGTRACEINRC(10, "SKGImportPluginMny::importFile-PAYEE", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
@@ -218,29 +226,24 @@ SKGError SKGImportPluginMny::importFile()
                     //Is already created?
                     SKGPayeeObject payeeObject(m_importer->getDocument());
                     err = payeeObject.setName(name);
-                    if (!err) err = payeeObject.save();
+                    IFOKDO(err, payeeObject.save())
 
                     m_mapIdPayee[id] = payeeObject;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(2);
+            IFOKDO(err, m_importer->getDocument()->stepForward(2))
         }
 
         //Step 3-Import securities
-        if (!err) {
-            QJson::Parser parser;
-            bool ok = false;
-            QFile file(temporaryPath % "/securities.json");
-            file.open(QIODevice::ReadOnly);
-            QByteArray json = file.readAll();
-            file.close();
-            QVariantList list = parser.parse(json, &ok).toList();
-            if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-            else {
+        IFOK(err) {
+            QVariant var;
+            err = readJsonFile(temporaryPath % "/securities.json", var);
+            QVariantList list = var.toList();
+            IFOK(err) {
                 SKGTRACEINRC(10, "SKGImportPluginMny::importFile-UNITS", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
@@ -256,22 +259,22 @@ SKGError SKGImportPluginMny::importFile()
                     //Is already created?
                     SKGUnitObject unitobject(m_importer->getDocument());
                     err = unitobject.setName(name);
-                    if (!err) err = unitobject.setSymbol(symbol);
-                    if (!err) err = unitobject.setType(SKGUnitObject::SHARE);
+                    IFOKDO(err, unitobject.setSymbol(symbol))
+                    IFOKDO(err, unitobject.setType(SKGUnitObject::SHARE))
                     //The unit is not saved because it will be saved when used
 
                     m_mapIdSecurity[id] = unitobject;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(3);
+            IFOKDO(err, m_importer->getDocument()->stepForward(3))
         }
 
         //Step 4-Import accounts
-        if (!err) {
+        IFOK(err) {
             /*
             {
                 "id" : 1,
@@ -299,22 +302,17 @@ SKGError SKGImportPluginMny::importFile()
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
 
             SKGBankObject bank(m_importer->getDocument());
-            if (!err) err = bank.setName("Microsof Money");
-            if (!err) err = bank.save();
+            IFOKDO(err, bank.setName("Microsof Money"))
+            IFOKDO(err, bank.save())
 
             //Create accounts
             for (int i = 0; !err && i < nb; ++i) {
                 QString accountDir = list[i];
 
-                QJson::Parser parser;
-                bool ok = false;
-                QFile file(temporaryPath % "/" % accountDir % "/account.json");
-                file.open(QIODevice::ReadOnly);
-                QByteArray json = file.readAll();
-                file.close();
-                QVariantMap account = parser.parse(json, &ok).toMap();
-                if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-                else {
+                QVariant var;
+                err = readJsonFile(temporaryPath % "/" % accountDir % "/account.json", var);
+                QVariantMap account = var.toMap();
+                IFOK(err) {
                     //Create currency
                     SKGUnitObject unitObj;
                     SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), account["currencyCode"].toString(), unitObj);
@@ -322,34 +320,34 @@ SKGError SKGImportPluginMny::importFile()
                     //Create account
                     SKGAccountObject accountObj;
                     err = bank.addAccount(accountObj);
-                    if (!err) err = accountObj.setName(account["name"].toString());
+                    IFOKDO(err, accountObj.setName(account["name"].toString()))
                     int type = account["type"].toInt();
-                    if (!err) err = accountObj.setType(type == 0 ? SKGAccountObject::CURRENT :
-                                                           type == 1 ? SKGAccountObject::CREDITCARD :
-                                                           type == 3 ? SKGAccountObject::ASSETS :
-                                                           type == 5 ? SKGAccountObject::INVESTMENT :
-                                                           type == 6 ? SKGAccountObject::LOAN :
-                                                           SKGAccountObject::OTHER);//TODO
-                    if (!err) err = accountObj.save();
+                    IFOKDO(err, accountObj.setType(type == 0 ? SKGAccountObject::CURRENT :
+                                                   type == 1 ? SKGAccountObject::CREDITCARD :
+                                                   type == 3 ? SKGAccountObject::ASSETS :
+                                                   type == 5 ? SKGAccountObject::INVESTMENT :
+                                                   type == 6 ? SKGAccountObject::LOAN :
+                                                   SKGAccountObject::OTHER));//TODO
+                    IFOKDO(err, accountObj.save())
 
                     //Update initial balance
-                    if (!err) err = accountObj.setInitialBalance(account["startingBalance"].toDouble(), unitObj);
+                    IFOKDO(err, accountObj.setInitialBalance(account["startingBalance"].toDouble(), unitObj))
 
-                    if (!err) err = accountObj.setClosed(account["closed"].toBool());
-                    if (!err) err = accountObj.save();
+                    IFOKDO(err, accountObj.setClosed(account["closed"].toBool()))
+                    IFOKDO(err, accountObj.save())
 
                     m_mapIdAccount[account["id"].toString()] = accountObj;
                 }
 
-                if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
             }
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+            SKGENDTRANSACTION(m_importer->getDocument(),  err);
         }
-        if (!err) err = m_importer->getDocument()->stepForward(4);
+        IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
         //Step 5-Import operation
-        if (!err) {
+        IFOK(err) {
             //List directories
             QStringList list = temporaryDir.entryList(QStringList() << "*.d", QDir::Dirs);
             SKGTRACEINRC(10, "SKGImportPluginMny::importFile-OPERATIONS", err);
@@ -361,15 +359,10 @@ SKGError SKGImportPluginMny::importFile()
             for (int i = 0; !err && i < nb; ++i) {
                 QString accountDir = list[i];
 
-                QJson::Parser parser;
-                bool ok = false;
-                QFile file(temporaryPath % "/" % accountDir % "/transactions.json");
-                file.open(QIODevice::ReadOnly);
-                QByteArray json = file.readAll();
-                file.close();
-                QVariantList operations = parser.parse(json, &ok).toList();
-                if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
-                else {
+                QVariant var;
+                err = readJsonFile(temporaryPath % "/" % accountDir % "/transactions.json", var);
+                QVariantList operations = var.toList();
+                IFOK(err) {
                     int nbo = operations.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nbo);
                     for (int j = 0; !err && j < nbo; ++j) {
@@ -380,7 +373,7 @@ SKGError SKGImportPluginMny::importFile()
 
                             SKGUnitObject unitObj;
                             if (securityId.isEmpty()) {
-                                if (!err) err = accountObj.getUnit(unitObj);
+                                IFOKDO(err, accountObj.getUnit(unitObj))
                             } else {
                                 unitObj = m_mapIdSecurity[securityId];
                                 if (!unitObj.getID()) {
@@ -390,11 +383,11 @@ SKGError SKGImportPluginMny::importFile()
                             }
 
                             SKGOperationObject operationObj;
-                            if (!err) err = accountObj.addOperation(operationObj, true);
-                            if (!err) err = operationObj.setUnit(unitObj);
-                            if (!err) err = operationObj.setDate(QDateTime::fromMSecsSinceEpoch(operation["date"].toULongLong()).date());
-                            if (!err) err = operationObj.setComment(operation["memo"].toString());
-                            if (!err) {
+                            IFOKDO(err, accountObj.addOperation(operationObj, true))
+                            IFOKDO(err, operationObj.setUnit(unitObj))
+                            IFOKDO(err, operationObj.setDate(QDateTime::fromMSecsSinceEpoch(operation["date"].toULongLong()).date()))
+                            IFOKDO(err, operationObj.setComment(operation["memo"].toString()))
+                            IFOK(err) {
                                 //The number is something like "0     4220725"
                                 QString number = operation["number"].toString();
                                 if (!number.isEmpty()) {
@@ -402,14 +395,14 @@ SKGError SKGImportPluginMny::importFile()
                                     err = operationObj.setNumber(SKGServices::stringToInt(ln.at(ln.count() - 1)));
                                 }
                             }
-                            if (!err) err = operationObj.setAttribute("t_imported", "T");
-                            if (!err) err = operationObj.setImportID("MNY-" % operation["id"].toString());
+                            IFOKDO(err, operationObj.setAttribute("t_imported", "T"))
+                            IFOKDO(err, operationObj.setImportID("MNY-" % operation["id"].toString()))
                             QString payId = operation["payeeId"].toString();
                             if (!payId.isEmpty() && !err) err = operationObj.setPayee(m_mapIdPayee[payId]);
-                            if (!err) err = operationObj.setStatus(operation["reconciled"].toBool() ? SKGOperationObject::CHECKED :
-                                                                       operation["cleared"].toBool() ? SKGOperationObject::POINTED :
-                                                                       SKGOperationObject::NONE);
-                            if (!err) err = operationObj.save(false);
+                            IFOKDO(err, operationObj.setStatus(operation["reconciled"].toBool() ? SKGOperationObject::CHECKED :
+                                                               operation["cleared"].toBool() ? SKGOperationObject::POINTED :
+                                                               SKGOperationObject::NONE));
+                            IFOKDO(err, operationObj.save(false))
 
                             double amount = operation["amount"].toDouble();
 
@@ -423,13 +416,13 @@ SKGError SKGImportPluginMny::importFile()
                                     QVariantMap transaction = split["transaction"].toMap();
 
                                     SKGSubOperationObject subOperationObj;
-                                    if (!err) err = operationObj.addSubOperation(subOperationObj);
+                                    IFOKDO(err, operationObj.addSubOperation(subOperationObj))
                                     QString catId = transaction["categoryId"].toString();
                                     if (!catId.isEmpty() && !err) err = subOperationObj.setCategory(m_mapIdCategory[catId]);
                                     double splitAmount = transaction["amount"].toDouble();
-                                    if (!err) err = subOperationObj.setQuantity(splitAmount);
-                                    if (!err) err = subOperationObj.setComment(operation["memo"].toString());
-                                    if (!err) err = subOperationObj.save(false, false);
+                                    IFOKDO(err, subOperationObj.setQuantity(splitAmount))
+                                    IFOKDO(err, subOperationObj.setComment(operation["memo"].toString()))
+                                    IFOKDO(err, subOperationObj.save(false, false))
                                     amount -= splitAmount;
                                 }
 
@@ -437,41 +430,41 @@ SKGError SKGImportPluginMny::importFile()
                                 if (qAbs(amount) > 0.00001) {
                                     //Create one more sub operation to align amounts
                                     SKGSubOperationObject subOperationObj;
-                                    if (!err) err = operationObj.addSubOperation(subOperationObj);
-                                    if (!err) err = subOperationObj.setQuantity(amount);
-                                    if (!err) err = subOperationObj.setComment(operation["memo"].toString());
-                                    if (!err) err = subOperationObj.save(false, false);
+                                    IFOKDO(err, operationObj.addSubOperation(subOperationObj))
+                                    IFOKDO(err, subOperationObj.setQuantity(amount))
+                                    IFOKDO(err, subOperationObj.setComment(operation["memo"].toString()))
+                                    IFOKDO(err, subOperationObj.save(false, false))
 
-                                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("Warning message", "The operation '%1' has been repaired because its amount was not equal to the sum of the amounts of its splits", operationObj.getDisplayName()), SKGDocument::Warning);
+                                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("Warning message", "The operation '%1' has been repaired because its amount was not equal to the sum of the amounts of its splits", operationObj.getDisplayName()), SKGDocument::Warning))
                                 }
                             } else {
                                 //No
                                 SKGSubOperationObject subOperationObj;
-                                if (!err) err = operationObj.addSubOperation(subOperationObj);
+                                IFOKDO(err, operationObj.addSubOperation(subOperationObj))
                                 QString catId = operation["categoryId"].toString();
                                 if (!catId.isEmpty() && !err) err = subOperationObj.setCategory(m_mapIdCategory[catId]);
-                                if (!err) err = subOperationObj.setQuantity(amount);
-                                if (!err) err = subOperationObj.setComment(operation["memo"].toString());
-                                if (!err) err = subOperationObj.save(false, false);
+                                IFOKDO(err, subOperationObj.setQuantity(amount))
+                                IFOKDO(err, subOperationObj.setComment(operation["memo"].toString()))
+                                IFOKDO(err, subOperationObj.save(false, false))
                             }
                         }
 
                         if (!err && index % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
                         ++index;
 
-                        if (!err) err = m_importer->getDocument()->stepForward(j + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(j + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
 
-                if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
             }
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+            SKGENDTRANSACTION(m_importer->getDocument(),  err);
         }
 
-        if (!err) err = m_importer->getDocument()->stepForward(5);
+        IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
         //Step 6-Group operation
         if (!err && m_parameters["find_and_group_transfers"] == "Y") {
@@ -479,9 +472,9 @@ SKGError SKGImportPluginMny::importFile()
             err = m_importer->findAndGroupTransfers(nbg, true);
         }
 
-        if (!err) err = m_importer->getDocument()->stepForward(6);
+        IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
-        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+        SKGENDTRANSACTION(m_importer->getDocument(),  err);
     } else {
         if (p.exitCode() == 1) err.setReturnCode(ERR_ENCRYPTION).setMessage(i18nc("Error message",  "Invalid password"));
         else err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The execution of '%1' failed", cmd)).addError(ERR_FAIL, i18nc("Error message",  "The extraction from the Microsoft Money document '%1' failed", m_importer->getFileName().prettyUrl()));
