@@ -66,9 +66,9 @@ SKGError SKGImportPluginMT940::importFile()
 
     //Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MT940"), 2);
-    if (!err) {
+    IFOK(err) {
         //Open file
-        if (!err) {
+        IFOK(err) {
             QFile file(m_importer->getLocalFileName());
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
             else {
@@ -87,7 +87,7 @@ SKGError SKGImportPluginMT940::importFile()
                 file.close();
 
                 //Step 1 done
-                if (!err) err = m_importer->getDocument()->stepForward(1);
+                IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
                 //Read lines
                 bool importActivated = false;
@@ -98,7 +98,7 @@ SKGError SKGImportPluginMT940::importFile()
                 QString bankName = "MT940";
 
                 int nb = lines.count();
-                if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
+                IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb))
                 for (int i = 0; i < nb && !err; ++i) {
                     //Read line
                     QString line = lines.at(i);
@@ -125,7 +125,7 @@ SKGError SKGImportPluginMT940::importFile()
                                 //Search if account is already existing
                                 SKGObjectBase::SKGListSKGObjectBase listAccount;
                                 err = m_importer->getDocument()->getObjects("v_account", "t_number='" % number % '\'', listAccount);
-                                if (!err) {
+                                IFOK(err) {
                                     if (listAccount.count() == 1) {
                                         //Yes ! Only one account found
                                         account = listAccount.at(0);
@@ -134,15 +134,15 @@ SKGError SKGImportPluginMT940::importFile()
                                         if (listAccount.count() > 1) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "More than one possible account found."));
 
                                         SKGBankObject bank(m_importer->getDocument());
-                                        if (!err) err = bank.setName(bankName);
-                                        if (!err) err = bank.setNumber(bankName);
+                                        IFOKDO(err, bank.setName(bankName))
+                                        IFOKDO(err, bank.setNumber(bankName))
                                         if (!err && bank.load().isFailed()) err = bank.save();
-                                        if (!err) err = bank.addAccount(account);
-                                        if (!err) err = account.setName(name);
-                                        if (!err) err = account.setNumber(number);
-                                        if (!err) err = account.setType(SKGAccountObject::CURRENT);
+                                        IFOKDO(err, bank.addAccount(account))
+                                        IFOKDO(err, account.setName(name))
+                                        IFOKDO(err, account.setNumber(number))
+                                        IFOKDO(err, account.setType(SKGAccountObject::CURRENT))
                                         if (!err && account.load().isFailed()) err = account.save();
-                                        if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Default account '%1' created for import", name));
+                                        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Default account '%1' created for import", name)))
                                     }
                                 }
 
@@ -154,12 +154,12 @@ SKGError SKGImportPluginMT940::importFile()
                                 err = SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), val.mid(7, 3), unit);
                                 //Example C040802EUR16,40
                                 if (account.getNbOperation() > 1) {
-                                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", account.getName()), SKGDocument::Warning);
+                                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", account.getName()), SKGDocument::Warning))
                                 } else {
                                     //Set initial balance
-                                    if (!err) err = account.setInitialBalance((val[0] == 'C' ? 1.0 : -1.0) * SKGServices::stringToDouble(val.right(val.count() - 10)), unit);
-                                    if (!err) err = account.save();
-                                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set with MT940 file content", account.getName()));
+                                    IFOKDO(err, account.setInitialBalance((val[0] == 'C' ? 1.0 : -1.0) * SKGServices::stringToDouble(val.right(val.count() - 10)), unit))
+                                    IFOKDO(err, account.save())
+                                    IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set with MT940 file content", account.getName())))
                                 }
 
                                 in86 = false;
@@ -188,51 +188,51 @@ SKGError SKGImportPluginMT940::importFile()
                                 }
 
                                 err = account.addOperation(operation, true);
-                                if (!err) err = operation.setDate(date);
-                                if (!err) err = operation.setUnit(unit);
-                                if (!err) err = operation.setAttribute("t_imported", "T");
+                                IFOKDO(err, operation.setDate(date))
+                                IFOKDO(err, operation.setUnit(unit))
+                                IFOKDO(err, operation.setAttribute("t_imported", "T"))
                                 //if(!err) err = operation.setImportID("MT940");
-                                if (!err) err = operation.save();
+                                IFOKDO(err, operation.save())
 
                                 SKGSubOperationObject subop;
                                 err = operation.addSubOperation(subop);
-                                if (!err) err = subop.setQuantity(sign * SKGServices::stringToDouble(amountString));
-                                if (!err) err = subop.save();
+                                IFOKDO(err, subop.setQuantity(sign * SKGServices::stringToDouble(amountString)))
+                                IFOKDO(err, subop.save())
 
                                 in86 = false;
                             } else if (line.startsWith(QLatin1String(":NS:")) && !operation.exist()) {
                                 QString val = line.right(line.count() - 4);
                                 QString comment = account.getComment();
                                 comment += (comment.isEmpty() || val.isEmpty() ? "" : " ") % val;
-                                if (!err) err = account.setComment(comment);
-                                if (!err) err = account.save();
+                                IFOKDO(err, account.setComment(comment))
+                                IFOKDO(err, account.save())
                             } else if (line.startsWith(QLatin1String(":86:")) || line.startsWith(QLatin1String(":NS:"))) {
                                 QString val = line.right(line.count() - 4);
                                 QString comment = operation.getComment();
                                 comment += (comment.isEmpty() || val.isEmpty() ? "" : " ") % val;
-                                if (!err) err = operation.setComment(comment);
-                                if (!err) err = operation.save();
+                                IFOKDO(err, operation.setComment(comment))
+                                IFOKDO(err, operation.save())
 
                                 in86 = true;
                             } else if (in86) {
                                 QString val = line;
                                 QString comment = operation.getComment();
                                 comment += (comment.isEmpty() || val.isEmpty() ? "" : " ") % val;
-                                if (!err) err = operation.setComment(comment);
-                                if (!err) err = operation.save();
+                                IFOKDO(err, operation.setComment(comment))
+                                IFOKDO(err, operation.save())
                             }
                         }
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
                 //Step 2 done
-                if (!err) err = m_importer->getDocument()->stepForward(2);
+                IFOKDO(err, m_importer->getDocument()->stepForward(2))
             }
         }
     }
-    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+    SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
     return err;
 }
