@@ -68,8 +68,8 @@ SKGError SKGImportPluginOfx::importFile()
     SKGTRACEINRC(2, "SKGImportPluginOfx::importFile", err);
 
     if (!QFile(m_importer->getLocalFileName()).exists()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    if (!err) err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX"));
-    if (!err) {
+    IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX")))
+    IFOK(err) {
         SKGImportPluginOfx::m_ofxError = SKGError();
         SKGImportPluginOfx::m_ofxInitialBalance.clear();
 
@@ -82,32 +82,31 @@ SKGError SKGImportPluginOfx::importFile()
             //ofx_set_security_cb(ctx, ofxSecurityCallback, this);
             int rc = libofx_proc_file(ctx, m_importer->getLocalFileName().toUtf8(), AUTODETECT);
             if (rc)  err = SKGError(ERR_FAIL, i18nc("Error message",  "Import OFX file '%1' failed", m_importer->getFileName().prettyUrl()));
-            if (!err) err = SKGImportPluginOfx::m_ofxError;
-            {
+            IFOKDO(err, SKGImportPluginOfx::m_ofxError) {
                 //This is an option ==> no error management
-                SKGError err;
+                SKGError err2;
                 int nb = SKGImportPluginOfx::m_ofxInitialBalance.count();
-                for (int i = 0; !err && i < nb; ++i) {
+                for (int i = 0; !err2 && i < nb; ++i) {
                     OfxStatementData data = SKGImportPluginOfx::m_ofxInitialBalance.at(i);
 
                     //Get account
                     SKGAccountObject act;
-                    if (!err) err = getAccount(data.account_ptr, m_importer->getDocument(), act);
+                    if (!err2) err2 = getAccount(data.account_ptr, m_importer->getDocument(), act);
 
                     //Date of balance
                     QDate date = (data.ledger_balance_date_valid == true ? QDateTime::fromTime_t (data.ledger_balance_date).date() : QDate::currentDate());
 
                     //Get unit
                     SKGUnitObject unit;
-                    if (!err) err = m_importer->getDefaultUnit(unit);
+                    if (!err2) err2 = m_importer->getDefaultUnit(unit);
 
                     //Current amount
                     double currentAmount = act.getAmount(date);
 
                     //Update account
-                    if (!err) err = act.setInitialBalance(data.ledger_balance - currentAmount, unit);
-                    if (!err) err = act.save();
-                    if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", act.getName()));
+                    if (!err2) err2 = act.setInitialBalance(data.ledger_balance - currentAmount, unit);
+                    if (!err2) err2 = act.save();
+                    if (!err2) err2 = m_importer->getDocument()->sendMessage(i18nc("An information message", "The initial balance of '%1' has been set", act.getName()));
                 }
             }
         } catch (...) {
@@ -116,7 +115,7 @@ SKGError SKGImportPluginOfx::importFile()
 
         SKGImportPluginOfx::m_ofxInitialBalance.clear();
 
-        if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+        SKGENDTRANSACTION(m_importer->getDocument(),  err);
     }
     return err;
 }
@@ -334,76 +333,22 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
         if (!SKGImportPluginOfx::m_ofxError && data.invtransactiontype_valid == true) SKGImportPluginOfx::m_ofxError = ope.setMode(i18nc("Noun, the title of an item", "Title"));
         if (!SKGImportPluginOfx::m_ofxError && data.transactiontype_valid == true) {
             QString mode;
-            switch (data.transactiontype) {
-            case OFX_CREDIT: {
-                mode = i18nc("Noun, type of OFX transaction", "Credit");
-                break;
-            }
-            case OFX_DEBIT: {
-                mode = i18nc("Noun, type of OFX transaction", "Debit");
-                break;
-            }
-            case OFX_INT: {
-                mode = i18nc("Noun, type of OFX transaction", "Interest");
-                break;
-            }
-            case OFX_DIV: {
-                mode = i18nc("Noun, type of OFX transaction", "Dividend");
-                break;
-            }
-            case OFX_FEE: {
-                mode = i18nc("Noun, type of OFX transaction", "FI fee");
-                break;
-            }
-            case OFX_SRVCHG: {
-                mode = i18nc("Noun, type of OFX transaction", "Service charge");
-                break;
-            }
-            case OFX_DEP: {
-                mode = i18nc("Noun, type of OFX transaction", "Deposit");
-                break;
-            }
-            case OFX_ATM: {
-                mode = i18nc("Noun, type of OFX transaction", "ATM");
-                break;
-            }
-            case OFX_POS: {
-                mode = i18nc("Noun, type of OFX transaction", "Point of sale");
-                break;
-            }
-            case OFX_XFER: {
-                mode = i18nc("An operation mode", "Transfer");
-                break;
-            }
-            case OFX_CHECK: {
-                mode = i18nc("An operation mode", "Check");
-                break;
-            }
-            case OFX_PAYMENT: {
-                mode = i18nc("Noun, type of OFX transaction", "Electronic payment");
-                break;
-            }
-            case OFX_CASH: {
-                mode = i18nc("An operation mode", "Withdrawal");
-                break;
-            }
-            case OFX_DIRECTDEP: {
-                mode = i18nc("Noun, type of OFX transaction", "Deposit");
-                break;
-            }
-            case OFX_DIRECTDEBIT: {
-                mode = i18nc("An operation mode", "Direct debit");
-                break;
-            }
-            case OFX_REPEATPMT: {
-                mode = i18nc("Noun, type of OFX transaction", "Repeating payment");
-                break;
-            }
-            case OFX_OTHER: {
-                mode = "";
-                break;
-            }
-            }
+            if (data.transactiontype == OFX_CREDIT) mode = i18nc("Noun, type of OFX transaction", "Credit");
+            else if (data.transactiontype == OFX_DEBIT) mode = i18nc("Noun, type of OFX transaction", "Debit");
+            else if (data.transactiontype == OFX_INT) mode = i18nc("Noun, type of OFX transaction", "Interest");
+            else if (data.transactiontype == OFX_DIV) mode = i18nc("Noun, type of OFX transaction", "Dividend");
+            else if (data.transactiontype == OFX_FEE) mode = i18nc("Noun, type of OFX transaction", "FI fee");
+            else if (data.transactiontype == OFX_SRVCHG) mode = i18nc("Noun, type of OFX transaction", "Service charge");
+            else if (data.transactiontype == OFX_DEP) mode = i18nc("Noun, type of OFX transaction", "Deposit");
+            else if (data.transactiontype == OFX_ATM) mode = i18nc("Noun, type of OFX transaction", "ATM");
+            else if (data.transactiontype == OFX_POS) mode = i18nc("Noun, type of OFX transaction", "Point of sale");
+            else if (data.transactiontype == OFX_XFER) mode = i18nc("An operation mode", "Transfer");
+            else if (data.transactiontype == OFX_CHECK) mode = i18nc("An operation mode", "Check");
+            else if (data.transactiontype == OFX_PAYMENT) mode = i18nc("Noun, type of OFX transaction", "Electronic payment");
+            else if (data.transactiontype == OFX_CASH) mode = i18nc("An operation mode", "Withdrawal");
+            else if (data.transactiontype == OFX_DIRECTDEP) mode = i18nc("Noun, type of OFX transaction", "Deposit");
+            else if (data.transactiontype == OFX_REPEATPMT) mode = i18nc("Noun, type of OFX transaction", "Repeating payment");
+            else if (data.transactiontype == OFX_DIRECTDEBIT) mode = i18nc("An operation mode", "Direct debit");
 
             SKGImportPluginOfx::m_ofxError = ope.setMode(mode);
         }
