@@ -79,13 +79,13 @@ SKGError SKGImportPluginQif::importFile()
 
     //Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "QIF"), 3);
-    if (!err) {
+    IFOK(err) {
         //Create account if needed
         QDateTime now = QDateTime::currentDateTime();
         QString postFix = SKGServices::dateToSqlString(now);
 
         //Step 1 done
-        if (!err) err = m_importer->getDocument()->stepForward(1);
+        IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
         //Open file
         QFile file(m_importer->getLocalFileName());
@@ -138,13 +138,13 @@ SKGError SKGImportPluginQif::importFile()
             QString dateFormat = m_parameters["date_format"];
             if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates); //Automatic detection
             if (dateFormat.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
-            if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat));
+            IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat)))
 
             //Step 2 done
-            if (!err) err = m_importer->getDocument()->stepForward(2);
+            IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
             //Treat all lines
-            if (!err) {
+            IFOK(err) {
                 SKGAccountObject* account = NULL;
                 SKGOperationObject currentOperation;
                 SKGOperationObject payement;
@@ -189,8 +189,8 @@ SKGError SKGImportPluginQif::importFile()
                         if (account == NULL) {
                             SKGAccountObject defAccount;
                             err = m_importer->getDefaultAccount(defAccount);
-                            if (!err) err = defAccount.addOperation(currentOperation, true);
-                            if (!err) account = new SKGAccountObject(defAccount);
+                            IFOKDO(err, defAccount.addOperation(currentOperation, true))
+                            IFOK(err) account = new SKGAccountObject(defAccount);
                         }
 
                         if (!err && account) {
@@ -198,7 +198,7 @@ SKGError SKGImportPluginQif::importFile()
                                                    (QString::compare(line, "!type:ccard", Qt::CaseInsensitive) == 0 ? SKGAccountObject::CREDITCARD :
                                                     (QString::compare(line, "!type:invst", Qt::CaseInsensitive) == 0 ? SKGAccountObject::INVESTMENT :
                                                      (QString::compare(line, "!type:oth a", Qt::CaseInsensitive) == 0 ? SKGAccountObject::ASSETS : SKGAccountObject::OTHER))));
-                            if (!err) err = account->save();
+                            IFOKDO(err, account->save())
                         }
                     } else if (QString::compare(line, "!account", Qt::CaseInsensitive) == 0) {
                         inSection = 'A';
@@ -207,11 +207,11 @@ SKGError SKGImportPluginQif::importFile()
                     } else if (QString::compare(line, "!type:cat", Qt::CaseInsensitive) == 0) {
                         inSection = 'C';
                         openingbalancecreated = false;
-                        if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Categories found and imported"));
+                        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Categories found and imported")))
                     } else if (QString::compare(line, "!type:prices", Qt::CaseInsensitive) == 0) {
                         inSection = 'U';
                         openingbalancecreated = false;
-                        if (!err) err = m_importer->getDocument()->sendMessage(i18nc("An information message",  "Units prices found and imported"));
+                        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Units prices found and imported")))
                     } else if (line.at(0) == '!') {
                         inSection = '?';
                         openingbalancecreated = false;
@@ -239,17 +239,17 @@ SKGError SKGImportPluginQif::importFile()
                             //Check if the account already exist
                             SKGAccountObject account2;
                             err = SKGNamedObject::getObjectByName(m_importer->getDocument(), "account", val, account2);
-                            if (err) {
+                            IFKO(err) {
                                 //Create account
                                 SKGBankObject bank(m_importer->getDocument());
                                 err = bank.setName(i18nc("Noun",  "Bank for import %1", postFix));
                                 if (!err && bank.load().isFailed()) err = bank.save(false);
-                                if (!err) err = bank.addAccount(account2);
-                                if (!err) err = account2.setName(val);
+                                IFOKDO(err, bank.addAccount(account2))
+                                IFOKDO(err, account2.setName(val))
                                 if (!err && account2.load().isFailed()) err = account2.save(false);     //Save only
                             }
 
-                            if (!err) {
+                            IFOK(err) {
                                 delete account;
                                 account = new SKGAccountObject(account2);
                             }
@@ -312,36 +312,41 @@ SKGError SKGImportPluginQif::importFile()
                             */
                             //Operation creation
                             SKGUnitObject unit;
-                            double initBalance;
-                            if (!err) {
+                            IFOK(err) {
                                 if (account != NULL) {
                                     err = account->addOperation(currentOperation, true);
-                                    if (!openingbalancecreated) account->getInitialBalance(initBalance, unit);
+                                    if (!openingbalancecreated) {
+                                        double initBalance;
+                                        account->getInitialBalance(initBalance, unit);
+                                    }
                                 } else {
                                     SKGAccountObject defAccount;
                                     err = m_importer->getDefaultAccount(defAccount);
-                                    if (!err) err = defAccount.addOperation(currentOperation, true);
-                                    if (!openingbalancecreated) defAccount.getInitialBalance(initBalance, unit);
+                                    IFOKDO(err, defAccount.addOperation(currentOperation, true))
+                                    if (!openingbalancecreated) {
+                                        double initBalance;
+                                        defAccount.getInitialBalance(initBalance, unit);
+                                    }
                                 }
                                 currentOperationInitialized = true;
                             }
 
                             //Set date
                             currentOperationDate = SKGServices::stringToTime(SKGServices::dateToSqlString(val, dateFormat)).date();
-                            if (!err) err = currentOperation.setDate(currentOperationDate);
+                            IFOKDO(err, currentOperation.setDate(currentOperationDate))
 
                             //Set unit
-                            if (!err) {
+                            IFOK(err) {
                                 //Create unit if needed
                                 //If an initial balance is existing for the account then we use the unit else we look for the most appropriate unit
                                 if (!unit.exist()) err = m_importer->getDefaultUnit(unit, &currentOperationDate);
-                                if (!err)  err = currentOperation.setUnit(unit);
+                                IFOKDO(err, currentOperation.setUnit(unit))
                             }
 
-                            if (!err) currentOperation.save();
+                            IFOK(err) currentOperation.save();
 
                             //Create suboperation
-                            if (!err) err = currentOperation.addSubOperation(currentSubOperation);
+                            IFOKDO(err, currentOperation.addSubOperation(currentSubOperation))
                         } else if (op == 'Y') {
                             //Y     Security
                             if (!div) {
@@ -349,12 +354,12 @@ SKGError SKGImportPluginQif::importFile()
 
                                 SKGUnitObject unit(m_importer->getDocument());
                                 err = unit.setName(currentUnitForInvestment);
-                                if (!err) err = unit.setSymbol(currentUnitForInvestment);
+                                IFOKDO(err, unit.setSymbol(currentUnitForInvestment))
                                 if (unit.load().isFailed()) {
-                                    if (!err) err = unit.setType(investmentAccount ? SKGUnitObject::SHARE : SKGUnitObject::CURRENCY);
-                                    if (!err) err = unit.save(false);       //Save only
+                                    IFOKDO(err, unit.setType(investmentAccount ? SKGUnitObject::SHARE : SKGUnitObject::CURRENCY))
+                                    IFOKDO(err, unit.save(false))
                                 }
-                                if (!err) err = currentOperation.setUnit(unit);
+                                IFOKDO(err, currentOperation.setUnit(unit))
                             } else {
                                 //For dividend, if comment is empty, we set the security in comment
                                 if (currentOperation.getComment().isEmpty()) err = currentOperation.setComment(val);
@@ -368,7 +373,7 @@ SKGError SKGImportPluginQif::importFile()
                             if (subops.count()) {
                                 SKGSubOperationObject subpayement(subops.at(0));
                                 err = subpayement.setQuantity(subpayement.getQuantity() + quantity);
-                                if (!err) err = subpayement.save();
+                                IFOKDO(err, subpayement.save())
                             }
 
                             SKGSubOperationObject subcommission;
@@ -378,22 +383,24 @@ SKGError SKGImportPluginQif::importFile()
                                 else {
                                     SKGAccountObject defAccount;
                                     err = m_importer->getDefaultAccount(defAccount);
-                                    if (!err) err = defAccount.addOperation(payement, true);
+                                    IFOKDO(err, defAccount.addOperation(payement, true))
                                 }
-                                if (!err) err = payement.setDate(currentOperationDate);
-                                if (!err) {
+                                IFOKDO(err, payement.setDate(currentOperationDate))
+                                IFOK(err) {
                                     //If an initial balance is existing for the account then we use the unit else we look for the most appropriate unit
                                     SKGUnitObject unit;
-                                    double initBalance;
-                                    if (account && !openingbalancecreated) account->getInitialBalance(initBalance, unit);
+                                    if (account && !openingbalancecreated) {
+                                        double initBalance;
+                                        account->getInitialBalance(initBalance, unit);
+                                    }
                                     if (!unit.exist()) err = m_importer->getDefaultUnit(unit, &currentOperationDate);
-                                    if (!err)  err = payement.setUnit(unit);
+                                    IFOKDO(err, payement.setUnit(unit))
                                 }
-                                if (!err) err = payement.save();
+                                IFOKDO(err, payement.save())
                             }
-                            if (!err) err = payement.addSubOperation(subcommission);
-                            if (!err) err = subcommission.setQuantity(-quantity);
-                            if (!err) err = subcommission.save(false, false);     //Save only whitout reload
+                            IFOKDO(err, payement.addSubOperation(subcommission))
+                            IFOKDO(err, subcommission.setQuantity(-quantity))
+                            IFOKDO(err, subcommission.save(false, false))
                         } else if (op == 'I') {
                             //I     Price
                             currentUnitPrice = SKGServices::stringToDouble(val);
@@ -499,28 +506,30 @@ SKGError SKGImportPluginQif::importFile()
                                     else {
                                         SKGAccountObject defAccount;
                                         err = m_importer->getDefaultAccount(defAccount);
-                                        if (!err) err = defAccount.addOperation(payement, true);
+                                        IFOKDO(err, defAccount.addOperation(payement, true))
                                     }
-                                    if (!err) err = payement.setDate(currentOperationDate);
-                                    if (!err) {
+                                    IFOKDO(err, payement.setDate(currentOperationDate))
+                                    IFOK(err) {
                                         //Create unit if needed
                                         //If an initial balance is existing for the account then we use the unit else we look for the most appropriate unit
                                         SKGUnitObject unit;
-                                        double initBalance;
-                                        if (account && !openingbalancecreated) account->getInitialBalance(initBalance, unit);
+                                        if (account && !openingbalancecreated) {
+                                            double initBalance;
+                                            account->getInitialBalance(initBalance, unit);
+                                        }
                                         if (!unit.exist()) err = m_importer->getDefaultUnit(unit, &currentOperationDate);
-                                        if (!err)  err = payement.setUnit(unit);
+                                        IFOKDO(err, payement.setUnit(unit))
                                     }
-                                    if (!err) err = payement.save();  //Save only
-                                    if (!err) err = currentOperation.setGroupOperation(payement);
+                                    IFOKDO(err, payement.save())
+                                    IFOKDO(err, currentOperation.setGroupOperation(payement))
 
                                     SKGSubOperationObject subpayement;
-                                    if (!err) err = payement.addSubOperation(subpayement);
-                                    if (!err) err = subpayement.setQuantity(-previousQuantity);
-                                    if (!err) err = subpayement.save();
+                                    IFOKDO(err, payement.addSubOperation(subpayement))
+                                    IFOKDO(err, subpayement.setQuantity(-previousQuantity))
+                                    IFOKDO(err, subpayement.save())
                                 }
 
-                                if (!err) err = currentSubOperation.setQuantity(quantityFactor * SKGServices::stringToDouble(val));
+                                IFOKDO(err, currentSubOperation.setQuantity(quantityFactor * SKGServices::stringToDouble(val)))
                             }
                         } else if (op == 'T') {
                             //T     Amount
@@ -539,10 +548,10 @@ SKGError SKGImportPluginQif::importFile()
                                 err = currentSubOperation.setQuantity(vald);
 
                                 //save
-                                if (!err) err = currentSubOperation.save();
+                                IFOKDO(err, currentSubOperation.save())
 
                                 //Create suboperation
-                                if (!err) err = currentOperation.addSubOperation(currentSubOperation);
+                                IFOKDO(err, currentOperation.addSubOperation(currentSubOperation))
 
                                 latestSubCatMustBeRemoved = true;
                             }
@@ -553,14 +562,14 @@ SKGError SKGImportPluginQif::importFile()
                             val.remove("[auto]");
 
                             err = SKGPayeeObject::createPayee(m_importer->getDocument(), val, currentPayee);
-                            if (!err) err = currentOperation.setPayee(currentPayee);
+                            IFOKDO(err, currentOperation.setPayee(currentPayee))
                         } else if (op == 'A') {
                             //A      Address (up to 5 lines; 6th line is an optional message)
                             QString add = currentPayee.getAddress();
                             if (!add.isEmpty()) add += ' ';
                             add += val;
                             err = currentPayee.setAddress(add);
-                            if (!err) err = currentPayee.save();
+                            IFOKDO(err, currentPayee.save())
                         } else if (op == 'M') {
                             //M     Memo
                             //Set Memo
@@ -594,24 +603,24 @@ SKGError SKGImportPluginQif::importFile()
 
                                             SKGAccountObject newAccount(m_importer->getDocument());
                                             err = newAccount.setName(accountName);
-                                            if (!err) {
+                                            IFOK(err) {
                                                 if (newAccount.exist()) {
                                                     //Oups, the real account is existing and it is another one
                                                     err = newAccount.load();
 
                                                     //We move the operation in the right account
-                                                    if (!err) err = currentOperation.setParentAccount(newAccount);
-                                                    if (!err) err = currentOperation.save();
+                                                    IFOKDO(err, currentOperation.setParentAccount(newAccount))
+                                                    IFOKDO(err, currentOperation.save())
 
                                                     //We delete the previous account if empty
-                                                    if (!err) {
+                                                    IFOK(err) {
                                                         if (account->getNbOperation() == 0) err = account->remove();
                                                         delete account;
                                                         account = new SKGAccountObject(newAccount);
                                                     }
                                                 } else {
                                                     err = account->setName(accountName);
-                                                    if (!err) err = account->save();
+                                                    IFOKDO(err, account->save())
                                                 }
                                             }
                                         }
@@ -630,7 +639,7 @@ SKGError SKGImportPluginQif::importFile()
                                     val.replace(',', OBJECTSEPARATOR);
                                     val.replace(';', OBJECTSEPARATOR);
                                     err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), val, Category);
-                                    if (!err)  err = currentSubOperation.setCategory(Category);
+                                    IFOKDO(err, currentSubOperation.setCategory(Category))
                                 }
                             }
                         } else if (op == 'C') {
@@ -649,12 +658,12 @@ SKGError SKGImportPluginQif::importFile()
                                 if (!err && opening) {
                                     //Specific values for initial balance
                                     err = currentOperation.setStatus(SKGOperationObject::CHECKED);
-                                    if (!err) err = currentOperation.setAttribute("d_date", "0000-00-00");
+                                    IFOKDO(err, currentOperation.setAttribute("d_date", "0000-00-00"))
                                     openingbalancecreated = true;
                                 }
 
-                                if (!err) err = currentOperation.setImportID(hash.toHex());
-                                if (!err) err = currentOperation.save();
+                                IFOKDO(err, currentOperation.setImportID(hash.toHex()))
+                                IFOKDO(err, currentOperation.save())
                                 if (!latestSubCatMustBeRemoved && !err) err = currentSubOperation.save();
 
                                 //Create transfer is needed
@@ -662,8 +671,8 @@ SKGError SKGImportPluginQif::importFile()
                                     //Get origin op
                                     SKGOperationObject opOrigin(m_importer->getDocument(), currentOperation.getID());
                                     SKGAccountObject accountOrigin;
-                                    if (!err) err = opOrigin.getParentAccount(accountOrigin);
-                                    if (!err) {
+                                    IFOKDO(err, opOrigin.getParentAccount(accountOrigin))
+                                    IFOK(err) {
                                         //Is the created operation already existing as a transfer?
                                         double qua = SKGServices::stringToDouble(opOrigin.getAttribute("f_QUANTITY"));
                                         QString wc = "t_import_id='QIF TRANSFER-" % SKGServices::stringToSqlString(transferAccount) % "' AND t_ACCOUNT='" % SKGServices::stringToSqlString(accountOrigin.getName()) %
@@ -676,15 +685,15 @@ SKGError SKGImportPluginQif::importFile()
                                             //We have to merge them and we do not need to create the transfer
                                             SKGOperationObject firstOne(obs.at(0));
                                             err = opOrigin.setStatus(SKGOperationObject::NONE);  //To be sure we can delete it
-                                            if (!err) err = opOrigin.save();
-                                            if (!err) err = firstOne.mergeAttribute(opOrigin);
+                                            IFOKDO(err, opOrigin.save())
+                                            IFOKDO(err, firstOne.mergeAttribute(opOrigin))
 
                                             SKGObjectBase::SKGListSKGObjectBase list;
-                                            if (!err) err = currentOperation.getGroupedOperations(list);
+                                            IFOKDO(err, currentOperation.getGroupedOperations(list))
                                             foreach(const SKGObjectBase & o, list) {
                                                 SKGOperationObject op(o);
-                                                if (!err) err = op.setStatus(SKGOperationObject::NONE); //To be sure we can delete it
-                                                if (!err) err = op.remove(false, true);
+                                                IFOKDO(err, op.setStatus(SKGOperationObject::NONE))
+                                                IFOKDO(err, op.remove(false, true))
                                             }
                                         } else {
                                             //Create target account if needed
@@ -697,9 +706,9 @@ SKGError SKGImportPluginQif::importFile()
                                                 if (!accountTransfer.exist()) {
                                                     //The account is created in the same bank by default
                                                     SKGBankObject bankOrigin;
-                                                    if (!err) err = accountOrigin.getBank(bankOrigin);
-                                                    if (!err) err = accountTransfer.setBank(bankOrigin);
-                                                    if (!err) err = accountTransfer.save(false, true);
+                                                    IFOKDO(err, accountOrigin.getBank(bankOrigin))
+                                                    IFOKDO(err, accountTransfer.setBank(bankOrigin))
+                                                    IFOKDO(err, accountTransfer.save(false, true))
                                                 } else err = accountTransfer.load();
 
                                                 m_accountCache[transferAccount] = accountTransfer;
@@ -710,22 +719,22 @@ SKGError SKGImportPluginQif::importFile()
                                             opOrigin.getUnit(unit);
 
                                             SKGOperationObject opTransfer;
-                                            if (!err) err = accountTransfer.addOperation(opTransfer, true);
-                                            if (!err) err = opTransfer.setDate(opOrigin.getDate());
-                                            if (!err) err = opTransfer.setComment(opOrigin.getComment());
+                                            IFOKDO(err, accountTransfer.addOperation(opTransfer, true))
+                                            IFOKDO(err, opTransfer.setDate(opOrigin.getDate()))
+                                            IFOKDO(err, opTransfer.setComment(opOrigin.getComment()))
                                             SKGPayeeObject payeeObj;
                                             opTransfer.getPayee(payeeObj);
-                                            if (!err) err = opTransfer.setPayee(payeeObj);
-                                            if (!err) err = opTransfer.setStatus(opOrigin.getStatus());
-                                            if (!err) err = opTransfer.setUnit(unit);
-                                            if (!err) err = opTransfer.setImportID("QIF TRANSFER-" % accountOrigin.getName()); //To be able to identify it later
-                                            if (!err) err = opTransfer.setGroupOperation(opOrigin);
-                                            if (!err) err = opTransfer.save();
+                                            IFOKDO(err, opTransfer.setPayee(payeeObj))
+                                            IFOKDO(err, opTransfer.setStatus(opOrigin.getStatus()))
+                                            IFOKDO(err, opTransfer.setUnit(unit))
+                                            IFOKDO(err, opTransfer.setImportID("QIF TRANSFER-" % accountOrigin.getName()))
+                                            IFOKDO(err, opTransfer.setGroupOperation(opOrigin))
+                                            IFOKDO(err, opTransfer.save())
 
                                             SKGSubOperationObject subopTransfer;
-                                            if (!err) err = opTransfer.addSubOperation(subopTransfer);
-                                            if (!err) err = subopTransfer.setQuantity(-qua);
-                                            if (!err) err = subopTransfer.save();
+                                            IFOKDO(err, opTransfer.addSubOperation(subopTransfer))
+                                            IFOKDO(err, subopTransfer.setQuantity(-qua))
+                                            IFOKDO(err, subopTransfer.save())
                                         }
                                     }
                                 }
@@ -755,19 +764,19 @@ SKGError SKGImportPluginQif::importFile()
                     }
 
                     if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
                 delete account;
                 account = NULL;
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
                 //Lines treated
-                if (!err) err = m_importer->getDocument()->stepForward(3);
+                IFOKDO(err, m_importer->getDocument()->stepForward(3))
             }
         }
     }
-    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+    SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
     return err;
 }
@@ -794,11 +803,11 @@ SKGError SKGImportPluginQif::exportFile()
         if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
 
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "QIF"), 3);
-        if (!err) {
+        IFOK(err) {
 
             //Export categories
             SKGObjectBase::SKGListSKGObjectBase categories;
-            if (!err) err = m_importer->getDocument()->getObjects("v_category_display_tmp", "1=1 ORDER BY t_fullname, id", categories);
+            IFOKDO(err, m_importer->getDocument()->getObjects("v_category_display_tmp", "1=1 ORDER BY t_fullname, id", categories))
             int nbcat = categories.count();
             if (!err && nbcat) {
                 stream << "!Type:Cat\n";
@@ -815,21 +824,21 @@ SKGError SKGImportPluginQif::exportFile()
                         }
                         stream << "^" << endl;
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(1);
+            IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
             SKGServices::SKGUnitInfo primaryUnit = m_importer->getDocument()->getPrimaryUnit();
 
             //Get operations
             QString currentAccountName;
             SKGObjectBase::SKGListSKGObjectBase operations;
-            if (!err) err = m_importer->getDocument()->getObjects("v_operation_display_all", "t_template='N' ORDER BY t_ACCOUNT, d_date, id", operations);
+            IFOKDO(err, m_importer->getDocument()->getObjects("v_operation_display_all", "t_template='N' ORDER BY t_ACCOUNT, d_date, id", operations))
             int nb = operations.count();
-            if (!err) {
+            IFOK(err) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export operations"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     SKGOperationObject operation(operations.at(i));
@@ -944,7 +953,7 @@ SKGError SKGImportPluginQif::exportFile()
                     //Get sub operations
                     SKGObjectBase::SKGListSKGObjectBase suboperations;
                     err = operation.getSubOperations(suboperations);
-                    if (!err) {
+                    IFOK(err) {
                         int nb = suboperations.size();
                         QString category;
                         if (nb == 1) {
@@ -968,7 +977,7 @@ SKGError SKGImportPluginQif::exportFile()
 
                             SKGAccountObject transferAccount;
                             err = transfer.getParentAccount(transferAccount);
-                            if (!err) category.prepend('[' % transferAccount.getName() % ']');
+                            IFOK(err) category.prepend('[' % transferAccount.getName() % ']');
                         }
                         if (!category.isEmpty()) stream << 'L' << category << endl;
 
@@ -990,16 +999,16 @@ SKGError SKGImportPluginQif::exportFile()
                     }
 
                     stream << '^' << endl;
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(2);
+            IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
             //Export prices
             SKGObjectBase::SKGListSKGObjectBase unitvalues;
-            if (!err) err = m_importer->getDocument()->getObjects("v_unitvalue", "1=1 ORDER BY (select t_name from unit where v_unitvalue.rd_unit_id=unit.id), d_date", unitvalues);
+            IFOKDO(err, m_importer->getDocument()->getObjects("v_unitvalue", "1=1 ORDER BY (select t_name from unit where v_unitvalue.rd_unit_id=unit.id), d_date", unitvalues))
             nb = unitvalues.count();
             if (!err && nb) {
                 stream << "!Type:Prices\n";
@@ -1008,7 +1017,7 @@ SKGError SKGImportPluginQif::exportFile()
                     SKGUnitValueObject unitVal(unitvalues.at(i));
                     SKGUnitObject unit;
                     err = unitVal.getUnit(unit);
-                    if (!err) {
+                    IFOK(err) {
                         QStringList vals;
                         QString v = unit.getSymbol();
                         if (v.isEmpty()) v = unit.getName();
@@ -1018,14 +1027,14 @@ SKGError SKGImportPluginQif::exportFile()
 
                         stream << SKGServices::stringsToCsv(vals) << endl;
                     }
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
                 stream << "^" << endl;
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(3);
-            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+            IFOKDO(err, m_importer->getDocument()->stepForward(3))
+            SKGENDTRANSACTION(m_importer->getDocument(),  err);
         }
     }
 
