@@ -72,15 +72,15 @@ SKGError SKGImportPluginSkg::importFile()
     else {
         SKGDocumentBank docOrigin;
         err = docOrigin.load(lfile, m_parameters["password"]);
-        if (!err) {
+        IFOK(err) {
             QMap<QString, SKGObjectBase> mapOriginNew;
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "SKG"), 10);
 
             //Step 1 - units
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listUnits;
                 err = docOrigin.getObjects("v_unit", "1=1 order by rd_unit_id, t_type", listUnits);
-                if (!err) {
+                IFOK(err) {
                     int nb = listUnits.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -88,55 +88,54 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGUnitObject unit(unitOrigin.cloneInto(m_importer->getDocument()));
                         if (unit.load().isFailed()) {
                             //This unit does not exist yet
-                            if (!err) {
+                            IFOK(err) {
                                 SKGUnitObject::UnitType unitType = unitOrigin.getType();
                                 if (unitType == SKGUnitObject::PRIMARY || unitType == SKGUnitObject::SECONDARY) unitType = SKGUnitObject::CURRENCY;
                                 err = unit.setType(unitType);
                             }
-                            if (!err) {
+                            IFOK(err) {
                                 SKGUnitObject parentUnitOrigin;
                                 unitOrigin.getUnit(parentUnitOrigin);
 
                                 SKGUnitObject parentUnit(mapOriginNew[parentUnitOrigin.getUniqueID()]);
                                 if (parentUnit != unit) err = unit.setUnit(parentUnit);
                             }
-                            if (!err) err = unit.save(false);    //Save only
+                            IFOKDO(err, unit.save(false))
                         }
                         mapOriginNew[unitOrigin.getUniqueID()] = unit;
 
                         //Duplicate properties
-                        if (!err) err = copyParameters(unitOrigin, unit);
+                        IFOKDO(err, copyParameters(unitOrigin, unit))
 
                         //Unit values
                         SKGObjectBase::SKGListSKGObjectBase listUnitsValues;
-                        if (!err) err = unitOrigin.getUnitValues(listUnitsValues);
+                        IFOKDO(err, unitOrigin.getUnitValues(listUnitsValues))
                         int nb2 = listUnitsValues.count();
                         for (int j = 0; !err && j < nb2; ++j) {
                             SKGUnitValueObject unitValueOrigin(listUnitsValues.at(j));
 
                             SKGUnitValueObject  unitval;
                             err = unit.addUnitValue(unitval);
-                            if (!err) err = unitval.setDate(unitValueOrigin.getDate());
-                            if (!err) err = unitval.setQuantity(unitValueOrigin.getQuantity());
-                            if (!err) err = unitval.save(true);    //Save or update
+                            IFOKDO(err, unitval.setDate(unitValueOrigin.getDate()))
+                            IFOKDO(err, unitval.setQuantity(unitValueOrigin.getQuantity()))
+                            IFOKDO(err, unitval.save(true))
 
                             //Duplicate properties
-                            if (!err) err = copyParameters(unitValueOrigin, unitval);
+                            IFOKDO(err, copyParameters(unitValueOrigin, unitval))
                         }
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(1);
+            IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
             //Step 2 - bank and accounts
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listBanks;
                 err = docOrigin.getObjects("v_bank", "", listBanks);
-                if (!err) {
+                IFOK(err) {
                     int nb = listBanks.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -144,45 +143,44 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGBankObject bank(bankOrigin.cloneInto(m_importer->getDocument()));
                         if (bank.load().isFailed()) {
                             //This bank does not exist yet
-                            if (!err) err = bank.save(false);    //Save only
+                            IFOKDO(err, bank.save(false))
                         }
 
                         //Duplicate properties
-                        if (!err) err = copyParameters(bankOrigin, bank);
+                        IFOKDO(err, copyParameters(bankOrigin, bank))
 
                         //Accounts
                         SKGObjectBase::SKGListSKGObjectBase listAccounts;
-                        if (!err) err = bankOrigin.getAccounts(listAccounts);
+                        IFOKDO(err, bankOrigin.getAccounts(listAccounts))
                         int nb2 = listAccounts.count();
                         for (int j = 0; !err && j < nb2; ++j) {
                             SKGAccountObject accountOrigin(listAccounts.at(j));
                             SKGAccountObject account(accountOrigin.cloneInto(m_importer->getDocument()));
                             if (account.load().isFailed()) {
                                 //This account does not exist yet
-                                if (!err) err = account.setBank(bank);
+                                IFOKDO(err, account.setBank(bank))
                                 //Initial balance will be set on operation creation
-                                if (!err) err = account.save(false);    //Save only
+                                IFOKDO(err, account.save(false))
                             }
 
                             //Duplicate properties
-                            if (!err) err = copyParameters(accountOrigin, account);
+                            IFOKDO(err, copyParameters(accountOrigin, account))
 
                             mapOriginNew[accountOrigin.getUniqueID()] = account;
                         }
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(2);
+            IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
             //Step 3 - categories
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listCategories;
                 err = docOrigin.getObjects("v_category", "", listCategories);
-                if (!err) {
+                IFOK(err) {
                     int nb = listCategories.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -191,22 +189,21 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGCategoryObject cat;
                         err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), catOrigin.getFullName(), cat);
                         //Duplicate properties
-                        if (!err) err = copyParameters(catOrigin, cat);
+                        IFOKDO(err, copyParameters(catOrigin, cat))
                         mapOriginNew[catOrigin.getUniqueID()] = cat;
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(3);
+            IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
             //Step 4 - trackers
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listRefund;
                 err = docOrigin.getObjects("v_refund", "", listRefund);
-                if (!err) {
+                IFOK(err) {
                     int nb = listRefund.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import trackers"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -214,22 +211,21 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGTrackerObject trac(tracOrigin.cloneInto(m_importer->getDocument()));
                         err = trac.save();
                         //Duplicate properties
-                        if (!err) err = copyParameters(tracOrigin, trac);
+                        IFOKDO(err, copyParameters(tracOrigin, trac))
                         mapOriginNew[tracOrigin.getUniqueID()] = trac;
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(4);
+            IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
             //Step 5 - rules
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listRules;
                 err = docOrigin.getObjects("v_rule", "", listRules);
-                if (!err) {
+                IFOK(err) {
                     int nb = listRules.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import rules"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -237,21 +233,20 @@ SKGError SKGImportPluginSkg::importFile()
                         SKGRuleObject rul(rulOrigin.cloneInto(m_importer->getDocument()));
                         err = rul.save(false);  //Save only
                         //Duplicate properties
-                        if (!err) err = copyParameters(rulOrigin, rul);
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, copyParameters(rulOrigin, rul))
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(5);
+            IFOKDO(err, m_importer->getDocument()->stepForward(5))
 
             //Step 6 - payee
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listPayee;
                 err = docOrigin.getObjects("v_payee", "", listPayee);
-                if (!err) {
+                IFOK(err) {
                     int nb = listPayee.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -259,110 +254,108 @@ SKGError SKGImportPluginSkg::importFile()
 
                         SKGPayeeObject pay;
                         err = SKGPayeeObject::createPayee(m_importer->getDocument(), paylOrigin.getName(), pay);
-                        if (!err) err = pay.setAddress(paylOrigin.getAddress());
-                        if (!err) err = pay.save();
+                        IFOKDO(err, pay.setAddress(paylOrigin.getAddress()))
+                        IFOKDO(err, pay.save())
                         //Duplicate properties
-                        if (!err) err = copyParameters(paylOrigin, pay);
+                        IFOKDO(err, copyParameters(paylOrigin, pay))
                         mapOriginNew[paylOrigin.getUniqueID()] = pay;
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(6);
+            IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
             //Step 7 - operations and suboperation
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listOperations;
                 err = docOrigin.getObjects("v_operation", "", listOperations);
-                if (!err) {
+                IFOK(err) {
                     int nb = listOperations.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         SKGOperationObject operationOrigin(listOperations.at(i));
                         SKGOperationObject operation(operationOrigin.cloneInto(m_importer->getDocument()));
-                        if (!err) err = operation.setAttribute("r_recurrentoperation_id", "");
-                        if (!err) err = operation.setImported(true);
-                        if (!err) {
+                        IFOKDO(err, operation.setAttribute("r_recurrentoperation_id", ""))
+                        IFOKDO(err, operation.setImported(true))
+                        IFOK(err) {
                             QString importID = operationOrigin.getImportID();
                             if (importID.isEmpty()) importID = "SKG-" % SKGServices::intToString(operationOrigin.getID());
                             err = operation.setImportID(importID);
                         }
-                        if (!err) {
+                        IFOK(err) {
                             SKGAccountObject actOrig;
                             err = operationOrigin.getParentAccount(actOrig);
-                            if (!err) {
+                            IFOK(err) {
                                 SKGAccountObject act(mapOriginNew[actOrig.getUniqueID()]);
                                 act.setClosed(false); //To be sure that the modification is possible. NOT SAVED
-                                if (!err) err = operation.setParentAccount(act);
+                                IFOKDO(err, operation.setParentAccount(act))
                             }
                         }
-                        if (!err) {
+                        IFOK(err) {
                             SKGPayeeObject payeeOrig;
                             operationOrigin.getPayee(payeeOrig);     //Error not managed
-                            if (!err) err = operation.setPayee(SKGPayeeObject(mapOriginNew[payeeOrig.getUniqueID()]));
+                            IFOKDO(err, operation.setPayee(SKGPayeeObject(mapOriginNew[payeeOrig.getUniqueID()])))
                         }
-                        if (!err) {
+                        IFOK(err) {
                             SKGUnitObject unitOrig;
                             err = operationOrigin.getUnit(unitOrig);
-                            if (!err) err = operation.setUnit(SKGUnitObject(mapOriginNew[unitOrig.getUniqueID()]));
+                            IFOKDO(err, operation.setUnit(SKGUnitObject(mapOriginNew[unitOrig.getUniqueID()])))
                         }
-                        if (!err) {
+                        IFOK(err) {
                             SKGOperationObject groupOrig;
                             operationOrigin.getGroupOperation(groupOrig);
                             err = operation.setGroupOperation(SKGOperationObject(mapOriginNew[groupOrig.getUniqueID()]));
                         }
-                        if (!err) err = operation.save(false);    //Save only
+                        IFOKDO(err, operation.save(false))
 
                         mapOriginNew[operationOrigin.getUniqueID()] = operation;
 
                         //Duplicate properties
-                        if (!err) err = copyParameters(operationOrigin, operation);
+                        IFOKDO(err, copyParameters(operationOrigin, operation))
 
                         //Sub operation
                         SKGObjectBase::SKGListSKGObjectBase listSuboperations;
-                        if (!err) err = operationOrigin.getSubOperations(listSuboperations);
+                        IFOKDO(err, operationOrigin.getSubOperations(listSuboperations))
                         int nb2 = listSuboperations.count();
                         for (int j = 0; !err && j < nb2; ++j) {
                             SKGSubOperationObject subopOrigin(listSuboperations.at(j));
 
                             SKGSubOperationObject subop(subopOrigin.cloneInto(m_importer->getDocument()));
                             err = subop.setParentOperation(operation);
-                            if (!err) {
+                            IFOK(err) {
                                 SKGCategoryObject catOrig;
                                 subopOrigin.getCategory(catOrig);    //Error not managed
                                 err = subop.setCategory(SKGCategoryObject(mapOriginNew[catOrig.getUniqueID()]));
                             }
-                            if (!err) {
+                            IFOK(err) {
                                 SKGTrackerObject tracOrig;
                                 subopOrigin.getTracker(tracOrig);    //Error not managed
-                                if (!err) err = subop.setTracker(SKGTrackerObject(mapOriginNew[tracOrig.getUniqueID()]), true);
+                                IFOKDO(err, subop.setTracker(SKGTrackerObject(mapOriginNew[tracOrig.getUniqueID()]), true))
                             }
-                            if (!err) err = subop.save(false);    //Save only
+                            IFOKDO(err, subop.save(false))
 
                             //Duplicate properties
-                            if (!err) err = copyParameters(subopOrigin, subop);
+                            IFOKDO(err, copyParameters(subopOrigin, subop))
                         }
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
 
                         if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(7);
+            IFOKDO(err, m_importer->getDocument()->stepForward(7))
             /*                                      SKGObjectBase opWithThisHash;
                                                 if ( SKGObjectBase::getObject ( m_importer->getDocument(), "operation", "t_imported IN ('Y','P') AND t_import_id='"+QString ( hash.toHex() ) +'\'', opWithThisHash ).isSucceeded() )*/
 
             //Step 8 - recurrent
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase ListRecurrentOperations;
                 err = docOrigin.getObjects("v_recurrentoperation", "", ListRecurrentOperations);
-                if (!err) {
+                IFOK(err) {
                     int nb = ListRecurrentOperations.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled operations"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -371,26 +364,25 @@ SKGError SKGImportPluginSkg::importFile()
 
                         SKGOperationObject opOrig;
                         err = recuOrigin.getParentOperation(opOrig);
-                        if (!err) err = recu.setParentOperation(SKGOperationObject(mapOriginNew[opOrig.getUniqueID()]));
-                        if (!err) err = recu.save(false);    //Save only
+                        IFOKDO(err, recu.setParentOperation(SKGOperationObject(mapOriginNew[opOrig.getUniqueID()])))
+                        IFOKDO(err, recu.save(false))
 
                         //Duplicate properties
-                        if (!err) err = copyParameters(recuOrigin, recu);
+                        IFOKDO(err, copyParameters(recuOrigin, recu))
 
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(8);
+            IFOKDO(err, m_importer->getDocument()->stepForward(8))
 
             //Step 9 - nodes
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listNodes;
                 err = docOrigin.getObjects("v_node", "", listNodes);
-                if (!err) {
+                IFOK(err) {
                     int nb = listNodes.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import bookmarks"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -398,52 +390,49 @@ SKGError SKGImportPluginSkg::importFile()
 
                         SKGNodeObject node;
                         err = SKGNodeObject::createPathNode(m_importer->getDocument(), i18n("Imported bookmarks") % OBJECTSEPARATOR % nodeOrigin.getFullName(), node);
-                        if (!err) err = node.setData(nodeOrigin.getData());
-                        if (!err) err = node.setOrder(nodeOrigin.getOrder());
-                        if (!err) err = node.setAutoStart(nodeOrigin.isAutoStart());
-                        if (!err) err = node.save(true, false);
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, node.setData(nodeOrigin.getData()))
+                        IFOKDO(err, node.setOrder(nodeOrigin.getOrder()))
+                        IFOKDO(err, node.setAutoStart(nodeOrigin.isAutoStart()))
+                        IFOKDO(err, node.save(true, false))
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(9);
+            IFOKDO(err, m_importer->getDocument()->stepForward(9))
 
             //Step 10 - interest
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listInterests;
                 err = docOrigin.getObjects("v_interest", "", listInterests);
-                if (!err) {
+                IFOK(err) {
                     int nb = listInterests.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import interests"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         SKGInterestObject interestOrigin(listInterests.at(i));
                         SKGInterestObject interest(interestOrigin.cloneInto(m_importer->getDocument()));
-                        if (!err) {
+                        IFOK(err) {
                             SKGAccountObject actOrig;
                             err = interestOrigin.getAccount(actOrig);
-                            if (!err) err = interest.setAccount(SKGAccountObject(mapOriginNew[actOrig.getUniqueID()]));
+                            IFOKDO(err, interest.setAccount(SKGAccountObject(mapOriginNew[actOrig.getUniqueID()])))
                         }
-                        if (!err) err = interest.save();
+                        IFOKDO(err, interest.save())
 
                         //Duplicate properties
-                        if (!err) err = copyParameters(interestOrigin, interest);
+                        IFOKDO(err, copyParameters(interestOrigin, interest))
 
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true);
-                    else  m_importer->getDocument()->endTransaction(false);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
                 }
             }
-            if (!err) err = m_importer->getDocument()->stepForward(10);
+            IFOKDO(err, m_importer->getDocument()->stepForward(10))
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true);
-            else  m_importer->getDocument()->endTransaction(false);
+            SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
-            if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder("ANALYZE"))
         }
     }
     return err;
@@ -475,7 +464,7 @@ SKGError SKGImportPluginSkg::exportFile()
             err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
         } else {
             m_importer->getDocument()->getDatabase()->commit();
-            if (!err) err = SKGServices::copySqliteDatabase(fileDb, m_importer->getDocument()->getDatabase(), false);
+            IFOKDO(err, SKGServices::copySqliteDatabase(fileDb, m_importer->getDocument()->getDatabase(), false))
             m_importer->getDocument()->getDatabase()->transaction();
         }
 
@@ -491,11 +480,11 @@ SKGError SKGImportPluginSkg::exportFile()
         if (SKGServices::upload(tempFile, file)) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Creation file '%1' failed", file));
     } else {
         err = SKGServices::cryptFile(tempFile, file, "", true, m_importer->getDocument()->getDocumentHeader());
-        if (!err) {
+        IFOK(err) {
             SKGDocumentBank doc;
             err = doc.load(file);
-            if (!err) err = doc.removeAllTransactions();
-            if (!err) err = doc.saveAs(file, true);
+            IFOKDO(err, doc.removeAllTransactions())
+            IFOKDO(err, doc.saveAs(file, true))
         }
     }
 
@@ -510,14 +499,14 @@ SKGError SKGImportPluginSkg::copyParameters(const SKGObjectBase& iFrom, const SK
 
     SKGObjectBase::SKGListSKGObjectBase params;
     err = iFrom.getDocument()->getObjects("parameters", "t_uuid_parent='" % SKGServices::stringToSqlString(iFrom.getUniqueID()) % '\'', params);
-    if (!err) {
+    IFOK(err) {
         int nb = params.count();
-        SKGDocument* documentTarget = (SKGDocument*) iTo.getDocument();
+        SKGDocument* documentTarget = iTo.getDocument();
         for (int i = 0; !err && i < nb; ++i) {
             SKGObjectBase orig = params.at(i);
             SKGObjectBase param = orig.cloneInto(documentTarget);
             err = param.setAttribute("t_uuid_parent", iTo.getUniqueID());
-            if (!err) err = param.save(true, false);
+            IFOKDO(err, param.save(true, false))
         }
     }
     return err;
