@@ -93,10 +93,10 @@ SKGError SKGImportPluginXhb::importFile()
             QMap<QString, SKGPayeeObject> mapIdPayee;
 
             SKGUnitObject unit;
-            if (!err) err = m_importer->getDefaultUnit(unit);
+            IFOKDO(err, m_importer->getDefaultUnit(unit))
 
             //Step 1-Create accounts
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList accountList = docElem.elementsByTagName("account");
                 int nb = accountList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
@@ -108,34 +108,36 @@ SKGError SKGImportPluginXhb::importFile()
                     SKGBankObject bank(m_importer->getDocument());
                     QString bname = getAttribute(account,  "bankname");
                     if (bname.isEmpty()) bname = "HOMEBANK";
-                    if (!err) err = bank.setName(bname);
-                    if (!err) err = bank.save();
+                    IFOKDO(err, bank.setName(bname))
+                    IFOKDO(err, bank.save())
 
                     //Creation of the account
                     SKGAccountObject accountObj;
-                    if (!err) err = bank.addAccount(accountObj);
-                    if (!err) err = accountObj.setName(getAttribute(account,  "name"));
-                    if (!err) err = accountObj.setNumber(getAttribute(account,  "number"));
+                    IFOKDO(err, bank.addAccount(accountObj))
+                    IFOKDO(err, accountObj.setName(getAttribute(account,  "name")))
+                    IFOKDO(err, accountObj.setNumber(getAttribute(account,  "number")))
+                    IFOKDO(err, accountObj.setMinLimitAmount(SKGServices::stringToDouble(getAttribute(account,  "minimum"))))
+                    IFOKDO(err, accountObj.minLimitAmountEnabled(accountObj.getMinLimitAmount() != 0.0))
                     QString type = getAttribute(account,  "type");
-                    if (!err) err = accountObj.setType(type == "2" ? SKGAccountObject::WALLET : (type == "3" ? SKGAccountObject::ASSETS : (type == "4" ? SKGAccountObject::CREDITCARD : (type == "5" ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT))));
-                    if (!err) {
+                    IFOKDO(err, accountObj.setType(type == "2" ? SKGAccountObject::WALLET : (type == "3" ? SKGAccountObject::ASSETS : (type == "4" ? SKGAccountObject::CREDITCARD : (type == "5" ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT)))))
+                    IFOK(err) {
                         QString flags = getAttribute(account,  "flags");
                         err = accountObj.setClosed(flags == "2" ||  flags == "3");
                     }
-                    if (!err) err = accountObj.save();
-                    if (!err) err = accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "initial")), unit);
+                    IFOKDO(err, accountObj.save())
+                    IFOKDO(err, accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "initial")), unit))
 
                     mapIdAccount[getAttribute(account,  "key")] = accountObj;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(1);
+            IFOKDO(err, m_importer->getDocument()->stepForward(1))
 
             //Step 2-Get payees
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList partyList = docElem.elementsByTagName("pay");
                 int nb = partyList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
@@ -146,15 +148,15 @@ SKGError SKGImportPluginXhb::importFile()
                     err = SKGPayeeObject::createPayee(m_importer->getDocument(), getAttribute(party,  "name"), payeeObject);
                     mapIdPayee[getAttribute(party,  "key")] = payeeObject;
 
-                    if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(2);
+            IFOKDO(err, m_importer->getDocument()->stepForward(2))
 
             //Step 3-Create categories
-            if (!err) {
+            IFOK(err) {
                 QDomNodeList categoryList = docElem.elementsByTagName("cat");
                 int nb = categoryList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), 2 * nb);
@@ -166,19 +168,19 @@ SKGError SKGImportPluginXhb::importFile()
                         //Creation of the category
                         bool catCreated = false;
                         SKGCategoryObject catObj(m_importer->getDocument());
-                        QString parent = getAttribute(category,  "parent");
-                        if (parent == "0" && j == 0) {
-                            if (!err) err = catObj.setName(getAttribute(category,  "name"));
-                            if (!err) err = catObj.save();
+                        QString parent2 = getAttribute(category,  "parent");
+                        if (parent2 == "0" && j == 0) {
+                            IFOKDO(err, catObj.setName(getAttribute(category,  "name")))
+                            IFOKDO(err, catObj.save())
 
                             mapIdCategory[getAttribute(category,  "key")] = catObj;
                             catCreated = true;
 
-                        } else if (parent != "0" && j == 1) {
-                            SKGCategoryObject catParentObj = mapIdCategory[parent];
-                            if (!err) err = catObj.setName(getAttribute(category,  "name"));
-                            if (!err) err = catObj.setParentCategory(catParentObj);
-                            if (!err) err = catObj.save();
+                        } else if (parent2 != "0" && j == 1) {
+                            SKGCategoryObject catParentObj = mapIdCategory[parent2];
+                            IFOKDO(err, catObj.setName(getAttribute(category,  "name")))
+                            IFOKDO(err, catObj.setParentCategory(catParentObj))
+                            IFOKDO(err, catObj.save())
 
                             mapIdCategory[getAttribute(category,  "key")] = catObj;
                             catCreated = true;
@@ -193,25 +195,25 @@ SKGError SKGImportPluginXhb::importFile()
                                     SKGBudgetObject budget(m_importer->getDocument());
 
                                     int year = QDate::currentDate().year();
-                                    if (!err) err = budget.setCategory(catObj);
-                                    if (!err) err = budget.setYear(year);
-                                    if (!err) err = budget.setMonth(m);
-                                    if (!err) err = budget.setBudgetedAmount(SKGServices::stringToDouble(getAttribute(category,  'b' % SKGServices::intToString(b0.isEmpty() ? m : 0))));
-                                    if (!err) err = budget.save();
+                                    IFOKDO(err, budget.setCategory(catObj))
+                                    IFOKDO(err, budget.setYear(year))
+                                    IFOKDO(err, budget.setMonth(m))
+                                    IFOKDO(err, budget.setBudgetedAmount(SKGServices::stringToDouble(getAttribute(category,  'b' % SKGServices::intToString(b0.isEmpty() ? m : 0)))))
+                                    IFOKDO(err, budget.save())
                                 }
                             }
                         }
 
-                        if (!err) err = m_importer->getDocument()->stepForward(nb * j + i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(nb * j + i + 1))
                     }
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(3);
+            IFOKDO(err, m_importer->getDocument()->stepForward(3))
 
             //Step 4-Create transaction
-            if (!err) {
+            IFOK(err) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), 2);
                 for (int j = 1; !err && j <= 2; ++j) {
                     QDomNodeList transactionList = docElem.elementsByTagName(j == 1 ? "ope" : "fav");
@@ -242,25 +244,25 @@ SKGError SKGImportPluginXhb::importFile()
 
                             //Creation of the operation
                             SKGOperationObject opObj;
-                            if (!err) err = account.addOperation(opObj, true);
-                            if (!err) err = opObj.setDate(date);
-                            if (!err) err = opObj.setUnit(unit);
-                            if (!err) err = opObj.setPayee(payee);
-                            if (!err) err = opObj.setMode(mode);
+                            IFOKDO(err, account.addOperation(opObj, true))
+                            IFOKDO(err, opObj.setDate(date))
+                            IFOKDO(err, opObj.setUnit(unit))
+                            IFOKDO(err, opObj.setPayee(payee))
+                            IFOKDO(err, opObj.setMode(mode))
 
-                            if (!err) err = opObj.setComment(comment);
-                            if (!err) err = opObj.setTemplate(j == 2);
-                            if (!err) err = opObj.setImported(true);
-                            if (!err) err = opObj.setImportID("HXB-" % SKGServices::intToString(i));
-                            if (!err) err = opObj.setStatus(status);
-                            if (!err) err = opObj.save();
+                            IFOKDO(err, opObj.setComment(comment))
+                            IFOKDO(err, opObj.setTemplate(j == 2))
+                            IFOKDO(err, opObj.setImported(true))
+                            IFOKDO(err, opObj.setImportID("HXB-" % SKGServices::intToString(i)))
+                            IFOKDO(err, opObj.setStatus(status))
+                            IFOKDO(err, opObj.save())
 
                             SKGSubOperationObject subObj;
-                            if (!err) err = opObj.addSubOperation(subObj);
-                            if (!err) err = subObj.setCategory(category);
-                            if (!err) err = subObj.setComment(comment);
-                            if (!err) err = subObj.setQuantity(amount);
-                            if (!err) err = subObj.save();
+                            IFOKDO(err, opObj.addSubOperation(subObj))
+                            IFOKDO(err, subObj.setCategory(category))
+                            IFOKDO(err, subObj.setComment(comment))
+                            IFOKDO(err, subObj.setQuantity(amount))
+                            IFOKDO(err, subObj.save())
 
                             //Transfert
                             /*if(dst_account != idAccount && dst_account != "0") {
@@ -294,21 +296,21 @@ SKGError SKGImportPluginXhb::importFile()
                             if (j == 2) {
                                 //Creation of scheduled operation
                                 SKGRecurrentOperationObject recu;
-                                if (!err) err = opObj.addRecurrentOperation(recu);
+                                IFOKDO(err, opObj.addRecurrentOperation(recu))
                                 int limit = SKGServices::stringToInt(getAttribute(transaction,  "limit"));
-                                if (!err) err = recu.timeLimit(flags & (1 << 7));
-                                if (!err) err = recu.setTimeLimit(limit);
+                                IFOKDO(err, recu.timeLimit(flags & (1 << 7)))
+                                IFOKDO(err, recu.setTimeLimit(limit))
                                 int punit = SKGServices::stringToInt(getAttribute(transaction,  "unit"));
                                 int pstep = SKGServices::stringToInt(getAttribute(transaction,  "every"));
                                 SKGRecurrentOperationObject::PeriodUnit p = SKGRecurrentOperationObject::MONTH;
                                 if (punit == 0) p = SKGRecurrentOperationObject::DAY;
                                 else if (punit == 1) p = SKGRecurrentOperationObject::WEEK;
                                 else if (punit == 3) p = SKGRecurrentOperationObject::YEAR;
-                                if (!err) err = recu.setPeriodIncrement(pstep);
-                                if (!err) err = recu.setPeriodUnit(p);
-                                if (!err) err = recu.warnEnabled(flags & (1 << 5));
-                                if (!err) err = recu.autoWriteEnabled(flags & (1 << 2));
-                                if (!err) err = recu.save();
+                                IFOKDO(err, recu.setPeriodIncrement(pstep))
+                                IFOKDO(err, recu.setPeriodUnit(p))
+                                IFOKDO(err, recu.warnEnabled(flags & (1 << 5)))
+                                IFOKDO(err, recu.autoWriteEnabled(flags & (1 << 2)))
+                                IFOKDO(err, recu.save())
                                 //#define OF_VALID        (1<<0)
                                 //#define OF_INCOME       (1<<1)
                                 //#define OF_AUTO         (1<<2)
@@ -321,20 +323,20 @@ SKGError SKGImportPluginXhb::importFile()
                         }
 
                         if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
-                        if (!err) err = m_importer->getDocument()->stepForward(i + 1);
+                        IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
-                    if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
-                    if (!err) err = m_importer->getDocument()->stepForward(j);
+                    SKGENDTRANSACTION(m_importer->getDocument(),  err);
+                    IFOKDO(err, m_importer->getDocument()->stepForward(j))
                 }
 
-                if (!err) err = m_importer->getDocument()->endTransaction(true); m_importer->getDocument()->endTransaction(false);
+                SKGENDTRANSACTION(m_importer->getDocument(),  err);
             }
-            if (!err) err = m_importer->getDocument()->stepForward(4);
+            IFOKDO(err, m_importer->getDocument()->stepForward(4))
 
-            if (!err) err = m_importer->getDocument()->endTransaction(true); else  m_importer->getDocument()->endTransaction(false);
+            SKGENDTRANSACTION(m_importer->getDocument(),  err);
 
-            if (!err) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder("ANALYZE"))
         }
     }
 
