@@ -61,7 +61,7 @@ SKGError SKGImportPluginXml::exportFile()
     SKGError err;
     QDomDocument doc;
     err = SKGServices::copySqliteDatabaseToXml(m_importer->getDocument()->getDatabase(), doc);
-    if (!err) {
+    IFOK(err) {
         KSaveFile file(m_importer->getLocalFileName(false));
         if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
         else {
