@@ -110,7 +110,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(SKGDocument* iDocument)
     setMainWidget(m_label);
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
     connect(m_label, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 }
@@ -193,7 +193,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
             bool exist = false;
             SKGError err = doc->existObjects("account", "", exist);
-            if (!err) {
+            IFOK(err) {
                 QString html;
                 if (!exist) {
                     html = "<html><body>" % i18nc("Message, do not translate URL", "First, you have to create at least one account<br>from <a href=\"%1\">\"Bank and Account\"</a> page or <a href=\"%2\">import</a> operations.", "skg://Skrooge_bank_plugin", "skg://import_operation") % "</body></html>";
@@ -242,7 +242,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                     err = doc->executeSelectSqliteOrder(
                               QString("SELECT t_name, t_TYPENLS, t_UNIT, ") % (m_menuPastOperations && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT") % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
                               listTmp);
-                    if (!err) {
+                    IFOK(err) {
                         html += "<html><body><table>";
                         double sumTypeV1 = 0;
                         double sumV1 = 0;
