@@ -32,13 +32,13 @@ class SKGDocumentBank;
 class SKGBankPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGBankPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGBankPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -76,7 +76,7 @@ public:
      * @param iIndex the index of the widget
      * @return The dashboard widget of the plugin
      */
-    virtual SKGWidget* getDashboardWidget(int iIndex);
+    virtual SKGBoardWidget* getDashboardWidget(int iIndex);
 
     /**
      * The page widget of the plugin.
@@ -124,7 +124,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advice() const;
+    virtual SKGAdviceList advice(const QStringList& iIgnoredAdvice);
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
@@ -133,13 +133,13 @@ public:
      * @return an object managing the error. MUST return ERR_NOTIMPL if iAdviceIdentifier is not known
      *   @see SKGError
      */
-    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const;
+    virtual SKGError executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution);
 
 private Q_SLOTS:
-    void actionReconciliate();
+    void onReconciliate();
 
 private:
-    Q_DISABLE_COPY(SKGBankPlugin);
+    Q_DISABLE_COPY(SKGBankPlugin)
 
     SKGDocumentBank* m_currentBankDocument;
     KAction* m_reconciliateAction;
