@@ -78,7 +78,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
                 QDomDocument doc2("SKGML");
                 QDomElement root2 = doc2.createElement("parameters");
                 doc2.appendChild(root2);
-                root2.setAttribute("graphMode", SKGServices::intToString((int) SKGTableWithGraph::LINE));
+                root2.setAttribute("graphMode", SKGServices::intToString(static_cast<int>(SKGTableWithGraph::LINE)));
 
                 {
                     QDomDocument doc3("SKGML");
@@ -208,7 +208,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     ui.kWidgetSelector->setSelectedMode(0);
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 }
 
@@ -220,7 +220,7 @@ SKGBankPluginWidget::~SKGBankPluginWidget()
 bool SKGBankPluginWidget::eventFilter(QObject* object, QEvent* event)
 {
     if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = (QKeyEvent*) event;
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAccountCreatorAdd->isEnabled()) {
                 ui.kAccountCreatorAdd->click();
@@ -404,7 +404,7 @@ void SKGBankPluginWidget::onAccountCreatorModified()
                               (ui.kAmountEdit->valid() || ui.kAmountEdit->text().isEmpty() || ui.kAmountEdit->text() == NOUPDATE);
     bool activated = activatedForWallet &&
                      ui.kAccountCreatorBank->text().length() > 0;
-    bool wallet = ((SKGAccountObject::AccountType)(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt()) == SKGAccountObject::WALLET);
+    bool wallet = (static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt()) == SKGAccountObject::WALLET);
 
     int nbSelect = getNbSelectedObjects();
     ui.kAccountCreatorAdd->setEnabled(activated || (wallet && activatedForWallet));
@@ -439,15 +439,15 @@ void SKGBankPluginWidget::onAddAccountClicked()
         QString bankName = ui.kAccountCreatorBank->text();
         QString accountName = ui.kAccountCreatorAccount->text();
         QString name = bankName % '-' % accountName;
-        SKGAccountObject::AccountType accountType = (SKGAccountObject::AccountType)(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
+        SKGAccountObject::AccountType accountType = static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
         if (accountType == SKGAccountObject::WALLET) bankName = "";
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Creating an account", "Account creation '%1'", name), err);
 
             //Create bank object in case of missing
             SKGBankObject bankObj(getDocument());
-            if (!err) err = bankObj.setName(ui.kAccountCreatorBank->text());
-            if (!err) {
+            IFOKDO(err, bankObj.setName(ui.kAccountCreatorBank->text()))
+            IFOK(err) {
                 //Build icon name
                 QString icon = ui.kAccountCreatorIcon->currentText();
                 if (!QFile(icon).exists() && !icon.isEmpty()) {
@@ -459,33 +459,33 @@ void SKGBankPluginWidget::onAddAccountClicked()
                 }
                 err = bankObj.setIcon(icon);
             }
-            if (!err) err = bankObj.setNumber(ui.kAccountCreatorBankNumber->text());
+            IFOKDO(err, bankObj.setNumber(ui.kAccountCreatorBankNumber->text()))
 
-            if (!err) err = bankObj.save();
-            if (!err) err = bankObj.load();
+            IFOKDO(err, bankObj.save())
+            IFOKDO(err, bankObj.load())
 
             //Create account object in case of missing
-            if (!err) err = bankObj.addAccount(accountObj);
-            if (!err) err = accountObj.setName(accountName);
-            if (!err) err = accountObj.setAgencyNumber(ui.kAccountCreatorAgencyNumber->text());
-            if (!err) err = accountObj.setAgencyAddress(ui.kAccountCreatorAddress->text());
-            if (!err) err = accountObj.setComment(ui.kAccountCreatorComment->text());
-            if (!err) err = accountObj.setNumber(ui.kAccountCreatorNumber->text());
-            if (!err) err = accountObj.setType(accountType);
+            IFOKDO(err, bankObj.addAccount(accountObj))
+            IFOKDO(err, accountObj.setName(accountName))
+            IFOKDO(err, accountObj.setAgencyNumber(ui.kAccountCreatorAgencyNumber->text()))
+            IFOKDO(err, accountObj.setAgencyAddress(ui.kAccountCreatorAddress->text()))
+            IFOKDO(err, accountObj.setComment(ui.kAccountCreatorComment->text()))
+            IFOKDO(err, accountObj.setNumber(ui.kAccountCreatorNumber->text()))
+            IFOKDO(err, accountObj.setType(accountType))
 
-            if (!err) err = accountObj.maxLimitAmountEnabled(ui.kMaxLimit->isChecked());
-            if (!err) err = accountObj.setMaxLimitAmount(ui.kMaxLimitAmout->value());
+            IFOKDO(err, accountObj.maxLimitAmountEnabled(ui.kMaxLimit->isChecked()))
+            IFOKDO(err, accountObj.setMaxLimitAmount(ui.kMaxLimitAmout->value()))
 
-            if (!err) err = accountObj.minLimitAmountEnabled(ui.kMinLimit->isChecked());
-            if (!err) err = accountObj.setMinLimitAmount(ui.kMinLimitAmout->value());
+            IFOKDO(err, accountObj.minLimitAmountEnabled(ui.kMinLimit->isChecked()))
+            IFOKDO(err, accountObj.setMinLimitAmount(ui.kMinLimitAmout->value()))
 
-            if (!err) err = accountObj.save(false);
-            if (!err) err = setInitialBalanceFromEditor(accountObj);
-            if (!err) err = accountObj.save();
+            IFOKDO(err, accountObj.save(false))
+            IFOKDO(err, setInitialBalanceFromEditor(accountObj))
+            IFOKDO(err, accountObj.save())
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successfully created an account", "Account '%1' created", name));
             ui.kView->getView()->selectObject(accountObj.getUniqueID());
         } else err.addError(ERR_FAIL, i18nc("Error message : Could not create an account",  "Account creation failed"));
@@ -524,18 +524,18 @@ void SKGBankPluginWidget::onModifyAccountClicked()
         }
 
         QString bankName = ui.kAccountCreatorBank->text();
-        SKGAccountObject::AccountType accountType = (SKGAccountObject::AccountType)(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
+        SKGAccountObject::AccountType accountType = static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
         if (accountType == SKGAccountObject::WALLET) bankName = "";
 
         for (int i = 0; !err && i < nb; ++i) {
             SKGAccountObject accountObj(selection[i]);
             err = accountObj.setName(ui.kAccountCreatorAccount->text());
-            if (!err) err = accountObj.setNumber(ui.kAccountCreatorNumber->text());
-            if (!err) err = setInitialBalanceFromEditor(accountObj);
-            if (!err && ui.kAccountCreatorType->text() != NOUPDATE) err = accountObj.setType((SKGAccountObject::AccountType)(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt()));
-            if (!err) err = accountObj.setAgencyNumber(ui.kAccountCreatorAgencyNumber->text());
-            if (!err) err = accountObj.setAgencyAddress(ui.kAccountCreatorAddress->text());
-            if (!err) err = accountObj.setComment(ui.kAccountCreatorComment->text());
+            IFOKDO(err, accountObj.setNumber(ui.kAccountCreatorNumber->text()))
+            IFOKDO(err, setInitialBalanceFromEditor(accountObj))
+            if (!err && ui.kAccountCreatorType->text() != NOUPDATE) err = accountObj.setType(static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt()));
+            IFOKDO(err, accountObj.setAgencyNumber(ui.kAccountCreatorAgencyNumber->text()))
+            IFOKDO(err, accountObj.setAgencyAddress(ui.kAccountCreatorAddress->text()))
+            IFOKDO(err, accountObj.setComment(ui.kAccountCreatorComment->text()))
 
             if (!err && ui.kMaxLimit->checkState() != Qt::PartiallyChecked) err = accountObj.maxLimitAmountEnabled(ui.kMaxLimit->isChecked());
             if (!err && ui.kMaxLimitAmout->text() != NOUPDATE) err = accountObj.setMaxLimitAmount(ui.kMaxLimitAmout->value());
@@ -543,7 +543,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             if (!err && ui.kMinLimit->checkState() != Qt::PartiallyChecked) err = accountObj.minLimitAmountEnabled(ui.kMinLimit->isChecked());
             if (!err && ui.kMaxLimitAmout->text() != NOUPDATE) err = accountObj.setMinLimitAmount(ui.kMinLimitAmout->value());
 
-            if (!err) err = accountObj.save();
+            IFOKDO(err, accountObj.save())
 
             //Update bank
             SKGBankObject bankObj;
@@ -552,14 +552,14 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             } else {
                 if (SKGNamedObject::getObjectByName(getDocument(), "bank", bankName, bankObj).isSucceeded()) {
                     //The created bank already exist ==> update parent bank
-                    if (!err) err = accountObj.setBank(bankObj);
-                    if (!err) err = accountObj.save();
+                    IFOKDO(err, accountObj.setBank(bankObj))
+                    IFOKDO(err, accountObj.save())
                 } else {
                     //The bank does not exist
                     int code = KMessageBox::Yes;
                     SKGBankObject currentBank;
                     err = accountObj.getBank(currentBank);
-                    if (!err) {
+                    IFOK(err) {
                         SKGObjectBase::SKGListSKGObjectBase accounts;
                         err = currentBank.getAccounts(accounts);
                         if (!err && accounts.count() > 1) {
@@ -569,22 +569,22 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                         }
                     }
 
-                    if (!err) err = accountObj.getBank(bankObj);
+                    IFOKDO(err, accountObj.getBank(bankObj))
                     if (code == KMessageBox::Yes) {
                         //The bank does not exist ==> update this one
-                        if (!err) err = bankObj.setName(bankName);
+                        IFOKDO(err, bankObj.setName(bankName))
                     } else {
                         //The bank does not exist ==> create a new one
-                        if (!err) err = bankObj.resetID();
-                        if (!err) err = bankObj.setName(bankName);
-                        if (!err) err = bankObj.save();
-                        if (!err) err = accountObj.setBank(bankObj);
-                        if (!err) err = accountObj.save();
+                        IFOKDO(err, bankObj.resetID())
+                        IFOKDO(err, bankObj.setName(bankName))
+                        IFOKDO(err, bankObj.save())
+                        IFOKDO(err, accountObj.setBank(bankObj))
+                        IFOKDO(err, accountObj.save())
                     }
                 }
             }
             if (ui.kAccountCreatorIcon->text() != NOUPDATE) {
-                if (!err) {
+                IFOK(err) {
                     //Build icon name
                     QString icon = ui.kAccountCreatorIcon->currentText();
                     if (!QFile(icon).exists() && !icon.isEmpty()) {
@@ -596,20 +596,20 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                     err = bankObj.setIcon(icon);
                 }
             }
-            if (!err) err = bankObj.setNumber(ui.kAccountCreatorBankNumber->text());
-            if (!err) err = bankObj.save();
+            IFOKDO(err, bankObj.setNumber(ui.kAccountCreatorBankNumber->text()))
+            IFOKDO(err, bankObj.save())
 
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
 
         //Remove bank without account
-        if (!err) {
+        IFOK(err) {
             err = getDocument()->executeSqliteOrder("DELETE FROM bank WHERE NOT EXISTS(SELECT 1 FROM account WHERE account.rd_bank_id = bank.id)");
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successfully updated an account", "Account updated."));
+    IFOKDO(err, SKGError(0, i18nc("Successfully updated an account", "Account updated.")))
     else err.addError(ERR_FAIL, i18nc("Error message : Could not update an account",  "Update failed"));
     //Display error
     SKGMainPanel::displayErrorMessage(err);
@@ -748,12 +748,12 @@ void SKGBankPluginWidget::refreshInfoZone()
     }
 }
 
-QWidget* SKGBankPluginWidget::mainWidget() const
+QWidget* SKGBankPluginWidget::mainWidget()
 {
     return ui.kView->getView();
 }
 
-QList< QWidget* > SKGBankPluginWidget::printableWidgets() const
+QList< QWidget* > SKGBankPluginWidget::printableWidgets()
 {
     QList< QWidget* > output;
     output.push_back(mainWidget());
