@@ -75,14 +75,14 @@ public:
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() const;
+    virtual QWidget* mainWidget();
 
     /**
      * Get the printable widgets.
      * The default implementation returns the main widget.
      * @return the printable widgets.
      */
-    virtual QList<QWidget*> printableWidgets() const;
+    virtual QList<QWidget*> printableWidgets();
 
     /**
      * To know if this page contains an editor. MUST BE OVERWRITTEN
