@@ -35,7 +35,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit SKGBudgetDelegate(QObject* parent = 0, SKGDocument* iDoc = NULL);
+    explicit SKGBudgetDelegate(QObject* iParent = 0, SKGDocument* iDoc = NULL);
 
     /**
      * Default Destructor
