@@ -197,7 +197,7 @@ void SKGBudgetPlugin::onProcessRules()
         err = SKGBudgetRuleObject::processAllRules(m_currentBankDocument);
     }
     //status bar
-    if (!err) {
+    IFOK(err) {
         err = SKGError(0, i18nc("Successful message after an user action", "Budget rules processed"));
     } else err.addError(ERR_FAIL, i18nc("Error message", "Budget rules failed"));
 
