@@ -188,7 +188,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     this->installEventFilter(this);
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 }
 
@@ -201,7 +201,7 @@ SKGBudgetPluginWidget::~SKGBudgetPluginWidget()
 bool SKGBudgetPluginWidget::eventFilter(QObject* object, QEvent* event)
 {
     if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = (QKeyEvent*) event;
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAddBtn->isEnabled()) {
                 ui.kAddBtn->click();
@@ -259,7 +259,7 @@ QString SKGBudgetPluginWidget::getDefaultStateAttribute()
     return "SKGBUDGET_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGBudgetPluginWidget::mainWidget() const
+QWidget* SKGBudgetPluginWidget::mainWidget()
 {
     return ui.kView->getView();
 }
@@ -329,7 +329,7 @@ void SKGBudgetPluginWidget::onAddClicked()
             uniqueIDs.push_back(budgetRule.getUniqueID());
         }
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Budget rule created"));
             ui.kView->getView()->selectObjects(uniqueIDs);
         } else err.addError(ERR_FAIL, i18nc("Error message", "Budget rule creation failed"));
@@ -359,22 +359,22 @@ void SKGBudgetPluginWidget::onAddClicked()
                 }
             } else {
                 //Automatic creation
-                if (ui.kAutoBudgetCheck->isChecked()) err = SKGBudgetObject::createAutomaticBudget((SKGDocumentBank*) getDocument(),
+                if (ui.kAutoBudgetCheck->isChecked()) err = SKGBudgetObject::createAutomaticBudget(static_cast<SKGDocumentBank*>(getDocument()),
                             ui.kYearAuto->value(),
                             ui.kYearAutoBase->value(),
                             ui.kUseScheduledOperation->isChecked(),
                             ui.kRemovePrevious->isChecked());
-                if (!err) err = getDocument()->stepForward(1);
+                IFOKDO(err, getDocument()->stepForward(1))
 
-                if (!err) err = SKGBudgetObject::balanceBudget((SKGDocumentBank*) getDocument(),
-                                    ui.kYearAuto->value(), (ui.kBalancingMonthly->isChecked() ? 0 : -1),
-                                    ui.kBalancingAnnual->isChecked());
-                if (!err) err = getDocument()->stepForward(2);
+                IFOKDO(err, SKGBudgetObject::balanceBudget(static_cast<SKGDocumentBank*>(getDocument()),
+                        ui.kYearAuto->value(), (ui.kBalancingMonthly->isChecked() ? 0 : -1),
+                        ui.kBalancingAnnual->isChecked()));
+                IFOKDO(err, getDocument()->stepForward(2))
             }
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Budget created"));
             ui.kView->getView()->selectObjects(uniqueIDs);
         } else err.addError(ERR_FAIL, i18nc("Error message", "Budget creation failed"));
@@ -398,7 +398,7 @@ void SKGBudgetPluginWidget::onUpdateClicked()
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Budget rule updated"));
         } else err.addError(ERR_FAIL, i18nc("Error message",  "Budget rule update failed"));
     } else {
@@ -414,12 +414,12 @@ void SKGBudgetPluginWidget::onUpdateClicked()
                     err = updateBudget(budget);
                 }
 
-                if (!err) err = getDocument()->stepForward(i + 1);
+                IFOKDO(err, getDocument()->stepForward(i + 1))
             }
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Budget updated"));
         } else err.addError(ERR_FAIL, i18nc("Error message",  "Budget update failed"));
     }
@@ -437,9 +437,9 @@ SKGError SKGBudgetPluginWidget::updateBudget(SKGBudgetObject& iBudget, int iMont
 
     SKGCategoryObject cat;
     QString catName = ui.kCategoryEdit->text().trimmed();
-    if (!err) err = SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catName, cat, true);
-    if (!err) err = iBudget.setCategory(cat);
-    if (!err) err = iBudget.enableSubCategoriesInclusion(ui.kIncludingSubCategories->isChecked());
+    IFOKDO(err, SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catName, cat, true))
+    IFOKDO(err, iBudget.setCategory(cat))
+    IFOKDO(err, iBudget.enableSubCategoriesInclusion(ui.kIncludingSubCategories->isChecked()))
 
     double val = ui.kAmountEdit->value();
     //Is the sign forced ?
@@ -450,9 +450,9 @@ SKGError SKGBudgetPluginWidget::updateBudget(SKGBudgetObject& iBudget, int iMont
         //Are we able to find to sign with the category ?
         if (cat2.getAttribute("t_TYPEEXPENSE") == "-") val = -val;
     }
-    if (!err)  err = iBudget.setBudgetedAmount(val);
+    IFOKDO(err, iBudget.setBudgetedAmount(val))
 
-    if (!err) err = iBudget.save();
+    IFOKDO(err, iBudget.save())
     return err;
 }
 
@@ -461,26 +461,26 @@ SKGError SKGBudgetPluginWidget::updateBudgetRule(SKGBudgetRuleObject& iRule)
     SKGError err;
     SKGCategoryObject cat;
     QString catName = ui.kCategoryRule->text().trimmed();
-    if (!err) err = SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catName, cat, true);
+    IFOKDO(err, SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catName, cat, true))
     SKGCategoryObject catchange;
     QString catchangeName = ui.kCategoryTransfer->text().trimmed();
-    if (!err) err = SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catchangeName, catchange, true);
-    if (!err) err = iRule.enableCategoryCondition(ui.kCategoryCheck->isChecked());
-    if (!err) err = iRule.setBudgetCategory(cat);
-    if (!err) err = iRule.enableYearCondition(ui.kYearCheck->isChecked());
-    if (!err) err = iRule.setBudgetYear(ui.kYearRule->value());
-    if (!err) err = iRule.enableMonthCondition(ui.kMonthCheck->isChecked());
-    if (!err) err = iRule.setBudgetMonth(ui.kMonthRule->value());
-    if (!err) {
+    IFOKDO(err, SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catchangeName, catchange, true))
+    IFOKDO(err, iRule.enableCategoryCondition(ui.kCategoryCheck->isChecked()))
+    IFOKDO(err, iRule.setBudgetCategory(cat))
+    IFOKDO(err, iRule.enableYearCondition(ui.kYearCheck->isChecked()))
+    IFOKDO(err, iRule.setBudgetYear(ui.kYearRule->value()))
+    IFOKDO(err, iRule.enableMonthCondition(ui.kMonthCheck->isChecked()))
+    IFOKDO(err, iRule.setBudgetMonth(ui.kMonthRule->value()))
+    IFOK(err) {
         bool absolute = (ui.kUnitCmb->currentIndex() == 1);
         double val = ui.kAmountEdit2->value();
         if (!absolute) val = qMin(qMax(double(0), val), double(100));
         err = iRule.setQuantity(val, absolute);
     }
-    if (!err) err = iRule.setCondition((SKGBudgetRuleObject::Condition) ui.kConditionCmb->itemData(ui.kConditionCmb->currentIndex()).toInt());
-    if (!err) err = iRule.enableCategoryChange(ui.kCategoryTransferCheck->isChecked());
-    if (!err) err = iRule.setTransfer((SKGBudgetRuleObject::Mode) ui.kModeCmb->itemData(ui.kModeCmb->currentIndex()).toInt(), catchange);
-    if (!err) err = iRule.save();
+    IFOKDO(err, iRule.setCondition(static_cast<SKGBudgetRuleObject::Condition>(ui.kConditionCmb->itemData(ui.kConditionCmb->currentIndex()).toInt())))
+    IFOKDO(err, iRule.enableCategoryChange(ui.kCategoryTransferCheck->isChecked()))
+    IFOKDO(err, iRule.setTransfer(static_cast<SKGBudgetRuleObject::Mode>(ui.kModeCmb->itemData(ui.kModeCmb->currentIndex()).toInt()), catchange))
+    IFOKDO(err, iRule.save())
     return err;
 }
 
@@ -555,9 +555,9 @@ bool SKGBudgetPluginWidget::isEditor()
 void SKGBudgetPluginWidget::refreshInfoZone()
 {
     SKGTRACEIN(10, "SKGBudgetPluginWidget::refreshInfoZone");
-    KLocale* locale = KGlobal::locale();
+    KLocale* loc = KGlobal::locale();
     SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
-    if (doc && locale && ui.kWidgetSelector->getSelectedMode() != 2) {
+    if (doc && loc && ui.kWidgetSelector->getSelectedMode() != 2) {
         SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
         SKGServices::SKGUnitInfo secondary = doc->getSecondaryUnit();
         //Refresh info area with selection
