@@ -74,7 +74,7 @@ public:
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() const;
+    virtual QWidget* mainWidget();
 
     /**
      * To know if this page contains an editor. MUST BE OVERWRITTEN
