@@ -72,14 +72,14 @@ int SKGCalculatorPlugin::getNbDashboardWidgets()
 
 QString SKGCalculatorPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    if (iIndex == 0) return i18nc("The estimated amount of money earned through interests on a remunerated account", "Estimated interest");
-    return "";
+    Q_UNUSED(iIndex);
+    return i18nc("The estimated amount of money earned through interests on a remunerated account", "Estimated interest");
 }
 
 SKGBoardWidget* SKGCalculatorPlugin::getDashboardWidget(int iIndex)
 {
-    if (iIndex == 0) return new SKGInterestBoardWidget(m_currentBankDocument);
-    return NULL;
+    Q_UNUSED(iIndex);
+    return new SKGInterestBoardWidget(m_currentBankDocument);
 }
 
 SKGTabPage* SKGCalculatorPlugin::getWidget()
