@@ -98,7 +98,7 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     connect(ui.kDisplayAccountCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(onFilterChanged()), Qt::QueuedConnection);
     connect(ui.KYearEdit, SIGNAL(currentIndexChanged(int)), this, SLOT(onFilterChanged()) , Qt::QueuedConnection);
 
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 
     //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
@@ -118,7 +118,7 @@ SKGCalculatorPluginWidget::~SKGCalculatorPluginWidget()
 bool SKGCalculatorPluginWidget::eventFilter(QObject* object, QEvent* event)
 {
     if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = (QKeyEvent*) event;
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAdd->isEnabled()) {
                 ui.kAdd->click();
@@ -230,9 +230,9 @@ void SKGCalculatorPluginWidget::onSelectionChanged()
 
             ui.kDateEdit->setDate(interest.getDate());
             ui.kRateEdit->setValue(interest.getRate());
-            ui.kCreditValueDate->setCurrentIndex((int) interest.getIncomeValueDateMode());
-            ui.kDebitValueDate->setCurrentIndex((int) interest.getExpenditueValueDateMode());
-            ui.kMode->setCurrentIndex((int) interest.getInterestComputationMode());
+            ui.kCreditValueDate->setCurrentIndex(static_cast<int>(interest.getIncomeValueDateMode()));
+            ui.kDebitValueDate->setCurrentIndex(static_cast<int>(interest.getExpenditueValueDateMode()));
+            ui.kMode->setCurrentIndex(static_cast<int>(interest.getInterestComputationMode()));
         }
 
         Q_EMIT selectionChanged();
@@ -319,11 +319,11 @@ void SKGCalculatorPluginWidget::computeInterest()
     //Compute
     SKGAccountObject account(getDocument());
     SKGError err = account.setName(ui.kDisplayAccountCombo->currentText());
-    if (!err) err = account.load();
+    IFOKDO(err, account.load())
     QList<SKGAccountObject::SKGInterestItem> oInterestList;
     double oInterests = 0;
-    if (!err) err = account.getInterestItems(oInterestList, oInterests, SKGServices::stringToInt(ui.KYearEdit->text()));
-    if (!err) {
+    IFOKDO(err, account.getInterestItems(oInterestList, oInterests, SKGServices::stringToInt(ui.KYearEdit->text())))
+    IFOK(err) {
         //Refresh table
         ui.kInterestResultTable->setState(ui.kInterestResultTable->getState());
 
@@ -408,21 +408,21 @@ void SKGCalculatorPluginWidget::onAdd()
 
             //Get Parent account
             SKGAccountObject accountObj(getDocument());
-            if (!err) err = accountObj.setName(accountname);
-            if (!err) err = accountObj.load();
+            IFOKDO(err, accountObj.setName(accountname))
+            IFOKDO(err, accountObj.load())
 
             //Create interest object
-            if (!err) err = accountObj.addInterest(interestObj);
-            if (!err) err = interestObj.setDate(ui.kDateEdit->date());
-            if (!err) err = interestObj.setRate(ui.kRateEdit->value());
-            if (!err) err = interestObj.setIncomeValueDateMode((SKGInterestObject::ValueDateMode) ui.kCreditValueDate->currentIndex());
-            if (!err) err = interestObj.setExpenditueValueDateMode((SKGInterestObject::ValueDateMode) ui.kDebitValueDate->currentIndex());
-            if (!err) err = interestObj.setInterestComputationMode((SKGInterestObject::InterestMode) ui.kMode->currentIndex());
-            if (!err) err = interestObj.save();
+            IFOKDO(err, accountObj.addInterest(interestObj))
+            IFOKDO(err, interestObj.setDate(ui.kDateEdit->date()))
+            IFOKDO(err, interestObj.setRate(ui.kRateEdit->value()))
+            IFOKDO(err, interestObj.setIncomeValueDateMode(static_cast<SKGInterestObject::ValueDateMode>(ui.kCreditValueDate->currentIndex())))
+            IFOKDO(err, interestObj.setExpenditueValueDateMode(static_cast<SKGInterestObject::ValueDateMode>(ui.kDebitValueDate->currentIndex())))
+            IFOKDO(err, interestObj.setInterestComputationMode(static_cast<SKGInterestObject::InterestMode>(ui.kMode->currentIndex())))
+            IFOKDO(err, interestObj.save())
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("User defined parameters for computing interests were successfully created", "Interest parameter created"));
             ui.kInterestView->selectObject(interestObj.getUniqueID());
         } else err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be created",  "Interest parameter creation failed"));
@@ -440,8 +440,8 @@ void SKGCalculatorPluginWidget::onUpdate()
     //Get Parent account
     QString accountname = ui.kDisplayAccountCombo->currentText();
     SKGAccountObject accountObj(getDocument());
-    if (!err) err = accountObj.setName(accountname);
-    if (!err) err = accountObj.load();
+    IFOKDO(err, accountObj.setName(accountname))
+    IFOKDO(err, accountObj.load())
 
     SKGObjectBase::SKGListSKGObjectBase updatedInterest = getSelectedObjects();
     int nb = updatedInterest.count();
@@ -452,18 +452,18 @@ void SKGCalculatorPluginWidget::onUpdate()
         for (int i = 0; !err && i < nb; ++i) {
             interestObj = updatedInterest.at(i);
             if (nb == 1) {
-                if (!err) err = interestObj.setDate(ui.kDateEdit->date());
-                if (!err) err = interestObj.setRate(ui.kRateEdit->value());
+                IFOKDO(err, interestObj.setDate(ui.kDateEdit->date()))
+                IFOKDO(err, interestObj.setRate(ui.kRateEdit->value()))
             }
-            if (!err) err = interestObj.setIncomeValueDateMode((SKGInterestObject::ValueDateMode) ui.kCreditValueDate->currentIndex());
-            if (!err) err = interestObj.setExpenditueValueDateMode((SKGInterestObject::ValueDateMode) ui.kDebitValueDate->currentIndex());
-            if (!err) err = interestObj.setInterestComputationMode((SKGInterestObject::InterestMode) ui.kMode->currentIndex());
-            if (!err) err = interestObj.save();
+            IFOKDO(err, interestObj.setIncomeValueDateMode(static_cast<SKGInterestObject::ValueDateMode>(ui.kCreditValueDate->currentIndex())))
+            IFOKDO(err, interestObj.setExpenditueValueDateMode(static_cast<SKGInterestObject::ValueDateMode>(ui.kDebitValueDate->currentIndex())))
+            IFOKDO(err, interestObj.setInterestComputationMode(static_cast<SKGInterestObject::InterestMode>(ui.kMode->currentIndex())))
+            IFOKDO(err, interestObj.save())
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("User defined parameters for computing interests were successfully updated", "Interest parameter updated"));
+    IFOKDO(err, SKGError(0, i18nc("User defined parameters for computing interests were successfully updated", "Interest parameter updated")))
     else err.addError(ERR_FAIL, i18nc("Error message: User defined parameters for computing interests could not be updated",  "Interest parameter update failed"));
 
     //Display error
@@ -480,8 +480,8 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
     SKGTRACEIN(10, "SKGCalculatorPluginWidget::onAmortizationComputation");
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-    KLocale* locale = KGlobal::locale();
-    if (locale) {
+    KLocale* loc = KGlobal::locale();
+    if (loc) {
         //Get unit
         SKGServices::SKGUnitInfo unitInfo;
         unitInfo.Symbol = ui.kUnitEdit->text();
@@ -513,11 +513,11 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
             sumInterest += roundedInterest;
 
             //Add items
-            ui.kAmortizationTable->setItem(i, 0, new QTableWidgetItem(locale->formatMoney(amount, unitInfo.Symbol, unitInfo.NbDecimal)));
-            ui.kAmortizationTable->setItem(i, 1, new QTableWidgetItem(locale->formatMoney(principal, unitInfo.Symbol, unitInfo.NbDecimal)));
-            ui.kAmortizationTable->setItem(i, 2, new QTableWidgetItem(locale->formatMoney(roundedInterest, unitInfo.Symbol, unitInfo.NbDecimal)));
-            ui.kAmortizationTable->setItem(i, 3, new QTableWidgetItem(locale->formatMoney(insurance, unitInfo.Symbol, unitInfo.NbDecimal)));
-            ui.kAmortizationTable->setItem(i, 4, new QTableWidgetItem(locale->formatMoney(dueAmount, unitInfo.Symbol, unitInfo.NbDecimal)));
+            ui.kAmortizationTable->setItem(i, 0, new QTableWidgetItem(loc->formatMoney(amount, unitInfo.Symbol, unitInfo.NbDecimal)));
+            ui.kAmortizationTable->setItem(i, 1, new QTableWidgetItem(loc->formatMoney(principal, unitInfo.Symbol, unitInfo.NbDecimal)));
+            ui.kAmortizationTable->setItem(i, 2, new QTableWidgetItem(loc->formatMoney(roundedInterest, unitInfo.Symbol, unitInfo.NbDecimal)));
+            ui.kAmortizationTable->setItem(i, 3, new QTableWidgetItem(loc->formatMoney(insurance, unitInfo.Symbol, unitInfo.NbDecimal)));
+            ui.kAmortizationTable->setItem(i, 4, new QTableWidgetItem(loc->formatMoney(dueAmount, unitInfo.Symbol, unitInfo.NbDecimal)));
         }
 
         ui.kAmortizationResult->setText(i18n("Number of payments:	%1\n"
@@ -528,19 +528,19 @@ void SKGCalculatorPluginWidget::onAmortizationComputation()
                                              "Total insurance paid: 	%6\n"
                                              "Total paid: 		%7" ,
                                              SKGServices::intToString(numberPayments),
-                                             locale->formatMoney(periodicAmount, unitInfo.Symbol, unitInfo.NbDecimal),
-                                             locale->formatMoney(insurance, unitInfo.Symbol, unitInfo.NbDecimal),
-                                             locale->formatMoney(ui.kLoanEdit->value(), unitInfo.Symbol, unitInfo.NbDecimal),
-                                             locale->formatMoney(sumInterest, unitInfo.Symbol, unitInfo.NbDecimal),
-                                             locale->formatMoney(numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal),
-                                             locale->formatMoney(ui.kLoanEdit->value() + sumInterest + numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal)
+                                             loc->formatMoney(periodicAmount, unitInfo.Symbol, unitInfo.NbDecimal),
+                                             loc->formatMoney(insurance, unitInfo.Symbol, unitInfo.NbDecimal),
+                                             loc->formatMoney(ui.kLoanEdit->value(), unitInfo.Symbol, unitInfo.NbDecimal),
+                                             loc->formatMoney(sumInterest, unitInfo.Symbol, unitInfo.NbDecimal),
+                                             loc->formatMoney(numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal),
+                                             loc->formatMoney(ui.kLoanEdit->value() + sumInterest + numberPayments * insurance, unitInfo.Symbol, unitInfo.NbDecimal)
                                             ));
     }
 
     QApplication::restoreOverrideCursor();
 }
 
-QWidget* SKGCalculatorPluginWidget::zoomableWidget() const
+QWidget* SKGCalculatorPluginWidget::zoomableWidget()
 {
     if (ui.kWidgetSelector->getSelectedMode() == 0) return ui.kInterestView;
     else return ui.kAmortizationTable;
