@@ -96,8 +96,7 @@ QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
     SKGTRACEIN(1, "SKGCategoriesPlugin::getDashboardWidgetTitle");
     if (iIndex == 0) return i18nc("Report header",  "5 main categories of expenditure");
     else if (iIndex == 1) return i18nc("Report header",  "5 main variations");
-    else if (iIndex == 2) return i18nc("Report header",  "Budget");
-    return "";
+    return i18nc("Report header",  "Budget");
 }
 
 SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
@@ -127,11 +126,10 @@ SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
                                        getDashboardWidgetTitle(iIndex),
                                        KStandardDirs().findResource("data", "skrooge/html/default/categories_variations.html"),
                                        QStringList() << "v_operation_consolidated", true);
-    else if (iIndex == 2) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                     getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", "skrooge/html/default/budget_table.html"),
-                                     QStringList() << "v_budget", true);
-    return NULL;
+    return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                  getDashboardWidgetTitle(iIndex),
+                                  KStandardDirs().findResource("data", "skrooge/html/default/budget_table.html"),
+                                  QStringList() << "v_budget", true);
 }
 
 void SKGCategoriesPlugin::refresh()
@@ -198,7 +196,7 @@ void SKGCategoriesPlugin::importStandardCategories()
 
 
     //status
-    if (!err)  err = SKGError(0, i18nc("Successful message after an user action", "Standard categories imported."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Standard categories imported.")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Importing standard categories failed."));
 
     //Display error
@@ -328,7 +326,7 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
             if (pos != -1) categoriesUsed.push_back(cat.left(pos));
         }
 
-        if (!err) {
+        IFOK(err) {
             QString sql;
             if (categoriesUsed.count())  sql = "DELETE FROM category WHERE t_fullname NOT IN ('" % categoriesUsed.join("','") % "')";
             else sql = "DELETE FROM category";
@@ -337,7 +335,7 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Unused categories deleted"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Unused categories deleted")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Unused categories deletion failed"));
 
     //Display error
