@@ -50,7 +50,12 @@ K_PLUGIN_FACTORY(SKGImportExportPluginFactory, registerPlugin<SKGImportExportPlu
  */
 K_EXPORT_PLUGIN(SKGImportExportPluginFactory("skrooge_importexport", "skrooge_importexport"))
 
-SKGImportExportPlugin::SKGImportExportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_install(false)
+SKGImportExportPlugin::SKGImportExportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent),
+    m_importAction(NULL), m_importBackendAction(NULL), m_importCsvUnitAction(NULL), m_exportFileAction(NULL),
+    m_processingFoundTransfert(NULL), m_processingBank(NULL), m_processingAnonymize(NULL), m_validateImportedOperationsAction(NULL),
+    m_openNotValidatedAction(NULL), m_mergeImportedOperationAction(NULL), m_currentBankDocument(NULL),
+    m_install(false)
 {
     SKGTRACEIN(10, "SKGImportExportPlugin::SKGImportExportPlugin");
 }
@@ -370,12 +375,14 @@ SKGError SKGImportExportPlugin::importbackends()
                 delete dlg;
                 QApplication::restoreOverrideCursor();
 
-                if (rc != QDialog::Accepted) continue;
+                if (rc != QDialog::Accepted) {
+                    continue;
+                }
             }
 
             QString codec = m_currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
             if (codec.isEmpty()) codec = QTextCodec::codecForLocale()->name();
-            if (!err) err = m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec);
+            IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec))
 
             SKGImportExportManager imp1(m_currentBankDocument, KUrl("." % backends[i]));
             QMap<QString, QString> parameters = imp1.getImportParameters();
@@ -385,19 +392,19 @@ SKGError SKGImportExportPlugin::importbackends()
             imp1.setAutomaticApplyRules(skgimportexport_settings::apply_rules());
             imp1.setSinceLastImportDate(skgimportexport_settings::since_last_import());
             imp1.setCodec(codec);
-            if (!err) err = imp1.importFile();
-            if (!err) err = m_currentBankDocument->stepForward(i + 1);
+            IFOKDO(err, imp1.importFile())
+            IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
         }
 
         //Memorize the last download date
-        if (!err) err = m_currentBankDocument->setParameter("SKG_LAST_BACKEND_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd"));
+        IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_BACKEND_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd")))
     }
 
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 
     //Open last modified operations if setting activated
-    if (!err) openLastModifiedIfSetting();
+    IFOK(err) openLastModifiedIfSetting();
 
     return err;
 }
@@ -442,7 +449,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                 bool automatic_rule = skgimportexport_settings::apply_rules();
                 bool since_last = skgimportexport_settings::since_last_import();
 
-                if (!err) err = m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec);
+                IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_CODEC_USED_FOR_IMPORT", codec))
 
                 for (int i = 0; !err && i < nbFiles; ++i) {
                     //Get Filename
@@ -508,7 +515,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                         imp1.setImportParameters(parameters);
                     }
 
-                    if (!err) err = imp1.importFile();
+                    IFOKDO(err, imp1.importFile())
                     if (err && err.getReturnCode() == ERR_ENCRYPTION) {
                         QString pwd;
                         QString additionalMessage;
@@ -531,7 +538,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                                 parameters["password"] = pwd;
                                 imp1.setImportParameters(parameters);
                                 err = imp1.importFile();
-                                if (err) {
+                                IFKO(err) {
                                     if (err.getReturnCode() == ERR_ENCRYPTION) {
                                         additionalMessage = i18nc("The user did not provide the correct password", "<b>Wrong password.</b>\n");
                                     } else {
@@ -550,13 +557,13 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                         err.addError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName.prettyUrl()));
                     }
 
-                    if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                    IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                 }
             }
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18np("%1 file successfully imported.", "%1 files successfully imported.", nbFiles));
         }
 
@@ -573,7 +580,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
         }
 
         //Open last modified operations if setting activated
-        if (!err) openLastModifiedIfSetting();
+        IFOK(err) openLastModifiedIfSetting();
     }
 }
 
@@ -597,7 +604,7 @@ void SKGImportExportPlugin::exportFile()
 
         {
             SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Export"), err);
-            if (!err) {
+            IFOK(err) {
                 SKGImportExportManager imp1(m_currentBankDocument, fileName);
                 imp1.setCodec(lastCodecUsed);
                 err = imp1.exportFile();
@@ -605,7 +612,7 @@ void SKGImportExportPlugin::exportFile()
         }
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "File '%1' successfully exported.", fileName));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "File '%1' successfully exported.", fileName)))
         else err.addError(ERR_FAIL, i18nc("Error message", "Export of '%1' failed", fileName));
 
         //Display error
@@ -624,7 +631,7 @@ void SKGImportExportPlugin::anonymize()
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("An anonymized document is a document where all private data has been removed", "Document anonymized."));
+        IFOKDO(err, SKGError(0, i18nc("An anonymized document is a document where all private data has been removed", "Document anonymized.")))
 
         //Display error
         SKGMainPanel::displayErrorMessage(err);
@@ -639,14 +646,14 @@ void SKGImportExportPlugin::findTransfers()
         int NbOperationsMerged = 0;
         {
             SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Find and group transfers"), err);
-            if (!err) {
+            IFOK(err) {
                 SKGImportExportManager imp1(m_currentBankDocument);
                 err = imp1.findAndGroupTransfers(NbOperationsMerged);
             }
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             if (NbOperationsMerged) err = SKGError(0, i18np("Document successfully processed. %1 transfer created.",
                                                        "Document successfully processed. %1 transfers created.", NbOperationsMerged));
             else err = m_currentBankDocument->sendMessage(i18nc("Information message", "No transfers found"));
@@ -666,21 +673,21 @@ void SKGImportExportPlugin::cleanBanks()
     SKGTRACEINRC(10, "SKGImportExportPlugin::cleanBanks", err);
     {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Clean bank's imports"), err);
-        if (!err) {
+        IFOK(err) {
             SKGImportExportManager imp1(m_currentBankDocument);
             err = imp1.cleanBankImport();
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Document successfully cleaned."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Document successfully cleaned.")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Clean failed."));
 
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 
     //Open last modified operations if setting activated
-    if (!err) openLastModifiedIfSetting();
+    IFOK(err) openLastModifiedIfSetting();
 }
 
 void SKGImportExportPlugin::validateImportedOperations()
@@ -697,15 +704,15 @@ void SKGImportExportPlugin::validateImportedOperations()
                 SKGOperationObject op(selection[i]);
                 if (op.getAttribute("t_imported") == "P") {
                     err = op.setImported(true);
-                    if (!err) err = op.save();
+                    IFOKDO(err, op.save())
                 }
-                if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
             }
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Imported operations validated."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Imported operations validated.")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
 
     //Display error
@@ -745,14 +752,14 @@ void SKGImportExportPlugin::mergeImportedOperation()
                 } else {
                     SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Merge imported operations"), err);
                     err = opManual.mergeAttribute(opImported);
-                    if (err) err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
+                    IFKO(err) err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
                 }
             }
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Imported operations merged."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Imported operations merged.")))
 
     //Display error
     SKGMainPanel::displayErrorMessage(err);
@@ -781,7 +788,7 @@ void SKGImportExportPlugin::validateAllOperations()
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Message for successful user action", "Operations validated."));
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Operations validated.")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Validation failed"));
 
     //Display error
@@ -877,40 +884,40 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                 //Get account
                 SKGAccountObject act(m_currentBankDocument);
                 err = act.setName(listAccounts.at(iSolution));
-                if (!err) err = act.load();
+                IFOKDO(err, act.load())
 
                 //Get unit
                 SKGUnitObject unit(m_currentBankDocument);
-                if (!err) err = unit.setName(m_currentBankDocument->getPrimaryUnit().Name);
-                if (!err) err = unit.load();
+                IFOKDO(err, unit.setName(m_currentBankDocument->getPrimaryUnit().Name))
+                IFOKDO(err, unit.load())
 
                 //Add operation
                 SKGOperationObject op;
-                if (!err) err = act.addOperation(op);
-                if (!err) err = op.setDate(date);
-                if (!err) err = op.setUnit(unit);
+                IFOKDO(err, act.addOperation(op))
+                IFOKDO(err, op.setDate(date))
+                IFOKDO(err, op.setUnit(unit))
 
                 if (!payee.isEmpty()) {
                     //Get payee
                     SKGPayeeObject pa;
-                    if (!err) err = SKGPayeeObject::createPayee(m_currentBankDocument, payee, pa, true);
-                    if (!err) err = op.setPayee(pa);
+                    IFOKDO(err, SKGPayeeObject::createPayee(m_currentBankDocument, payee, pa, true))
+                    IFOKDO(err, op.setPayee(pa))
                 }
-                if (!err) {
+                IFOK(err) {
                     int pos1 = fileName.indexOf("{");
                     int pos2 = fileName.indexOf("}");
                     if (pos1 != -1 && pos2 > pos1) err = op.setImportID("KR-" % fileName.mid(pos1 + 1, pos2 - pos1 - 1));
                 }
-                if (!err) err = op.save();
+                IFOKDO(err, op.save())
 
                 //Add suboperation
                 SKGSubOperationObject sop;
-                if (!err) err = op.addSubOperation(sop);
-                if (!err) err = sop.setQuantity(-amount);
-                if (!err) err = sop.save();
+                IFOKDO(err, op.addSubOperation(sop))
+                IFOKDO(err, sop.setQuantity(-amount))
+                IFOKDO(err, sop.save())
 
                 //Finalize the importation
-                if (!err) {
+                IFOK(err) {
                     bool automatic_validation = skgimportexport_settings::automatic_validation();
                     bool automatic_rule = skgimportexport_settings::apply_rules();
                     bool since_last = skgimportexport_settings::since_last_import();
@@ -927,7 +934,7 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
             }
 
             //status bar
-            if (!err) {
+            IFOK(err) {
                 err = SKGError(0, i18nc("Message for successful user action", "Operations imported."));
                 QFile::remove(fileName);
             } else err.addError(ERR_FAIL, i18nc("Error message", "Import failed"));
