@@ -85,7 +85,7 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     addAction(m_menuSuboperation);
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
 SKGOperationBoardWidget::~SKGOperationBoardWidget()
@@ -183,7 +183,7 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                                % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''")
                                % " group by d_DATEMONTH, t_TYPEEXPENSE",
                                listTmp);
-            if (!err) {
+            IFOK(err) {
                 double income_previous_month = 0;
                 double expense_previous_month = 0;
                 double income_month = 0;
