@@ -56,7 +56,11 @@ K_PLUGIN_FACTORY(SKGOperationPluginFactory, registerPlugin<SKGOperationPlugin>()
  */
 K_EXPORT_PLUGIN(SKGOperationPluginFactory("skrooge_operation", "skrooge_operation"))
 
-SKGOperationPlugin::SKGOperationPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGOperationPlugin::SKGOperationPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent),
+    m_duplicateAction(NULL), m_createTemplateAction(NULL), m_switchToPointedAction(NULL), m_openHighLights(NULL), m_openLastModified(NULL),
+    m_openSuboperations(NULL), m_openDuplicate(NULL), m_groupOperation(NULL), m_ungroupOperation(NULL), m_mergeOperationAction(NULL),
+    m_open(NULL), m_currentBankDocument(NULL)
 {
     SKGTRACEIN(10, "SKGOperationPlugin::SKGOperationPlugin");
 }
@@ -276,18 +280,16 @@ int SKGOperationPlugin::getNbDashboardWidgets()
 QString SKGOperationPlugin::getDashboardWidgetTitle(int iIndex)
 {
     if (iIndex == 0) return i18nc("Noun, the title of a section", "Income && Expenditure");
-    else if (iIndex == 1) return i18nc("Noun, the title of a section", "Highlighted operations");
-    return "";
+    return i18nc("Noun, the title of a section", "Highlighted operations");
 }
 
 SKGBoardWidget* SKGOperationPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGOperationBoardWidget(m_currentBankDocument);
-    else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                     getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", "skrooge/html/default/highlighted_operations.html"),
-                                     QStringList() << "operation");
-    return NULL;
+    return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                  getDashboardWidgetTitle(iIndex),
+                                  KStandardDirs().findResource("data", "skrooge/html/default/highlighted_operations.html"),
+                                  QStringList() << "operation");
 }
 
 SKGTabPage* SKGOperationPlugin::getWidget()
@@ -364,19 +366,19 @@ void SKGOperationPlugin::onGroupOperation()
         if (nb >= 2) {
             SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Group operations"), err, nb);
             SKGOperationObject main(selection.at(0));
-            if (!err) err = m_currentBankDocument->stepForward(1);
+            IFOKDO(err, m_currentBankDocument->stepForward(1))
             for (int i = 1; !err && i < nb; ++i) {
                 SKGOperationObject operationObj(selection.at(i));
-                if (!err) err = operationObj.setGroupOperation(main);
-                if (!err) err = operationObj.save();
-                if (!err) err = main.load();
+                IFOKDO(err, operationObj.setGroupOperation(main))
+                IFOKDO(err, operationObj.save())
+                IFOKDO(err, main.load())
 
-                if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
             }
         }
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Operations grouped."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operations grouped.")))
         else err.addError(ERR_FAIL, i18nc("Error message",  "Group creation failed"));
 
         //Display error
@@ -396,15 +398,15 @@ void SKGOperationPlugin::onUngroupOperation()
             SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Ungroup operation"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
                 SKGOperationObject operationObj(selection.at(i));
-                if (!err) err = operationObj.setGroupOperation(operationObj);
-                if (!err) err = operationObj.save();
+                IFOKDO(err, operationObj.setGroupOperation(operationObj))
+                IFOKDO(err, operationObj.save())
 
-                if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
             }
         }
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Operation ungrouped."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation ungrouped.")))
         else err.addError(ERR_FAIL, i18nc("Error message",  "Group deletion failed"));
 
         //Display error
@@ -424,15 +426,15 @@ void SKGOperationPlugin::onSwitchToPointed()
             SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Switch to pointed"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
                 SKGOperationObject operationObj(selection.at(i));
-                if (!err) err = operationObj.setStatus(operationObj.getStatus() != SKGOperationObject::POINTED ? SKGOperationObject::POINTED : SKGOperationObject::NONE);
-                if (!err) err = operationObj.save();
+                IFOKDO(err, operationObj.setStatus(operationObj.getStatus() != SKGOperationObject::POINTED ? SKGOperationObject::POINTED : SKGOperationObject::NONE))
+                IFOKDO(err, operationObj.save())
 
-                if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
             }
         }
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Operation pointed."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation pointed.")))
         else err.addError(ERR_FAIL, i18nc("Error message",  "Switch failed"));
 
         //Display error
@@ -454,15 +456,15 @@ void SKGOperationPlugin::onDuplicate()
             for (int i = 0; !err && i < nb; ++i) {
                 SKGOperationObject operationObj(selection.at(i));
                 SKGOperationObject dup;
-                if (!err) err = operationObj.duplicate(dup);
-                if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                IFOKDO(err, operationObj.duplicate(dup))
+                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
 
                 listUUID.push_back(dup.getUniqueID());
             }
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Operation duplicated."));
             SKGOperationPluginWidget* w = qobject_cast<SKGOperationPluginWidget*>(SKGMainPanel::getMainPanel()->currentPage());
             if (w) w->getTableView()->selectObjects(listUUID, true);
@@ -487,15 +489,15 @@ void SKGOperationPlugin::onCreateTemplate()
             for (int i = 0; !err && i < nb; ++i) {
                 SKGOperationObject operationObj(selection.at(i));
                 SKGOperationObject dup;
-                if (!err) err = operationObj.duplicate(dup , QDate::currentDate(), true);
-                if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                IFOKDO(err, operationObj.duplicate(dup , QDate::currentDate(), true))
+                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
 
                 listUUID.push_back(dup.getUniqueID());
             }
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Template created."));
             SKGOperationPluginWidget* w = qobject_cast<SKGOperationPluginWidget*>(SKGMainPanel::getMainPanel()->currentPage());
             if (w) {
@@ -1020,7 +1022,7 @@ void SKGOperationPlugin::onRemoveGroupWithOneOperation()
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Message for successful user action", "Remove groups done."));
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Remove groups done.")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Remove groups failed"));
 
     //Display error
@@ -1038,7 +1040,7 @@ void SKGOperationPlugin::onAlignComment()
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Message for successful user action", "Comments aligned."));
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Comments aligned.")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Comments alignment failed"));
 
     //Display error
@@ -1064,7 +1066,7 @@ void SKGOperationPlugin::onMergeSubOperations()
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Operations merged."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operations merged.")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
 
     //Display error
