@@ -45,6 +45,7 @@
 #include <QMap>
 #include <QtCore/qfile.h>
 #include <qtablewidget.h>
+#include <QScriptEngine>
 
 SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument), m_lastFastEditionOperationFound(0), m_showClosedAccounts(false),
@@ -190,7 +191,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
     m_tableDelegate->addParameterValue("total", '0');
     ui.kSubOperationsTable->setItemDelegate(m_tableDelegate);
     ui.kSubOperationsTable->setTextElideMode(Qt::ElideMiddle);
-    connect(ui.kSubOperationsTable, SIGNAL(removeSelectedItems()), this, SLOT(onRemoveSubOperation()));
+    connect(ui.kSubOperationsTable, SIGNAL(removeLine(int)), this, SLOT(onRemoveSubOperation(int)));
 
     ui.kTargetAccountEdit->hide();
     ui.kTargetAccountLabel->hide();
@@ -221,9 +222,9 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
 
     m_frozenLogo = KStandardDirs::locate("icon", QString::fromLatin1("hicolor/16x16/actions/skrooge_freeze.png"));
 
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 
-    connect(ui.kUnitEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
+    connect(ui.kUnitEdit, SIGNAL(editTextChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
     connect(ui.kAmountEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
     connect(ui.kAmountSharesEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
     connect(ui.kCommissionEdit, SIGNAL(textChanged(QString)), this, SLOT(onOperationCreatorModified()), Qt::QueuedConnection);
@@ -320,7 +321,7 @@ bool SKGOperationPluginWidget::eventFilter(QObject* object, QEvent* event)
             }
         }
     } else if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = (QKeyEvent*) event;
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAddOperationBtn->isEnabled()) {
                 ui.kAddOperationBtn->click();
@@ -562,7 +563,6 @@ void SKGOperationPluginWidget::onUpdateOperationClicked()
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGOperationPluginWidget::onUpdateOperationClicked", err);
-    bool confirmed = true;
     //Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
@@ -573,10 +573,8 @@ void SKGOperationPluginWidget::onUpdateOperationClicked()
     }
 
     //status bar
-    if (!err) {
-        if (confirmed) err = SKGError(0, i18nc("Successful message after an user action", "Operation updated"));
-        else err = SKGError(0, i18nc("Successful message after an user action", "Operation canceled"));
-    } else err.addError(ERR_FAIL, i18nc("Error message",  "Operation update failed"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation canceled")))
+    else err.addError(ERR_FAIL, i18nc("Error message",  "Operation update failed"));
 
     //Display error
     SKGMainPanel::displayErrorMessage(err);
@@ -603,7 +601,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
         SKGOperationObject operationObj = SKGOperationObject(obj.getDocument(), obj.getID());
 
         SKGObjectBase::SKGListSKGObjectBase gops;
-        if (!err) err = operationObj.getGroupedOperations(gops);
+        IFOKDO(err, operationObj.getGroupedOperations(gops))
         if (gops.count() == 2 &&  ui.kWidgetSelector->getSelectedMode() < 2) {
             getDocument()->sendMessage(i18nc("An information message", "You modified one part of a transfer"), SKGDocument::Warning);
         }
@@ -620,7 +618,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
             } else {
                 //It's a real operation, we take the first one
                 SKGObjectBase::SKGListSKGObjectBase subOps;
-                if (!err) err = operationObj.getSubOperations(subOps);
+                IFOKDO(err, operationObj.getSubOperations(subOps))
                 nbSubop = subOps.count();
                 if (nbSubop) subOp = subOps[0];
             }
@@ -629,14 +627,14 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
             if (!err && trackerName != NOUPDATE) {
                 SKGTrackerObject tracker;
                 err = SKGTrackerObject::createTracker(static_cast<SKGDocumentBank*>(getDocument()), trackerName, tracker, true);
-                if (!err) err = subOp.setTracker(tracker);
+                IFOKDO(err, subOp.setTracker(tracker))
             }
 
             SKGCategoryObject cat;
             QString catName = ui.kCategoryEdit->text().trimmed();
             if (!err &&  catName != NOUPDATE) {
                 err = SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catName, cat, true);
-                if (!err) err = subOp.setCategory(cat);
+                IFOKDO(err, subOp.setCategory(cat))
             } else {
                 //Get current category to be able to find the appropriate sign
                 subOp.getCategory(cat);
@@ -663,7 +661,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
             if (!err && ui.kCommentEdit->text() != NOUPDATE) {
                 err = subOp.setComment(ui.kCommentEdit->text());
             }
-            if (!err) err = subOp.save();
+            IFOKDO(err, subOp.save())
         } else if (ui.kWidgetSelector->getSelectedMode() == 1) {
             //Case split
             int nbsubop = ui.kSubOperationsTable->rowCount();
@@ -691,27 +689,27 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
                 }
 
                 //Create sub operation object
-                if (!err) {
+                IFOK(err) {
                     SKGCategoryObject cat;
                     err = SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catName, cat, true);
-                    if (!err) err = subOperation.setCategory(cat);
+                    IFOKDO(err, subOperation.setCategory(cat))
                 }
-                if (!err) {
+                IFOK(err) {
                     SKGTrackerObject tracker;
                     err = SKGTrackerObject::createTracker(static_cast<SKGDocumentBank*>(getDocument()), trackerName, tracker, true);
-                    if (!err) err = subOperation.setTracker(tracker);
+                    IFOKDO(err, subOperation.setTracker(tracker))
                 }
-                if (!err) err = subOperation.setComment(comment);
-                if (!err) err = subOperation.setQuantity(val);
+                IFOKDO(err, subOperation.setComment(comment))
+                IFOKDO(err, subOperation.setQuantity(val))
                 if (formula.startsWith(QLatin1String("=")) && !err) err = subOperation.setFormula(formula);
-                if (!err) err = subOperation.save();
+                IFOKDO(err, subOperation.save())
 
                 //The sub operation created or updated mustn't be removed
                 listIdSubOp.push_back(subOperation.getID());
             }
 
             //Remove useless subop
-            if (!err) {
+            IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase subOps;
                 err = operationObj.getSubOperations(subOps);
                 int nbsubop = subOps.count();
@@ -730,8 +728,8 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
 
             SKGSubOperationObject subOperation;
             SKGObjectBase::SKGListSKGObjectBase subOps;
-            if (!err) err = operationObj.getSubOperations(subOps);
-            if (!err) {
+            IFOKDO(err, operationObj.getSubOperations(subOps))
+            IFOK(err) {
                 subOperation = subOps.at(0);
 
                 double oldQuantity = subOperation.getQuantity();
@@ -755,41 +753,42 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
             if (!err && trackerName != NOUPDATE) {
                 SKGTrackerObject tracker;
                 err = SKGTrackerObject::createTracker(static_cast<SKGDocumentBank*>(getDocument()), trackerName, tracker, true);
-                if (!err) err = subOperation.setTracker(tracker);
+                IFOKDO(err, subOperation.setTracker(tracker))
             }
 
             SKGCategoryObject cat;
             QString catName = ui.kCategoryEdit->text().trimmed();
             if (!err &&  catName != NOUPDATE) {
                 err = SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), ui.kCategoryEdit->text(), cat, true);
-                if (!err) err = subOperation.setCategory(cat);
+                IFOKDO(err, subOperation.setCategory(cat))
             }
-            if (!err) err = subOperation.setComment(operationObj.getComment());
-            if (!err) err = subOperation.save();
+            IFOKDO(err, subOperation.setComment(operationObj.getComment()))
+            IFOKDO(err, subOperation.save())
 
             //Get account
             SKGAccountObject accountObj2(getDocument());
-            if (!err) err = accountObj2.setName(ui.kTargetAccountEdit->currentText());
-            if (!err) err = accountObj2.load();
+            IFOKDO(err, accountObj2.setName(ui.kTargetAccountEdit->currentText()))
+            IFOKDO(err, accountObj2.load())
 
             //Check unit of target account
             SKGUnitObject unit;
-            if (!err) err = operationObj.getUnit(unit);
+            IFOKDO(err, operationObj.getUnit(unit))
 
             //Correction bug 2299303 vvv
             SKGUnitObject unitTargetAccount;
-            if (!err) err = accountObj2.getUnit(unitTargetAccount);
+            IFOKDO(err, accountObj2.getUnit(unitTargetAccount))
             if (!err && unitTargetAccount.exist() && unit != unitTargetAccount) {
                 //The unit of the operation is not compliant with the unit of the target account
                 //We ask to the user if he wants to continue or convert into the target account
                 bool ok = false;
                 QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+                int decimal = qMax(unit.getNumberDecimal(), unitTargetAccount.getNumberDecimal());
                 double newval = KInputDialog::getDouble(i18nc("Question", "Confirmation"),
                                                         i18nc("Question", "The operation's unit is not compatible with the target account.\n"
                                                                 "Click Cancel if you want to continue anyway; "
                                                                 "otherwise, enter the value in the target account's unit (%1):", unitTargetAccount.getSymbol()),
-                                                        SKGUnitObject::convert(operationQuantity, unit, unitTargetAccount),
-                                                        -DBL_MAX, DBL_MAX, 2, &ok, this);
+                                                        SKGUnitObject::convert(operationQuantity, unit, unitTargetAccount, ui.kDateEdit->date()),
+                                                        -DBL_MAX, DBL_MAX, 0.1, decimal, &ok, this);
                 QApplication::restoreOverrideCursor();
                 if (ok) {
                     operationQuantity = newval;
@@ -801,59 +800,59 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
             //create transferred operation
             SKGOperationObject operation2;
 
-            if (!err) {
+            IFOK(err) {
                 if (gops.count() == 2) {
                     operation2 = (obj == SKGOperationObject(gops.at(0)) ? gops.at(1) : gops.at(0));
                     if (ui.kTargetAccountEdit->text() != NOUPDATE) err = operation2.setParentAccount(accountObj2);
                 } else err = accountObj2.addOperation(operation2);
             }
             if (nb == 1) {
-                if (!err) err = operation2.setMode(ui.kTypeEdit->currentText());
+                IFOKDO(err, operation2.setMode(ui.kTypeEdit->currentText()))
                 QString payeeName = ui.kPayeeEdit->currentText();
                 if (!err &&  payeeName != NOUPDATE) {
                     SKGPayeeObject payeeObject;
                     err = SKGPayeeObject::createPayee(static_cast<SKGDocumentBank*>(getDocument()), payeeName, payeeObject, true);
-                    if (!err) err = operation2.setPayee(payeeObject);
+                    IFOKDO(err, operation2.setPayee(payeeObject))
                 }
-                if (!err) err = operation2.setNumber(SKGServices::stringToInt(ui.kNumberEdit->text()));
-                if (!err) err = operation2.setComment(ui.kCommentEdit->text());
-                if (!err) err = operation2.setDate(ui.kDateEdit->date());
-                if (!err) err = operation2.setUnit(unit);
+                IFOKDO(err, operation2.setNumber(SKGServices::stringToInt(ui.kNumberEdit->text())))
+                IFOKDO(err, operation2.setComment(ui.kCommentEdit->text()))
+                IFOKDO(err, operation2.setDate(ui.kDateEdit->date()))
+                IFOKDO(err, operation2.setUnit(unit))
 
             } else {
-                if (!err) err = operation2.setMode(operationObj.getMode());
-                if (!err) err = operation2.setAttribute("r_payee_id", operationObj.getAttribute("r_payee_id"));
-                if (!err) err = operation2.setNumber(operationObj.getNumber());
-                if (!err) err = operation2.setComment(operationObj.getComment());
-                if (!err) err = operation2.setDate(operationObj.getDate());
-                if (!err) err = operation2.setUnit(unit);
+                IFOKDO(err, operation2.setMode(operationObj.getMode()))
+                IFOKDO(err, operation2.setAttribute("r_payee_id", operationObj.getAttribute("r_payee_id")))
+                IFOKDO(err, operation2.setNumber(operationObj.getNumber()))
+                IFOKDO(err, operation2.setComment(operationObj.getComment()))
+                IFOKDO(err, operation2.setDate(operationObj.getDate()))
+                IFOKDO(err, operation2.setUnit(unit))
             }
-            if (!err) err = operation2.setGroupOperation(operationObj);
-            if (!err) err = operationObj.load();
-            if (!err) err = operation2.setTemplate(isTemplateMode());
-            if (!err) err = operation2.save();
+            IFOKDO(err, operation2.setGroupOperation(operationObj))
+            IFOKDO(err, operationObj.load())
+            IFOKDO(err, operation2.setTemplate(isTemplateMode()))
+            IFOKDO(err, operation2.save())
 
             //Create sub operation object
             SKGSubOperationObject subOperation2;
 
             SKGObjectBase::SKGListSKGObjectBase subops;
-            if (!err) err = operation2.getSubOperations(subops);
-            if (!err) {
+            IFOKDO(err, operation2.getSubOperations(subops))
+            IFOK(err) {
                 if (subops.count()) subOperation2 = subops.at(0);
                 else err = operation2.addSubOperation(subOperation2);
             }
-            if (!err) err = subOperation2.setQuantity(operationQuantity);
-            if (!err) err = subOperation2.setCategory(cat);
-            if (!err) err = subOperation2.setComment(operationObj.getComment());
-            if (!err) err = subOperation2.save();
+            IFOKDO(err, subOperation2.setQuantity(operationQuantity))
+            IFOKDO(err, subOperation2.setCategory(cat))
+            IFOKDO(err, subOperation2.setComment(operationObj.getComment()))
+            IFOKDO(err, subOperation2.save())
 
         }
 
-        if (!err) err = operationObj.setTemplate(isTemplateMode());
+        IFOKDO(err, operationObj.setTemplate(isTemplateMode()))
 
         if (nb == 1) {
-            if (!err) err = operationObj.setNumber(SKGServices::stringToInt(ui.kNumberEdit->text()));
-            if (!err) err = operationObj.setDate(ui.kDateEdit->date());
+            IFOKDO(err, operationObj.setNumber(SKGServices::stringToInt(ui.kNumberEdit->text())))
+            IFOKDO(err, operationObj.setDate(ui.kDateEdit->date()))
         }
         if (!err && ui.kCommentEdit->text() != NOUPDATE) {
             if (obj.getTable() != "v_operation_consolidated")  err = operationObj.setComment(ui.kCommentEdit->text());
@@ -862,23 +861,23 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
         if (!err && ui.kAccountEdit->text() != NOUPDATE) {
             SKGAccountObject account(getDocument());
             err = account.setName(ui.kAccountEdit->text());
-            if (!err) err = account.load();
-            if (!err) err = operationObj.setParentAccount(account);
+            IFOKDO(err, account.load())
+            IFOKDO(err, operationObj.setParentAccount(account))
         }
         if (!err && ui.kTypeEdit->text() != NOUPDATE) err = operationObj.setMode(ui.kTypeEdit->text());
         QString payeeName = ui.kPayeeEdit->currentText();
         if (!err &&  payeeName != NOUPDATE) {
             SKGPayeeObject payeeObject;
             err = SKGPayeeObject::createPayee(static_cast<SKGDocumentBank*>(getDocument()), payeeName, payeeObject, true);
-            if (!err) err = operationObj.setPayee(payeeObject);
+            IFOKDO(err, operationObj.setPayee(payeeObject))
         }
         if (!err && ui.kUnitEdit->text() != NOUPDATE) {
             //Correction bug 282983 vvv
             //Check unit of target account
             SKGAccountObject account;
-            if (!err) err = operationObj.getParentAccount(account);
+            IFOKDO(err, operationObj.getParentAccount(account))
             SKGUnitObject unitTargetAccount;
-            if (!err) err = account.getUnit(unitTargetAccount);
+            IFOKDO(err, account.getUnit(unitTargetAccount))
 
             SKGUnitObject unit = ui.kUnitEdit->getUnit();
 
@@ -889,12 +888,13 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
                     //We ask to the user if he wants to continue or convert into the target account
                     QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
                     double currentAmount = ui.kAmountEdit->value();
+                    int decimal = qMax(unit.getNumberDecimal(), unitTargetAccount.getNumberDecimal());
                     double newval = KInputDialog::getDouble(i18nc("Question", "Confirmation"),
                                                             i18nc("Question", "The operation's unit is not compatible with the target account.\n"
                                                                     "Click Cancel if you want to continue anyway; "
                                                                     "otherwise, enter the value in the target account's unit (%1):", unitTargetAccount.getSymbol()),
-                                                            SKGUnitObject::convert(currentAmount, unit, unitTargetAccount),
-                                                            -DBL_MAX, DBL_MAX, 2, &ok, this);
+                                                            SKGUnitObject::convert(currentAmount, unit, unitTargetAccount, ui.kDateEdit->date()),
+                                                            -DBL_MAX, DBL_MAX, 0.1, decimal, &ok, this);
                     ratio = newval / currentAmount;
                     QApplication::restoreOverrideCursor();
                 }
@@ -906,7 +906,7 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
                     for (int i = 0; !err && i < nbsubops; ++i) {
                         SKGSubOperationObject subop(subops.at(i));
                         err = subop.setQuantity(subop.getQuantity() * ratio);
-                        if (!err) err = subop.save(true, false);
+                        IFOKDO(err, subop.save(true, false))
                     }
 
                     //Change unit
@@ -917,13 +917,13 @@ SKGError SKGOperationPluginWidget::updateSelection(const SKGObjectBase::SKGListS
                 //Correction bug 283842 ^^^^
             }
             //Correction bug 282983 ^^^
-            if (!err) err = operationObj.setUnit(unit);
+            IFOKDO(err, operationObj.setUnit(unit))
         }
 
         //Save
-        if (!err) err = operationObj.save();
+        IFOKDO(err, operationObj.save())
 
-        if (!err) err = getDocument()->stepForward(i + 1);
+        IFOKDO(err, getDocument()->stepForward(i + 1))
     }
 
     return err;
@@ -939,7 +939,6 @@ void SKGOperationPluginWidget::onAddOperationClicked()
     QString catName = ui.kCategoryEdit->currentText();
     QString trackerName = ui.kTrackerEdit->currentText();
 
-    bool confirmed = true;
     SKGOperationObject operation;
     {
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Operation creation"), err);
@@ -955,118 +954,119 @@ void SKGOperationPluginWidget::onAddOperationClicked()
 
         //Get account
         SKGAccountObject accountObj(getDocument());
-        if (!err) err = accountObj.setName(accountName);
-        if (!err) err = accountObj.load();
+        IFOKDO(err, accountObj.setName(accountName))
+        IFOKDO(err, accountObj.load())
 
         //Create operation object
-        if (!err) err = accountObj.addOperation(operation);
-        if (!err) err = operation.setMode(ui.kTypeEdit->currentText());
+        IFOKDO(err, accountObj.addOperation(operation))
+        IFOKDO(err, operation.setMode(ui.kTypeEdit->currentText()))
         QString payeeName = ui.kPayeeEdit->currentText();
-        if (!err) {
+        IFOK(err) {
             SKGPayeeObject payeeObject;
             err = SKGPayeeObject::createPayee(static_cast<SKGDocumentBank*>(getDocument()), payeeName, payeeObject, true);
-            if (!err) err = operation.setPayee(payeeObject);
+            IFOKDO(err, operation.setPayee(payeeObject))
         }
-        if (!err) err = operation.setNumber(SKGServices::stringToInt(ui.kNumberEdit->text()));
-        if (!err) err = operation.setComment(ui.kCommentEdit->text());
-        if (!err) err = operation.setDate(ui.kDateEdit->date());
-        if (!err) err = operation.setTemplate(isTemplateMode());
+        IFOKDO(err, operation.setNumber(SKGServices::stringToInt(ui.kNumberEdit->text())))
+        IFOKDO(err, operation.setComment(ui.kCommentEdit->text()))
+        IFOKDO(err, operation.setDate(ui.kDateEdit->date()))
+        IFOKDO(err, operation.setTemplate(isTemplateMode()))
         SKGUnitObject unit = ui.kUnitEdit->getUnit();
-        if (!err) err = operation.setUnit(unit);
-        if (!err) err = operation.save();
+        IFOKDO(err, operation.setUnit(unit))
+        IFOKDO(err, operation.save())
 
         if (ui.kWidgetSelector->getSelectedMode() <= 2) {
             //STD OPERATION (SPLIT , TRANSFER OR NOT)
             //We must create a suboperation, just be sure to be able to update it
             SKGSubOperationObject subOperation;
-            if (!err) err = operation.addSubOperation(subOperation);
-            if (!err) err = subOperation.setQuantity(0);
-            if (!err) err = subOperation.save();
+            IFOKDO(err, operation.addSubOperation(subOperation))
+            IFOKDO(err, subOperation.setQuantity(0))
+            IFOKDO(err, subOperation.save())
 
             SKGObjectBase::SKGListSKGObjectBase list;
             list << operation;
-            if (!err) err = updateSelection(list, true);
+            IFOKDO(err, updateSelection(list, true))
 
         } else if (ui.kWidgetSelector->getSelectedMode() == 3) {
             //PURCHASE OR SALE SHARE
             //Create sub operation object
             SKGSubOperationObject subOperation;
             double val = ui.kAmountEdit->value();
-            if (!err) err = operation.addSubOperation(subOperation);
-            if (!err) err = subOperation.setQuantity(val);
-            if (!err) err = subOperation.save();
+            IFOKDO(err, operation.addSubOperation(subOperation))
+            IFOKDO(err, subOperation.setQuantity(val))
+            IFOKDO(err, subOperation.save())
 
             if (!err && val > 0) err = operation.setProperty("SKG_OP_ORIGINAL_AMOUNT", SKGServices::doubleToString(ui.kAmountSharesEdit->value()));
-            if (!err) err = operation.save();
+            IFOKDO(err, operation.save())
 
             //Get account
             SKGAccountObject accountObj2(getDocument());
-            if (!err) err = accountObj2.setName(ui.kPaymentAccountEdit->currentText());
-            if (!err) err = accountObj2.load();
+            IFOKDO(err, accountObj2.setName(ui.kPaymentAccountEdit->currentText()))
+            IFOKDO(err, accountObj2.load())
 
             //create paiement operation for shares
             SKGOperationObject operation2;
-            if (!err) err = accountObj2.addOperation(operation2);
-            if (!err) err = operation2.setMode(ui.kTypeEdit->currentText());
+            IFOKDO(err, accountObj2.addOperation(operation2))
+            IFOKDO(err, operation2.setMode(ui.kTypeEdit->currentText()))
             QString payeeName = ui.kPayeeEdit->currentText();
-            if (!err) {
+            IFOK(err) {
                 SKGPayeeObject payeeObject;
                 err = SKGPayeeObject::createPayee(static_cast<SKGDocumentBank*>(getDocument()), payeeName, payeeObject, true);
-                if (!err) err = operation2.setPayee(payeeObject);
+                IFOKDO(err, operation2.setPayee(payeeObject))
             }
-            if (!err) err = operation2.setNumber(SKGServices::stringToInt(ui.kNumberEdit->text()));
-            if (!err) err = operation2.setComment(ui.kCommentEdit->text());
-            if (!err) err = operation2.setDate(ui.kDateEdit->date());
-            if (!err) {
+            IFOKDO(err, operation2.setNumber(SKGServices::stringToInt(ui.kNumberEdit->text())))
+            IFOKDO(err, operation2.setComment(ui.kCommentEdit->text()))
+            IFOKDO(err, operation2.setDate(ui.kDateEdit->date()))
+            IFOK(err) {
                 SKGUnitObject unitOfUnit;
                 err = unit.getUnit(unitOfUnit);
-                if (err) {
+                IFKO(err) {
                     unitOfUnit = SKGUnitObject(getDocument());
                     err = unitOfUnit.setSymbol(static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol);
-                    if (!err) err = unitOfUnit.load();
+                    IFOKDO(err, unitOfUnit.load())
                 }
 
-                if (!err) err = operation2.setUnit(unitOfUnit);
+                IFOKDO(err, operation2.setUnit(unitOfUnit))
             }
-            if (!err) err = operation2.setGroupOperation(operation);
-            if (!err) err = operation2.setTemplate(isTemplateMode());
-            if (!err) err = operation2.save();
+            IFOKDO(err, operation2.setGroupOperation(operation))
+            IFOKDO(err, operation2.setTemplate(isTemplateMode()))
+            IFOKDO(err, operation2.save())
 
             //Create main sub operation
             SKGSubOperationObject subOperation2;
-            if (!err) err = operation2.addSubOperation(subOperation2);
-            if (!err) err = subOperation2.setComment(i18nc("Noun", "Shares"));
-            if (!err) err = subOperation2.setQuantity(ui.kAmountSharesEdit->value() * (val > 0 ? -1 : 1));
-            if (!err) err = subOperation2.save();
+            IFOKDO(err, operation2.addSubOperation(subOperation2))
+            IFOKDO(err, subOperation2.setComment(i18nc("Noun", "Shares")))
+            IFOKDO(err, subOperation2.setQuantity(ui.kAmountSharesEdit->value() * (val > 0 ? -1 : 1)))
+            IFOKDO(err, subOperation2.save())
 
             //Create commission sub operation
             if (ui.kAmountSharesEdit->value()) {
                 SKGSubOperationObject subOperation2;
-                if (!err) err = operation2.addSubOperation(subOperation2);
-                if (!err) err = subOperation2.setComment(i18nc("Noun", "Commission"));
-                if (!err) err = subOperation2.setQuantity(-ui.kCommissionEdit->value());
-                if (!err) err = subOperation2.save();
+                IFOKDO(err, operation2.addSubOperation(subOperation2))
+                IFOKDO(err, subOperation2.setComment(i18nc("Noun", "Commission")))
+                IFOKDO(err, subOperation2.setQuantity(-ui.kCommissionEdit->value()))
+                IFOKDO(err, subOperation2.save())
             }
 
             //Create tax sub operation
             if (ui.kTaxEdit->value()) {
                 SKGSubOperationObject subOperation2;
-                if (!err) err = operation2.addSubOperation(subOperation2);
-                if (!err) err = subOperation2.setComment(i18nc("Noun", "Tax"));
-                if (!err) err = subOperation2.setQuantity(-ui.kTaxEdit->value());
-                if (!err) err = subOperation2.save();
+                IFOKDO(err, operation2.addSubOperation(subOperation2))
+                IFOKDO(err, subOperation2.setComment(i18nc("Noun", "Tax")))
+                IFOKDO(err, subOperation2.setQuantity(-ui.kTaxEdit->value()))
+                IFOKDO(err, subOperation2.save())
             }
         }
     }
 
     //status bar
-    if (!err) {
-        if (confirmed) {
-            err = SKGError(0, i18nc("Successful message after an user action", "Operation created"));
-            ui.kOperationView->getView()->selectObject(operation.getUniqueID());
-        } else err = SKGError(0, i18nc("Successful message after an user action", "Operation canceled"));
+    IFOK(err) {
+        err = SKGError(0, i18nc("Successful message after an user action", "Operation created"));
+        ui.kOperationView->getView()->selectObject(operation.getUniqueID());
     } else err.addError(ERR_FAIL, i18nc("Error message",  "Operation creation failed"));
 
+    //Notification for object creation
+    SKGMainPanel::getMainPanel()->displayMessage("", SKGDocument::Positive);
+
     //Display error
     SKGMainPanel::displayErrorMessage(err);
 
@@ -1367,7 +1367,7 @@ void SKGOperationPluginWidget::onDoubleClick()
             err = op.duplicate(operation);
 
             //status bar
-            if (!err) {
+            IFOK(err) {
                 setTemplateMode(false);
                 err = SKGError(0, i18nc("Successful message after an user action", "Operation created"));
                 ui.kOperationView->getView()->selectObject(operation.getUniqueID());
@@ -1407,10 +1407,10 @@ void SKGOperationPluginWidget::onRefreshInformationZoneDelayed()
 void SKGOperationPluginWidget::onRefreshInformationZone()
 {
     SKGTRACEIN(1, "SKGOperationPluginWidget::onRefreshInformationZone");
-    KLocale* locale = KGlobal::locale();
+    KLocale* loc = KGlobal::locale();
     SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
     QString current = currentAccount();
-    if (doc && locale) {
+    if (doc && loc) {
         SKGServices::SKGUnitInfo unit1 = doc->getPrimaryUnit();
         SKGServices::SKGUnitInfo unit2 = doc->getSecondaryUnit();
         if (m_modeInfoZone == 0) {
@@ -1602,11 +1602,11 @@ void SKGOperationPluginWidget::onAccountChanged()
         //Get account object
         SKGAccountObject act(getDocument());
         SKGError err = act.setName(currentAccount());
-        if (!err) err = act.load();
+        IFOKDO(err, act.load())
 
         //Get unit
         SKGUnitObject unit;
-        if (!err) err = act.getUnit(unit);
+        IFOKDO(err, act.getUnit(unit))
         if (!err && !unit.getSymbol().isEmpty()) ui.kUnitEdit->setText(unit.getSymbol());
     }
     onFilterChanged();
@@ -1963,25 +1963,7 @@ void SKGOperationPluginWidget::onRemoveSubOperation(int iRow)
 {
     SKGTRACEIN(10, "SKGOperationPluginWidget::onRemoveSubOperation");
     bool previous = ui.kSubOperationsTable->blockSignals(true);
-    QList<int> rowsToRemove;
-    if (iRow != -1) {
-        rowsToRemove.append(iRow);
-    } else {
-        QList<QTableWidgetItem*> selectedItems = ui.kSubOperationsTable->selectedItems();
-        int nb = selectedItems.count();
-        for (int i = 0; i < nb; ++i) {
-            QTableWidgetItem* item = selectedItems.at(i);
-            int row = item->row();
-            if (!rowsToRemove.contains(row)) {
-                rowsToRemove.append(row);
-            }
-        }
-    }
-
-    for (int j = rowsToRemove.count() - 1; j >= 0 ; --j) {
-
-        ui.kSubOperationsTable->removeRow(rowsToRemove.at(j));
-    }
+    ui.kSubOperationsTable->removeRow(iRow);
 
     // If all rows removed, add an empty line
     if (ui.kSubOperationsTable->rowCount() == 0) {
@@ -2048,11 +2030,11 @@ void SKGOperationPluginWidget::onAutoPoint()
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Auto point account"), err);
         SKGAccountObject act(getDocument());
         err = act.setName(currentAccount());
-        if (!err) err = act.load();
-        if (!err) err = act.autoReconcile(ui.kReconcilitorAmountEdit->value());
+        IFOKDO(err, act.load())
+        IFOKDO(err, act.autoReconcile(ui.kReconcilitorAmountEdit->value()))
     }
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Account auto pointed."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Account auto pointed.")))
 
     //Display error
     SKGMainPanel::displayErrorMessage(err);
@@ -2066,20 +2048,20 @@ void SKGOperationPluginWidget::onAddFakeOperation()
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Create fake operation"), err);
 
         SKGAccountObject accountObj(getDocument());
-        if (!err) err = accountObj.setName(currentAccount());
-        if (!err) err = accountObj.load();
+        IFOKDO(err, accountObj.setName(currentAccount()))
+        IFOKDO(err, accountObj.load())
 
         SKGOperationObject op;
-        if (!err) err = accountObj.addOperation(op);
-        if (!err) err = op.setDate(QDate::currentDate());
-        if (!err) err = op.setComment(i18nc("Noun, default comment for a fake operation", "Fake operation"));
+        IFOKDO(err, accountObj.addOperation(op))
+        IFOKDO(err, op.setDate(QDate::currentDate()))
+        IFOKDO(err, op.setComment(i18nc("Noun, default comment for a fake operation", "Fake operation")))
         SKGUnitObject unit ;
-        if (!err) err = accountObj.getUnit(unit);
-        if (!err) err = op.setUnit(unit);
-        if (!err) err = op.save();
+        IFOKDO(err, accountObj.getUnit(unit))
+        IFOKDO(err, op.setUnit(unit))
+        IFOKDO(err, op.save())
 
         SKGSubOperationObject sop;
-        if (!err) err = op.addSubOperation(sop);
+        IFOKDO(err, op.addSubOperation(sop))
 
         SKGStringListList listTmp2;
         double diff = 0;
@@ -2090,12 +2072,12 @@ void SKGOperationPluginWidget::onAddFakeOperation()
             diff = SKGServices::stringToDouble(listTmp2.at(1).at(0)) - ui.kReconcilitorAmountEdit->value() * unit.getAmount();
         }
 
-        if (!err) err = sop.setQuantity(-diff);
-        if (!err) err = sop.save();
+        IFOKDO(err, sop.setQuantity(-diff))
+        IFOKDO(err, sop.save())
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Fake operation created."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Fake operation created.")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Creation failed"));
 
     //Display error
@@ -2112,18 +2094,18 @@ void SKGOperationPluginWidget::onValidatePointedOperations()
     SKGObjectBase::SKGListSKGObjectBase list;
     err = getDocument()->getObjects("v_operation_display", "t_status='P' AND t_ACCOUNT='" % SKGServices::stringToSqlString(account) % '\'', list);
     int nb = list.count();
-    if (!err) {
+    IFOK(err) {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Switch to checked"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
             SKGOperationObject op(list[i]);
             err = op.setStatus(SKGOperationObject::CHECKED);
-            if (!err) err = op.save();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, op.save())
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Operation checked."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation checked.")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Switch failed"));
 
     //Display error
@@ -2170,7 +2152,7 @@ void SKGOperationPluginWidget::addSubOperationLine(int row, const QString& categ
     if (row == 0 && category.isEmpty()) ui.kSubOperationsTable->horizontalHeader()->resizeSection(0, 300);
 }
 
-QWidget* SKGOperationPluginWidget::mainWidget() const
+QWidget* SKGOperationPluginWidget::mainWidget()
 {
     return ui.kOperationView->getView();
 }
@@ -2182,10 +2164,7 @@ SKGError SKGOperationPluginWidget::getSelectedOperation(SKGOperationObject& oper
     if (selectedOperations.count() > 0) {
         operation = selectedOperations.at(0);
         err.setReturnCode(0);
-    } else {
-        err.setReturnCode(1);
-        err.setMessage(i18nc("Error message",  "No Operation Selected"));
-    }
+    } else err.setReturnCode(1).setMessage(i18nc("Error message",  "No Operation Selected"));
     return err;
 }
 
