@@ -85,7 +85,7 @@ public:
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() const;
+    virtual QWidget* mainWidget();
 
     /**
      * Set or not the template mode
@@ -127,7 +127,7 @@ private Q_SLOTS:
     void onDoubleClick();
     void onQuantityChanged();
     void onSubopCellChanged(int row, int column);
-    void onRemoveSubOperation(int iRow = -1);
+    void onRemoveSubOperation(int iRow);
     void onRefreshInformationZone();
     void onRefreshInformationZoneDelayed();
     void onRotateAccountTools();
