@@ -44,31 +44,31 @@ static const int COMMENTINDEX = 2;
  */
 static const int REFUNDINDEX = 3;
 
-SKGSplitTableDelegate::SKGSplitTableDelegate(QObject* parent, SKGDocument* iDoc) : QItemDelegate(parent), m_document(iDoc) {}
+SKGSplitTableDelegate::SKGSplitTableDelegate(QObject* iParent, SKGDocument* iDoc) : QItemDelegate(iParent), m_document(iDoc) {}
 
 SKGSplitTableDelegate::~SKGSplitTableDelegate()
 {
     m_document = NULL;
 }
 
-QWidget* SKGSplitTableDelegate::createEditor(QWidget* parent,
+QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
         const QStyleOptionViewItem& option ,
         const QModelIndex& index) const
 {
     if (index.column() == CATEGORYINDEX) {
-        SKGComboBox* editor = new SKGComboBox(parent);
+        SKGComboBox* editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document) SKGMainPanel::fillWithDistinctValue(editor, m_document, "category", "t_fullname", "");
 
         return editor;
     } else if (index.column() == COMMENTINDEX) {
-        SKGComboBox* editor = new SKGComboBox(parent);
+        SKGComboBox* editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document) SKGMainPanel::fillWithDistinctValue(editor, m_document, "v_operation_all_comment", "t_comment", "");
 
         return editor;
     } else if (index.column() == AMOUNTINDEX) {
-        SKGCalculatorEdit* editor = new SKGCalculatorEdit(parent);
+        SKGCalculatorEdit* editor = new SKGCalculatorEdit(iParent);
         editor->setMode(SKGCalculatorEdit::EXPRESSION);
         QMapIterator<QString, double> i(m_parameters);
         while (i.hasNext()) {
@@ -78,14 +78,14 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* parent,
 
         return editor;
     } else if (index.column() == REFUNDINDEX) {
-        SKGComboBox* editor = new SKGComboBox(parent);
+        SKGComboBox* editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document) SKGMainPanel::fillWithDistinctValue(editor, m_document, "refund", "t_name", "t_close='N'");
 
         return editor;
     }
 
-    return QItemDelegate::createEditor(parent, option , index);
+    return QItemDelegate::createEditor(iParent, option , index);
 }
 
 void SKGSplitTableDelegate::setEditorData(QWidget* editor, const QModelIndex& index) const
