@@ -36,7 +36,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit SKGSplitTableDelegate(QObject* parent = 0, SKGDocument* iDoc = NULL);
+    explicit SKGSplitTableDelegate(QObject* iParent = 0, SKGDocument* iDoc = NULL);
 
     /**
      * Default Destructor
@@ -46,12 +46,12 @@ public:
     /**
      * Returns the widget used to edit the item specified by index for editing.
      * The parent widget and style option are used to control how the editor widget appears.
-     * @param parent parant widget
+     * @param iParent parant widget
      * @param option options
      * @param index index
      * @return the widget
      */
-    virtual QWidget* createEditor(QWidget* parent,
+    virtual QWidget* createEditor(QWidget* iParent,
                                   const QStyleOptionViewItem& option ,
                                   const QModelIndex& index) const;
 
