@@ -152,7 +152,7 @@ void SKGPayeePlugin::deleteUnusedPayees() const
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Unused payees deleted"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Unused payees deleted")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Unused payees deletion failed"));
 
     //Display error
