@@ -52,7 +52,7 @@ SKGReportBoardWidget::SKGReportBoardWidget(SKGDocumentBank* iDocument)
     setMainWidget(m_graph);
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
 SKGReportBoardWidget::~SKGReportBoardWidget()
