@@ -51,7 +51,9 @@ K_PLUGIN_FACTORY(SKGReportPluginFactory, registerPlugin<SKGReportPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGReportPluginFactory("skrooge_report", "skrooge_report"))
 
-SKGReportPlugin::SKGReportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGReportPlugin::SKGReportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent),
+    m_openReportAction(NULL), m_currentBankDocument(NULL)
 {
     SKGTRACEIN(10, "SKGReportPlugin::SKGReportPlugin");
 }
@@ -114,14 +116,14 @@ int SKGReportPlugin::getNbDashboardWidgets()
 
 QString SKGReportPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    if (iIndex == 0) return i18nc("Noun, the title of a section", "Report");
-    return "";
+    Q_UNUSED(iIndex);
+    return i18nc("Noun, the title of a section", "Report");
 }
 
 SKGBoardWidget* SKGReportPlugin::getDashboardWidget(int iIndex)
 {
-    if (iIndex == 0) return new SKGReportBoardWidget(m_currentBankDocument);
-    return NULL;
+    Q_UNUSED(iIndex);
+    return new SKGReportBoardWidget(m_currentBankDocument);
 }
 
 SKGTabPage* SKGReportPlugin::getWidget()
