@@ -169,7 +169,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     connect(ui.kCorrectedBy, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kCorrectedByMode, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
 
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)));
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)));
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
 
     if (iMinimmumMode) {
@@ -361,12 +361,12 @@ QString SKGReportPluginWidget::getDefaultStateAttribute()
     return "SKGREPORT_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGReportPluginWidget::zoomableWidget() const
+QWidget* SKGReportPluginWidget::zoomableWidget()
 {
     return ui.kTableWithGraph->table();
 }
 
-QList< QWidget* > SKGReportPluginWidget::printableWidgets() const
+QList< QWidget* > SKGReportPluginWidget::printableWidgets()
 {
     QList<QWidget*> output;
     if (ui.kTableWithGraph->isTableVisible()) output.push_back(ui.kTableWithGraph->table());
@@ -588,6 +588,7 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
         one *= 7;
         break;
     case 2:
+    default:
         // Interval is in months
         strfFormat = "'%Y-%m'";
         sqlInterval = "MONTH";
@@ -612,6 +613,7 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
             b = a.addDays(7 - 1);
             break;
         case 2:
+        default:
             // Interval is in months
             a = a.addDays(1 - a.day());
             b = a.addMonths(1).addDays(-1);
@@ -642,6 +644,7 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
             a = b.addDays(-val + 1);
             break;
         case 2:
+        default:
             // Interval is in months
             b = b.addDays(-b.day());
             a = a.addDays(1 - a.day()).addMonths(-val);
@@ -671,6 +674,7 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
             a = a.addDays(-val);
             break;
         case 2:
+        default:
             // Interval is in months
             a = a.addMonths(-val);
             break;
@@ -709,6 +713,7 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause(QString* oWhereClausFo
             b = a.addDays(6);
             break;
         case 2:
+        default:
             // Interval is in months
             a = a.addDays(1 - a.day()).addMonths(1 - val);
             b = a.addMonths(1).addDays(-1);
@@ -921,9 +926,9 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     } else {
                         //Create budgeted operations
                         SKGObjectBase::SKGListSKGObjectBase budgets;
-                        if (!err) err = doc->getObjects("v_budget",
-                                                            "t_PERIOD>STRFTIME('%Y-%m', date('now')) AND "
-                                                            "t_PERIOD<=STRFTIME('%Y-%m', '" % SKGServices::dateToSqlString(QDateTime(lastDate)) % "')", budgets);
+                        IFOKDO(err, doc->getObjects("v_budget",
+                                                    "t_PERIOD>STRFTIME('%Y-%m', date('now')) AND "
+                                                    "t_PERIOD<=STRFTIME('%Y-%m', '" % SKGServices::dateToSqlString(QDateTime(lastDate)) % "')", budgets));
                         int nb = budgets.count();
                         if (nb) {
                             //Get most active account
@@ -935,9 +940,9 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 
                                 //Get unit
                                 SKGUnitObject unit(doc);
-                                if (!err) err = unit.setName(doc->getPrimaryUnit().Name);
-                                if (!err) err = unit.setSymbol(doc->getPrimaryUnit().Symbol);
-                                if (!err) err = unit.load();
+                                IFOKDO(err, unit.setName(doc->getPrimaryUnit().Name))
+                                IFOKDO(err, unit.setSymbol(doc->getPrimaryUnit().Symbol))
+                                IFOKDO(err, unit.load())
 
 
                                 doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create budgeted operations"), nb);
@@ -949,18 +954,18 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                                     budget.getCategory(cat);
 
                                     SKGOperationObject op;
-                                    if (!err) err = account.addOperation(op);
-                                    if (!err) err = op.setDate(QDate(budget.getYear(), qMax(budget.getMonth(), 1), 1));
-                                    if (!err) err = op.setUnit(unit);
-                                    if (!err) err = op.save();
+                                    IFOKDO(err, account.addOperation(op))
+                                    IFOKDO(err, op.setDate(QDate(budget.getYear(), qMax(budget.getMonth(), 1), 1)))
+                                    IFOKDO(err, op.setUnit(unit))
+                                    IFOKDO(err, op.save())
 
                                     SKGSubOperationObject sop;
-                                    if (!err) err = op.addSubOperation(sop);
-                                    if (!err) err = sop.setCategory(cat);
-                                    if (!err) err = sop.setQuantity(budget.getBudgetedAmount());
-                                    if (!err) err = sop.save();
+                                    IFOKDO(err, op.addSubOperation(sop))
+                                    IFOKDO(err, sop.setCategory(cat))
+                                    IFOKDO(err, sop.setQuantity(budget.getBudgetedAmount()))
+                                    IFOKDO(err, sop.save())
 
-                                    if (!err) err = doc->stepForward(i + 1);
+                                    IFOKDO(err, doc->stepForward(i + 1))
                                 }
                             }
                         }
@@ -1025,8 +1030,8 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     coef = coef % "COALESCE((SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MAX(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % " and u2.d_date<=v_operation_consolidated.d_date)), (SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MIN(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % ")),0)";
                 }
 
-                if (!err) err = doc->getConsolidatedView(tableName, attCol, attLine, "f_REALCURRENTAMOUNT" % coef,
-                                    (mode == 3 ? "COUNT" : "TOTAL"), condition, table);
+                IFOKDO(err, doc->getConsolidatedView(tableName, attCol, attLine, "f_REALCURRENTAMOUNT" % coef,
+                                                     (mode == 3 ? "COUNT" : "TOTAL"), condition, table));
                 int nbLines = table.count();
                 IFSKGTRACEL(10) {
                     QStringList dump = SKGServices::tableToDump(table, SKGServices::DUMP_TEXT);
@@ -1056,7 +1061,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     }
                 }
 
-                if (!err) {
+                IFOK(err) {
                     //Update title
                     if (nbLines) {
                         //Change title
