@@ -45,7 +45,8 @@ K_PLUGIN_FACTORY(SKGScheduledPluginFactory, registerPlugin<SKGScheduledPlugin>()
  */
 K_EXPORT_PLUGIN(SKGScheduledPluginFactory("skrooge_scheduled", "skrooge_scheduled"))
 
-SKGScheduledPlugin::SKGScheduledPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_counterAdvice(0)
+SKGScheduledPlugin::SKGScheduledPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) :
+    SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_scheduleOperationAction(NULL), m_counterAdvice(0)
 {
     SKGTRACEIN(10, "SKGScheduledPlugin::SKGScheduledPlugin");
 }
@@ -118,17 +119,16 @@ int SKGScheduledPlugin::getNbDashboardWidgets()
 
 QString SKGScheduledPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    if (iIndex == 0) return i18nc("Noun, the title of a section", "Scheduled operations");
-    return "";
+    Q_UNUSED(iIndex);
+    return i18nc("Noun, the title of a section", "Scheduled operations");
 }
 
 SKGBoardWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
 {
-    if (iIndex == 0) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                getDashboardWidgetTitle(iIndex),
-                                KStandardDirs().findResource("data", "skrooge/html/default/scheduled_operations.html"),
-                                QStringList() << "v_recurrentoperation_display");
-    return NULL;
+    return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                  getDashboardWidgetTitle(iIndex),
+                                  KStandardDirs().findResource("data", "skrooge/html/default/scheduled_operations.html"),
+                                  QStringList() << "v_recurrentoperation_display");
 }
 
 SKGTabPage* SKGScheduledPlugin::getWidget()
@@ -203,21 +203,21 @@ SKGError SKGScheduledPlugin::savePreferences() const
                     SKGRecurrentOperationObject recOp(recurrents.at(i));
                     SKGOperationObject operationObj;
 
-                    if (!err) recOp.getParentOperation(operationObj);
+                    IFOK(err) recOp.getParentOperation(operationObj);
 
                     SKGOperationObject operationObjOrig = operationObj;
-                    if (!err) err = operationObjOrig.duplicate(operationObj , operationObjOrig.getDate(), true);
+                    IFOKDO(err, operationObjOrig.duplicate(operationObj , operationObjOrig.getDate(), true))
 
-                    if (!err) err = recOp.setParentOperation(operationObj);
-                    if (!err) err = recOp.save();
-                    if (!err) err = recOp.load();
+                    IFOKDO(err, recOp.setParentOperation(operationObj))
+                    IFOKDO(err, recOp.save())
+                    IFOKDO(err, recOp.load())
 
-                    if (!err) err = operationObjOrig.setAttribute("r_recurrentoperation_id", SKGServices::intToString(recOp.getID()));
-                    if (!err) err = operationObjOrig.save();
+                    IFOKDO(err, operationObjOrig.setAttribute("r_recurrentoperation_id", SKGServices::intToString(recOp.getID())))
+                    IFOKDO(err, operationObjOrig.save())
 
-                    if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                    IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                 }
-                if (!err) m_currentBankDocument->sendMessage(i18nc("An information message",  "All scheduled operations have been converted in template"));
+                IFOK(err) m_currentBankDocument->sendMessage(i18nc("An information message",  "All scheduled operations have been converted in template"));
             }
         }
     }
@@ -234,26 +234,26 @@ SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperat
     if (!isTemplate && skgscheduled_settings::create_template()) {
         //The selected operation is not a template and settings is set to create one
         operationObjOrig = operationObjDuplicate;
-        if (!err) err = operationObjOrig.duplicate(operationObjDuplicate, operationObjOrig.getDate(), true);
-        if (!err) m_currentBankDocument->sendMessage(i18nc("An information message",  "A template has been created"), SKGDocument::Positive);
+        IFOKDO(err, operationObjOrig.duplicate(operationObjDuplicate, operationObjOrig.getDate(), true))
+        IFOK(err) m_currentBankDocument->sendMessage(i18nc("An information message",  "A template has been created"), SKGDocument::Positive);
     }
 
     SKGRecurrentOperationObject recOp;
     err = operationObjDuplicate.addRecurrentOperation(recOp);
-    if (!err) err = recOp.warnEnabled(skgscheduled_settings::remind_me());
-    if (!err) err = recOp.setWarnDays(skgscheduled_settings::remind_me_days());
-    if (!err) err = recOp.autoWriteEnabled(skgscheduled_settings::auto_write());
-    if (!err) err = recOp.setAutoWriteDays(skgscheduled_settings::auto_write_days());
-    if (!err) err = recOp.timeLimit(skgscheduled_settings::nb_times());
-    if (!err) err = recOp.setTimeLimit(skgscheduled_settings::nb_times_val());
-    if (!err) err = recOp.setPeriodIncrement(skgscheduled_settings::once_every());
-    if (!err) err = recOp.setPeriodUnit((SKGRecurrentOperationObject::PeriodUnit) SKGServices::stringToInt(skgscheduled_settings::once_every_unit()));
+    IFOKDO(err, recOp.warnEnabled(skgscheduled_settings::remind_me()))
+    IFOKDO(err, recOp.setWarnDays(skgscheduled_settings::remind_me_days()))
+    IFOKDO(err, recOp.autoWriteEnabled(skgscheduled_settings::auto_write()))
+    IFOKDO(err, recOp.setAutoWriteDays(skgscheduled_settings::auto_write_days()))
+    IFOKDO(err, recOp.timeLimit(skgscheduled_settings::nb_times()))
+    IFOKDO(err, recOp.setTimeLimit(skgscheduled_settings::nb_times_val()))
+    IFOKDO(err, recOp.setPeriodIncrement(skgscheduled_settings::once_every()))
+    IFOKDO(err, recOp.setPeriodUnit(static_cast<SKGRecurrentOperationObject::PeriodUnit>(SKGServices::stringToInt(skgscheduled_settings::once_every_unit()))))
     if (!err && !isTemplate) err = recOp.setDate(recOp.getNextDate());
-    if (!err) err = recOp.save();
+    IFOKDO(err, recOp.save())
     if (!isTemplate && skgscheduled_settings::create_template()) {
-        if (!err) err = recOp.load();
-        if (!err) err = operationObjOrig.setAttribute("r_recurrentoperation_id", SKGServices::intToString(recOp.getID()));
-        if (!err) err = operationObjOrig.save();
+        IFOKDO(err, recOp.load())
+        IFOKDO(err, operationObjOrig.setAttribute("r_recurrentoperation_id", SKGServices::intToString(recOp.getID())))
+        IFOKDO(err, operationObjOrig.save())
     }
 
     oRecurrent = recOp;
@@ -277,18 +277,18 @@ void SKGScheduledPlugin::onScheduleOperation()
                 SKGOperationObject operationObj(selection.at(i));
                 SKGRecurrentOperationObject rop;
                 err = scheduleOperation(operationObj, rop);
-                if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                 list.push_back(operationObj.getUniqueID());
             }
 
-            if (!err) {
+            IFOK(err) {
                 //Open the scheduled operation
                 SKGMainPanel::getMainPanel()->openPage("skg://skrooge_scheduled_plugin/?selection=" % SKGServices::encodeForUrl(SKGServices::stringsToCsv(list)));
             }
         }
 
         //status bar
-        if (!err)  err = SKGError(0, i18nc("Successful message after an user action", "Operation scheduled."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation scheduled.")))
         else err.addError(ERR_FAIL, i18nc("Error message",  "Operation schedule failed"));
 
         //Display error
@@ -381,24 +381,24 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Update scheduled operation"), err);
             SKGOperationObject op(m_currentBankDocument, idOper);
             SKGObjectBase::SKGListSKGObjectBase subOps;
-            if (!err) err = op.getSubOperations(subOps);
+            IFOKDO(err, op.getSubOperations(subOps))
 
             if (subOps.count() == 1) {
                 //Change the quantity of the sub operation
                 SKGSubOperationObject so1(subOps.at(0));
-                if (!err) err = so1.setQuantity(amount);
-                if (!err) err = so1.save();
+                IFOKDO(err, so1.setQuantity(amount))
+                IFOKDO(err, so1.save())
             } else if (subOps.count() >= 1) {
                 //Add a split
                 SKGSubOperationObject so1;
-                if (!err) err = op.addSubOperation(so1);
-                if (!err) err = so1.setQuantity(amount - op.getCurrentAmount());
-                if (!err) err = so1.save();
+                IFOKDO(err, op.addSubOperation(so1))
+                IFOKDO(err, so1.setQuantity(amount - op.getCurrentAmount()))
+                IFOKDO(err, so1.save())
             }
         }
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Scheduled operation updated."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled operation updated.")))
         else err.addError(ERR_FAIL, i18nc("Error message", "Update failed"));
 
         //Display error
@@ -415,17 +415,17 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
             SKGOperationObject op(m_currentBankDocument, idOper);
             SKGRecurrentOperationObject rop;
             err = scheduleOperation(op, rop);
-            if (!err) err = rop.setPeriodUnit(SKGRecurrentOperationObject::MONTH);
-            if (!err) err = rop.setPeriodIncrement(1);
-            if (!err) err = rop.setDate(op.getDate());
-            if (!err) err = rop.setDate(rop.getNextDate());
-            if (!err) err = rop.save(true, false);
+            IFOKDO(err, rop.setPeriodUnit(SKGRecurrentOperationObject::MONTH))
+            IFOKDO(err, rop.setPeriodIncrement(1))
+            IFOKDO(err, rop.setDate(op.getDate()))
+            IFOKDO(err, rop.setDate(rop.getNextDate()))
+            IFOKDO(err, rop.save(true, false))
 
             m_counterAdvice = 0; //To force the update
         }
 
         //status bar
-        if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Operation scheduled."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Operation scheduled.")))
         else err.addError(ERR_FAIL, i18nc("Error message", "Schedule failed"));
 
         //Display error
