@@ -97,7 +97,7 @@ SKGScheduledPluginWidget::~SKGScheduledPluginWidget()
 bool SKGScheduledPluginWidget::eventFilter(QObject* object, QEvent* event)
 {
     if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = (QKeyEvent*) event;
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
             if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kModifyBtn->isEnabled()) {
                 ui.kModifyBtn->click();
@@ -140,7 +140,7 @@ QString SKGScheduledPluginWidget::getDefaultStateAttribute()
     return "SKGSCHEDULED_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGScheduledPluginWidget::mainWidget() const
+QWidget* SKGScheduledPluginWidget::mainWidget()
 {
     return ui.kView->getView();
 }
@@ -189,7 +189,7 @@ void SKGScheduledPluginWidget::onSelectionChanged()
 
         ui.kFirstOccurenceDate->setDate(recOp.getDate());
         ui.kOnceEveryVal->setValue(recOp.getPeriodIncrement());
-        ui.kOnceEveryUnit->setCurrentIndex((int) recOp.getPeriodUnit());
+        ui.kOnceEveryUnit->setCurrentIndex(static_cast<int>(recOp.getPeriodUnit()));
 
         ui.kRemindMeVal->setValue(recOp.getWarnDays());
         ui.kRemindMe->setCheckState(recOp.isWarnEnabled() ? Qt::Checked : Qt::Unchecked);
@@ -207,7 +207,7 @@ void SKGScheduledPluginWidget::onSelectionChanged()
 void SKGScheduledPluginWidget::onNbOccurrenceChanged()
 {
     QDate firstDate = ui.kFirstOccurenceDate->date();
-    SKGRecurrentOperationObject::PeriodUnit punit = (SKGRecurrentOperationObject::PeriodUnit) ui.kOnceEveryUnit->currentIndex();
+    SKGRecurrentOperationObject::PeriodUnit punit = static_cast<SKGRecurrentOperationObject::PeriodUnit>(ui.kOnceEveryUnit->currentIndex());
     int p = ui.kOnceEveryVal->value();
 
     if (ui.kLastOccurenceDate == this->sender()) {
@@ -258,21 +258,21 @@ void SKGScheduledPluginWidget::onUpdate()
 
             //Update it
             if (nb == 1) err = recOp.setDate(ui.kFirstOccurenceDate->date());
-            if (!err) err = recOp.setPeriodIncrement(ui.kOnceEveryVal->value());
-            if (!err) err = recOp.setPeriodUnit((SKGRecurrentOperationObject::PeriodUnit) ui.kOnceEveryUnit->currentIndex());
-            if (!err) err = recOp.setWarnDays(ui.kRemindMeVal->value());
-            if (!err) err = recOp.warnEnabled(ui.kRemindMe->checkState() == Qt::Checked);
-            if (!err) err = recOp.setAutoWriteDays(ui.kAutoWriteVal->value());
-            if (!err) err = recOp.autoWriteEnabled(ui.kAutoWrite->checkState() == Qt::Checked);
-            if (!err) err = recOp.setTimeLimit(ui.kNbTimesVal->value());
-            if (!err) err = recOp.timeLimit(ui.kNbTimes->checkState() == Qt::Checked);
-            if (!err) err = recOp.save();
+            IFOKDO(err, recOp.setPeriodIncrement(ui.kOnceEveryVal->value()))
+            IFOKDO(err, recOp.setPeriodUnit(static_cast<SKGRecurrentOperationObject::PeriodUnit>(ui.kOnceEveryUnit->currentIndex())))
+            IFOKDO(err, recOp.setWarnDays(ui.kRemindMeVal->value()))
+            IFOKDO(err, recOp.warnEnabled(ui.kRemindMe->checkState() == Qt::Checked))
+            IFOKDO(err, recOp.setAutoWriteDays(ui.kAutoWriteVal->value()))
+            IFOKDO(err, recOp.autoWriteEnabled(ui.kAutoWrite->checkState() == Qt::Checked))
+            IFOKDO(err, recOp.setTimeLimit(ui.kNbTimesVal->value()))
+            IFOKDO(err, recOp.timeLimit(ui.kNbTimes->checkState() == Qt::Checked))
+            IFOKDO(err, recOp.save())
 
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Recurrent operation updated."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Recurrent operation updated.")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Update failed"));
 
     //Display error
@@ -301,11 +301,11 @@ void SKGScheduledPluginWidget::onProcess(bool iImmediately)
             //Process it
             int nbi = 0;
             err = recOp.process(nbi, true, (iImmediately ? recOp.getDate() : QDate::currentDate()));
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Recurrent operation inserted."));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Recurrent operation inserted.")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Insertion failed"));
 
     //Display error
