@@ -70,7 +70,7 @@ public:
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() const;
+    virtual QWidget* mainWidget();
 
 protected:
     /**
