@@ -60,7 +60,7 @@ SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
     addAction(m_menuFavorite);
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
 SKGAlarmBoardWidget::~SKGAlarmBoardWidget()
