@@ -103,7 +103,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     ui.kActionCreator->setParameters(iDocument, "v_operation_consolidated", attributeForUpdate, true);
 
     //Bind operation view
-    ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_rule", "1=1 ORDER BY f_sortorder", this, "", false));
+    ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_rule_display", "1=1 ORDER BY f_sortorder", this, "", false));
     ui.kView->getView()->sortByColumn(0, Qt::AscendingOrder);
 
     //Add registered global action in contextual menu
@@ -138,7 +138,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     dataModified("", 0);
 
     onSelectionChanged();
@@ -155,7 +155,7 @@ SKGSearchPluginWidget::~SKGSearchPluginWidget()
 bool SKGSearchPluginWidget::eventFilter(QObject* object, QEvent* event)
 {
     if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = (QKeyEvent*) event;
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAdd->isEnabled()) {
                 ui.kAdd->click();
@@ -201,7 +201,7 @@ QString SKGSearchPluginWidget::getDefaultStateAttribute()
     return "SKGSEARCH_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGSearchPluginWidget::mainWidget() const
+QWidget* SKGSearchPluginWidget::mainWidget()
 {
     return ui.kView->getView();
 }
@@ -241,17 +241,17 @@ void SKGSearchPluginWidget::onAddRule()
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Search and process creation"), err);
             rule = SKGRuleObject(getDocument());
-            if (!err) err = rule.setXMLSearchDefinition(ui.kQueryCreator->getXMLCondition());
-            if (!err) err = rule.setOrder(-1);
+            IFOKDO(err, rule.setXMLSearchDefinition(ui.kQueryCreator->getXMLCondition()))
+            IFOKDO(err, rule.setOrder(-1))
 
             QString xml = getXMLActionDefinition();
-            if (!err) err = rule.setActionType(xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType(ui.kWidgetSelector->getSelectedMode()));
-            if (!err) err = rule.setXMLActionDefinition(xml);
-            if (!err) err = rule.save();
+            IFOKDO(err, rule.setActionType(xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType(ui.kWidgetSelector->getSelectedMode())))
+            IFOKDO(err, rule.setXMLActionDefinition(xml))
+            IFOKDO(err, rule.save())
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Search and process created"));
             ui.kView->getView()->selectObject(rule.getUniqueID());
         } else err.addError(ERR_FAIL, i18nc("Error message",  "Search and process creation failed"));
@@ -268,13 +268,13 @@ void SKGSearchPluginWidget::onOpen()
     SKGRuleObject rule;
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     rule = SKGRuleObject(getDocument());
-    if (!err) err = rule.setXMLSearchDefinition(ui.kQueryCreator->getXMLCondition());
-    if (!err) err = rule.setOrder(-1);
+    IFOKDO(err, rule.setXMLSearchDefinition(ui.kQueryCreator->getXMLCondition()))
+    IFOKDO(err, rule.setOrder(-1))
 
     QString xml = getXMLActionDefinition();
-    if (!err) err = rule.setActionType(xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType(ui.kWidgetSelector->getSelectedMode()));
-    if (!err) err = rule.setXMLActionDefinition(xml);
-    if (!err) open(rule, (sender() == ui.kSearch ? SKGSearchPluginWidget::TABLE : SKGSearchPluginWidget::REPORT));
+    IFOKDO(err, rule.setActionType(xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType(ui.kWidgetSelector->getSelectedMode())))
+    IFOKDO(err, rule.setXMLActionDefinition(xml))
+    IFOK(err) open(rule, (sender() == ui.kSearch ? SKGSearchPluginWidget::TABLE : SKGSearchPluginWidget::REPORT));
     QApplication::restoreOverrideCursor();
 
     //Display error
@@ -290,16 +290,16 @@ void SKGSearchPluginWidget::onModifyRule()
         SKGObjectBase::SKGListSKGObjectBase rules = getSelectedObjects();
         if (rules.count() == 1) {
             SKGRuleObject rule(rules.at(0));
-            if (!err) err = rule.setXMLSearchDefinition(ui.kQueryCreator->getXMLCondition());
+            IFOKDO(err, rule.setXMLSearchDefinition(ui.kQueryCreator->getXMLCondition()))
             QString xml = getXMLActionDefinition();
-            if (!err) err = rule.setActionType(xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType(ui.kWidgetSelector->getSelectedMode()));
-            if (!err) err = rule.setXMLActionDefinition(xml);
-            if (!err) err = rule.save();
+            IFOKDO(err, rule.setActionType(xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType(ui.kWidgetSelector->getSelectedMode())))
+            IFOKDO(err, rule.setXMLActionDefinition(xml))
+            IFOKDO(err, rule.save())
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Search and process updated"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search and process updated")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Search and process update failed"));
 
     //Display error
@@ -322,7 +322,7 @@ void SKGSearchPluginWidget::onSelectionChanged()
         SKGRuleObject rule(selection.at(0));
         ui.kQueryCreator->setXMLCondition(rule.getXMLSearchDefinition());
 
-        int index = qMax(0, ((int) rule.getActionType()));
+        int index = qMax(0, static_cast<int>(rule.getActionType()));
         if (ui.kWidgetSelector->getSelectedMode() != -1) ui.kWidgetSelector->setSelectedMode(index);
         if (index == 1) {
             //Set update mode
@@ -363,15 +363,15 @@ void SKGSearchPluginWidget::onTop()
             err = getDocument()->executeSelectSqliteOrder("SELECT min(f_sortorder) from rule", result);
             if (!err && result.count() == 2)  order = SKGServices::stringToDouble(result.at(1).at(0)) - 1;
 
-            if (!err) err = rule.setOrder(order);
-            if (!err) err = rule.save();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, rule.setOrder(order))
+            IFOKDO(err, rule.save())
+            IFOKDO(err, getDocument()->stepForward(i + 1))
 
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Search updated"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search updated")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
 
     //Display error
@@ -394,7 +394,7 @@ void SKGSearchPluginWidget::onUp()
             double order = rule.getOrder();
             SKGStringListList result;
             err = getDocument()->executeSelectSqliteOrder("SELECT f_sortorder from rule where f_sortorder<" % SKGServices::doubleToString(order) % " ORDER BY f_sortorder DESC", result);
-            if (!err) {
+            IFOK(err) {
                 if (result.count() == 2) {
                     order = SKGServices::stringToDouble(result.at(1).at(0)) - 1;
                 } else if (result.count() >= 2) {
@@ -402,15 +402,15 @@ void SKGSearchPluginWidget::onUp()
                 }
             }
 
-            if (!err) err = rule.setOrder(order);
-            if (!err) err = rule.save();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, rule.setOrder(order))
+            IFOKDO(err, rule.save())
+            IFOKDO(err, getDocument()->stepForward(i + 1))
 
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Search updated"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search updated")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
 
     //Display error
@@ -433,7 +433,7 @@ void SKGSearchPluginWidget::onDown()
             double order = rule.getOrder();
             SKGStringListList result;
             err = getDocument()->executeSelectSqliteOrder("SELECT f_sortorder from rule where f_sortorder>" % SKGServices::doubleToString(order) % " ORDER BY f_sortorder ASC", result);
-            if (!err) {
+            IFOK(err) {
                 if (result.count() == 2) {
                     order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
                 } else if (result.count() >= 2) {
@@ -441,15 +441,15 @@ void SKGSearchPluginWidget::onDown()
                 }
             }
 
-            if (!err) err = rule.setOrder(order);
-            if (!err) err = rule.save();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, rule.setOrder(order))
+            IFOKDO(err, rule.save())
+            IFOKDO(err, getDocument()->stepForward(i + 1))
 
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Search updated"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search updated")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
 
     //Display error
@@ -474,15 +474,15 @@ void SKGSearchPluginWidget::onBottom()
             err = getDocument()->executeSelectSqliteOrder("SELECT max(f_sortorder) from rule", result);
             if (!err && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
 
-            if (!err) err = rule.setOrder(order);
-            if (!err) err = rule.save();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, rule.setOrder(order))
+            IFOKDO(err, rule.save())
+            IFOKDO(err, getDocument()->stepForward(i + 1))
 
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Search updated"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Search updated")))
     else err.addError(ERR_FAIL, i18nc("Error message",  "Search update failed"));
 
     //Display error
