@@ -103,7 +103,7 @@ public:
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() const;
+    virtual QWidget* mainWidget();
 
     /**
      * Open operations corresponding to a rule
