@@ -64,7 +64,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
         ui.kView->getView()->resizeColumnToContents(0);
     }
 
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     connect(ui.kView->getView(), SIGNAL(clickEmptyArea()), this, SLOT(cleanEditor()));
     connect(ui.kView->getView(), SIGNAL(doubleClicked(QModelIndex)), SKGMainPanel::getMainPanel()->getGlobalAction("open"), SLOT(trigger()));
     connect(ui.kView->getView(), SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
@@ -83,7 +83,7 @@ SKGTrackerPluginWidget::~SKGTrackerPluginWidget()
 bool SKGTrackerPluginWidget::eventFilter(QObject* object, QEvent* event)
 {
     if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = (QKeyEvent*) event;
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAddButton->isEnabled()) {
                 ui.kAddButton->click();
@@ -139,7 +139,7 @@ QString SKGTrackerPluginWidget::getDefaultStateAttribute()
     return "SKGREFUND_DEFAULT_PARAMETERS";
 }
 
-QWidget* SKGTrackerPluginWidget::mainWidget() const
+QWidget* SKGTrackerPluginWidget::mainWidget()
 {
     return ui.kView->getView();
 }
@@ -175,12 +175,12 @@ void SKGTrackerPluginWidget::onAddTracker()
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Tracker creation '%1'", name)  , err);
 
         err = SKGTrackerObject::createTracker(static_cast<SKGDocumentBank*>(getDocument()), name, tracker);
-        if (!err) err = tracker.setComment(ui.kCommentEdit->text());
-        if (!err) err = tracker.save();
+        IFOKDO(err, tracker.setComment(ui.kCommentEdit->text()))
+        IFOKDO(err, tracker.save())
     }
 
     //status bar
-    if (!err) {
+    IFOK(err) {
         err = SKGError(0, i18nc("Successful message after an user action", "Tracker '%1' created", name));
         ui.kView->getView()->selectObject(tracker.getUniqueID());
     } else err.addError(ERR_FAIL, i18nc("Error message", "Tracker creation failed"));
@@ -204,13 +204,13 @@ void SKGTrackerPluginWidget::onModifyTracker()
             //Modification of object
             SKGTrackerObject tracker(selection[i]);
             err = tracker.setName(ui.kNameInput->text());
-            if (!err) err = tracker.setComment(ui.kCommentEdit->text());
-            if (!err) err = tracker.save();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, tracker.setComment(ui.kCommentEdit->text()))
+            IFOKDO(err, tracker.save())
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Tracker updated"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Tracker updated")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Tracker update failed"));
 
     //Display error
