@@ -92,18 +92,16 @@ int SKGUnitPlugin::getNbDashboardWidgets()
 QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
 {
     if (iIndex == 0) return i18nc("Noun, the title of a section", "Quotes");
-    else if (iIndex == 1) return i18nc("Noun, the title of a section", "Stock portfolio");
-    return "";
+    else return i18nc("Noun, the title of a section", "Stock portfolio");
 }
 
 SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGUnitBoardWidget(m_currentBankDocument);
-    else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                     getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", "skrooge/html/default/portfolio.html"),
-                                     QStringList() << "v_operation_display");
-    return NULL;
+    else return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                           getDashboardWidgetTitle(iIndex),
+                                           KStandardDirs().findResource("data", "skrooge/html/default/portfolio.html"),
+                                           QStringList() << "v_operation_display");
 }
 
 void SKGUnitPlugin::refresh()
@@ -127,16 +125,16 @@ void SKGUnitPlugin::refresh()
             if (m_docUniqueIdentifier != doc_id) {
                 m_docUniqueIdentifier = doc_id;
                 //Check if current unit is existing
-                KLocale* locale = KGlobal::locale();
+                KLocale* loc = KGlobal::locale();
                 bool exist = false;
                 SKGError err = m_currentBankDocument->existObjects("unit", "", exist);
-                if (!err) {
+                IFOK(err) {
                     if (!exist) {
                         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create default unit"), err);
-                        if (!err) {
+                        IFOK(err) {
                             //Create default unit
                             SKGUnitObject unit;
-                            err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, locale->currencyCode(), unit);
+                            err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, loc->currencyCode(), unit);
 
                             //The file is considered has not modified
                             m_currentBankDocument->setFileNotModified();
@@ -159,11 +157,11 @@ void SKGUnitPlugin::refresh()
                             for (int i = 0; !err && i < nb; ++i) {
                                 SKGUnitObject unit(selection.at(i));
                                 err = SKGUnitPluginWidget::downloadUnitValue(unit, SKGUnitPluginWidget::getDownloadModeFromSettings());
-                                if (!err) err = m_currentBankDocument->stepForward(i + 1);
+                                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
                             }
 
                             //Memorize the last download date
-                            if (!err) err = m_currentBankDocument->setParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd"));
+                            IFOKDO(err, m_currentBankDocument->setParameter("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd")))
                         }
                     }
                 }
@@ -256,7 +254,7 @@ void SKGUnitPlugin::onSplitShare()
         }
 
         //status
-        if (!err)  err = SKGError(0, i18nc("Successful message after an user action", "Stock split."));
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Stock split.")))
         else err.addError(ERR_FAIL, i18nc("Error message", "Splitting stock failed."));
 
         //Display error
@@ -413,13 +411,13 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
                 SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Define primary currency"), err);
                 SKGUnitObject unitObj(m_currentBankDocument);
                 err = unitObj.setName(unit);
-                if (!err) err = unitObj.load();
-                if (!err) err = unitObj.setType(SKGUnitObject::PRIMARY);
-                if (!err) err = unitObj.save(true, false);
+                IFOKDO(err, unitObj.load())
+                IFOKDO(err, unitObj.setType(SKGUnitObject::PRIMARY))
+                IFOKDO(err, unitObj.save(true, false))
             }
 
             //status bar
-            if (!err) err = SKGError(0, i18nc("Message for successful user action", "Primary currency defined."));
+            IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Primary currency defined.")))
             else err.addError(ERR_FAIL, i18nc("Error message", "Primary currency definition failed"));
 
             //Display error
@@ -439,13 +437,13 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
                 SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Define secondary currency"), err);
                 SKGUnitObject unitObj(m_currentBankDocument);
                 err = unitObj.setName(unit);
-                if (!err) err = unitObj.load();
-                if (!err) err = unitObj.setType(SKGUnitObject::SECONDARY);
-                if (!err) err = unitObj.save(true, false);
+                IFOKDO(err, unitObj.load())
+                IFOKDO(err, unitObj.setType(SKGUnitObject::SECONDARY))
+                IFOKDO(err, unitObj.save(true, false))
             }
 
             //status bar
-            if (!err) err = SKGError(0, i18nc("Message for successful user action", "Secondary currency defined."));
+            IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Secondary currency defined.")))
             else err.addError(ERR_FAIL, i18nc("Error message", "Secondary currency definition failed"));
 
             //Display error
@@ -463,8 +461,8 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
             SKGError err;
             SKGUnitObject unitObj(m_currentBankDocument);
             err = unitObj.setName(unit);
-            if (!err) err = unitObj.load();
-            if (!err) err = SKGUnitPluginWidget::downloadUnitValue(unitObj, SKGUnitPluginWidget::getDownloadModeFromSettings());
+            IFOKDO(err, unitObj.load())
+            IFOKDO(err, SKGUnitPluginWidget::downloadUnitValue(unitObj, SKGUnitPluginWidget::getDownloadModeFromSettings()))
 
             //Display error
             SKGMainPanel::displayErrorMessage(err);
@@ -494,7 +492,7 @@ void SKGUnitPlugin::deleteUnusedUnits() const
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Unused units deleted"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Unused units deleted")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Unused units deletion failed"));
 
     //Display error
