@@ -238,7 +238,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     }
 
     //Refresh
-    connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     ui.kWidgetSelector->setSelectedMode(0);
 
     //Fill combo box for reference currency
@@ -266,7 +266,7 @@ SKGUnitPluginWidget::~SKGUnitPluginWidget()
 bool SKGUnitPluginWidget::eventFilter(QObject* object, QEvent* event)
 {
     if (event && event->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = (QKeyEvent*) event;
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object == this) {
             if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kUnitAdd->isEnabled()) {
                 ui.kUnitAdd->click();
@@ -431,19 +431,19 @@ void SKGUnitPluginWidget::onAddUnit()
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit creation '%1'", untiname), err);
 
             //Create unit object
-            if (!err) err = unitObj.setName(untiname);
-            if (!err) err = unitObj.setSymbol(ui.kSymbolCreatorUnit->text());
-            if (!err) err = unitObj.setCountry(ui.kCountryCreatorUnit->text());
-            if (!err) err = unitObj.setInternetCode(ui.kInternetCreatorUnit->text());
-            if (!err) err = unitObj.setType((SKGUnitObject::UnitType)(ui.kTypeCreatorUnit->itemData(ui.kTypeCreatorUnit->currentIndex()).toInt()));
-            if (!err) err = unitObj.setNumberDecimal(ui.kNbDecimal->value());
-            if (!err) err = unitObj.setUnit(ui.kUnitCreatorUnit->getUnit());
-            if (!err) err = unitObj.setDownloadSource(ui.kDownloadSource->text());
-            if (!err) err = unitObj.save();
+            IFOKDO(err, unitObj.setName(untiname))
+            IFOKDO(err, unitObj.setSymbol(ui.kSymbolCreatorUnit->text()))
+            IFOKDO(err, unitObj.setCountry(ui.kCountryCreatorUnit->text()))
+            IFOKDO(err, unitObj.setInternetCode(ui.kInternetCreatorUnit->text()))
+            IFOKDO(err, unitObj.setType(static_cast<SKGUnitObject::UnitType>(ui.kTypeCreatorUnit->itemData(ui.kTypeCreatorUnit->currentIndex()).toInt())))
+            IFOKDO(err, unitObj.setNumberDecimal(ui.kNbDecimal->value()))
+            IFOKDO(err, unitObj.setUnit(ui.kUnitCreatorUnit->getUnit()))
+            IFOKDO(err, unitObj.setDownloadSource(ui.kDownloadSource->text()))
+            IFOKDO(err, unitObj.save())
         }
 
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Unit '%1' created", untiname));
             ui.kUnitTableViewEdition->getView()->selectObject(unitObj.getUniqueID());
         } else err.addError(ERR_FAIL, i18nc("Error message", "Unit creation failed"));
@@ -455,7 +455,7 @@ void SKGUnitPluginWidget::onAddUnit()
             err = static_cast<SKGDocumentBank*>(getDocument())->addOrModifyUnitValue(untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject);
         }
         //status bar
-        if (!err) {
+        IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Unit value created for '%1'", untiname));
             //TODO doesn't work because of unit table is modified an refreshed
             ui.kUnitValueTableViewEdition->selectObject(unitValueObject.getUniqueID());
@@ -498,21 +498,21 @@ void SKGUnitPluginWidget::onModifyUnit()
         for (int i = 0; !err && i < nb; ++i) {
             //Modification of unit object
             SKGUnitObject unitObj(selection[i]);
-            if (!err) err = unitObj.setName(ui.kNameCreatorUnit->text());
-            if (!err) err = unitObj.setSymbol(ui.kSymbolCreatorUnit->text());
-            if (!err) err = unitObj.setCountry(ui.kCountryCreatorUnit->text());
-            if (!err) err = unitObj.setInternetCode(ui.kInternetCreatorUnit->text());
-            if (!err && ui.kTypeCreatorUnit->text() != NOUPDATE) err = unitObj.setType((SKGUnitObject::UnitType)(ui.kTypeCreatorUnit->itemData(ui.kTypeCreatorUnit->currentIndex()).toInt()));
-            if (!err) err = unitObj.setNumberDecimal(ui.kNbDecimal->value());
+            IFOKDO(err, unitObj.setName(ui.kNameCreatorUnit->text()))
+            IFOKDO(err, unitObj.setSymbol(ui.kSymbolCreatorUnit->text()))
+            IFOKDO(err, unitObj.setCountry(ui.kCountryCreatorUnit->text()))
+            IFOKDO(err, unitObj.setInternetCode(ui.kInternetCreatorUnit->text()))
+            if (!err && ui.kTypeCreatorUnit->text() != NOUPDATE) err = unitObj.setType(static_cast<SKGUnitObject::UnitType>(ui.kTypeCreatorUnit->itemData(ui.kTypeCreatorUnit->currentIndex()).toInt()));
+            IFOKDO(err, unitObj.setNumberDecimal(ui.kNbDecimal->value()))
             if (!err && ui.kUnitCreatorUnit->text() != NOUPDATE) err = unitObj.setUnit(ui.kUnitCreatorUnit->getUnit());
             if (!err && ui.kDownloadSource->text() != NOUPDATE) err = unitObj.setDownloadSource(ui.kDownloadSource->text());
-            if (!err) err = unitObj.save();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, unitObj.save())
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Message for successful user action", "Unit updated"));
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Unit updated")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Unit update failed"));
 
     //Display error
@@ -555,7 +555,7 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
 
     SKGUnitObject::UnitDownloadMode mode = SKGUnitObject::LAST;
     KAction* act = qobject_cast<KAction*>(sender());
-    if (act) mode = (SKGUnitObject::UnitDownloadMode) act->data().toInt();
+    if (act) mode = static_cast<SKGUnitObject::UnitDownloadMode>(act->data().toInt());
     else mode = SKGUnitPluginWidget::getDownloadModeFromSettings();
 
     SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
@@ -566,11 +566,11 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
             SKGUnitObject unit(selection.at(i));
             err = downloadUnitValue(unit, mode);
 
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
 
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Download done"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Download done")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Download failed"));
 
     //Display error
@@ -590,11 +590,11 @@ void SKGUnitPluginWidget::onSimplify()
             SKGUnitObject unit(selection.at(i));
             err = unit.simplify();
 
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
     }
 
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Simplification done"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Simplification done")))
     else err.addError(ERR_FAIL, i18nc("Error message", "Simplification failed"));
 
     //Display error
@@ -727,7 +727,7 @@ void SKGUnitPluginWidget::refreshUnitList()
     QApplication::restoreOverrideCursor();
 }
 
-QWidget* SKGUnitPluginWidget::mainWidget() const
+QWidget* SKGUnitPluginWidget::mainWidget()
 {
     if (ui.kUnitValueTableViewEdition->hasFocus())
         return ui.kUnitValueTableViewEdition;
@@ -754,7 +754,7 @@ void SKGUnitPluginWidget::onDeleteSource()
     if (!source.isEmpty() && source != i18nc("Native download source (Yahoo)", "Yahoo") && SKGUnitObject::downloadSources().contains(source)) {
         //This is a new source
         SKGError err = SKGUnitObject::deleteSource(source);
-        if (!err) ui.kDownloadSource->removeItem(ui.kDownloadSource->findText(source));
+        IFOK(err) ui.kDownloadSource->removeItem(ui.kDownloadSource->findText(source));
 
         //Display error
         SKGMainPanel::displayErrorMessage(err);
