@@ -45,7 +45,7 @@
 #define SRC_INTERESTS               "Interests"
 #define SRC_ALARMS                  "Alarms"
 
-SKGDataEngine::SKGDataEngine(QObject* parent, const QVariantList& args): DataEngine(parent, args), document(NULL) {}
+SKGDataEngine::SKGDataEngine(QObject* iParent, const QVariantList& args): DataEngine(iParent, args), document(NULL) {}
 
 SKGDataEngine::~SKGDataEngine()
 {
@@ -105,7 +105,7 @@ bool SKGDataEngine::getAccountData()
     SKGError err = document->executeSelectSqliteOrder("SELECT t_name, t_bank, t_typenls, f_CURRENTAMOUNT, t_close FROM v_account_display ORDER BY t_type,t_name", sqlResult);
 
     // We may receive an error from querying the SQLite database
-    if (err) return false;
+    IFKO(err) return false;
 
     // Put the data in the dataengine
     int nb = sqlResult.count();
@@ -136,7 +136,7 @@ bool SKGDataEngine::getIncomeExpenditureData()
     SKGError err = document->executeSelectSqliteOrder("SELECT d_DATEMONTH, t_TYPEEXPENSE, TOTAL(f_CURRENTAMOUNT) FROM v_operation_display WHERE t_TYPEEXPENSE IN ('+','-') AND d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TRANSFER='N' group by d_DATEMONTH, t_TYPEEXPENSE", data);
 
     // We may receive an error from querying the SQLite database
-    if (err) return false;
+    IFKO(err) return false;
 
     // Put the data in the dataengine
     int nb = data.count();
@@ -161,7 +161,7 @@ bool SKGDataEngine::getHighlightedOperationData()
     SKGError err = document->executeSelectSqliteOrder("SELECT id, d_date, t_payee, f_currentamount FROM v_operation_display WHERE t_bookmarked='Y' ORDER BY d_date", sqlResult);
 
     // We may receive an error from querying the SQLite database
-    if (err) return false;
+    IFKO(err) return false;
 
     // Put the data in the dataengine
     int nb = sqlResult.count();
@@ -188,7 +188,7 @@ bool SKGDataEngine::getScheduledOperationData()
     SKGError err = document->executeSelectSqliteOrder("SELECT id, d_date, t_payee, f_currentamount FROM v_recurrentoperation_display ORDER BY d_date LIMIT 5", sqlResult);
 
     // We may receive an error from querying the SQLite database
-    if (err) return false;
+    IFKO(err) return false;
 
     // Put the data in the dataengine
     int nb = sqlResult.count();
@@ -215,7 +215,7 @@ bool SKGDataEngine::getUnitsData()
     SKGError err = document->executeSelectSqliteOrder("SELECT id FROM v_unit_display WHERE t_type != 1 ORDER BY t_type ASC, t_name ASC", sqlResult);
 
     // We may receive an error from querying the SQLite database
-    if (err) return false;
+    IFKO(err) return false;
 
     // Put the data in the dataengine
     int nb = sqlResult.count();
@@ -280,7 +280,7 @@ bool SKGDataEngine::getInterestsData()
     SKGError err = document->executeSelectSqliteOrder("SELECT id,t_name FROM v_account WHERE t_close='N' AND EXISTS(select 1 from interest where interest.rd_account_id=v_account.id) ORDER BY t_name", sqlResult);
 
     // We may receive an error from querying the SQLite database
-    if (err) return false;
+    IFKO(err) return false;
 
     // Put the data in the dataengine
     int nb = sqlResult.count();
@@ -315,7 +315,7 @@ bool SKGDataEngine::getAlarmsData()
     SKGError err = document->executeSelectSqliteOrder("SELECT id FROM v_rule WHERE t_action_type='A'", sqlResult);
 
     // We may receive an error from querying the SQLite database
-    if (err) return false;
+    IFKO(err) return false;
 
     // Put the data in the dataengine
     int nb = sqlResult.count();
