@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGBKWidgetCollectionDesignerPlugin::SKGBKWidgetCollectionDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGBKWidgetCollectionDesignerPlugin::SKGBKWidgetCollectionDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_widgets.append(new SKGQueryCreatorDesignerPlugin(this));
     m_widgets.append(new SKGPredicatCreatorDesignerPlugin(this));
