@@ -36,9 +36,9 @@ class SKGBANKGUI_EXPORT SKGBKWidgetCollectionDesignerPlugin: public QObject, pub
 public:
     /**
      * Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGBKWidgetCollectionDesignerPlugin(QObject* parent = 0);
+    explicit SKGBKWidgetCollectionDesignerPlugin(QObject* iParent = 0);
 
     /**
      * To get the list of widgets
