@@ -50,10 +50,10 @@
 SKGObjectModel::SKGObjectModel(SKGDocumentBank* iDocument,
                                const QString& iTable,
                                const QString& iWhereClause,
-                               QWidget* parent,
+                               QWidget* iParent,
                                const QString& iParentAttribute,
                                bool iResetOnCreation)
-    : SKGObjectModelBase(iDocument, iTable, iWhereClause, parent, iParentAttribute, false)
+    : SKGObjectModelBase(iDocument, iTable, iWhereClause, iParent, iParentAttribute, false)
 {
     SKGTRACEIN(1, "SKGObjectModel::SKGObjectModel");
 
@@ -81,14 +81,14 @@ void SKGObjectModel::buidCache()
     m_budgetRuleTable = (getRealTable() == "budgetrule");
 
     if (m_unitvalueTable) {
-        SKGUnitValueObject unitValObject(getObject(index(0, 0)));
+        SKGUnitValueObject unitValObject(getObject(this->index(0, 0)));
         SKGUnitObject unitObject;
         unitValObject.getUnit(unitObject);
-        SKGUnitObject parent;
-        unitObject.getUnit(parent);
-        if (parent.exist()) {
-            m_cacheUnit.Name = parent.getName();
-            m_cacheUnit.Symbol = parent.getSymbol();
+        SKGUnitObject parentUnit;
+        unitObject.getUnit(parentUnit);
+        if (parentUnit.exist()) {
+            m_cacheUnit.Name = parentUnit.getName();
+            m_cacheUnit.Symbol = parentUnit.getSymbol();
             m_cacheUnit.Value = 1;
             m_cacheUnit.NbDecimal = unitObject.getNumberDecimal();
         } else {
@@ -252,22 +252,6 @@ QVariant SKGObjectModel::data(const QModelIndex& index, int role) const
                 }
                 return val;
             } else return "";
-        } else if (m_accountTable && att == "t_type") {
-            if (val == "C") return i18nc("Noun, a type of account", "Current");
-            else if (val == "D") return i18nc("Noun, a type of account", "Credit card");
-            else if (val == "A") return i18nc("Noun, a type of account", "Assets");
-            else if (val == "I") return i18nc("Noun, a type of account", "Investment");
-            else if (val == "W") return i18nc("Noun, a type of account", "Wallet");
-            else if (val == "L") return i18nc("Noun, a type of account", "Loan");
-            else if (val == "S") return i18nc("Noun, a type of account", "Saving");
-            else return i18nc("Noun", "Other");
-        } else if (m_unitTable && att == "t_type") {
-            if (val == "1") return i18nc("Noun", "Primary currency");
-            else if (val == "2") return i18nc("Noun", "Secondary currency");
-            else if (val == "C") return i18nc("Noun", "Currency");
-            else if (val == "S") return i18nc("Noun", "Share");
-            else if (val == "I") return i18nc("Noun, example CAC40, DOWJONES", "Index");
-            else return i18nc("Noun", "Object");
         } else if (m_interestTable && att == "t_expenditure_value_date_mode") {
             if (val == "0") return i18nc("Noun", "Day -0");
             else if (val == "1") return i18nc("Noun", "Day -1");
@@ -448,7 +432,7 @@ else return KIcon();
             QString att = m_listAttibutes[index.column()];
 
             if (att == "i_auto_write_days" || att == "i_warn_days" || att == "i_nb_times") {
-                return (int)(Qt::AlignVCenter | Qt::AlignLeft);
+                return static_cast<int>(Qt::AlignVCenter | Qt::AlignLeft);
             }
         }
         break;
@@ -605,7 +589,7 @@ else return KIcon();
                 }
             }
 
-            if (m_operationTable && toolTipString.isEmpty()) {
+            if (m_operationTable && toolTipString.isEmpty() && obj) {
                 SKGOperationObject op(*obj);
                 if (op.getStatus() == SKGOperationObject::POINTED) {
                     toolTipString = i18nc("A tool tip", "This operation is pointed but not checked yet.");
@@ -641,7 +625,6 @@ else return KIcon();
             toolTipString += toolTipStringBase;
         }
         return toolTipString;
-        break;
     }
     default: {
     }
@@ -659,16 +642,16 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
             if (m_accountTable) {
                 SKGAccountObject obj(getObject(index));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
-                                         ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
+                                         (static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
                 if (abs(obj.getCurrentAmount()) > 0.01) err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"), SKGDocument::Warning);
-                if (!err) err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
-                if (!err) err = obj.save();
+                IFOKDO(err, obj.setClosed(static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked))
+                IFOKDO(err, obj.save())
             } else if (m_trackerTable) {
                 SKGTrackerObject obj(getObject(index));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
-                                         ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
-                err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
-                if (!err) err = obj.save();
+                                         (static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
+                err = obj.setClosed(static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked);
+                IFOKDO(err, obj.save())
             } else if (m_operationTable) {
                 //Get the real object, not the object from the view
                 SKGObjectBase* objtmp = getObjectPointer(index);
@@ -688,7 +671,7 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                     }
                     if (t_status != statusinitial) {
                         err = obj.setStatus(t_status);
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     }
                 }
             } else if (m_recurrentoperationTable) {
@@ -702,13 +685,13 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Recurrent operation update"), err);
                     if (att == "i_warn_days") {
                         err = obj.warnEnabled(!obj.isWarnEnabled());
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     } else if (att == "i_auto_write_days") {
                         err = obj.autoWriteEnabled(!obj.isAutoWriteEnabled());
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     } else if (att == "i_nb_times") {
                         err = obj.timeLimit(!obj.hasTimeLimit());
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     }
                 }
             } else if (m_budgetRuleTable) {
@@ -722,16 +705,16 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err);
                     if (att == "i_year") {
                         err = obj.enableYearCondition(!obj.isYearConditionEnabled());
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     } else if (att == "i_month") {
                         err = obj.enableMonthCondition(!obj.isMonthConditionEnabled());
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     } else if (att == "t_CATEGORYCONDITION") {
                         err = obj.enableCategoryCondition(!obj.isCategoryConditionEnabled());
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     } else if (att == "t_CATEGORY") {
                         err = obj.enableCategoryChange(!obj.isCategoryChangeEnabled());
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     }
                 }
             } else if (m_budgetTable) {
@@ -745,7 +728,7 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                     SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget update"), err);
                     if (att == "t_CATEGORY") {
                         err = obj.enableSubCategoriesInclusion(!obj.isSubCategoriesInclusionEnabled());
-                        if (!err) err = obj.save();
+                        IFOKDO(err, obj.save())
                     }
                 }
             }
@@ -791,9 +774,9 @@ Qt::DropActions SKGObjectModel::supportedDropActions() const
 bool SKGObjectModel::dropMimeData(const QMimeData* data,
                                   Qt::DropAction action,
                                   int row, int column,
-                                  const QModelIndex& parent)
+                                  const QModelIndex& iParent)
 {
-    if (SKGObjectModelBase::dropMimeData(data, action, row, column, parent)) return true;
+    if (SKGObjectModelBase::dropMimeData(data, action, row, column, iParent)) return true;
     if (action == Qt::IgnoreAction) return true;
     if (!data || !(data->hasFormat("application/skg.category.ids") ||
                    data->hasFormat("application/skg.payee.ids") ||
@@ -810,7 +793,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
         QStringList newItems;
 
         SKGCategoryObject parentCategory;
-        if (parent.isValid()) parentCategory = getObject(parent);
+        if (iParent.isValid()) parentCategory = getObject(iParent);
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Move category"), err);
 
@@ -822,11 +805,11 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
                 SKGCategoryObject child(getDocument(), o_id);
                 err = child.load();
-                if (!err) {
-                    if (parent.isValid()) err = child.setParentCategory(parentCategory);
+                IFOK(err) {
+                    if (iParent.isValid()) err = child.setParentCategory(parentCategory);
                     else err = child.removeParentCategory();
                 }
-                if (!err) err = child.save();
+                IFOKDO(err, child.save())
             }
         }
     } else if (data->hasFormat("application/skg.payee.ids")) {
@@ -834,9 +817,9 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
-        if (parent.isValid()) {
+        if (iParent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge payees"), err);
-            SKGPayeeObject parentPayee(getObject(parent));
+            SKGPayeeObject parentPayee(getObject(iParent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
@@ -845,7 +828,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
                 SKGPayeeObject child(getDocument(), o_id);
                 err = child.load();
-                if (!err) err = parentPayee.merge(child);
+                IFOKDO(err, parentPayee.merge(child))
             }
         }
     } else if (data->hasFormat("application/skg.account.ids")) {
@@ -853,9 +836,9 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
-        if (parent.isValid()) {
+        if (iParent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge accounts"), err);
-            SKGAccountObject parentAccount(getObject(parent));
+            SKGAccountObject parentAccount(getObject(iParent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
@@ -864,7 +847,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
                 SKGAccountObject child(getDocument(), o_id);
                 err = child.load();
-                if (!err) err = parentAccount.merge(child);
+                IFOKDO(err, parentAccount.merge(child))
             }
         }
     } else if (data->hasFormat("application/skg.unit.ids")) {
@@ -872,9 +855,9 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
-        if (parent.isValid()) {
+        if (iParent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge units"), err);
-            SKGUnitObject parentUnit(getObject(parent));
+            SKGUnitObject parentUnit(getObject(iParent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
@@ -883,7 +866,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
                 SKGUnitObject child(getDocument(), o_id);
                 err = child.load();
-                if (!err) err = parentUnit.merge(child);
+                IFOKDO(err, parentUnit.merge(child))
             }
         }
     } else if (data->hasFormat("application/skg.refund.ids")) {
@@ -891,9 +874,9 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
-        if (parent.isValid()) {
+        if (iParent.isValid()) {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Merge trackers"), err);
-            SKGTrackerObject trackerUnit(getObject(parent));
+            SKGTrackerObject trackerUnit(getObject(iParent));
             while (!stream.atEnd() && !err) {
                 int o_id;
                 QString o_table;
@@ -902,7 +885,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* data,
 
                 SKGTrackerObject child(getDocument(), o_id);
                 err = child.load();
-                if (!err) err = trackerUnit.merge(child);
+                IFOKDO(err, trackerUnit.merge(child))
             }
         }
     }
