@@ -43,14 +43,14 @@ public:
      * @param iDocument the document where to search
      * @param iTable the table where to search
      * @param iWhereClause the where clause
-     * @param parent parent QT object
+     * @param iParent parent QT object
      * @param iParentAttribute the attribute to find the parent of an object clause to find children
      * @param iResetOnCreation to reset data during creation
      */
     explicit SKGObjectModel(SKGDocumentBank* iDocument,
                             const QString& iTable,
                             const QString& iWhereClause,
-                            QWidget* parent = NULL,
+                            QWidget* iParent = NULL,
                             const QString& iParentAttribute = "",
                             bool iResetOnCreation = true);
 
@@ -113,13 +113,13 @@ public:
      * @param action action
      * @param row row
      * @param column column
-     * @param parent parent
+     * @param iParent parent
      * @return true if the dropping was successful otherwise false.
      */
     virtual bool dropMimeData(const QMimeData* data,
                               Qt::DropAction action,
                               int row, int column,
-                              const QModelIndex& parent);
+                              const QModelIndex& iParent);
 
 protected Q_SLOTS:
     /**
