@@ -33,8 +33,8 @@
 #include <QCheckBox>
 #include <QApplication>
 
-SKGPredicatCreator::SKGPredicatCreator(QWidget* parent, SKGDocument* document, const QString& attribute, bool iModeUpdate, const QStringList& iListAtt)
-    : QWidget(parent), m_updateMode(iModeUpdate), m_kValue1(NULL), m_kValue2(NULL), m_kAttributes(NULL)
+SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document, const QString& attribute, bool iModeUpdate, const QStringList& iListAtt)
+    : QWidget(iParent), m_updateMode(iModeUpdate), m_kValue1(NULL), m_kValue2(NULL), m_kAttributes(NULL)
 {
     SKGServices::AttributeType attType = SKGServices::TEXT;
     if (document) attType = document->getAttributeType(attribute);
