@@ -47,13 +47,13 @@ class SKGBANKGUI_EXPORT SKGPredicatCreator : public QWidget
 public:
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      * @param document the document
      * @param attribute name of the attribute
      * @param iSQL to enable sql mode
      * @param iListAtt list of attribute
      */
-    explicit SKGPredicatCreator(QWidget* parent = 0, SKGDocument* document = NULL, const QString& attribute = "",
+    explicit SKGPredicatCreator(QWidget* iParent = 0, SKGDocument* document = NULL, const QString& attribute = "",
                                 bool iSQL = false, const QStringList& iListAtt = QStringList());
 
     /**
