@@ -29,8 +29,8 @@
 #include <QDomDocument>
 #include <QHeaderView>
 
-SKGQueryCreator::SKGQueryCreator(QWidget* parent)
-    : QWidget(parent), m_document(NULL), m_updateMode(false)
+SKGQueryCreator::SKGQueryCreator(QWidget* iParent)
+    : QWidget(iParent), m_document(NULL), m_updateMode(false)
 {
     ui.setupUi(this);
 
@@ -39,7 +39,7 @@ SKGQueryCreator::SKGQueryCreator(QWidget* parent)
     ui.kList->setWordWrap(false);
     ui.kList->horizontalHeader()->setMovable(true);
 
-    connect(ui.kList, SIGNAL(removeSelectedItems()), this, SLOT(onRemoveLine()));
+    connect(ui.kList, SIGNAL(removeLine(int)), this, SLOT(removeLine(int)));
 
 
     addNewLine();
@@ -99,8 +99,8 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
         }
         ui.kListAtt->sortItems();
         ui.kListAtt->setModelColumn(nbCol);
-        connect(ui.kList->verticalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(onRemoveLine(int)));
-        connect(ui.kList->horizontalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(onRemoveColumn(int)));
+        connect(ui.kList->verticalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(removeLine(int)));
+        connect(ui.kList->horizontalHeader(), SIGNAL(sectionClicked(int)), this, SLOT(removeColumn(int)));
 
         addNewLine();
     }
@@ -111,7 +111,7 @@ int SKGQueryCreator::getIndexQueryColumn(const QString& iAttribute , int row)
     //Search column for this attribute
     int output = -1;
     int nbCol = ui.kList->columnCount();
-    for (int i = 0; i < nbCol; ++i) {
+    for (int i = 0; i < nbCol && output == -1; ++i) {
         QTableWidgetItem* it_h = ui.kList->horizontalHeaderItem(i);
         if (it_h && iAttribute == it_h->data(Qt::UserRole).toString()) {
             if (row >= 0) {
@@ -120,12 +120,10 @@ int SKGQueryCreator::getIndexQueryColumn(const QString& iAttribute , int row)
                 if (it) {
                     if (it->text().isEmpty()) {
                         output = i;
-                        break;
                     }
                 }
             } else {
                 output = i;
-                break;
             }
         }
     }
@@ -341,49 +339,27 @@ void SKGQueryCreator::addNewLine()
     }
 }
 
-void SKGQueryCreator::onRemoveColumn(int iColumn)
+int SKGQueryCreator::getColumnsCount()
 {
-    QList<int> colToRemove;
-    if (iColumn != -1) {
-        colToRemove.append(iColumn);
-    } else {
-        QList<QTableWidgetItem*> selectedItems = ui.kList->selectedItems();
-        int nb = selectedItems.count();
-        for (int i = 0; i < nb; ++i) {
-            QTableWidgetItem* item = selectedItems.at(i);
-            int row = item->row();
-            if (!colToRemove.contains(row)) {
-                colToRemove.append(row);
-            }
-        }
-    }
-    for (int j = colToRemove.count() - 1; j >= 0 ; --j) {
-        ui.kList->removeColumn(colToRemove.at(j));
-    }
+    return ui.kList->horizontalHeader()->count();
+}
+
+int SKGQueryCreator::getLinesCount()
+{
+    return ui.kList->rowCount();
+}
+
+void SKGQueryCreator::removeColumn(int iColumn)
+{
+    ui.kList->removeColumn(iColumn);
 
     // To be sure that we have at least an empty line
     onCloseEditor();
 }
 
-void SKGQueryCreator::onRemoveLine(int iRow)
+void SKGQueryCreator::removeLine(int iRow)
 {
-    QList<int> rowsToRemove;
-    if (iRow != -1) {
-        if (!m_updateMode) rowsToRemove.append(iRow);
-    } else {
-        QList<QTableWidgetItem*> selectedItems = ui.kList->selectedItems();
-        int nb = selectedItems.count();
-        for (int i = 0; i < nb; ++i) {
-            QTableWidgetItem* item = selectedItems.at(i);
-            int row = item->row();
-            if (!rowsToRemove.contains(row)) {
-                rowsToRemove.append(row);
-            }
-        }
-    }
-    for (int j = rowsToRemove.count() - 1; j >= 0 ; --j) {
-        ui.kList->removeRow(rowsToRemove.at(j));
-    }
+    ui.kList->removeRow(iRow);
 
     // To be sure that we have at least an empty line
     onCloseEditor();
