@@ -40,9 +40,9 @@ class SKGBANKGUI_EXPORT SKGQueryCreator : public QWidget
 public:
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGQueryCreator(QWidget* parent = 0);
+    explicit SKGQueryCreator(QWidget* iParent = 0);
 
     /**
      * Default Destructor
@@ -70,21 +70,47 @@ public:
      */
     virtual QString getXMLCondition();
 
+    /**
+     * Get the number of line
+     * @return the number of line
+     */
+    virtual int getLinesCount();
+
+    /**
+     * Get the number of line
+     * @return the number of line
+     */
+    virtual int getColumnsCount();
+
 public Q_SLOTS:
     /**
      * Clear table content
      */
-    void clearContents();
+    virtual void clearContents();
+
+    /**
+     * Remove a line
+     * @param iRow the index of the line (-1 for all)
+     */
+    virtual void removeLine(int iRow = -1);
+
+    /**
+     * Remove a column
+     * @param iColumn the index of the column
+     */
+    virtual void removeColumn(int iColumn);
+
+    /**
+     * Add a new line
+     */
+    virtual void addNewLine();
 
 private Q_SLOTS:
-    void onRemoveLine(int iRow = -1);
-    void onRemoveColumn(int iColumn = -1);
     void onCloseEditor();
     void onAddColumn();
 private:
     Q_DISABLE_COPY(SKGQueryCreator)
 
-    void addNewLine();
     int getIndexQueryColumn(const QString& iAttribute, int row = -1);
     void addColumnFromAttribut(const QListWidgetItem* listItem);
 
