@@ -28,8 +28,8 @@
 #include <QTableWidget>
 #include <QPainter>
 
-SKGQueryDelegate::SKGQueryDelegate(QObject* parent, SKGDocument* iDoc, bool iModeUpdate, const QStringList& iListAtt):
-    QItemDelegate(parent), m_document(iDoc), m_updateMode(iModeUpdate), m_listAtt(iListAtt)
+SKGQueryDelegate::SKGQueryDelegate(QObject* iParent, SKGDocument* iDoc, bool iModeUpdate, const QStringList& iListAtt):
+    QItemDelegate(iParent), m_document(iDoc), m_updateMode(iModeUpdate), m_listAtt(iListAtt)
 {
 }
 
@@ -38,17 +38,17 @@ SKGQueryDelegate::~SKGQueryDelegate()
     m_document = NULL;
 }
 
-QWidget* SKGQueryDelegate::createEditor(QWidget* parent,
+QWidget* SKGQueryDelegate::createEditor(QWidget* iParent,
                                         const QStyleOptionViewItem& option ,
                                         const QModelIndex& index) const
 {
     SKGTRACEIN(1, "SKGQueryDelegate::createEditor");
     Q_UNUSED(option);
 
-    QTableWidgetItem* it_h = ((QTableWidget*) this->parent())->horizontalHeaderItem(index.column());
+    QTableWidgetItem* it_h = (static_cast<QTableWidget*>(this->parent()))->horizontalHeaderItem(index.column());
     QString attname = it_h->data(Qt::UserRole).toString();
 
-    SKGPredicatCreator* editor = new SKGPredicatCreator(parent, m_document, attname, m_updateMode, m_listAtt);
+    SKGPredicatCreator* editor = new SKGPredicatCreator(iParent, m_document, attname, m_updateMode, m_listAtt);
     connect(editor, SIGNAL(editingFinished()), this, SLOT(commitAndCloseEditor()));
     return editor;
 }
