@@ -37,7 +37,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit SKGQueryDelegate(QObject* parent = 0, SKGDocument* iDoc = NULL, bool iModeUpdate = false, const QStringList& iListAtt = QStringList());
+    explicit SKGQueryDelegate(QObject* iParent = 0, SKGDocument* iDoc = NULL, bool iModeUpdate = false, const QStringList& iListAtt = QStringList());
 
     /**
      * Default Destructor
@@ -47,12 +47,12 @@ public:
     /**
      * Returns the widget used to edit the item specified by index for editing.
      * The parent widget and style option are used to control how the editor widget appears.
-     * @param parent perant widget
+     * @param iParent perant widget
      * @param option options
      * @param index index
      * @return the widget
      */
-    QWidget* createEditor(QWidget* parent,
+    QWidget* createEditor(QWidget* iParent,
                           const QStyleOptionViewItem& option ,
                           const QModelIndex& index) const;
 
