@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGUnitComboBoxDesignerPlugin::SKGUnitComboBoxDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGUnitComboBoxDesignerPlugin::SKGUnitComboBoxDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGUnitComboBoxDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGUnitComboBoxDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGUnitComboBoxDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGUnitComboBox(parent);
+    return new SKGUnitComboBox(iParent);
 }
 
 QString SKGUnitComboBoxDesignerPlugin::name() const
