@@ -72,18 +72,18 @@ SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObjec
         err = getDocument()->executeSqliteOrder("DELETE FROM operation  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()));
 
         //Creation of new initial balance
-        if (!err) {
+        IFOK(err) {
             SKGOperationObject initialBalanceOp;
             err = addOperation(initialBalanceOp, true);
-            if (!err) err = initialBalanceOp.setAttribute("d_date", "0000-00-00");
-            if (!err) err = initialBalanceOp.setUnit(iUnit);
-            if (!err) err = initialBalanceOp.setStatus(SKGOperationObject::CHECKED);
-            if (!err) err = initialBalanceOp.save();
+            IFOKDO(err, initialBalanceOp.setAttribute("d_date", "0000-00-00"))
+            IFOKDO(err, initialBalanceOp.setUnit(iUnit))
+            IFOKDO(err, initialBalanceOp.setStatus(SKGOperationObject::CHECKED))
+            IFOKDO(err, initialBalanceOp.save())
 
             SKGSubOperationObject initialBalanceSubOp;
-            if (!err) err = initialBalanceOp.addSubOperation(initialBalanceSubOp);
-            if (!err) err = initialBalanceSubOp.setQuantity(iBalance);
-            if (!err) err = initialBalanceSubOp.save();
+            IFOKDO(err, initialBalanceOp.addSubOperation(initialBalanceSubOp))
+            IFOKDO(err, initialBalanceSubOp.setQuantity(iBalance))
+            IFOKDO(err, initialBalanceSubOp.save())
         }
     }
     return err;
@@ -107,7 +107,7 @@ SKGError SKGAccountObject::getInitialBalance(double& oBalance, SKGUnitObject& oU
 
         oUnit = SKGUnitObject(getDocument());
         err = oUnit.setSymbol(unitName);
-        if (!err) err = oUnit.load();
+        IFOKDO(err, oUnit.load())
     }
     return err;
 }
@@ -219,10 +219,10 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
                 QString unitid = listTmp.at(i).at(1);
 
                 double coef = 1;
-                QString val = getDocument()->getCachedValue("unitvalue-" % unitid);
-                if (!val.isEmpty()) {
+                QString val2 = getDocument()->getCachedValue("unitvalue-" % unitid);
+                if (!val2.isEmpty()) {
                     //Yes
-                    coef = SKGServices::stringToDouble(val);
+                    coef = SKGServices::stringToDouble(val2);
                 } else {
                     //No
                     SKGUnitObject unit(getDocument(), SKGServices::stringToInt(unitid));
@@ -231,7 +231,7 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
 
                 output += coef * SKGServices::stringToDouble(quantity);
             }
-            ((SKGDocument*) getDocument())->addValueInCache(key, SKGServices::doubleToString(output));
+            (static_cast<SKGDocument*>(getDocument()))->addValueInCache(key, SKGServices::doubleToString(output));
         } else {
             output = SKGServices::stringToDouble(val);
         }
@@ -241,16 +241,14 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
 
 SKGError SKGAccountObject::setType(SKGAccountObject::AccountType iType)
 {
-    SKGError err;
-    if (!err) err = setAttribute("t_type", (iType == CURRENT ? "C" :
-                                                (iType == CREDITCARD ? "D" :
-                                                        (iType == ASSETS ? "A" :
-                                                                (iType == INVESTMENT ? "I" :
-                                                                        (iType == WALLET ? "W" :
-                                                                                (iType == LOAN ? "L" :
-                                                                                        (iType == SAVING ? "S" :
-                                                                                                "O"))))))));
-    return err;
+    return setAttribute("t_type", (iType == CURRENT ? "C" :
+                                   (iType == CREDITCARD ? "D" :
+                                    (iType == ASSETS ? "A" :
+                                     (iType == INVESTMENT ? "I" :
+                                      (iType == WALLET ? "W" :
+                                       (iType == LOAN ? "L" :
+                                        (iType == SAVING ? "S" :
+                                         "O"))))))));
 }
 
 SKGAccountObject::AccountType SKGAccountObject::getType() const
@@ -336,13 +334,13 @@ SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
     //Get initial amount
     SKGStringListList listTmp;
     SKGError err = getDocument()->executeSelectSqliteOrder("SELECT t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
-    if (!err) {
+    IFOK(err) {
         //Is initial amount existing ?
         if (listTmp.count() > 1) {
             //Yes ==> then the amount is the amount of the initial value
             oUnit = SKGUnitObject(getDocument());
             err = oUnit.setSymbol(listTmp.at(1).at(0));
-            if (!err) err = oUnit.load();
+            IFOKDO(err, oUnit.load())
         } else {
             //No ==> we get the preferred unit
             SKGObjectBase::SKGListSKGObjectBase units;
@@ -387,10 +385,10 @@ SKGError SKGAccountObject::getInterest(const QDate& iDate, SKGInterestObject& oI
                    oInterest);
 
     //If not found then get first
-    if (err) err = SKGObjectBase::getDocument()->getObject("v_interest",
-                       "rd_account_id=" % SKGServices::intToString(getID()) % " AND d_date=(SELECT MIN(d_date) FROM interest WHERE rd_account_id=" %
-                       SKGServices::intToString(getID()) % ')',
-                       oInterest);
+    IFKO(err) err = SKGObjectBase::getDocument()->getObject("v_interest",
+                    "rd_account_id=" % SKGServices::intToString(getID()) % " AND d_date=(SELECT MIN(d_date) FROM interest WHERE rd_account_id=" %
+                    SKGServices::intToString(getID()) % ')',
+                    oInterest);
     return err;
 }
 
@@ -432,14 +430,14 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
     }
 
     //Add interest
-    if (!err) {
+    IFOK(err) {
         err = getDocument()->getObjects("v_interest", "rd_account_id=" % SKGServices::intToString(getID()) %
                                         " AND d_date>='" % SKGServices::dateToSqlString(QDateTime(initialDate)) % "' "
                                         " AND d_date<='" % SKGServices::dateToSqlString(QDateTime(lastDate)) % "' ORDER BY d_date", items);
 
         int pos = 0;
-        int nb = items.count();
-        for (int i = 0; !err && i < nb; ++i) {
+        int nb2 = items.count();
+        for (int i = 0; !err && i < nb2; ++i) {
             SKGInterestObject ob(items.at(i));
 
             SKGInterestItem itemI;
@@ -453,8 +451,8 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
             itemI.accruedInterest = 0;
             itemI.amount = 0;
 
-            int nb2 = oInterestList.count();
-            for (int j = pos; !err && j < nb2; ++j) {
+            int nb3 = oInterestList.count();
+            for (int j = pos; !err && j < nb3; ++j) {
                 if (itemI.date <= oInterestList.at(j).date) {
                     break;
                 } else {
@@ -468,7 +466,7 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
     }
 
     //Get first interest
-    if (!err) {
+    IFOK(err) {
         SKGInterestObject firstInterest;
         if (getInterest(initialDate, firstInterest).isSucceeded()) {
             if (firstInterest.getDate() < initialDate) {
@@ -490,15 +488,15 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
     }
 
     //Launch computation
-    if (!err) {
+    IFOK(err) {
         if (computationNeeded) {
 
             err = computeInterestItems(oInterestList, oInterests, y);
         } else {
             //Drop temporary table
-            if (!err) err = getDocument()->executeSqliteOrder("DROP TABLE IF EXISTS interest_result");
+            IFOKDO(err, getDocument()->executeSqliteOrder("DROP TABLE IF EXISTS interest_result"))
             //Create fake table
-            if (!err) err = getDocument()->executeSqliteOrder("CREATE TEMP TABLE interest_result(a)");
+            IFOKDO(err, getDocument()->executeSqliteOrder("CREATE TEMP TABLE interest_result(a)"))
         }
     }
     return err;
@@ -558,7 +556,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
                         else tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
                     }
                 } else {
-                    tmp.valueDate = tmp.date.addDays(tmp.amount >= 0 ? ((int) valueMode) - 1 : - ((int) valueMode) + 1);
+                    tmp.valueDate = tmp.date.addDays(tmp.amount >= 0 ? (static_cast<int>(valueMode)) - 1 : - (static_cast<int>(valueMode)) + 1);
                 }
             }
 
@@ -614,7 +612,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
     }
 
     //Create temporary table
-    if (!err) {
+    IFOK(err) {
         QStringList sqlOrders;
         sqlOrders << "DROP TABLE IF EXISTS interest_result"
                   << "CREATE TEMP TABLE interest_result("
@@ -631,8 +629,8 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
         err = getDocument()->executeSqliteOrders(sqlOrders);
 
         //Fill table
-        int nb = ioInterestList.count();
-        for (int i = 0; !err && i < nb; ++i) {
+        int nb2 = ioInterestList.count();
+        for (int i = 0; !err && i < nb2; ++i) {
             SKGInterestItem interest = ioInterestList.at(i);
             SKGObjectBase object = interest.object;
             QString sqlinsert =
@@ -683,7 +681,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         //Get all imported operation
         double diff = balance - iBalance;
         SKGObjectBase::SKGListSKGObjectBase operations;
-        if (!err) err = getDocument()->getObjects("v_operation", "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='N' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations);
+        IFOKDO(err, getDocument()->getObjects("v_operation", "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='N' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations))
 
 
         //Comparison
@@ -715,7 +713,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
             for (int i = 0; !err && i <= limit; ++i) {
                 SKGOperationObject op(operations.at(i));
                 err = op.setStatus(SKGOperationObject::POINTED);
-                if (!err) err = op.save(true, false);
+                IFOKDO(err, op.save(true, false))
             }
         } else {
             err = SKGError(ERR_FAIL, i18nc("Error message",  "Can not find the imported operations for obtaining the expected final balance"));
@@ -737,16 +735,16 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
 
     double balance2;
     SKGUnitObject unit2;
-    if (!err) err = const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2);
+    IFOKDO(err, const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2))
 
     //Transfert operations
     SKGObjectBase::SKGListSKGObjectBase ops;
-    if (!err) err = iAccount.getOperations(ops);
+    IFOKDO(err, iAccount.getOperations(ops))
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
         SKGOperationObject op(ops.at(i));
         err = op.setParentAccount(*this);
-        if (!err) err = op.save(true, false);
+        IFOKDO(err, op.save(true, false))
     }
 
     //Set initial balance
@@ -754,10 +752,10 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
     if (!unit1.exist()) unit = unit2;
     if (unit.exist()) {
         double balance = balance1 + SKGUnitObject::convert(balance2, unit2, unit);
-        if (!err) err = setInitialBalance(balance, unit);
+        IFOKDO(err, setInitialBalance(balance, unit))
     }
     //Remove account
-    if (!err) err = iAccount.remove();
+    IFOKDO(err, iAccount.remove())
     return err;
 }
 
