@@ -198,10 +198,11 @@ public:
     /**
      * Add a new operation to this account
      * @param oOperation the created operation
+     * @param iForce force the creation even if the account is closed
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError addOperation(SKGOperationObject& oOperation);
+    virtual SKGError addOperation(SKGOperationObject& oOperation, bool iForce = false);
 
     /**
      * Get number of operations
@@ -260,7 +261,7 @@ public:
     virtual bool isClosed() const;
 
     /**
-     * To bookmark or not an account
+     * To bookmark or not on an account
      * @param iBookmark the bookmark: true or false
      * @return an object managing the error
      *   @see SKGError
@@ -274,6 +275,66 @@ public:
      */
     virtual bool isBookmarked() const;
 
+    /**
+     * To enable the max amount limit or not on an account
+     * @param iEnabled the state: true or false
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError maxLimitAmountEnabled(bool iEnabled);
+
+    /**
+     * To know if the account has a max amount limit
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual bool isMaxLimitAmountEnabled() const;
+
+    /**
+     * To set the max amount limit
+     * @param iAmount the amount (in account's unit)
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setMaxLimitAmount(double iAmount);
+
+    /**
+     * To get the max amount limit (in account's unit)
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual double getMaxLimitAmount() const;
+
+    /**
+     * To enable the min amount limit or not on an account
+     * @param iEnabled the state: true or false
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError minLimitAmountEnabled(bool iEnabled);
+
+    /**
+     * To know if the account has a min amount limit
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual bool isMinLimitAmountEnabled() const;
+
+    /**
+     * To set the min amount limit
+     * @param iAmount the amount (in account's unit)
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setMinLimitAmount(double iAmount);
+
+    /**
+     * To get the min amount limit (in account's unit)
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual double getMinLimitAmount() const;
+
     /**
      * Get the unit
      * @param oUnit the unit
