@@ -24,6 +24,7 @@
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 #include "skgcategoryobject.h"
+#include "skgtransactionmng.h"
 
 #include <klocale.h>
 
@@ -123,18 +124,18 @@ SKGError SKGBudgetRuleObject::removeBudgetCategory()
 
 SKGError SKGBudgetRuleObject::setCondition(SKGBudgetRuleObject::Condition iCondition)
 {
-    return setAttribute("i_condition", SKGServices::intToString((int) iCondition));
+    return setAttribute("i_condition", SKGServices::intToString(static_cast<int>(iCondition)));
 }
 
 SKGBudgetRuleObject::Condition SKGBudgetRuleObject::getCondition() const
 {
-    return (SKGBudgetRuleObject::Condition) SKGServices::stringToInt(getAttribute("i_condition"));
+    return static_cast<SKGBudgetRuleObject::Condition>(SKGServices::stringToInt(getAttribute("i_condition")));
 }
 
 SKGError SKGBudgetRuleObject::setQuantity(double iQuantity, bool iAbsolute)
 {
     SKGError err = setAttribute("f_quantity", SKGServices::doubleToString(iQuantity));
-    if (!err) err = setAttribute("t_absolute", iAbsolute ? "Y" : "N");
+    IFOKDO(err, setAttribute("t_absolute", iAbsolute ? "Y" : "N"))
     return err;
 }
 
@@ -161,7 +162,7 @@ int SKGBudgetRuleObject::isCategoryChangeEnabled() const
 SKGError SKGBudgetRuleObject::setTransfer(SKGBudgetRuleObject::Mode iMode, const SKGCategoryObject& iCategory)
 {
     SKGError err = setAttribute("t_rule", iMode == NEXT ? "N" : iMode == CURRENT ? "C" : "Y");
-    if (!err) err = setAttribute("rc_category_id_target", SKGServices::intToString(iCategory.getID()));;
+    IFOKDO(err, setAttribute("rc_category_id_target", SKGServices::intToString(iCategory.getID()));)
     return err;
 }
 
@@ -182,28 +183,27 @@ SKGError SKGBudgetRuleObject::processAllRules(SKGDocumentBank* iDocument)
     if (iDocument) {
         //Initialize
         err = iDocument->executeSqliteOrder("UPDATE budget SET f_budgeted_modified=f_budgeted  WHERE f_budgeted_modified!=f_budgeted");
-        if (!err) err = iDocument->executeSqliteOrder("UPDATE budget SET f_transferred=0  WHERE f_transferred!=0");
+        IFOKDO(err, iDocument->executeSqliteOrder("UPDATE budget SET f_transferred=0  WHERE f_transferred!=0"))
 
         //Get budgets ordered by date
         SKGObjectBase::SKGListSKGObjectBase budgets;
-        if (!err) err = iDocument->getObjects("vm_budget_tmp", "length(t_RULES)>0 "
-                                                  "AND (t_PERIOD<=STRFTIME('%Y-%m', date('now')) OR t_PERIOD=STRFTIME('%Y', date('now'))) "
-                                                  "ORDER BY t_PERIOD, id", budgets);
+        IFOKDO(err, iDocument->getObjects("vm_budget_tmp", "length(t_RULES)>0 "
+                                          "AND (t_PERIOD<=STRFTIME('%Y-%m', date('now')) OR t_PERIOD=STRFTIME('%Y', date('now'))) "
+                                          "ORDER BY t_PERIOD, id", budgets));
         int nb = budgets.count();
         if (!err && nb && iDocument) {
             err = iDocument->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Apply rules"), nb);
             for (int i = 0; !err && i < nb; ++i) {
                 SKGBudgetObject bud(budgets.at(i));
                 err = bud.load(); //Reload to be sure that delta has been updated
-                if (!err) err = bud.process();
+                IFOKDO(err, bud.process())
 
-                if (!err) err = iDocument->stepForward(i + 1);
+                IFOKDO(err, iDocument->stepForward(i + 1))
             }
 
-            if (!err) err = iDocument->setParameter("SKG_LAST_BUDGET_PROCESSING", QDate::currentDate().toString("yyyy-MM-dd"));
+            IFOKDO(err, iDocument->setParameter("SKG_LAST_BUDGET_PROCESSING", QDate::currentDate().toString("yyyy-MM-dd")))
 
-            if (!err) err = iDocument->endTransaction(true);
-            else  iDocument->endTransaction(false);
+            SKGENDTRANSACTION(iDocument,  err);
         }
     }
 
