@@ -116,7 +116,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                     }
                 }
 
-                if (!err) err = oCategory.save();
+                IFOKDO(err, oCategory.save())
             } else {
                 //Get first and second parts of the branch
                 QString first = iFullPath.mid(0, posSeparator);
@@ -126,12 +126,12 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                 SKGCategoryObject FirstCategory;
                 err = SKGCategoryObject::createPathCategory(iDocument, first, FirstCategory);
 
-                if (!err) {
+                IFOK(err) {
                     //Get second category
                     err = FirstCategory.addCategory(oCategory);
 
                     //Add second under first
-                    if (!err) err = oCategory.setName(second);
+                    IFOKDO(err, oCategory.setName(second))
 
                     //Check if already existing
                     if (!err && iRenameIfAlreadyExist) {
@@ -143,7 +143,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                     }
 
                     //save
-                    if (!err) err = oCategory.save();
+                    IFOKDO(err, oCategory.save())
                 }
             }
 
@@ -186,7 +186,7 @@ SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory
             }
         } while (!err && current.getID() != 0);
 
-        if (!err) err = setAttribute("rd_category_id", SKGServices::intToString(iCategory.getID()));
+        IFOKDO(err, setAttribute("rd_category_id", SKGServices::intToString(iCategory.getID())))
     }
     return err;
 }
@@ -209,7 +209,7 @@ SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject& oCategory) const
     SKGError err;
     SKGCategoryObject parent;
     err = getParentCategory(parent);
-    if (!err) {
+    IFOK(err) {
         if (!parent.exist()) {
             //No parent
             oCategory = *this;
@@ -259,24 +259,24 @@ SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
     SKGError err;
 
     SKGObjectBase::SKGListSKGObjectBase ops;
-    if (!err) err = iCategory.getSubOperations(ops);
+    IFOKDO(err, iCategory.getSubOperations(ops))
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
         SKGSubOperationObject op(ops.at(i));
         err = op.setCategory(*this);
-        if (!err) err = op.save(true, false);
+        IFOKDO(err, op.save(true, false))
     }
 
     SKGObjectBase::SKGListSKGObjectBase cats;
-    if (!err) err = iCategory.getCategories(cats);
+    IFOKDO(err, iCategory.getCategories(cats))
     nb = cats.count();
     for (int i = 0; !err && i < nb; ++i) {
         SKGCategoryObject cat(cats.at(i));
         err = cat.setParentCategory(*this);
-        if (!err) err = cat.save(true, false);
+        IFOKDO(err, cat.save(true, false))
     }
 
-    if (!err) err = iCategory.remove();
+    IFOKDO(err, iCategory.remove())
     return err;
 }
 
