@@ -128,7 +128,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         if (!whereClause.isEmpty()) {
             SKGObjectBase::SKGListSKGObjectBase listAccount;
             err = m_document->getObjects("v_account", whereClause, listAccount);
-            if (!err) {
+            IFOK(err) {
                 if (listAccount.count() == 1) {
                     //Yes ! Only one account found
                     SKGAccountObject account(listAccount.at(0));
@@ -144,14 +144,14 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         if (m_defaultAccount == NULL) {
             SKGAccountObject account;
             SKGBankObject bank(m_document);
-            if (!err) err = bank.setName(bankname);
+            IFOKDO(err, bank.setName(bankname))
             if (!err && bank.load().isFailed()) err = bank.save(false);    //Save only
-            if (!err) err = bank.addAccount(account);
-            if (!err) err = account.setName(name);
-            if (!err) err = account.setNumber(number);
+            IFOKDO(err, bank.addAccount(account))
+            IFOKDO(err, account.setName(name))
+            IFOKDO(err, account.setNumber(number))
             if (!err && account.load().isFailed()) err = account.save(false);    //Save only
-            if (!err) m_defaultAccount = new SKGAccountObject(account);
-            if (!err) err = m_document->sendMessage(i18nc("An information message",  "Default account '%1' created for import", name));
+            IFOK(err) m_defaultAccount = new SKGAccountObject(account);
+            IFOKDO(err, m_document->sendMessage(i18nc("An information message",  "Default account '%1' created for import", name)))
         }
     }
 
@@ -190,7 +190,7 @@ SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDat
         //Check if a unit exist
         SKGObjectBase::SKGListSKGObjectBase listUnits;
         err = m_document->getObjects("v_unit", wc % " ORDER BY ABS(f_CURRENTAMOUNT-1) ASC" , listUnits);
-        if (!err) {
+        IFOK(err) {
             if (listUnits.count() == 0) {
                 //Not found, we have to create one
                 QDateTime now = QDateTime::currentDateTime();
@@ -199,22 +199,22 @@ SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDat
                 QString name = i18nc("Noun",  "Unit for import");
                 err = unit.setName(name);
                 if (unit.load().isFailed()) {
-                    if (!err) err = unit.setSymbol(name);
-                    if (!err) err = unit.save(false);    //Save only
+                    IFOKDO(err, unit.setSymbol(name))
+                    IFOKDO(err, unit.save(false))
 
                     SKGUnitValueObject unitval;
-                    if (!err) err = unit.addUnitValue(unitval);
-                    if (!err) err = unitval.setQuantity(1);
-                    if (!err) err = unitval.setDate(QDate(1970, 1, 1));
-                    if (!err) err = unitval.save(false, false);    //Save only without reload
+                    IFOKDO(err, unit.addUnitValue(unitval))
+                    IFOKDO(err, unitval.setQuantity(1))
+                    IFOKDO(err, unitval.setDate(QDate(1970, 1, 1)))
+                    IFOKDO(err, unitval.save(false, false))
 
-                    if (!err) err = m_document->sendMessage(i18nc("An information message",  "Default unit '%1' created for import", name));
+                    IFOKDO(err, m_document->sendMessage(i18nc("An information message",  "Default unit '%1' created for import", name)))
                 }
 
-                if (!err) m_defaultUnit = new SKGUnitObject(unit);
+                IFOK(err) m_defaultUnit = new SKGUnitObject(unit);
             } else {
                 //Found, we can use it
-                m_defaultUnit = new SKGUnitObject((SKGUnitObject) listUnits.at(0));
+                m_defaultUnit = new SKGUnitObject(listUnits.at(0));
             }
         }
     }
@@ -269,7 +269,7 @@ SKGError SKGImportExportManager::finalizeImportation()
             err = m_document->sendMessage(i18np("one operation not imported because it already exists", "%1 operations not imported because they already exists", nb), SKGDocument::Warning);
 
             //Remove operations imported for nothing
-            if (!err) err = m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % ')');
+            IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % ')'))
         }
 
         //Delete operations before the last import
@@ -280,32 +280,31 @@ SKGError SKGImportExportManager::finalizeImportation()
         }
 
         //For performances
-        if (!err) err = m_document->executeSqliteOrder("ANALYZE");
+        IFOKDO(err, m_document->executeSqliteOrder("ANALYZE"))
 
         //Apply rules
         if (!err && m_automaticApplyRulesOfImportedOperation) {
             SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-applyrules", err);
             //Get rules
             SKGObjectBase::SKGListSKGObjectBase rules;
-            err = m_document->getObjects("v_rule", "1=1 ORDER BY f_sortorder", rules);
+            IFOKDO(err, m_document->getObjects("v_rule", "1=1 ORDER BY f_sortorder", rules))
 
             int nb = rules.count();
-            err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Finalize import"), nb);
+            IFOKDO(err, m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Finalize import"), nb))
             for (int i = 0; !err && i < nb; ++i) {
                 SKGRuleObject rule(rules.at(i));
                 err = rule.execute(SKGRuleObject::IMPORTING);
-                if (!err) err = m_document->stepForward(i + 1);
+                IFOKDO(err, m_document->stepForward(i + 1))
             }
-            if (!err) err = m_document->endTransaction(true);
-            else m_document->endTransaction(false);
+            SKGENDTRANSACTION(m_document,  err);
 
             //A failure in rule will not block the transaction.
             //A warning message is sent
-            if (err) err = m_document->sendMessage(i18nc("Warning message", "Error during execution of rules:\n%1", err.getFullMessageWithHistorical()), SKGDocument::Error);
+            IFKO(err) err = m_document->sendMessage(i18nc("Warning message", "Error during execution of rules:\n%1", err.getFullMessageWithHistorical()), SKGDocument::Error);
         }
 
         //Change imported status
-        if (!err) {
+        IFOK(err) {
             SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-setfinalstatus", err);
             err = m_document->executeSqliteOrder(QString("UPDATE operation SET t_imported='") %
                                                  (m_automaticValidationOfImportedOperation ? "Y" : "P") %
@@ -465,9 +464,9 @@ SKGError SKGImportExportManager::importFile()
 
         err = m_document->executeSqliteOrder("ANALYZE");
 
-        if (!err) err = m_document->stepForward(1);
+        IFOKDO(err, m_document->stepForward(1))
 
-        if (!err) {
+        IFOK(err) {
             //Search plugins
             bool fileTreated = false;
             SKGImportPlugin* pluginInterface = getImportPlugin();
@@ -481,10 +480,10 @@ SKGError SKGImportExportManager::importFile()
 
             if (!err && !fileTreated)err.setReturnCode(ERR_NOTIMPL).setMessage(i18nc("Error message",  "This import mode is not yet implemented"));
         }
-        if (!err) err = m_document->stepForward(2);
+        IFOKDO(err, m_document->stepForward(2))
 
-        if (!err) err = finalizeImportation();
-        if (!err) err = m_document->stepForward(3);
+        IFOKDO(err, finalizeImportation())
+        IFOKDO(err, m_document->stepForward(3))
     }
 
     return err;
@@ -496,7 +495,7 @@ SKGError SKGImportExportManager::exportFile()
     SKGTRACEINRC(2, "SKGImportExportManager::exportFile", err);
     if (m_document) {
         err = m_document->executeSqliteOrder("ANALYZE");
-        if (!err) {
+        IFOK(err) {
             //Search plugins
             bool fileTreated = false;
             SKGImportPlugin* pluginInterface = getExportPlugin();
@@ -506,7 +505,7 @@ SKGError SKGImportExportManager::exportFile()
                 SKGTRACEL(2) << "Input filename=" << m_fileName.prettyUrl() << endl;
                 SKGTRACEL(2) << "Input local filename=" << getLocalFileName(false) << endl;
                 err = pluginInterface->exportFile();
-                if (!err) err = SKGServices::upload(KUrl::fromLocalFile(getLocalFileName(false)), m_fileName);
+                IFOKDO(err, SKGServices::upload(KUrl::fromLocalFile(getLocalFileName(false)), m_fileName))
             }
 
             if (!err && !fileTreated) err.setReturnCode(ERR_NOTIMPL).setMessage(i18nc("Error message",  "This export mode is not yet implemented"));
@@ -524,10 +523,10 @@ SKGError SKGImportExportManager::cleanBankImport()
     //Begin transaction
     if (m_document) {
         err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Clean import"), 3);
-        if (!err) {
+        IFOK(err) {
             //Step 1 Clean operations without mode and with comment with double space
             SKGObjectBase::SKGListSKGObjectBase operations;
-            if (!err) err = m_document->getObjects("operation", "t_imported!='N' and t_mode='' and t_comment like '%  %'", operations);
+            IFOKDO(err, m_document->getObjects("operation", "t_imported!='N' and t_mode='' and t_comment like '%  %'", operations))
 
             int nb = operations.count();
             for (int i = 0; !err && i < nb ; ++i) {
@@ -544,16 +543,16 @@ SKGError SKGImportExportManager::cleanBankImport()
 
                     //Modify
                     err = op.setComment(info.trimmed());
-                    if (!err)  err = op.setMode(mode.trimmed());
-                    if (!err)  err = op.save(true, false);    //No reload
+                    IFOKDO(err, op.setMode(mode.trimmed()))
+                    IFOKDO(err, op.save(true, false))   //No reload
                 }
             }
 
             //Step 1 done
-            if (!err) err = m_document->stepForward(1);
+            IFOKDO(err, m_document->stepForward(1))
 
             //Step 2 Clean operations without mode and with comment
-            if (!err) err = m_document->getObjects("operation", "t_imported!='N' and t_mode='' and t_comment!=''", operations);
+            IFOKDO(err, m_document->getObjects("operation", "t_imported!='N' and t_mode='' and t_comment!=''", operations))
 
             nb = operations.count();
             for (int i = 0; !err && i < nb ; ++i) {
@@ -570,16 +569,16 @@ SKGError SKGImportExportManager::cleanBankImport()
 
                     //Modify
                     err = op.setComment(info.trimmed());
-                    if (!err)  err = op.setMode(mode.trimmed());
-                    if (!err)  err = op.save(true, false);    //No reload
+                    IFOKDO(err, op.setMode(mode.trimmed()))
+                    IFOKDO(err, op.save(true, false))   //No reload
                 }
             }
 
             //Step 2 done
-            if (!err) err = m_document->stepForward(2);
+            IFOKDO(err, m_document->stepForward(2))
 
             //Step 3 Clean cheque without number
-            if (!err) err = m_document->getObjects("operation", "t_imported!='N' and i_number=0 and lower(t_mode)='cheque'", operations);
+            IFOKDO(err, m_document->getObjects("operation", "t_imported!='N' and i_number=0 and lower(t_mode)='cheque'", operations))
 
             nb = operations.count();
             for (int i = 0; !err && i < nb ; ++i) {
@@ -595,16 +594,15 @@ SKGError SKGImportExportManager::cleanBankImport()
 
                     //Modify
                     err = op.setNumber(number);
-                    if (!err)  err = op.save(true, false);    //No reload
+                    IFOKDO(err, op.save(true, false))   //No reload
                 }
             }
 
             //Step 3 done
-            if (!err) err = m_document->stepForward(3);
+            IFOKDO(err, m_document->stepForward(3))
         }
 
-        if (!err) err = m_document->endTransaction(true);
-        else  m_document->endTransaction(false);
+        SKGENDTRANSACTION(m_document,  err);
     }
 
     return err;
@@ -634,11 +632,11 @@ SKGError SKGImportExportManager::anonymize()
                 SKGBEGINPROGRESSTRANSACTION(*m_document, "##INTERNAL##" % i18nc("Progression step", "Anonymize"), err, nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     err = m_document->executeSqliteOrder(sqlOrders.at(i));
-                    if (!err) err = m_document->stepForward(i + 1);
+                    IFOKDO(err, m_document->stepForward(i + 1))
                 }
             }
 
-            if (!err) err = m_document->removeAllTransactions();
+            IFOKDO(err, m_document->removeAllTransactions())
         }
     }
     return err;
@@ -654,8 +652,8 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
     //Begin transaction
     if (m_document) {
         err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), 3);
-        if (!err) {
-            if (!err) err = m_document->executeSqliteOrder("ANALYZE");
+        IFOK(err) {
+            IFOKDO(err, m_document->executeSqliteOrder("ANALYZE"))
             //Look for operations with
             //  Same units
             //  Same dates
@@ -663,50 +661,48 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
             //  Different accounts
             //  Oposite amounts
             SKGStringListList listTmp;
-            if (!err) err = m_document->executeSelectSqliteOrder(
-                                    "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_QUANTITY+B.f_QUANTITY)<" % SKGServices::doubleToString(EPSILON) % " AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0" %
-                                    (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
-                                    listTmp);
+            IFOKDO(err, m_document->executeSelectSqliteOrder(
+                       "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_QUANTITY+B.f_QUANTITY)<" % SKGServices::doubleToString(EPSILON) % " AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0" %
+                       (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
+                       listTmp));
             //Step 1 done
-            if (!err) err = m_document->stepForward(1);
+            IFOKDO(err, m_document->stepForward(1))
 
             SKGStringListList listTmp2;
             //+A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
-            if (!err) err = m_document->executeSelectSqliteOrder(
-                                    "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_CURRENTAMOUNT+CAST(P.t_value AS REAL))<" % SKGServices::doubleToString(EPSILON) % " AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0" %
-                                    (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
-                                    listTmp2);
+            IFOKDO(err, m_document->executeSelectSqliteOrder(
+                       "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_CURRENTAMOUNT+CAST(P.t_value AS REAL))<" % SKGServices::doubleToString(EPSILON) % " AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0" %
+                       (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
+                       listTmp2));
 
             //Step 2 done
-            if (!err) err = m_document->stepForward(2);
+            IFOKDO(err, m_document->stepForward(2))
             listTmp2.removeAt(0);    //Remove header
             listTmp += listTmp2;
 
             //Group
             {
                 oNbOperationsMerged = listTmp.count();
-                if (!err) err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), oNbOperationsMerged - 1);
+                IFOKDO(err, m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), oNbOperationsMerged - 1))
                 for (int i = 1; !err && i < oNbOperationsMerged ; ++i) { //First line ignored because of it's header
                     SKGOperationObject op1(m_document, SKGServices::stringToInt(listTmp.at(i).at(0)));
                     SKGOperationObject op2(m_document, SKGServices::stringToInt(listTmp.at(i).at(1)));
 
                     if (!op1.isInGroup() && !op2.isInGroup()) {
                         err = op2.setGroupOperation(op1);
-                        if (!err) err = op2.save(true, false);    //No reload
+                        IFOKDO(err, op2.save(true, false))
                     }
-                    if (!err) err = m_document->stepForward(i);
+                    IFOKDO(err, m_document->stepForward(i))
                 }
-                if (!err) err = m_document->endTransaction(true);
-                else  m_document->endTransaction(false);
+                SKGENDTRANSACTION(m_document,  err);
             }
             oNbOperationsMerged = (oNbOperationsMerged - 1) * 2;
 
             //Step 3 done
-            if (!err) err = m_document->stepForward(3);
+            IFOKDO(err, m_document->stepForward(3))
 
         }
-        if (!err) err = m_document->endTransaction(true);
-        else  m_document->endTransaction(false);
+        SKGENDTRANSACTION(m_document,  err);
     }
 
     return err;
