@@ -73,24 +73,24 @@ QDate SKGInterestObject::getDate() const
 
 SKGError SKGInterestObject::setIncomeValueDateMode(SKGInterestObject::ValueDateMode iMode)
 {
-    return setAttribute("t_income_value_date_mode", (iMode == FIFTEEN ? "F" : SKGServices::intToString(((int) iMode) - 1)));
+    return setAttribute("t_income_value_date_mode", (iMode == FIFTEEN ? "F" : SKGServices::intToString(static_cast<int>(iMode) - 1)));
 }
 
 SKGInterestObject::ValueDateMode SKGInterestObject::getIncomeValueDateMode() const
 {
     QString mode = getAttribute("t_income_value_date_mode");
-    return (mode == "F" ? FIFTEEN : (SKGInterestObject::ValueDateMode)(SKGServices::stringToInt(mode) + 1));
+    return (mode == "F" ? FIFTEEN : static_cast<SKGInterestObject::ValueDateMode>(SKGServices::stringToInt(mode) + 1));
 }
 
 SKGError SKGInterestObject::setExpenditueValueDateMode(SKGInterestObject::ValueDateMode iMode)
 {
-    return setAttribute("t_expenditure_value_date_mode", (iMode == FIFTEEN ? "F" : SKGServices::intToString(((int) iMode) - 1)));
+    return setAttribute("t_expenditure_value_date_mode", (iMode == FIFTEEN ? "F" : SKGServices::intToString(static_cast<int>(iMode) - 1)));
 }
 
 SKGInterestObject::ValueDateMode SKGInterestObject::getExpenditueValueDateMode() const
 {
     QString mode = getAttribute("t_expenditure_value_date_mode");
-    return (mode == "F" ? FIFTEEN : (SKGInterestObject::ValueDateMode)(SKGServices::stringToInt(mode) + 1));
+    return (mode == "F" ? FIFTEEN : static_cast<SKGInterestObject::ValueDateMode>(SKGServices::stringToInt(mode) + 1));
 }
 
 SKGError SKGInterestObject::setInterestComputationMode(SKGInterestObject::InterestMode iMode)
