@@ -62,33 +62,33 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
     SKGTRACEINRC(20, "SKGOperationObject::duplicate", err);
     //Create the duplicated operation
     oOperation = SKGOperationObject(getDocument(), this->getID());  //To be sure the object is on v_operation
-    if (!err) err = oOperation.load();
-    if (!err) err = oOperation.resetID();
-    if (!err) err = oOperation.setDate(iDate);
-    if (!err) err = oOperation.setStatus(SKGOperationObject::NONE);
-    if (!err) err = oOperation.setImported(false);
-    if (!err) err = oOperation.setTemplate(iTemplateMode);
-    if (!err) err = oOperation.setImportID("");
-    if (!err) err = oOperation.bookmark(false);
-    if (!err) err = oOperation.setNumber(0);
-    if (!err) err = oOperation.setGroupOperation(oOperation);    //We have to ungroup first to be able to group after
-    if (!err) err = oOperation.save(false, false);    //Just an insert + no reload (doesn't work if the )
+    IFOKDO(err, oOperation.load())
+    IFOKDO(err, oOperation.resetID())
+    IFOKDO(err, oOperation.setDate(iDate))
+    IFOKDO(err, oOperation.setStatus(SKGOperationObject::NONE))
+    IFOKDO(err, oOperation.setImported(false))
+    IFOKDO(err, oOperation.setTemplate(iTemplateMode))
+    IFOKDO(err, oOperation.setImportID(""))
+    IFOKDO(err, oOperation.bookmark(false))
+    IFOKDO(err, oOperation.setNumber(0))
+    IFOKDO(err, oOperation.setGroupOperation(oOperation))
+    IFOKDO(err, oOperation.save(false, false))
 
     //Duplicate subop
-    if (!err) {
+    IFOK(err) {
         SKGListSKGObjectBase subops;
         err = getSubOperations(subops);
         int nbsupops = subops.count();
         for (int i = 0; !err && i < nbsupops; ++i) {
             SKGSubOperationObject subop(subops.at(i));
             err = subop.resetID();
-            if (!err) err = subop.setParentOperation(oOperation);
-            if (!err) err = subop.save(false);    //Just an insert
+            IFOKDO(err, subop.setParentOperation(oOperation))
+            IFOKDO(err, subop.save(false))
         }
     }
 
     //Duplicate grouped operation to support recurrent transfers
-    if (!err) {
+    IFOK(err) {
         SKGListSKGObjectBase goupops;
         err = getGroupedOperations(goupops);
         int nbgoupops = goupops.count();
@@ -98,34 +98,34 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
                 //Create the duplicated operation
                 SKGOperationObject newgroupop = groupop;
                 err = newgroupop.resetID();
-                if (!err) err = newgroupop.setDate(iDate);
-                if (!err) err = newgroupop.setStatus(SKGOperationObject::NONE);
-                if (!err) err = newgroupop.setImported(false);
-                if (!err) err = newgroupop.setTemplate(iTemplateMode);
-                if (!err) err = newgroupop.setImportID("");
-                if (!err) err = newgroupop.bookmark(false);
-                if (!err) err = newgroupop.setNumber(0);
-                if (!err) err = newgroupop.setGroupOperation(newgroupop);    //We have to ungroup first to be able to group after
-                if (!err) err = newgroupop.setGroupOperation(oOperation);
-                if (!err) err = newgroupop.save(false);    //Just an insert
+                IFOKDO(err, newgroupop.setDate(iDate))
+                IFOKDO(err, newgroupop.setStatus(SKGOperationObject::NONE))
+                IFOKDO(err, newgroupop.setImported(false))
+                IFOKDO(err, newgroupop.setTemplate(iTemplateMode))
+                IFOKDO(err, newgroupop.setImportID(""))
+                IFOKDO(err, newgroupop.bookmark(false))
+                IFOKDO(err, newgroupop.setNumber(0))
+                IFOKDO(err, newgroupop.setGroupOperation(newgroupop))
+                IFOKDO(err, newgroupop.setGroupOperation(oOperation))
+                IFOKDO(err, newgroupop.save(false))
 
                 //Duplicate subop
-                if (!err) {
+                IFOK(err) {
                     SKGListSKGObjectBase subops;
                     err = groupop.getSubOperations(subops);
                     int nbsupops = subops.count();
-                    for (int i = 0; !err && i < nbsupops; ++i) {
-                        SKGSubOperationObject subop(subops.at(i));
+                    for (int j = 0; !err && j < nbsupops; ++j) {
+                        SKGSubOperationObject subop(subops.at(j));
                         err = subop.resetID();
-                        if (!err) err = subop.setParentOperation(newgroupop);
-                        if (!err) err = subop.save(false);    //Just an insert
+                        IFOKDO(err, subop.setParentOperation(newgroupop))
+                        IFOKDO(err, subop.save(false))
                     }
                 }
             }
         }
     }
 
-    if (!err) err = oOperation.load();
+    IFOKDO(err, oOperation.load())
     return err;
 }
 
@@ -275,7 +275,7 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
         //Create a new group
         SKGStringListList result;
         err = getDocument()->executeSelectSqliteOrder("SELECT max(i_group_id) from operation", result);
-        if (!err) {
+        IFOK(err) {
             //Compute new group id
             QString newIdGroup('1');
             if (result.count() == 2) {
@@ -285,9 +285,9 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
             //Set group id
             SKGOperationObject op1 = SKGOperationObject(iOperation.getDocument(), iOperation.getID());
             err = op1.setAttribute("i_group_id", newIdGroup);
-            if (!err) err = op1.save(true, false);
+            IFOKDO(err, op1.save(true, false))
 
-            if (!err) err = setAttribute("i_group_id", newIdGroup);
+            IFOKDO(err, setAttribute("i_group_id", newIdGroup))
 
             //Update all objects of group2
             if (!err && !group1.isEmpty() && group1 != "0") err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group1);
@@ -385,7 +385,7 @@ double SKGOperationObject::getBalance() const
     SKGError err = getDocument()->executeSelectSqliteOrder("SELECT TOTAL(f_CURRENTAMOUNT) FROM v_operation WHERE t_template='N' AND "
                    "rd_account_id=" % getAttribute("rd_account_id") % " AND (d_date<'" % getAttribute("d_date") % "' OR "
                    "(d_date='" % getAttribute("d_date") % "' AND id<=" % SKGServices::intToString(getID()) % "))", result);
-    if (!err) {
+    IFOK(err) {
         output = SKGServices::stringToDouble(result.at(1).at(0));
     }
 
@@ -419,7 +419,7 @@ SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject&
     else {
         oRecurrentOperation = SKGRecurrentOperationObject(getDocument());
         err = oRecurrentOperation.setParentOperation(*this);
-        if (!err) oRecurrentOperation.setDate(getDate());
+        IFOK(err) oRecurrentOperation.setDate(getDate());
     }
     return err;
 }
@@ -439,43 +439,43 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
 {
     //Merge operation
     SKGError err = setDate(iDeletedOne.getDate());
-    if (!err) err = setImportID(iDeletedOne.getImportID());
-    if (!err) err = setAttribute("t_imported", iDeletedOne.getAttribute("t_imported"));
+    IFOKDO(err, setImportID(iDeletedOne.getImportID()))
+    IFOKDO(err, setAttribute("t_imported", iDeletedOne.getAttribute("t_imported")))
     if (!err && getComment().isEmpty()) err = setComment(iDeletedOne.getComment());
     SKGPayeeObject payee;
     getPayee(payee);
-    if (!err) err = setPayee(payee);
+    IFOKDO(err, setPayee(payee))
     if (!err && getMode().isEmpty()) err = setMode(iDeletedOne.getMode());
     if (!err && !isBookmarked()) err = bookmark(iDeletedOne.isBookmarked());
     if (!err && !getNumber()) err = setNumber(iDeletedOne.getNumber());
-    if (!err) err = save();
+    IFOKDO(err, save())
 
     //Merge suboperations
     if (qAbs(getCurrentAmount() - iDeletedOne.getCurrentAmount()) > 0.0001) {
         SKGObjectBase::SKGListSKGObjectBase subOps1;
-        if (!err) err = getSubOperations(subOps1);
+        IFOKDO(err, getSubOperations(subOps1))
 
         SKGObjectBase::SKGListSKGObjectBase subOps2;
-        if (!err) err = iDeletedOne.getSubOperations(subOps2);
+        IFOKDO(err, iDeletedOne.getSubOperations(subOps2))
 
         if (subOps2.count() == 1 && subOps1.count() == 1) {
             //Change the quantity of the sub operation
             SKGSubOperationObject so1(subOps1.at(0));
             SKGSubOperationObject so2(subOps2.at(0));
-            if (!err) err = so1.setQuantity(so2.getQuantity());
-            if (!err) err = so1.save();
+            IFOKDO(err, so1.setQuantity(so2.getQuantity()))
+            IFOKDO(err, so1.save())
         } else if (subOps2.count() >= 1 && subOps1.count() >= 1) {
             //Add a split
             SKGSubOperationObject so1;
-            if (!err) err = addSubOperation(so1);
-            if (!err) err = so1.setQuantity(iDeletedOne.getCurrentAmount() - getCurrentAmount());
-            if (!err) err = so1.save();
+            IFOKDO(err, addSubOperation(so1))
+            IFOKDO(err, so1.setQuantity(iDeletedOne.getCurrentAmount() - getCurrentAmount()))
+            IFOKDO(err, so1.save())
         }
-        if (!err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), SKGDocument::Positive);
+        IFOK(err) getDocument()->sendMessage(i18nc("An information message",  "Amount has been changed to be aligned with the imported operation"), SKGDocument::Positive);
     }
 
     //Delete useless operation
-    if (!err) err = iDeletedOne.remove(false);
+    IFOKDO(err, iDeletedOne.remove(false))
     return err;
 }
 
@@ -488,9 +488,9 @@ SKGError SKGOperationObject::mergeSuboperations(const SKGOperationObject& iDelet
     for (int i = 0; !err && i < nb; ++i) {
         SKGSubOperationObject subop(subops.at(i));
         err = subop.setParentOperation(*this);
-        if (!err) err = subop.save();
+        IFOKDO(err, subop.save())
     }
-    if (!err) err = iDeletedOne.remove();
+    IFOKDO(err, iDeletedOne.remove())
     return err;
 }
 
