@@ -211,37 +211,37 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, con
             if (nextDate.isValid() && iDate >= nextDate.addDays(-getAutoWriteDays())) {
                 SKGOperationObject op;
                 err = getParentOperation(op);
-                if (!err) {
+                IFOK(err) {
                     //Create the duplicated operation
                     SKGOperationObject newOp;
                     err = op.duplicate(newOp, nextDate);
 
                     if (!op.isTemplate()) {
                         //Set old op as recurrent
-                        if (!err) err = op.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID()));
-                        if (!err) err = op.save();
+                        IFOKDO(err, op.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID())))
+                        IFOKDO(err, op.save())
 
                         //Set new operation as reference
-                        if (!err) err = setParentOperation(newOp);
+                        IFOKDO(err, setParentOperation(newOp))
                     } else {
                         //Set new op as recurrent
-                        if (!err) err = newOp.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID()));
-                        if (!err) err = newOp.save();
+                        IFOKDO(err, newOp.setAttribute("r_recurrentoperation_id", SKGServices::intToString(getID())))
+                        IFOKDO(err, newOp.save())
                     }
 
-                    if (!err) err = setDate(getNextDate());
+                    IFOKDO(err, setDate(getNextDate()))
                     if (!err && hasTimeLimit()) err = setTimeLimit(getTimeLimit() - 1);
-                    if (!err) err = save();
-                    if (!err) err = load();
+                    IFOKDO(err, save())
+                    IFOKDO(err, load())
 
                     //Process again in case of multi insert needed
                     int nbi = 0;
-                    if (!err) err = process(nbi, iForce, iDate);
+                    IFOKDO(err, process(nbi, iForce, iDate))
                     oNbInserted = oNbInserted + 1 + nbi;
 
                     //Send message
-                    if (!err) err = newOp.load();
-                    if (!err) {
+                    IFOKDO(err, newOp.load())
+                    IFOK(err) {
                         err = getDocument()->sendMessage(i18nc("An information message", "Operation '%1' has been inserted", newOp.getDisplayName()), SKGDocument::Positive);
                     }
                 }
@@ -253,7 +253,7 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, con
             if (QDate::currentDate() >= nextDate.addDays(-getWarnDays())) {
                 SKGOperationObject op;
                 err = getParentOperation(op);
-                if (!err) {
+                IFOK(err) {
                     int nbdays = QDate::currentDate().daysTo(nextDate);
                     if (nbdays > 0) {
                         QString objname = op.getDisplayName();
