@@ -30,9 +30,7 @@
 #include <kstandarddirs.h>
 #include <grantlee/engine.h>
 #include <grantlee/templateloader.h>
-#ifdef SKGGRANTLEE17ENABLED
 #include <grantlee/metatype.h>
-#endif
 #include <kaboutdata.h>
 #include <kcomponentdata.h>
 #include <kcolorscheme.h>
@@ -43,12 +41,10 @@
 #include <QDir>
 
 
-#ifdef SKGGRANTLEE17ENABLED
 GRANTLEE_BEGIN_LOOKUP(SKGObjectBase)
 Q_UNUSED(object);
 Q_UNUSED(property);
 GRANTLEE_END_LOOKUP
-#endif
 
 SKGReportBank::SKGReportBank(SKGDocument* iDocument)
     : SKGReport(iDocument)
@@ -56,10 +52,8 @@ SKGReportBank::SKGReportBank(SKGDocument* iDocument)
     SKGTRACEIN(1, "SKGReportBank::SKGReportBank");
 
     //Grantlee initialization
-#ifdef SKGGRANTLEE17ENABLED
     Grantlee::MetaType::init();
     Grantlee::registerMetaType<SKGObjectBase>();
-#endif
 }
 
 SKGReportBank::~SKGReportBank()
@@ -86,12 +80,12 @@ QVariantList SKGReportBank::getPortfolio()
         SKGTRACEIN(10, "SKGReportBank::getPortfolio");
         QString month = getMonth();
         if (!month.isEmpty()) {
-            QDate date = QDate::fromString(month, "yyyy-MM");
+            QDate date = qMin(QDate::fromString(month, "yyyy-MM"), QDate::currentDate().addDays(1 - QDate::currentDate().day()));
             QDate date2 = date.addMonths(1).addDays(-1);
 
             SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-            KLocale* locale = KGlobal::locale();
-            if (doc && locale) {
+            KLocale* loc = KGlobal::locale();
+            if (doc && loc) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
                 //Get list of operations
@@ -105,7 +99,7 @@ QVariantList SKGReportBank::getPortfolio()
                          << i18nc("Column table title", "Quantity")
                          << i18nc("Column table title", "Purchase amount")
                          << i18nc("Column table title", "Initial amount")
-                         << locale->formatDate(date2, KLocale::ShortDate)
+                         << loc->formatDate(date2, KLocale::ShortDate)
                          << i18nc("Column table title", "Variation")
                          << i18nc("Column table title", "Variation %")
                          ;
@@ -144,22 +138,22 @@ QVariantList SKGReportBank::getPortfolio()
                     if (!current.unit.getName().isEmpty()) listUnitValues.push_back(current);
 
                     nb = listUnitValues.count();
-                    for (int i = 0; i < nb; ++i) {
-                        unitValues current = listUnitValues.at(i);
+                    for (int j = 0; j < nb; ++j) {
+                        unitValues current = listUnitValues.at(j);
 
                         SKGServices::SKGUnitInfo ui = current.unit.getUnitInfo();
                         ui.Value = 1;
 
-                        QVariantList line;
-                        line << current.unit.getSymbol()
-                             << current.unit.getName()
-                             << doc->formatMoney(current.quantity, ui, false)
-                             << current.purchaseAmount
-                             << current.initalAmount
-                             << current.currentAmount
-                             << current.currentAmount - current.initalAmount
-                             << (current.initalAmount == 0.0 ? 0.0 : (current.currentAmount - current.initalAmount) / current.initalAmount);
-                        table << QVariant(line);
+                        QVariantList line2;
+                        line2 << current.unit.getSymbol()
+                              << current.unit.getName()
+                              << doc->formatMoney(current.quantity, ui, false)
+                              << current.purchaseAmount
+                              << current.initalAmount
+                              << current.currentAmount
+                              << current.currentAmount - current.initalAmount
+                              << (current.initalAmount == 0.0 ? 0.0 : (current.currentAmount - current.initalAmount) / current.initalAmount);
+                        table << QVariant(line2);
                     }
                 }
             }
@@ -182,8 +176,8 @@ QVariantList SKGReportBank::getUnitTable()
             QDate date2 = date.addMonths(1).addDays(-1);
             QString previousmonth = date1.toString("yyyy-MM");
             SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-            KLocale* locale = KGlobal::locale();
-            if (doc && locale) {
+            KLocale* loc = KGlobal::locale();
+            if (doc && loc) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
                 SKGObjectBase::SKGListSKGObjectBase units;
@@ -192,8 +186,8 @@ QVariantList SKGReportBank::getUnitTable()
                     QVariantList line;
                     line << "sum"
                          << doc->getDisplay("t_UNIT")
-                         << locale->formatDate(date1, KLocale::ShortDate)
-                         << locale->formatDate(date2, KLocale::ShortDate)
+                         << loc->formatDate(date1, KLocale::ShortDate)
+                         << loc->formatDate(date2, KLocale::ShortDate)
                          << "%"
                          << doc->getDisplay("t_symbol");
                     table << QVariant(line);
@@ -201,9 +195,9 @@ QVariantList SKGReportBank::getUnitTable()
                         SKGUnitObject unit(item);
                         double v1 = unit.getAmount(date1);
                         double v2 = unit.getAmount(date2);
-                        QVariantList line;
-                        line << false << unit.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << unit.getSymbol();
-                        table << QVariant(line);
+                        QVariantList line2;
+                        line2 << false << unit.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << unit.getSymbol();
+                        table << QVariant(line2);
                     }
                 }
             }
@@ -227,16 +221,16 @@ QVariantList SKGReportBank::getAccountTable()
             QDate date3 = date2.addYears(-1);
             QString previousmonth = date1.toString("yyyy-MM");
             SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-            KLocale* locale = KGlobal::locale();
-            if (doc && locale) {
+            KLocale* loc = KGlobal::locale();
+            if (doc && loc) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
                 SKGObjectBase::SKGListSKGObjectBase accounts;
                 SKGError err = doc->getObjects("v_account_display", "1=1 ORDER BY t_TYPENLS, t_BANK, t_name", accounts);
-                if (!err) {
+                IFOK(err) {
                     QVariantList line;
-                    line << "sum" << doc->getDisplay("t_ACCOUNT") << locale->formatDate(date1, KLocale::ShortDate) << locale->formatDate(date2, KLocale::ShortDate) <<
-                         "%" << locale->formatDate(date3, KLocale::ShortDate) << locale->formatDate(date2, KLocale::ShortDate) << "%";
+                    line << "sum" << doc->getDisplay("t_ACCOUNT") << loc->formatDate(date1, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) <<
+                         "%" << loc->formatDate(date3, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) << "%";
                     table.push_back(line);
                     double sumTypeV1 = 0;
                     double sumTypeV2 = 0;
@@ -255,12 +249,12 @@ QVariantList SKGReportBank::getAccountTable()
                         bool closed = account.isClosed();
                         if (type != currentType) {
                             if (!currentType.isEmpty()) {
-                                QVariantList line;
-                                line << true << i18nc("Noun",  "Total of %1", currentType) << sumTypeV1 << sumTypeV2 <<
-                                     (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2
-                                     << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
-                                     << "" << "";
-                                table.push_back(line);
+                                QVariantList line2;
+                                line2 << true << i18nc("Noun",  "Total of %1", currentType) << sumTypeV1 << sumTypeV2 <<
+                                      (100.0 * (sumTypeV2 - sumTypeV1) / qAbs(sumTypeV1)) << sumTypeV3 << sumTypeV2
+                                      << (100.0 * (sumTypeV2 - sumTypeV3) / qAbs(sumTypeV3))
+                                      << "" << "";
+                                table.push_back(line2);
                                 sumTypeV1 = 0;
                                 sumTypeV2 = 0;
                                 sumTypeV3 = 0;
@@ -268,15 +262,15 @@ QVariantList SKGReportBank::getAccountTable()
                             currentType = type;
                         }
                         if (!closed || qAbs(v1) > 0.01 || qAbs(v2) > 0.01 || qAbs(v3) > 0.01) {
-                            QVariantList line;
+                            QVariantList line2;
                             QString icon = account.getAttribute("t_ICON");
                             if (!icon.isEmpty()) {
                                 QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                                 icon = dirLogo.absoluteFilePath(icon);
                             }
-                            line << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
-                                 << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute("t_BANK") << icon ;
-                            table.push_back(line);
+                            line2 << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
+                                  << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute("t_BANK") << icon ;
+                            table.push_back(line2);
                             ;
                         }
                         sumTypeV1 += v1;
@@ -323,16 +317,16 @@ QVariantList SKGReportBank::getBankTable()
             QDate date3 = date2.addYears(-1);
             QString previousmonth = date1.toString("yyyy-MM");
             SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-            KLocale* locale = KGlobal::locale();
-            if (doc && locale) {
+            KLocale* loc = KGlobal::locale();
+            if (doc && loc) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
                 SKGObjectBase::SKGListSKGObjectBase accounts;
                 SKGError err = doc->getObjects("v_account", "1=1 ORDER BY t_BANK", accounts);
-                if (!err) {
+                IFOK(err) {
                     QVariantList line;
-                    line << "sum" << doc->getDisplay("t_BANK") << locale->formatDate(date1, KLocale::ShortDate) << locale->formatDate(date2, KLocale::ShortDate) <<
-                         "%" << locale->formatDate(date3, KLocale::ShortDate) << locale->formatDate(date2, KLocale::ShortDate) << "%";
+                    line << "sum" << doc->getDisplay("t_BANK") << loc->formatDate(date1, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) <<
+                         "%" << loc->formatDate(date3, KLocale::ShortDate) << loc->formatDate(date2, KLocale::ShortDate) << "%";
                     table.push_back(line);
                     double sumTypeV1 = 0;
                     double sumTypeV2 = 0;
@@ -413,7 +407,7 @@ QVariantList SKGReportBank::getScheduledOperations()
         SKGTRACEIN(10, "SKGReportBank::getScheduledOperations");
         SKGObjectBase::SKGListSKGObjectBase objs;
         SKGError err = m_document->getObjects("v_recurrentoperation_display", "i_nb_times!=0 ORDER BY d_date LIMIT 5", objs);
-        if (!err) {
+        IFOK(err) {
             int nb = objs.count();
             if (nb) {
                 for (int i = 0; i < nb; ++i) {
