@@ -22,6 +22,7 @@
 #include "skgruleobject.h"
 #include "skgunitvalueobject.h"
 #include "skgtraces.h"
+#include "skgtransactionmng.h"
 
 #include <klocale.h>
 
@@ -83,7 +84,7 @@ SKGError SKGRuleObject::save(bool iInsertOrUpdate, bool iReloadAfterSave)
 
 SKGError SKGRuleObject::setXMLSearchDefinition(const QString& iXml)
 {
-    setSearchDescription(SKGRuleObject::getDescriptionFromXML((SKGDocument*) getDocument(), iXml, false, SEARCH));
+    setSearchDescription(SKGRuleObject::getDescriptionFromXML(static_cast<SKGDocument*>(getDocument()), iXml, false, SEARCH));
     return setAttribute("t_definition", iXml);
 }
 
@@ -94,7 +95,7 @@ QString SKGRuleObject::getXMLSearchDefinition() const
 
 SKGError SKGRuleObject::setXMLActionDefinition(const QString& iXml)
 {
-    setActionDescription(SKGRuleObject::getDescriptionFromXML((SKGDocument*) getDocument(), iXml, false, getActionType()));
+    setActionDescription(SKGRuleObject::getDescriptionFromXML(static_cast<SKGDocument*>(getDocument()), iXml, false, getActionType()));
     return setAttribute("t_action_definition", iXml);
 }
 
@@ -145,14 +146,14 @@ SKGError SKGRuleObject::setOrder(double iOrder)
         err = getDocument()->executeSelectSqliteOrder("SELECT max(f_sortorder) from rule", result);
         if (!err && result.count() == 2) order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
     }
-    if (!err) err = setAttribute("f_sortorder", SKGServices::doubleToString(order));
+    IFOKDO(err, setAttribute("f_sortorder", SKGServices::doubleToString(order)))
     return err;
 }
 
 QString SKGRuleObject::getSelectSqlOrder(const QString& iAdditionalCondition) const
 {
     QString wc = iAdditionalCondition;
-    QString wc2 = SKGRuleObject::getDescriptionFromXML((SKGDocument*) getDocument(), getXMLSearchDefinition(), true, SEARCH);
+    QString wc2 = SKGRuleObject::getDescriptionFromXML(static_cast<SKGDocument*>(getDocument()), getXMLSearchDefinition(), true, SEARCH);
     if (!wc2.isEmpty()) {
         if (wc.isEmpty()) wc = wc2;
         else wc = '(' % wc % ") AND (" % wc2 % ')';
@@ -171,7 +172,7 @@ SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
         QString wc = getSelectSqlOrder();
         if (wc.isEmpty()) wc = "1=1";
 
-        SKGDocument* doc = (SKGDocument*) getDocument();
+        SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
 
         QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
         if (list.count()) {
@@ -205,12 +206,12 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
         QString wc = getSelectSqlOrder(addSql);
         if (wc.isEmpty()) wc = "1=1";
 
-        SKGDocument* doc = (SKGDocument*) getDocument();
+        SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
         if (doc) {
             QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, UPDATE, true);  //SQL + SET clause
             int nb = list.count();
             err = doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Apply rule"), nb);
-            if (!err) {
+            IFOK(err) {
                 //All sql orders must be executed to be sure than i_tmp is reset
                 SKGError err2;
                 for (int i = 0; i < nb; ++i) {
@@ -222,7 +223,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 }
             }
 
-            if (!err) {
+            IFOK(err) {
                 SKGStringListList result;
                 err = doc->executeSelectSqliteOrder("SELECT changes()", result);
                 if (!err && result.count() == 2) {
@@ -231,15 +232,14 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 }
             }
 
-            if (!err) err = doc->endTransaction(true);
-            else doc->endTransaction(false);
+            SKGENDTRANSACTION(doc,  err);
         }
     } else if (getActionType() == SKGRuleObject::ALARM) {
         //Alarm mode
         QString wc = getSelectSqlOrder();
         if (wc.isEmpty()) wc = "1=1";
 
-        SKGDocument* doc = (SKGDocument*) getDocument();
+        SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
         if (doc) {
             QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
             if (list.count()) {
@@ -255,7 +255,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
             }
         }
     }
-    if (err) err.addError(ERR_FAIL, i18nc("Error message", "Rule %1 failed", getAttribute("i_ORDER")));
+    IFKO(err) err.addError(ERR_FAIL, i18nc("Error message", "Rule %1 failed", getAttribute("i_ORDER")));
     return err;
 }
 
