@@ -72,7 +72,7 @@ SKGError SKGTrackerObject::createTracker(SKGDocumentBank* iDocument,
             //No, we have to create it
             oTracker = SKGTrackerObject(iDocument);
             err = oTracker.setName(iName);
-            if (!err) err = oTracker.save();
+            IFOKDO(err, oTracker.save())
 
             if (!err && iSendPopupMessageOnCreation && iDocument) {
                 err = iDocument->sendMessage(i18nc("Information message", "Tracker '%1' has been created" , iName), SKGDocument::Positive);
@@ -121,15 +121,15 @@ SKGError SKGTrackerObject::merge(const SKGTrackerObject& iTracker)
     SKGError err;
 
     SKGObjectBase::SKGListSKGObjectBase ops;
-    if (!err) err = iTracker.getSubOperations(ops);
+    IFOKDO(err, iTracker.getSubOperations(ops))
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
         SKGSubOperationObject op(ops.at(i));
         err = op.setTracker(*this);
-        if (!err) err = op.save(true, false);
+        IFOKDO(err, op.save(true, false))
     }
 
-    if (!err) err = iTracker.remove();
+    IFOKDO(err, iTracker.remove())
     return err;
 }
 
