@@ -289,8 +289,8 @@ SKGError SKGUnitObject::createCurrencyUnit(SKGDocumentBank* iDocument, const QSt
         if (info.Value == 1 && !err && (type == SKGUnitObject::CURRENCY || type == SKGUnitObject::SECONDARY)) {
             SKGUnitObject primunit(iDocument);
             err = primunit.setSymbol(prim.Symbol);
-            if (!err) err = primunit.load();
-            if (!err) {
+            IFOKDO(err, primunit.load())
+            IFOK(err) {
                 QString codeprimunit = getInternationalCode(primunit.getName());
                 QString codeunit = getInternationalCode(info.Name);
                 if (!codeprimunit.isEmpty()) {
@@ -299,30 +299,30 @@ SKGError SKGUnitObject::createCurrencyUnit(SKGDocumentBank* iDocument, const QSt
 
                     parentUnit = SKGUnitObject(iDocument);
                     err = parentUnit.setSymbol(prim.Symbol);
-                    if (!err) err = parentUnit.load();
+                    IFOKDO(err, parentUnit.load())
                 }
             }
 
         }
 
-        if (!err) err = oUnit.setName(info.Name);
+        IFOKDO(err, oUnit.setName(info.Name))
         if (!err && oUnit.exist()) err = oUnit.load();
-        if (!err) err = oUnit.setType(type);
-        if (!err) err = oUnit.setSymbol(info.Symbol);
-        if (!err) err = oUnit.setInternetCode(info.Internet);
-        if (!err) err = oUnit.setDownloadSource(info.Source);
-        if (!err) err = oUnit.setCountry(info.Country);
-        if (!err) err = oUnit.setNumberDecimal(info.NbDecimal);
+        IFOKDO(err, oUnit.setType(type))
+        IFOKDO(err, oUnit.setSymbol(info.Symbol))
+        IFOKDO(err, oUnit.setInternetCode(info.Internet))
+        IFOKDO(err, oUnit.setDownloadSource(info.Source))
+        IFOKDO(err, oUnit.setCountry(info.Country))
+        IFOKDO(err, oUnit.setNumberDecimal(info.NbDecimal))
         if (!err && parentUnit.exist()) err = oUnit.setUnit(parentUnit);
-        if (!err) err = oUnit.save();
+        IFOKDO(err, oUnit.save())
 
         //Creation of the value
         if (info.Value > 0) {
             SKGUnitValueObject unitValue;
-            if (!err) err = oUnit.addUnitValue(unitValue);
-            if (!err) err = unitValue.setDate(info.Date);
-            if (!err) err = unitValue.setQuantity(info.Value);
-            if (!err) err = unitValue.save();
+            IFOKDO(err, oUnit.addUnitValue(unitValue))
+            IFOKDO(err, unitValue.setDate(info.Date))
+            IFOKDO(err, unitValue.setQuantity(info.Value))
+            IFOKDO(err, unitValue.save())
         }
     }
     return err;
@@ -402,7 +402,7 @@ SKGError SKGUnitObject::setType(SKGUnitObject::UnitType iType)
             if (!err && iType == PRIMARY) err = getDocument()->executeSqliteOrder("UPDATE unit SET t_type='2' WHERE t_type='1'");
         }
     }
-    if (!err) err = setAttribute("t_type", (iType == CURRENCY ? "C" : (iType == PRIMARY ? "1" : (iType == SECONDARY ? "2" : (iType == SHARE ? "S" : (iType == INDEX ? "I" : "O"))))));
+    IFOKDO(err, setAttribute("t_type", (iType == CURRENCY ? "C" : (iType == PRIMARY ? "1" : (iType == SECONDARY ? "2" : (iType == SHARE ? "S" : (iType == INDEX ? "I" : "O")))))))
     return err;
 }
 
@@ -486,10 +486,10 @@ SKGError SKGUnitObject::simplify()
                     groups[key] = group;
                 }
 
-                if (!err) err = getDocument()->stepForward(nb - i);
+                IFOKDO(err, getDocument()->stepForward(nb - i))
             }
         }
-        if (!err) err = getDocument()->stepForward(1);
+        IFOKDO(err, getDocument()->stepForward(1))
 
         //Simplify
         {
@@ -522,10 +522,10 @@ SKGError SKGUnitObject::simplify()
                     }
                 }
 
-                if (!err) err = getDocument()->stepForward(i + 1);
+                IFOKDO(err, getDocument()->stepForward(i + 1))
             }
         }
-        if (!err) err = getDocument()->stepForward(2);
+        IFOKDO(err, getDocument()->stepForward(2))
     }
     return err;
 }
@@ -558,10 +558,10 @@ SKGError SKGUnitObject::getUnitValue(const QDate& iDate, SKGUnitValueObject& oUn
                    oUnitValue);
 
     //If not found then get first
-    if (err) err = SKGObjectBase::getDocument()->getObject("v_unitvalue",
-                       "rd_unit_id=" % SKGServices::intToString(getID()) % " AND d_date=(select MIN(d_date) from unitvalue where rd_unit_id=" %
-                       SKGServices::intToString(getID()) % ')',
-                       oUnitValue);
+    IFKO(err) err = SKGObjectBase::getDocument()->getObject("v_unitvalue",
+                    "rd_unit_id=" % SKGServices::intToString(getID()) % " AND d_date=(select MIN(d_date) from unitvalue where rd_unit_id=" %
+                    SKGServices::intToString(getID()) % ')',
+                    oUnitValue);
     return err;
 }
 
@@ -589,11 +589,11 @@ double SKGUnitObject::getAmount(const QDate& iDate) const
             }
 
             output = coef * quantity;
-            ((SKGDocument*) getDocument())->addValueInCache(key, SKGServices::doubleToString(output));
+            (static_cast<SKGDocument*>(getDocument()))->addValueInCache(key, SKGServices::doubleToString(output));
 
             if (getAttribute("i_NBVALUES") == "1") {
                 //Store value for this symbol for all date
-                ((SKGDocument*) getDocument())->addValueInCache("unitvalue-" % ids, SKGServices::doubleToString(output));
+                (static_cast<SKGDocument*>(getDocument()))->addValueInCache("unitvalue-" % ids, SKGServices::doubleToString(output));
             }
         } else {
             output = SKGServices::stringToDouble(val);
@@ -632,8 +632,8 @@ SKGError SKGUnitObject::split(double iRatio) const
 
         err = getDocument()->executeSqliteOrder("UPDATE unitvalue SET f_quantity=f_quantity/" % SKGServices::doubleToString(iRatio) %
                                                 " WHERE rd_unit_id=" % SKGServices::intToString(getID()));
-        if (!err) err = getDocument()->executeSqliteOrder("UPDATE suboperation SET f_value=f_value*" % SKGServices::doubleToString(iRatio) %
-                            " WHERE rd_operation_id IN (SELECT id FROM operation WHERE rc_unit_id=" % SKGServices::intToString(getID()) % ')');
+        IFOKDO(err, getDocument()->executeSqliteOrder("UPDATE suboperation SET f_value=f_value*" % SKGServices::doubleToString(iRatio) %
+                " WHERE rd_operation_id IN (SELECT id FROM operation WHERE rc_unit_id=" % SKGServices::intToString(getID()) % ')'));
     } else err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Invalid ratio. Ratio must be greater than 0."));
     return err;
 }
@@ -766,9 +766,9 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                 //Create value
                 SKGUnitValueObject val;
                 err = addUnitValue(val);
-                if (!err) err = val.setDate(firstDate);
-                if (!err) err = val.setQuantity(value);
-                if (!err) err = val.save();
+                IFOKDO(err, val.setDate(firstDate))
+                IFOKDO(err, val.setQuantity(value))
+                IFOKDO(err, val.save())
 
             }
 
@@ -793,8 +793,8 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
             if (!last) {
                 QString path = "http://ichart.finance.yahoo.com/table.csv?s=" % code % "&ignore=.csv&" % parameters;
                 QByteArray stream;
-                SKGError err = SKGServices::downloadToStream(KUrl(path), stream);
-                if (!err) {
+                SKGError err2 = SKGServices::downloadToStream(KUrl(path), stream);
+                if (!err2) {
                     //The file is something like this
                     //Date,Open,High,Low,Close,Volume,Adj Close
                     //2008-08-29,41.64,41.86,41.04,41.32,308800,41.32
@@ -804,21 +804,21 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     //2008-08-25,40.52,41.02,40.52,40.80,100100,40.80
                     QStringList lines = SKGServices::splitCSVLine(stream, '\n');
                     int nb = lines.count();
-                    for (int i = 1; i < nb && !err && (i < nbMaxValues - 1 || nbMaxValues == 0); ++i) { //-1 because the value of the day will be loaded after
+                    for (int i = 1; i < nb && !err2 && (i < nbMaxValues - 1 || nbMaxValues == 0); ++i) { //-1 because the value of the day will be loaded after
                         //Read line
                         QString line = lines.at(i);
                         QStringList fields = SKGServices::splitCSVLine(line, ',');
-                        if (fields.count() != 7) err.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
+                        if (fields.count() != 7) err2.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
                         else {
                             QDate ds = QDate::fromString(fields[0], "yyyy-MM-dd");
                             double val = SKGServices::stringToDouble(fields[6]);
 
                             //Creation or update of the value
                             SKGUnitValueObject value;
-                            if (!err) err = addUnitValue(value);
-                            if (!err) err = value.setDate(ds);
-                            if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                            if (!err) err = value.save();
+                            if (!err2) err2 = addUnitValue(value);
+                            if (!err2) err2 = value.setDate(ds);
+                            if (!err2) err2 = value.setQuantity(invert && val != 0 ? 1 / val : val);
+                            if (!err2) err2 = value.save();
                         }
                     }
                 } else {
@@ -826,7 +826,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     doc->sendMessage(i18nc("A warning message", "History for %1 not found on Yahoo", code), SKGDocument::Warning);
                 }
             }
-            if (!err) {
+            IFOK(err) {
                 //Build list of additional download information
                 //http://www.etraderzone.com/free-scripts/50-yahoo-stock-quotes.html?catid=34%3Aexcel-script
                 QStringList unitYahooCode;
@@ -1017,17 +1017,17 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     if (nb != unitYahooTitle.count() + 2) {
                         err = getDocument()->sendMessage(i18nc("An error message", "Additional information was not downloaded because of invalid number of fields (found=%1, expected=%2) for %3 in following string:\n%4", SKGServices::intToString(nb), SKGServices::intToString(unitYahooTitle.count() + 2), unitname, line), SKGDocument::Warning);
 
-                        if (!err) err = downloadUnitValue(iMode, nbMaxValues, false);
+                        IFOKDO(err, downloadUnitValue(iMode, nbMaxValues, false))
                     } else {
                         if ((ds = QDate::fromString(fields[1], "M/d/yyyy")).isValid()) {
                             double val = SKGServices::stringToDouble(fields[0]);
 
                             //Creation or update of the value
                             SKGUnitValueObject value;
-                            if (!err) err = addUnitValue(value);
-                            if (!err) err = value.setDate(ds);
-                            if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                            if (!err) err = value.save();
+                            IFOKDO(err, addUnitValue(value))
+                            IFOKDO(err, value.setDate(ds))
+                            IFOKDO(err, value.setQuantity(invert && val != 0 ? 1 / val : val))
+                            IFOKDO(err, value.save())
                         } else err.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
 
                         for (int j = 2; !err && j < nb; ++j) {
@@ -1049,7 +1049,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                 QHash< QString, QString > properties;
                 err = SKGServices::readPropertyFile(fileName, properties);
 
-                if (!err) {
+                IFOK(err) {
                     QString path = properties["url"].replace("%1", code);
                     QString mode = properties["mode"].toUpper();
                     QString price = properties["price"].replace("%1", code);
@@ -1090,10 +1090,10 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
 
                                     //Creation or update of the value
                                     SKGUnitValueObject value;
-                                    if (!err) err = addUnitValue(value);
-                                    if (!err) err = value.setDate(ds);
-                                    if (!err) err = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                                    if (!err) err = value.save();
+                                    IFOKDO(err, addUnitValue(value))
+                                    IFOKDO(err, value.setDate(ds))
+                                    IFOKDO(err, value.setQuantity(invert && val != 0 ? 1 / val : val))
+                                    IFOKDO(err, value.save())
 
                                     nbLoaded++;
                                 }
@@ -1108,7 +1108,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
         }
     }
 
-    if (err) {
+    IFKO(err) {
         err.addError(ERR_FAIL, i18nc("Error message", "Impossible to download unit %1 with Internet code %2.", unitname, code));
     }
 
@@ -1142,14 +1142,14 @@ SKGError SKGUnitObject::openURL()
                 QHash< QString, QString > properties;
                 err = SKGServices::readPropertyFile(fileName, properties);
 
-                if (!err) {
+                IFOK(err) {
                     url = properties["url"].replace("%1", code);
                 }
             }
         }
     }
 
-    if (err) {
+    IFKO(err) {
         err.addError(ERR_FAIL, i18nc("Error message", "Impossible to open unit %1 with Internet code %2.", unitname, code));
     } else {
         QDesktopServices::openUrl(QUrl(url));
@@ -1171,15 +1171,15 @@ SKGError SKGUnitObject::merge(const SKGUnitObject& iUnit)
     SKGError err;
 
     SKGObjectBase::SKGListSKGObjectBase ops;
-    if (!err) err = iUnit.getOperations(ops);
+    IFOKDO(err, iUnit.getOperations(ops))
     int nb = ops.count();
     for (int i = 0; !err && i < nb; ++i) {
         SKGOperationObject op(ops.at(i));
         err = op.setUnit(*this);
-        if (!err) err = op.save(true, false);
+        IFOKDO(err, op.save(true, false))
     }
 
-    if (!err) err = iUnit.remove();
+    IFOKDO(err, iUnit.remove())
     return err;
 }
 
