@@ -63,11 +63,11 @@ public:
        A constructor for the KDatePickerPopup.
        @param items List of all desirable items, separated with a bitwise OR.
        @param date Initial date of datepicker-widget.
-       @param parent The object's parent.
+       @param iParent The object's parent.
     */
     explicit KDatePickerPopup(Items items = DatePicker,
                               const QDate& date = QDate::currentDate(),
-                              QWidget* parent = 0);
+                              QWidget* iParent = 0);
 
     /**
        @return A pointer to the private variable mDatePicker, an instance of
