@@ -49,8 +49,8 @@ public:
 
 using namespace KPIM;
 
-KDateValidator::KDateValidator(QObject* parent)
-    : QValidator(parent), d(new KDateValidatorPrivate)
+KDateValidator::KDateValidator(QObject* iParent)
+    : QValidator(iParent), d(new KDateValidatorPrivate)
 {
 }
 
