@@ -45,7 +45,7 @@ public:
         FixupBackward
     };
 
-    explicit KDateValidator(QObject* parent = 0);
+    explicit KDateValidator(QObject* iParent = 0);
     virtual ~KDateValidator();
 
     void setKeywords(const QStringList& keywords);
