@@ -61,9 +61,9 @@ public:
 
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGCalculatorEdit(QWidget* parent = 0);
+    explicit SKGCalculatorEdit(QWidget* iParent = 0);
 
     /**
      * Default Destructor
