@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGColorButtonDesignerPlugin::SKGColorButtonDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGColorButtonDesignerPlugin::SKGColorButtonDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGColorButtonDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGColorButtonDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGColorButtonDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGColorButton(parent);
+    return new SKGColorButton(iParent);
 }
 
 QString SKGColorButtonDesignerPlugin::name() const
