@@ -42,9 +42,9 @@ class SKGBASEGUI_EXPORT SKGComboBox : public KComboBox
 public:
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGComboBox(QWidget* parent = 0);
+    explicit SKGComboBox(QWidget* iParent = 0);
 
     /**
      * Default Destructor
