@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGComboBoxDesignerPlugin::SKGComboBoxDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGComboBoxDesignerPlugin::SKGComboBoxDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGComboBoxDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGComboBoxDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGComboBoxDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGComboBox(parent);
+    return new SKGComboBox(iParent);
 }
 
 QString SKGComboBoxDesignerPlugin::name() const
