@@ -26,8 +26,8 @@
 #include <kglobal.h>
 #include <klocale.h>
 
-SKGDateEdit::SKGDateEdit(QWidget* parent, const char* name)
-    : KPIM::KDateEdit(parent) //TODO: Migrate on KDateCombo
+SKGDateEdit::SKGDateEdit(QWidget* iParent, const char* name)
+    : KPIM::KDateEdit(iParent) //TODO: Migrate on KDateCombo
 {
     setObjectName(name);
     setMode(CURRENT);
