@@ -51,10 +51,10 @@ public:
 
     /**
      * Constructor
-     * @param parent the parent
+     * @param iParent the parent
      * @param name name
      */
-    explicit SKGDateEdit(QWidget* parent = 0, const char* name = 0);
+    explicit SKGDateEdit(QWidget* iParent = 0, const char* name = 0);
 
     /**
      * Destructor
