@@ -26,8 +26,8 @@
 #include <QDomDocument>
 #include <klineedit.h>
 
-SKGFilteredTableView::SKGFilteredTableView(QWidget* parent)
-    : QWidget(parent), m_objectModel(NULL), m_refreshNeeded(true)
+SKGFilteredTableView::SKGFilteredTableView(QWidget* iParent)
+    : QWidget(iParent), m_objectModel(NULL), m_refreshNeeded(true)
 {
     ui.setupUi(this);
     ui.kConfigure->setIcon(KIcon("configure"));
@@ -51,7 +51,7 @@ QString SKGFilteredTableView::getState()
     doc.appendChild(root);
 
     root.setAttribute("show", ui.kShow->getState());
-    root.setAttribute("filter", ui.kFilterEdit->lineEdit()->text());
+    root.setAttribute("filter", getSearchField()->lineEdit()->text());
 
     //Memorize table settings
     root.setAttribute("view", ui.kView->getState());
@@ -64,11 +64,11 @@ void SKGFilteredTableView::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString show = root.attribute("show");
+    QString show2 = root.attribute("show");
     QString filter = root.attribute("filter");
 
-    if (!show.isEmpty()) ui.kShow->setState(show);
-    ui.kFilterEdit->setText(filter);
+    if (!show2.isEmpty()) ui.kShow->setState(show2);
+    getSearchField()->setText(filter);
 
     if (m_objectModel) {
         bool previous = m_objectModel->blockRefresh(true);
@@ -90,6 +90,11 @@ SKGTreeView* SKGFilteredTableView::getView() const
     return ui.kView;
 }
 
+KFilterProxySearchLine* SKGFilteredTableView::getSearchField() const
+{
+    return ui.kFilterEdit;
+}
+
 void SKGFilteredTableView::onFilterChanged()
 {
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -133,7 +138,7 @@ void SKGFilteredTableView::setModel(SKGObjectModelBase* iModel)
         modelProxy->setSortRole(Qt::UserRole);
         modelProxy->setDynamicSortFilter(true);
 
-        ui.kFilterEdit->setProxy(modelProxy);
+        getSearchField()->setProxy(modelProxy);
 
         ui.kView->setModel(modelProxy);
 
