@@ -37,12 +37,12 @@ class SKGBASEGUI_EXPORT SKGFlowLayout : public QLayout
 public:
     /**
      * Constructor
-     * @param parent the parent
+     * @param iParent the parent
      * @param margin margin
      * @param hSpacing horizontal spacing
      * @param vSpacing vertical spacing
      */
-    explicit SKGFlowLayout(QWidget* parent, int margin = -1, int hSpacing = -1, int vSpacing = -1);
+    explicit SKGFlowLayout(QWidget* iParent, int margin = -1, int hSpacing = -1, int vSpacing = -1);
 
     /**
      * Constructor
