@@ -59,7 +59,7 @@ protected:
     virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* mouseEvent);
 
 private:
-    Q_DISABLE_COPY(SKGGraphicsScene);
+    Q_DISABLE_COPY(SKGGraphicsScene)
 };
 
 #endif
