@@ -53,9 +53,9 @@ class SKGBASEGUI_EXPORT SKGGraphicsView : public QWidget
 public:
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGGraphicsView(QWidget* parent = 0);
+    explicit SKGGraphicsView(QWidget* iParent = 0);
 
     /**
      * Default Destructor
@@ -123,6 +123,12 @@ public Q_SLOTS:
      */
     virtual void onPrint();
 
+    /**
+     * Export to a file
+     * @param iFileName the file name
+     */
+    virtual void exportInFile(const QString& iFileName);
+
     /**
      * Export
      */
