@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGGraphicsViewDesignerPlugin::SKGGraphicsViewDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGGraphicsViewDesignerPlugin::SKGGraphicsViewDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGGraphicsViewDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGGraphicsViewDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGGraphicsViewDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGGraphicsView(parent);
+    return new SKGGraphicsView(iParent);
 }
 
 QString SKGGraphicsViewDesignerPlugin::name() const
