@@ -24,8 +24,8 @@
 
 #include "kactioncollection.h"
 
-SKGInterfacePlugin::SKGInterfacePlugin(QObject* parent)
-    : KParts::ReadOnlyPart(parent)
+SKGInterfacePlugin::SKGInterfacePlugin(QObject* iParent)
+    : KParts::ReadOnlyPart(iParent)
 {}
 SKGInterfacePlugin::~SKGInterfacePlugin()
 {}
