@@ -154,7 +154,7 @@ public:
         Q_UNUSED(iTime);
         QProgressBar* progressBar = NULL;
         QPushButton* button = NULL;
-        doublePointer* pointers = (doublePointer*) iProgressBar;
+        doublePointer* pointers = static_cast<doublePointer*>(iProgressBar);
         if (pointers) {
             progressBar = static_cast<QProgressBar*>(pointers->p1);
             button = static_cast<QPushButton*>(pointers->p2);
@@ -218,12 +218,12 @@ public:
         }
     }
 
-    bool iconInSystemtray() {
+    static bool iconInSystemtray() {
         return skgbasegui_settings::icon_in_system_tray();
     }
 
     void refreshTabPosition() {
-        m_tabWidget->setTabPosition((KTabWidget::TabPosition) skgbasegui_settings::main_tabs_position());
+        m_tabWidget->setTabPosition(static_cast<KTabWidget::TabPosition>(skgbasegui_settings::main_tabs_position()));
     }
 };
 
@@ -307,9 +307,9 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
         if (version.isEmpty() || SKGServices::stringToDouble(version) < 1) {
             SKGTRACE << "WARNING: plugin [" << name << "] not loaded because of version too old (<1)" << endl;
         } else {
-            KPluginFactory* factory = loader.factory();
-            if (factory) {
-                SKGInterfacePlugin* pluginInterface = factory->create<SKGInterfacePlugin> (this);
+            KPluginFactory* factory2 = loader.factory();
+            if (factory2) {
+                SKGInterfacePlugin* pluginInterface = factory2->create<SKGInterfacePlugin> (this);
                 if (pluginInterface) {
                     if (pluginInterface->isEnabled() && pluginInterface->setupActions(getDocument(), iArguments)) {
                         //Add plugin in about
@@ -322,28 +322,28 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
                                     author = authors.at(0);
                                     authorId = authors.at(1);
                                 }
-                                int pos = listAuthors.indexOf(author);
-                                if (pos == -1) {
+                                int pos2 = listAuthors.indexOf(author);
+                                if (pos2 == -1) {
                                     listAuthors.push_back(author);
                                     listTasks.push_back(i18n("Developer of plugin '%1'", name));
                                     listEmails.push_back(email);
                                     listOscs.push_back(authorId);
                                 } else {
-                                    listTasks[pos] += i18n(", '%1'", name);
+                                    listTasks[pos2] += i18n(", '%1'", name);
                                 }
                             }
                         }
 
                         //Store plugin
                         int nbplugin = d->m_pluginsList.count();
-                        int pos = nbplugin;
+                        int pos3 = nbplugin;
                         for (int j = nbplugin - 1; j >= 0; --j) {
                             if (pluginInterface->getOrder() < d->m_pluginsList.at(j)->getOrder()) {
-                                pos = j;
+                                pos3 = j;
                             }
                         }
 
-                        d->m_pluginsList.insert(pos, pluginInterface);
+                        d->m_pluginsList.insert(pos3, pluginInterface);
                         pluginInterface->setObjectName(id);
 
                         //Build temporary tips file
@@ -362,9 +362,9 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
                     }
                 }
             } else {
-                QString msg = i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2: %3", id, service->library(), loader.errorString());
-                getDocument()->sendMessage(msg);
-                SKGTRACEL(1) << "WARNING:" << msg << endl;
+                QString msg2 = i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2: %3", id, service->library(), loader.errorString());
+                getDocument()->sendMessage(msg2);
+                SKGTRACEL(1) << "WARNING:" << msg2 << endl;
             }
         }
     }
@@ -421,9 +421,9 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     //Add a status bar
     statusBar()->show();
 
-    QPalette palette = QApplication::palette();
-    palette.setColor(QPalette::Base, Qt::transparent);
-    d->ui.kContextList->setPalette(palette);
+    QPalette palette2 = QApplication::palette();
+    palette2.setColor(QPalette::Base, Qt::transparent);
+    d->ui.kContextList->setPalette(palette2);
 
     QAction* toggle = d->ui.kDockContext->toggleViewAction();
     KAction* panelAction = actionCollection()->addAction("view_context");
@@ -461,16 +461,16 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
                     contextItem->setStatusTip(pluginInterface->statusTip());
                     contextItem->setToolTip(pluginInterface->toolTip());
                     contextItem->setData(12, j);     //context item ==> plugin
-                    int page = d->ui.kContextList->count();
-                    pluginInterface->setProperty("contextItem", page); //plugin ==> context item
+                    int page2 = d->ui.kContextList->count();
+                    pluginInterface->setProperty("contextItem", page2); //plugin ==> context item
 
                     d->ui.kContextList->addItem(contextItem);
 
                     KAction* action = contextMenu->addAction(icon, title);
                     if (action) {
                         action->setCheckable(false);
-                        action->setData(page);
-                        contextItem->setData(15, (qlonglong) action);     //context item ==> action
+                        action->setData(page2);
+                        contextItem->setData(15, qVariantFromValue(static_cast<void*>(action)));     //context item ==> action
                         if (!shortCutPrefix.isEmpty()) {
                             ++shortCutIndex;
                             if (shortCutIndex == 10) {
@@ -588,15 +588,15 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
 
     //Set progress bar call back
     if (getDocument()) {
-        d->m_progressObjects.p1 = (void*) kProgressBar;
-        d->m_progressObjects.p2 = (void*) kCancelButton;
-        getDocument()->setProgressCallback(&SKGMainPanelPrivate::progressBarCallBack, (void*) &d->m_progressObjects);
+        d->m_progressObjects.p1 = static_cast<void*>(kProgressBar);
+        d->m_progressObjects.p2 = static_cast<void*>(kCancelButton);
+        getDocument()->setProgressCallback(&SKGMainPanelPrivate::progressBarCallBack, static_cast<void*>(&d->m_progressObjects));
     }
 
     //Connection
     if (getDocument()) {
-        connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(refresh()), Qt::QueuedConnection);
-        connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(notify(int)), Qt::QueuedConnection);
+        connect(getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(refresh()), Qt::QueuedConnection);
+        connect(getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(notify(int)), Qt::QueuedConnection);
     }
     connect(d->ui.kContextList, SIGNAL(itemPressed(QListWidgetItem*)), this, SLOT(onBeforeOpenContext()));
     connect(d->ui.kContextList, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(onOpenContext()));
@@ -657,7 +657,7 @@ SKGMainPanel::~SKGMainPanel()
 {
     SKGTRACEIN(1, "SKGMainPanel::~SKGMainPanel");
     SKGMainPanelPrivate::m_mainPanel = NULL;
-    disconnect((const QObject*) getDocument(), 0, this, 0);
+    disconnect(getDocument(), 0, this, 0);
 
     //close plugins
     int nb = d->m_pluginsList.count();
@@ -683,7 +683,7 @@ void SKGMainPanel::setContextVisibility(QListWidgetItem* iItem, bool iVisibility
         iItem->setHidden(!iVisibility);
 
         //Hide corresponding action
-        KAction* act = (KAction*) iItem->data(15).toLongLong();
+        KAction* act = static_cast< KAction* >(iItem->data(15).value<void*>());
         if (act) act->setVisible(iVisibility);
 
         //Save state in settings
@@ -745,6 +745,11 @@ QAction* SKGMainPanel::getGlobalAction(const QString& iIdentifier, bool iWarnIfN
     return act;
 }
 
+QMap< QString, QAction* > SKGMainPanel::getGlobalActions() const
+{
+    return d->m_registeredGlogalAction;
+}
+
 SKGInterfacePlugin* SKGMainPanel::getPluginByIndex(int iIndex)
 {
     SKGInterfacePlugin* output = NULL;
@@ -946,36 +951,38 @@ void SKGMainPanel::onPrevious()
     SKGTabPage* cPage = currentPage();
     if (cPage) {
         //Get index in history of page to refresh
-        int pos = ((QAction*) sender())->data().toInt();
+        int pos = static_cast<QAction*>(sender())->data().toInt();
 
         //Get lists
         QList<SKGTabPage::SKGPageHistoryItem> listPrevious = cPage->getPreviousPages();
-        QList<SKGTabPage::SKGPageHistoryItem> listNext = cPage->getNextPages();
-        SKGTabPage::SKGPageHistoryItem current = currentPageHistoryItem();
+        if (pos < listPrevious.count()) {
+            QList<SKGTabPage::SKGPageHistoryItem> listNext = cPage->getNextPages();
+            SKGTabPage::SKGPageHistoryItem current = currentPageHistoryItem();
 
-        //Get item to refresh
-        SKGTabPage::SKGPageHistoryItem item = listPrevious.at(pos);
+            //Get item to refresh
+            SKGTabPage::SKGPageHistoryItem item = listPrevious.at(pos);
 
-        //Open page
-        cPage = openPage(getPluginByName(item.plugin), currentPageIndex(), item.state, item.name, item.bookmarkID);
-        if (cPage) {
-            cPage->setBookmarkID(item.bookmarkID);
+            //Open page
+            cPage = openPage(getPluginByName(item.plugin), currentPageIndex(), item.state, item.name, item.bookmarkID);
+            if (cPage) {
+                cPage->setBookmarkID(item.bookmarkID);
 
-            //Update lists
-            listNext.insert(0, current);
-            listPrevious.removeAt(pos);
-            for (int i = 0; i < pos; ++i) {
-                SKGTabPage::SKGPageHistoryItem item = listPrevious.at(0);  //Because the list is modified
-                listNext.insert(0, item);
-                listPrevious.removeAt(0);
+                //Update lists
+                listNext.insert(0, current);
+                listPrevious.removeAt(pos);
+                for (int i = 0; i < pos; ++i) {
+                    SKGTabPage::SKGPageHistoryItem item = listPrevious.at(0);  //Because the list is modified
+                    listNext.insert(0, item);
+                    listPrevious.removeAt(0);
+                }
+
+                //Set lists
+                cPage->setPreviousPages(listPrevious);
+                cPage->setNextPages(listNext);
             }
 
-            //Set lists
-            cPage->setPreviousPages(listPrevious);
-            cPage->setNextPages(listNext);
+            refresh();
         }
-
-        refresh();
     }
 }
 
@@ -1057,7 +1064,7 @@ void SKGMainPanel::onNext()
     SKGTabPage* cPage = currentPage();
     if (cPage) {
         //Get index in history of page to refresh
-        int pos = ((QAction*) sender())->data().toInt();
+        int pos = static_cast<QAction*>(sender())->data().toInt();
 
         //Get lists
         QList<SKGTabPage::SKGPageHistoryItem> listPrevious = cPage->getPreviousPages();
@@ -1384,7 +1391,7 @@ void SKGMainPanel::onSettingsChanged()
         //Refresh plugins
         for (int i = 0; !err && i < nb; ++i) {
             err = getPluginByIndex(i)->savePreferences();
-            if (!err) err = getDocument()->stepForward(i + 1);
+            IFOKDO(err, getDocument()->stepForward(i + 1))
         }
 
         //Setting for icon
@@ -1572,7 +1579,7 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
             closePage(cPage);
 
             //Repair the history of closed page
-            d->m_historyClosedPages.removeLast();
+            if (!d->m_historyClosedPages.isEmpty()) d->m_historyClosedPages.removeLast();
         }
     }
 
@@ -1648,7 +1655,7 @@ int SKGMainPanel::countPages() const
 
 SKGTabPage* SKGMainPanel::page(int iIndex) const
 {
-    return (SKGTabPage*) d->m_tabWidget->widget(iIndex);
+    return static_cast<SKGTabPage*>(d->m_tabWidget->widget(iIndex));
 }
 
 void SKGMainPanel::setCurrentPage(int iIndex)
@@ -1854,12 +1861,12 @@ void SKGMainPanel::resetDefaultState()
             err = getDocument()->setParameter(name, "<!DOCTYPE SKGML>");
 
             //Refresh panel
-            if (!err) toSave->setState("");
+            IFOK(err) toSave->setState("");
         }
     }
 
     //status bar
-    if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Default state has been reset"));
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Default state has been reset")))
     displayErrorMessage(err);
 }
 
@@ -1925,7 +1932,7 @@ void SKGMainPanel::notify(int iTransaction)
             QList<SKGDocument::MessageType> listGroups;
             for (int i = 0; i < nbMessages; ++i) {
                 if (listGroups.count() == 0 || type.at(i) != listGroups.at(listGroups.count() - 1)) listGroups.push_back(type.at(i));
-                if ((int) type.at(i) >= (int) maxType) maxType = type.at(i);
+                if (static_cast<int>(type.at(i)) >= static_cast<int>(maxType)) maxType = type.at(i);
             }
 
             //Is the number of type acceptable?
@@ -1996,7 +2003,7 @@ KMessageWidget* SKGMainPanel::displayMessage(const QString& iMessage, SKGDocumen
     if (!iMessage.isEmpty()) {
         msg = new KMessageWidget(this);
         msg->setText(iMessage);
-        msg->setMessageType((KMessageWidget::MessageType) iType);
+        msg->setMessageType(static_cast<KMessageWidget::MessageType>(iType));
         QTimer::singleShot(iType == SKGDocument::Positive ? 5000 : iType == SKGDocument::Information ? 10000 : 20000, msg, SLOT(deleteLater()));
         d->m_mainLayout->insertWidget(qMax(d->m_mainLayout->indexOf(d->m_mainWidget) - 1, 0), msg);
     }
@@ -2009,6 +2016,9 @@ KMessageWidget* SKGMainPanel::displayMessage(const QString& iMessage, SKGDocumen
     notify->setText(iMessage);
     notify->sendEvent();
 
+    //Alert
+    if (iType == SKGDocument::Error || iType == SKGDocument::Warning) qApp->alert(this);
+
     return msg;
 }
 
@@ -2062,20 +2072,20 @@ void SKGMainPanel::onQuitAction()
     qApp->closeAllWindows();
 }
 
-QString SKGMainPanel::getSaveFileName(const QString& startDir, const QString& filter, QWidget* parent, const QString& caption, QString* iCodec)
+QString SKGMainPanel::getSaveFileName(const QString& startDir, const QString& filter, QWidget* iParent, const QString& caption, QString* iCodec)
 {
     QString fileName;
     if (iCodec) {
         QString lastCodecUsed = QTextCodec::codecForLocale()->name();
-        KEncodingFileDialog::Result result = KEncodingFileDialog::getSaveUrlAndEncoding(lastCodecUsed, startDir, filter , parent, caption);
+        KEncodingFileDialog::Result result = KEncodingFileDialog::getSaveUrlAndEncoding(lastCodecUsed, startDir, filter , iParent, caption);
         if (result.URLs.count()) fileName = result.URLs.at(0).pathOrUrl();
         *iCodec = result.encoding;
     } else {
-        fileName = KFileDialog::getSaveFileName(KUrl(startDir), filter , parent, caption);
+        fileName = KFileDialog::getSaveFileName(KUrl(startDir), filter , iParent, caption);
     }
     if (fileName.isEmpty()) return "";
     QFile f(fileName);
-    if (f.exists() && KMessageBox::warningContinueCancel(parent,
+    if (f.exists() && KMessageBox::warningContinueCancel(iParent,
             i18nc("Question", "File <b>%1</b> already exists. Do you really want to overwrite it?", fileName),
             i18nc("Question", "Warning"),
             KGuiItem(i18nc("Verb",  "Save"), KIcon("document-save"))) != KMessageBox::Continue) return "";
