@@ -81,12 +81,12 @@ public:
      * @li an URL starting with 'kfiledialog:///\<keyword\>' to start in the directory last used by a filedialog in the same application that specified the same keyword.
      * @li an URL starting with 'kfiledialog:///\<keyword\>?global' to start in the directory last used by a filedialog in any application that specified the same keyword.
      * @param filter a shell glob or a mime-type-filter that specifies which files to display. The preferred option is to set a list of mimetype names, see setMimeFilter() for details. Otherwise you can set the text to be displayed for the each glob, and provide multiple globs, see setFilter() for details.
-     * @param parent the widget the dialog will be centered on initially.
+     * @param iParent the widget the dialog will be centered on initially.
      * @param caption the name of the dialog widget.
      * @param iCodec a valid QString to get the codec.
      * @return the file name
      */
-    static QString getSaveFileName(const QString& startDir = KUrl().url(), const QString& filter = QString(), QWidget* parent = 0,
+    static QString getSaveFileName(const QString& startDir = KUrl().url(), const QString& filter = QString(), QWidget* iParent = 0,
                                    const QString& caption = QString(), QString* iCodec = NULL);
 
     /**
@@ -348,6 +348,12 @@ public Q_SLOTS:
      */
     virtual QAction* getGlobalAction(const QString& iIdentifier, bool iWarnIfNotExist = true);
 
+    /**
+     * Get all registered global actions
+     * @return actions
+     */
+    virtual QMap<QString, QAction*> getGlobalActions() const;
+
     /**
      * Get the temporary filename containing the tips of days
      * @return the file name
