@@ -40,10 +40,10 @@
 SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
                                        const QString& iTable,
                                        const QString& iWhereClause,
-                                       QWidget* parent,
+                                       QWidget* iParent,
                                        const QString& iParentAttribute,
                                        bool iResetOnCreation)
-    : QAbstractItemModel(parent), m_isResetRealyNeeded(iResetOnCreation), m_document(iDocument),
+    : QAbstractItemModel(iParent), m_isResetRealyNeeded(iResetOnCreation), m_document(iDocument),
       m_whereClause(iWhereClause),
       m_parentAttribute(iParentAttribute), m_refreshBlocked(false)
 {
@@ -51,8 +51,8 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
 
     setTable(iTable);
 
-    connect((const QObject*) m_document, SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)));
-    connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    connect(m_document, SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)));
+    if (SKGMainPanel::getMainPanel()) connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
 }
 
 SKGObjectModelBase::~SKGObjectModelBase()
@@ -381,22 +381,22 @@ void SKGObjectModelBase::refresh()
     QApplication::restoreOverrideCursor();
 }
 
-bool SKGObjectModelBase::hasChildren(const QModelIndex& parent) const
+bool SKGObjectModelBase::hasChildren(const QModelIndex& iParent) const
 {
-    if (parent.column() > 0) return false;
+    if (iParent.column() > 0) return false;
     _SKGTRACEIN(10, "SKGObjectModelBase::hasChildren");
 
-    if (parent.isValid() && m_parentAttribute.isEmpty() && m_groupby.isEmpty()) return false;
-    return QAbstractItemModel::hasChildren(parent);
+    if (iParent.isValid() && m_parentAttribute.isEmpty() && m_groupby.isEmpty()) return false;
+    return QAbstractItemModel::hasChildren(iParent);
 }
 
-int SKGObjectModelBase::rowCount(const QModelIndex& parent) const
+int SKGObjectModelBase::rowCount(const QModelIndex& iParent) const
 {
-    if (parent.column() > 0) return 0;
+    if (iParent.column() > 0) return 0;
     _SKGTRACEIN(10, "SKGObjectModelBase::rowCount");
 
     int idParent = 0;
-    if (parent.isValid()) idParent = parent.internalId();
+    if (iParent.isValid()) idParent = iParent.internalId();
 
     QList<int> children = m_parentChildRelations.value(idParent);
     //SKGTRACE << table << "-rowCount(" << idParent << " )=" << children.count() << endl;
@@ -404,19 +404,19 @@ int SKGObjectModelBase::rowCount(const QModelIndex& parent) const
 
 }
 
-int SKGObjectModelBase::columnCount(const QModelIndex& parent) const
+int SKGObjectModelBase::columnCount(const QModelIndex& iParent) const
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(iParent);
     return m_listAttibutes.count();
 }
 
-QModelIndex SKGObjectModelBase::index(int row, int column, const QModelIndex& parent) const
+QModelIndex SKGObjectModelBase::index(int row, int column, const QModelIndex& iParent) const
 {
-    if (!hasIndex(row, column, parent)) return QModelIndex();
+    if (!hasIndex(row, column, iParent)) return QModelIndex();
     _SKGTRACEIN(10, "SKGObjectModelBase::index");
 
     int idParent = 0;
-    if (parent.isValid())  idParent = parent.internalId();
+    if (iParent.isValid())  idParent = iParent.internalId();
 
     int idChild = m_parentChildRelations.value(idParent).at(row);
 
@@ -560,7 +560,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
             case SKGServices::DATE: {
                 QDate dval = SKGServices::stringToTime(val).date();
                 if (role == Qt::DisplayRole) {
-                    return KGlobal::locale()->formatDate(dval, (KLocale::DateFormat) skgbasegui_settings::date_format());
+                    return KGlobal::locale()->formatDate(dval, static_cast<KLocale::DateFormat>(skgbasegui_settings::date_format()));
                 } else {
                     return dval;
                 }
@@ -604,7 +604,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
     case Qt::TextAlignmentRole: {
         //Text alignment
         SKGServices::AttributeType attType = getAttributeType(index.column());
-        return (int)(Qt::AlignVCenter | (attType == SKGServices::FLOAT || attType == SKGServices::INTEGER ? Qt::AlignRight : Qt::AlignLeft));
+        return static_cast<int>(Qt::AlignVCenter | (attType == SKGServices::FLOAT || attType == SKGServices::INTEGER ? Qt::AlignRight : Qt::AlignLeft));
     }
     case Qt::DecorationRole: {
         //Decoration
@@ -612,16 +612,16 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
         QString att = m_listAttibutes[index.column()];
         if (obj->getTable().isEmpty()) {
             //This is a group
-            if (index.column() == 0) return qVariantFromValue((QIcon) KIcon("arrow-right"));;
+            if (index.column() == 0) return qVariantFromValue(static_cast<QIcon>(KIcon("arrow-right")));;
             return "";
         } else {
             if (index.column() == 0 && m_nodeTable) {
                 SKGNodeObject node(*obj);
                 return qVariantFromValue(node.getIcon());
             } else if (index.column() == 0 && m_doctransactionTable) {
-                return qVariantFromValue((QIcon) KIcon(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo"));
+                return qVariantFromValue(static_cast<QIcon>(KIcon(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo")));
             } else if (m_doctransactionTable && att == "t_savestep") {
-                if (obj->getAttribute("t_savestep") == "Y") return qVariantFromValue((QIcon) KIcon("document-save"));
+                if (obj->getAttribute("t_savestep") == "Y") return qVariantFromValue(static_cast<QIcon>(KIcon("document-save")));
             }
         }
         break;
@@ -669,7 +669,6 @@ QVariant SKGObjectModelBase::data(const QModelIndex& index, int role) const
             }
         }
         return toolTipString;
-        break;
     }
     case 99: {
         SKGObjectBase* obj = getObjectPointer(index);
@@ -688,12 +687,12 @@ Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex& index) const
 {
     _SKGTRACEIN(10, "SKGObjectModelBase::flags");
 
-    Qt::ItemFlags flags = QAbstractItemModel::flags(index) | Qt::ItemIsDropEnabled | Qt::ItemIsUserCheckable;
+    Qt::ItemFlags flags = QAbstractItemModel::flags(index) | Qt::ItemIsDropEnabled;
+
+    if (index.isValid()) flags |= Qt::ItemIsUserCheckable;
+
+    if (m_nodeTable && index.isValid()) flags |= Qt::ItemIsEditable | Qt::ItemIsDragEnabled;
 
-    if (m_nodeTable) {
-        flags |= Qt::ItemIsEditable;
-        if (index.isValid()) flags |= Qt::ItemIsDragEnabled;
-    }
     if (index.isValid()) {
         QString att = m_listAttibutes[index.column()];
         if (att.toLower() == att || !getDocument()->getRealAttribute(att).isEmpty()) flags |= Qt::ItemIsEditable;
@@ -716,7 +715,7 @@ bool SKGObjectModelBase::setData(const QModelIndex& index, const QVariant& value
             QString name = value.toString();
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", name), err);
             err = obj.setName(name);
-            if (!err) err = obj.save();
+            IFOKDO(err, obj.save())
         } else {
             SKGObjectBase obj(getObject(index));
 
@@ -724,7 +723,7 @@ bool SKGObjectModelBase::setData(const QModelIndex& index, const QVariant& value
             SKGObjectBase obj2(obj.getDocument(), obj.getRealTable(), obj.getID()); //To be sure this is not a complex object
             QString att = m_listAttibutes[index.column()];
             err = obj2.setAttribute(att, att.startsWith(QLatin1String("d_")) && value.canConvert<QDateTime>() ? SKGServices::dateToSqlString(value.toDateTime()) : value.toString());
-            if (!err) err = obj2.save();
+            IFOKDO(err, obj2.save())
         }
 
         SKGMainPanel::displayErrorMessage(err);
@@ -776,7 +775,7 @@ QMimeData* SKGObjectModelBase::mimeData(const QModelIndexList& indexes) const
 bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
                                       Qt::DropAction action,
                                       int row, int column,
-                                      const QModelIndex& parent)
+                                      const QModelIndex& iParent)
 {
     Q_UNUSED(row);
     if (action == Qt::IgnoreAction) return true;
@@ -785,11 +784,11 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
 
     SKGError err;
     //Drop files
-    if (data->hasUrls() && parent.isValid() && getRealTable() != "node") {
+    if (data->hasUrls() && iParent.isValid() && getRealTable() != "node") {
         QList<QUrl> urls = data->urls();
         int nb = urls.count();
         {
-            SKGObjectBase obj(getObject(parent));
+            SKGObjectBase obj(getObject(iParent));
 
             SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Property creation"), err, nb);
             for (int i = 0; !err && i < nb; ++i) {
@@ -800,7 +799,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
                     name = i18n("File") % " (" % SKGServices::intToString(index) % ')';
                 }
                 err = obj.setProperty(name, urls.at(i).toLocalFile(), action == Qt::LinkAction ? "" : urls.at(i).toLocalFile());
-                if (!err) err = getDocument()->stepForward(i + 1);
+                IFOKDO(err, getDocument()->stepForward(i + 1))
             }
         }
     }
@@ -810,7 +809,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
-        QModelIndex parentIndex = parent;
+        QModelIndex parentIndex = iParent;
         SKGNodeObject parentNode;
         if (parentIndex.isValid()) {
             parentNode = getObject(parentIndex);
@@ -848,16 +847,16 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
                 //Set parent
                 SKGNodeObject child(getDocument(), o_id);
                 err = child.load();
-                if (!err) {
+                IFOK(err) {
                     if (parentIndex.isValid()) err = child.setParentNode(parentNode);
                     else err = child.removeParentNode();
                 }
 
                 //Set order
-                if (!err)  err = child.setOrder((min + max) / 2.0);
+                IFOKDO(err, child.setOrder((min + max) / 2.0))
 
                 //Save
-                if (!err) err = child.save();
+                IFOKDO(err, child.save())
             }
         }
     }
