@@ -47,14 +47,14 @@ public:
      * @param iDocument the document where to search
      * @param iTable the table where to search
      * @param iWhereClause the where clause
-     * @param parent parent QT object
+     * @param iParent parent QT object
      * @param iParentAttribute the attribute to find the parent of an object clause to find children
      * @param iResetOnCreation to reset data during creation
      */
     SKGObjectModelBase(SKGDocument* iDocument,
                        const QString& iTable,
                        const QString& iWhereClause,
-                       QWidget* parent = NULL,
+                       QWidget* iParent = NULL,
                        const QString& iParentAttribute = "",
                        bool iResetOnCreation = true);
 
@@ -78,26 +78,26 @@ public:
 
     /**
      * Returns true if parent has at least one child.
-     * @param parent the parent
+     * @param iParent the parent
      * @return true or false
      */
-    virtual bool hasChildren(const QModelIndex& parent = QModelIndex()) const;
+    virtual bool hasChildren(const QModelIndex& iParent = QModelIndex()) const;
 
     /**
      * Returns the number of row for the given parent.
-     * @param parent the parent
+     * @param iParent the parent
      * @return the number of row
      */
-    virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
+    virtual int rowCount(const QModelIndex& iParent = QModelIndex()) const;
 
     /**
      * Returns the index of the item in the model specified by the given row, column and parent index.
      * @param row row
      * @param column column
-     * @param parent parent
+     * @param iParent parent
      * @return the index
      */
-    virtual QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const;
+    virtual QModelIndex index(int row, int column, const QModelIndex& iParent = QModelIndex()) const;
 
     /**
      * Returns the parent of the model item with the given index, or QModelIndex() if it has no parent.
@@ -108,10 +108,10 @@ public:
 
     /**
      * Returns the number of columns for the given parent.
-     * @param parent the parent
+     * @param iParent the parent
      * @return the number of column
      */
-    virtual int columnCount(const QModelIndex& parent = QModelIndex()) const;
+    virtual int columnCount(const QModelIndex& iParent = QModelIndex()) const;
 
     /**
      * Returns the data stored under the given role for the item referred to by the index.
@@ -286,13 +286,13 @@ public:
      * @param action action
      * @param row row
      * @param column column
-     * @param parent parent
+     * @param iParent parent
      * @return true if the dropping was successful otherwise false.
      */
     virtual bool dropMimeData(const QMimeData* data,
                               Qt::DropAction action,
                               int row, int column,
-                              const QModelIndex& parent);
+                              const QModelIndex& iParent);
 Q_SIGNALS:
     /**
      * Emitted before reset
