@@ -24,8 +24,8 @@
 #include <kcolorscheme.h>
 #include <QStringBuilder>
 
-SKGProgressBar::SKGProgressBar(QWidget* parent)
-    : QProgressBar(parent), m_negative(-1), m_neutral(-1), m_positive(-1)
+SKGProgressBar::SKGProgressBar(QWidget* iParent)
+    : QProgressBar(iParent), m_negative(-1), m_neutral(-1), m_positive(-1)
 {
     //Define color style
     KColorScheme scheme(QPalette::Normal);
