@@ -34,9 +34,9 @@ class SKGBASEGUI_EXPORT SKGProgressBar : public QProgressBar
 public:
     /**
      * Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGProgressBar(QWidget* parent = 0);
+    explicit SKGProgressBar(QWidget* iParent = 0);
 
     /**
      * Destructor
