@@ -26,8 +26,8 @@
 #include <kmenu.h>
 #include <kicon.h>
 
-SKGShow::SKGShow(QWidget* parent)
-    : QToolButton(parent), m_mode(OR), m_inTrigger(false), m_displayTitle(true)
+SKGShow::SKGShow(QWidget* iParent)
+    : QToolButton(iParent), m_mode(OR), m_inTrigger(false), m_displayTitle(true)
 {
     setPopupMode(QToolButton::InstantPopup);
     setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
