@@ -69,9 +69,9 @@ public:
 
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGShow(QWidget* parent = 0);
+    explicit SKGShow(QWidget* iParent = 0);
 
     /**
      * Default Destructor
