@@ -26,8 +26,8 @@
 
 #include <QRegExp>
 
-SKGSortFilterProxyModel::SKGSortFilterProxyModel(QObject* parent)
-    : QSortFilterProxyModel(parent)
+SKGSortFilterProxyModel::SKGSortFilterProxyModel(QObject* iParent)
+    : QSortFilterProxyModel(iParent)
 {
     _SKGTRACEIN(10, "SKGSortFilterProxyModel::SKGSortFilterProxyModel");
 
