@@ -33,9 +33,9 @@ class SKGBASEGUI_EXPORT SKGSortFilterProxyModel : public QSortFilterProxyModel
 public:
     /**
      * Contructor
-     * @param parent parent widget
+     * @param iParent parent widget
      */
-    explicit SKGSortFilterProxyModel(QObject* parent = 0);
+    explicit SKGSortFilterProxyModel(QObject* iParent = 0);
 
     /**
      * Destructor
