@@ -23,8 +23,8 @@
 #include <QHeaderView>
 
 
-SKGTableView::SKGTableView(QWidget* parent)
-    : SKGTreeView(parent)
+SKGTableView::SKGTableView(QWidget* iParent)
+    : SKGTreeView(iParent)
 {
     this->setAllColumnsShowFocus(true);
     this->setRootIsDecorated(false);
