@@ -33,9 +33,9 @@ class SKGBASEGUI_EXPORT SKGTableView : public SKGTreeView
 public:
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGTableView(QWidget* parent = 0);
+    explicit SKGTableView(QWidget* iParent = 0);
 
     /**
      * Default Destructor
