@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGTableViewDesignerPlugin::SKGTableViewDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGTableViewDesignerPlugin::SKGTableViewDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGTableViewDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGTableViewDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGTableViewDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGTableView(parent);
+    return new SKGTableView(iParent);
 }
 
 QString SKGTableViewDesignerPlugin::name() const
