@@ -34,9 +34,9 @@ class SKGBASEGUI_EXPORT SKGTableWidget : public QTableWidget
 public:
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGTableWidget(QWidget* parent = 0);
+    explicit SKGTableWidget(QWidget* iParent = 0);
 
     /**
      * Default Destructor
@@ -69,9 +69,9 @@ public:
 
 Q_SIGNALS:
     /**
-     * Selected items must be removed
+     * Line must be removed
      */
-    void removeSelectedItems();
+    void removeLine(int);
 
 protected:
     /**
