@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGTableWidgetDesignerPlugin::SKGTableWidgetDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGTableWidgetDesignerPlugin::SKGTableWidgetDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGTableWidgetDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGTableWidgetDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGTableWidgetDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGTableWidget(parent);
+    return new SKGTableWidget(iParent);
 }
 
 QString SKGTableWidgetDesignerPlugin::name() const
