@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGTableWithGraphDesignerPlugin::SKGTableWithGraphDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGTableWithGraphDesignerPlugin::SKGTableWithGraphDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGTableWithGraphDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGTableWithGraphDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGTableWithGraphDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGTableWithGraph(parent);
+    return new SKGTableWithGraph(iParent);
 }
 
 QString SKGTableWithGraphDesignerPlugin::name() const
