@@ -33,13 +33,13 @@
 #include <QTimer>
 #include <QStringList>
 
-SKGTabWidget::SKGTabWidget(QWidget* parent)
-    : KTabWidget(parent)
+SKGTabWidget::SKGTabWidget(QWidget* iParent)
+    : KTabWidget(iParent)
 {
     m_timerSave.setSingleShot(true);
     connect(&m_timerSave, SIGNAL(timeout()), this, SLOT(onRefreshSaveIcon()), Qt::QueuedConnection);
     connect(tabBar(), SIGNAL(moveTab(int,int)), this, SLOT(onMoveTab(int,int)));
-    if (parent) connect(static_cast<SKGMainPanel*>(parent), SIGNAL(currentPageChanged()), this, SLOT(onCurrentChanged()));
+    if (iParent) connect(static_cast<SKGMainPanel*>(iParent), SIGNAL(currentPageChanged()), this, SLOT(onCurrentChanged()));
 
     // Use new KDE for moving tabs.
     KTabBar* tabbar = qobject_cast< KTabBar* >(tabBar());
