@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGTabWidgetDesignerPlugin::SKGTabWidgetDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGTabWidgetDesignerPlugin::SKGTabWidgetDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGTabWidgetDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGTabWidgetDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGTabWidgetDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGTabWidget(parent);
+    return new SKGTabWidget(iParent);
 }
 
 QString SKGTabWidgetDesignerPlugin::name() const
