@@ -54,8 +54,8 @@
 #include <QPushButton>
 #include <kstandardaction.h>
 
-SKGTreeView::SKGTreeView(QWidget* parent)
-    : QTreeView(parent),
+SKGTreeView::SKGTreeView(QWidget* iParent)
+    : QTreeView(iParent),
       m_autoResize(true), m_autoResizeDone(false), m_actAutoResize(NULL),
       m_document(NULL), m_textResizable(true),
       m_model(NULL), m_proxyModel(NULL),
@@ -118,9 +118,9 @@ SKGTreeView::SKGTreeView(QWidget* parent)
 
     QAbstractScrollArea* scrollArea = qobject_cast<QAbstractScrollArea*>(this);
     if (scrollArea) {
-        QWidget* viewport = scrollArea->viewport();
-        if (viewport) {
-            viewport->installEventFilter(this);
+        QWidget* vp = scrollArea->viewport();
+        if (vp) {
+            vp->installEventFilter(this);
             scrollArea->installEventFilter(this);
         }
     }
@@ -156,7 +156,7 @@ QString SKGTreeView::getState()
     QHeaderView* hHeader = header();
     if (hHeader && m_model) {
         if (isSortingEnabled()) {
-            root.setAttribute("sortOrder", SKGServices::intToString((int) hHeader->sortIndicatorOrder()));
+            root.setAttribute("sortOrder", SKGServices::intToString(static_cast<int>(hHeader->sortIndicatorOrder())));
             root.setAttribute("sortColumn", m_model->getAttribute(hHeader->sortIndicatorSection()));
         }
         root.setAttribute("groupBy", m_groupby);
@@ -192,10 +192,10 @@ QString SKGTreeView::getState()
     root.setAttribute("alternatingRowColors", alternatingRowColors() ? "Y" : "N");
     root.setAttribute("zoomPosition", SKGServices::intToString(zoomPosition()));
 
-    QScrollBar* scroll = horizontalScrollBar();
-    if (scroll && scroll->value() == scroll->maximum() && scroll->value() != scroll->minimum()) root.setAttribute("stickH", "Y");
-    scroll = verticalScrollBar();
-    if (scroll && scroll->value() == scroll->maximum() && scroll->value() != scroll->minimum()) root.setAttribute("stickV", "Y");
+    QScrollBar* scroll2 = horizontalScrollBar();
+    if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) root.setAttribute("stickH", "Y");
+    scroll2 = verticalScrollBar();
+    if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) root.setAttribute("stickV", "Y");
     return doc.toString();
 }
 
@@ -223,7 +223,7 @@ void SKGTreeView::setState(const QString& iState)
         QString columnsSize = root.attribute("columnsSize");
         QString columnsVisibility = root.attribute("columnsVisibility");
         QString columnsAutoResize = root.attribute("columnsAutoResize");
-        QString alternatingRowColors = root.attribute("alternatingRowColors");
+        QString alternatingRowColors2 = root.attribute("alternatingRowColors");
         QString zoomPosition = root.attribute("zoomPosition");
         QString expandedGroups = root.attribute("expandedGroups");
         stickH = (root.attribute("stickH") == "Y");
@@ -267,7 +267,7 @@ void SKGTreeView::setState(const QString& iState)
             int index = SKGServices::splitCSVLine(columns, ';').indexOf(sortColumn);
             if (index == -1) index = m_model->getIndexAttribute(sortColumn);
             if (index == -1) index = 0;
-            qtsortorder = (Qt::SortOrder) SKGServices::stringToInt(sortOrder);
+            qtsortorder = static_cast<Qt::SortOrder>(SKGServices::stringToInt(sortOrder));
             this->sortByColumn(index, qtsortorder);
         }
 
@@ -284,7 +284,7 @@ void SKGTreeView::setState(const QString& iState)
         }
 
         //Set alternatingRowColors
-        if (!alternatingRowColors.isEmpty()) setAlternatingRowColors(alternatingRowColors == "Y");
+        if (!alternatingRowColors2.isEmpty()) setAlternatingRowColors(alternatingRowColors2 == "Y");
         if (!zoomPosition.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPosition));
 
         //Set expanded groups
@@ -309,21 +309,21 @@ void SKGTreeView::setState(const QString& iState)
 
 void SKGTreeView::onRangeChanged()
 {
-    QScrollBar* scroll = qobject_cast<QScrollBar*>(sender());
-    if ((stickH && scroll == horizontalScrollBar()) || (stickV && scroll == verticalScrollBar())) {
-        scroll->setValue(scroll->maximum());
+    QScrollBar* scroll2 = qobject_cast<QScrollBar*>(sender());
+    if ((stickH && scroll2 == horizontalScrollBar()) || (stickV && scroll2 == verticalScrollBar())) {
+        scroll2->setValue(scroll2->maximum());
     }
 }
 
 void SKGTreeView::onActionTriggered(int action)
 {
-    QScrollBar* scroll = qobject_cast<QScrollBar*>(sender());
-    if (scroll && action == QAbstractSlider::SliderToMaximum) {
-        if (scroll == horizontalScrollBar()) stickH = true;
-        if (scroll == verticalScrollBar()) stickV = true;
+    QScrollBar* scroll2 = qobject_cast<QScrollBar*>(sender());
+    if (scroll2 && action == QAbstractSlider::SliderToMaximum) {
+        if (scroll2 == horizontalScrollBar()) stickH = true;
+        if (scroll2 == verticalScrollBar()) stickV = true;
     } else {
-        if (scroll == horizontalScrollBar()) stickH = false;
-        if (scroll == verticalScrollBar()) stickV = false;
+        if (scroll2 == horizontalScrollBar()) stickH = false;
+        if (scroll2 == verticalScrollBar()) stickV = false;
     }
 }
 
@@ -659,7 +659,7 @@ void SKGTreeView::setAlternatingRowColors(bool enable)
 
 SKGObjectBase SKGTreeView::getFirstSelectedObject()
 {
-    return m_lastSelection.at(0);
+    return m_lastSelection.value(0);
 }
 
 SKGObjectBase::SKGListSKGObjectBase SKGTreeView::getSelectedObjects()
@@ -701,6 +701,7 @@ void SKGTreeView::selectObject(const QString& iUniqueID)
 void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirstOne)
 {
     SKGTRACEIN(10, "SKGTreeView::selectObjects");
+    SKGTRACEL(10) << iUniqueIDs.count() << " objects to select" << endl;
     int nbset = 0;
     QItemSelectionModel* selModel = selectionModel();
     if (selModel) {
@@ -761,7 +762,6 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
         selModel->blockSignals(previous);
     }
 
-    SKGTRACEL(10) << iUniqueIDs.count() << " objects to select" << endl;
     SKGTRACEL(10) << nbset << " objects selected" << endl;
 
     onSelectionChanged();
@@ -885,7 +885,7 @@ void SKGTreeView::setZoomPosition(int iZoomPosition)
     }
 }
 
-int SKGTreeView::zoomPosition() const
+int SKGTreeView::zoomPosition()
 {
     return this->font().pointSize() - m_fontOriginalPointSize;
 }
@@ -974,7 +974,7 @@ SKGStringListList SKGTreeView::getTableContent(const QModelIndex& iIndex) const
 
             SKGServices::AttributeType type = m_model->getAttributeType(j);
             QString display = m_model->data(idx, type == SKGServices::FLOAT || m_model->getObject(idx).getTable().isEmpty() ?  Qt::DisplayRole : Qt::UserRole).toString();
-            if (display.isEmpty()) m_model->data(idx, Qt::DisplayRole).toString();
+            if (display.isEmpty()) display = m_model->data(idx, Qt::DisplayRole).toString();
             row.append(display);
         }
 
@@ -990,19 +990,16 @@ SKGStringListList SKGTreeView::getTableContent(const QModelIndex& iIndex) const
 }
 
 
-void SKGTreeView::onExport()
+SKGError SKGTreeView::exportInFile(const QString& iFileName)
 {
-    _SKGTRACEIN(10, "SKGTreeView::onExport");
-    QString lastCodecUsed = QTextCodec::codecForLocale()->name();
-    QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "text/csv text/plain image/svg+xml application/pdf" , this, QString(), &lastCodecUsed);
-    if (fileName.isEmpty()) return;
-
     SKGError err;
-    QString extension = QFileInfo(fileName).suffix().toUpper();
+    _SKGTRACEIN(10, "SKGTreeView::exportInFile");
+    QString lastCodecUsed = QTextCodec::codecForLocale()->name();
+    QString extension = QFileInfo(iFileName).suffix().toUpper();
     if (extension == "CSV") {
         //Write file
-        KSaveFile file(fileName);
-        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , fileName));
+        KSaveFile file(iFileName);
+        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
         else {
             QTextStream out(&file);
             out.setCodec(lastCodecUsed.toAscii().constData());
@@ -1024,7 +1021,7 @@ void SKGTreeView::onExport()
 
         {
             QPrinter printer(QPrinter::HighResolution);
-            printer.setOutputFileName(fileName);
+            printer.setOutputFileName(iFileName);
             QPainter painter(&printer);
 
             QRect rect = painter.viewport();
@@ -1037,7 +1034,7 @@ void SKGTreeView::onExport()
         }
     } else if (extension == "SVG") {
         QSvgGenerator generator;
-        generator.setFileName(fileName);
+        generator.setFileName(iFileName);
         generator.setTitle(i18nc("Title of the content SVG export", "Skrooge SVG export"));
         generator.setDescription(i18nc("Description of the content SVG export", "A SVG drawing created by the Skrooge."));
 
@@ -1050,8 +1047,8 @@ void SKGTreeView::onExport()
         painter.end();
     } else {
         //Write file
-        KSaveFile file(fileName);
-        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , fileName));
+        KSaveFile file(iFileName);
+        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
         else {
             QTextStream out(&file);
             out.setCodec(lastCodecUsed.toAscii().constData());
@@ -1066,8 +1063,22 @@ void SKGTreeView::onExport()
         file.finalize();
         file.close();
     }
-    SKGMainPanel::displayErrorMessage(err);
-    QDesktopServices::openUrl(QUrl(fileName));
+
+
+    return err;
+}
+
+void SKGTreeView::onExport()
+{
+    _SKGTRACEIN(10, "SKGTreeView::onExport");
+    QString lastCodecUsed = QTextCodec::codecForLocale()->name();
+    QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "text/csv text/plain image/svg+xml application/pdf" , this, QString(), &lastCodecUsed);
+    if (!fileName.isEmpty()) {
+
+        SKGError err = exportInFile(fileName);
+        SKGMainPanel::displayErrorMessage(err);
+        QDesktopServices::openUrl(QUrl(fileName));
+    }
 }
 
 void SKGTreeView::setModel(QAbstractItemModel* iModel)
@@ -1075,7 +1086,7 @@ void SKGTreeView::setModel(QAbstractItemModel* iModel)
     if (iModel != this->model()) {
         m_model = qobject_cast<SKGObjectModelBase*> (iModel);
         m_proxyModel = qobject_cast<QSortFilterProxyModel*> (iModel);
-        if (m_proxyModel) m_model = (SKGObjectModelBase*) m_proxyModel->sourceModel();
+        if (m_proxyModel) m_model = qobject_cast<SKGObjectModelBase*>(m_proxyModel->sourceModel());
 
         if (m_model) {
             connect(m_model, SIGNAL(afterReset()), this, SLOT(setupHeaderMenu()));
