@@ -59,9 +59,9 @@ class SKGBASEGUI_EXPORT SKGTreeView : public QTreeView
 public:
     /**
      * Default Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGTreeView(QWidget* parent = 0);
+    explicit SKGTreeView(QWidget* iParent = 0);
 
     /**
      * Default Destructor
@@ -145,6 +145,20 @@ public:
      **/
     virtual KMenu* getHeaderMenu() const;
 
+    /**
+     * Export to a file
+     * @param iFileName the file name
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError exportInFile(const QString& iFileName);
+
+    /**
+     * Get the current schema
+     * @return the current schema
+     */
+    virtual QStringList getCurrentSchema() const;
+
 Q_SIGNALS:
     /**
      * Emitted when the empty area
@@ -194,7 +208,7 @@ public Q_SLOTS:
      * Get zoom position
      * @return zoom position (-10<=zoom position<=10)
      */
-    virtual int zoomPosition() const;
+    virtual int zoomPosition();
 
     /**
      * Save the selection
@@ -255,6 +269,16 @@ public Q_SLOTS:
      */
     virtual void expandAll();
 
+    /**
+     * Copy selection in clipboard
+     */
+    virtual void copy();
+
+    /**
+     * Switch auto resize
+     */
+    virtual void switchAutoResize();
+
 protected:
     /**
       * Event filtering
@@ -270,7 +294,6 @@ private Q_SLOTS:
     void showHeaderMenu();
     void showHeaderMenu(const QPoint& pos);
     void showHideColumn();
-    void switchAutoResize();
     void changeSchema();
     void saveDefaultClicked();
     void groupByChanged(QAction*);
@@ -280,7 +303,6 @@ private Q_SLOTS:
     void onExpand(const QModelIndex& index);
     void onCollapse(const QModelIndex& index);
     void onClick(const QModelIndex& index);
-    void copy();
     void onActionTriggered(int action);
     void onRangeChanged();
 
@@ -288,7 +310,6 @@ private Q_SLOTS:
 
 private:
     Q_DISABLE_COPY(SKGTreeView)
-    QStringList getCurrentSchema() const;
 
     KMenu* m_headerMenu;
     bool m_autoResize;
