@@ -40,8 +40,8 @@
 
 #include <QtPlugin>
 
-SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_widgets.append(new SKGCalculatorEditDesignerPlugin(this));
     m_widgets.append(new SKGComboBoxDesignerPlugin(this));
