@@ -36,9 +36,9 @@ class SKGBASEGUI_EXPORT SKGWidgetCollectionDesignerPlugin: public QObject, publi
 public:
     /**
      * Constructor
-     * @param parent the parent
+     * @param iParent the parent
      */
-    explicit SKGWidgetCollectionDesignerPlugin(QObject* parent = 0);
+    explicit SKGWidgetCollectionDesignerPlugin(QObject* iParent = 0);
 
     /**
      * To get the list of widgets
