@@ -24,8 +24,8 @@
 #include <QToolButton>
 #include <qpropertyanimation.h>
 
-SKGWidgetSelector::SKGWidgetSelector(QWidget* parent)
-    : QWidget(parent), m_currentMode(-1), m_alwaysOneOpen(false)
+SKGWidgetSelector::SKGWidgetSelector(QWidget* iParent)
+    : QWidget(iParent), m_currentMode(-1), m_alwaysOneOpen(false)
 {
     ui.setupUi(this);
 }
