@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGWidgetSelectorDesignerPlugin::SKGWidgetSelectorDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGWidgetSelectorDesignerPlugin::SKGWidgetSelectorDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGWidgetSelectorDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGWidgetSelectorDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGWidgetSelectorDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGWidgetSelector(parent);
+    return new SKGWidgetSelector(iParent);
 }
 
 QString SKGWidgetSelectorDesignerPlugin::name() const
