@@ -24,8 +24,8 @@
 
 #include <qtextstream.h>
 
-SKGZoomSelector::SKGZoomSelector(QWidget* parent)
-    : QWidget(parent), m_resetValue(0)
+SKGZoomSelector::SKGZoomSelector(QWidget* iParent)
+    : QWidget(iParent), m_resetValue(0)
 {
     ui.setupUi(this);
 
