@@ -26,8 +26,8 @@
 
 #include <QtPlugin>
 
-SKGZoomSelectorDesignerPlugin::SKGZoomSelectorDesignerPlugin(QObject* parent)
-    : QObject(parent)
+SKGZoomSelectorDesignerPlugin::SKGZoomSelectorDesignerPlugin(QObject* iParent)
+    : QObject(iParent)
 {
     m_initialized = false;
 }
@@ -44,9 +44,9 @@ bool SKGZoomSelectorDesignerPlugin::isInitialized() const
     return m_initialized;
 }
 
-QWidget* SKGZoomSelectorDesignerPlugin::createWidget(QWidget* parent)
+QWidget* SKGZoomSelectorDesignerPlugin::createWidget(QWidget* iParent)
 {
-    return new SKGZoomSelector(parent);
+    return new SKGZoomSelector(iParent);
 }
 
 QString SKGZoomSelectorDesignerPlugin::name() const
