@@ -45,6 +45,8 @@ class SKGBASEMODELER_EXPORT SKGDocument : public QObject
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.skg.SKGDocument")
 
+    typedef int (*progressFunction)(int, qint64, const QString&, void*);
+
     /**
      * This enumerate defines a type of modification
      */
@@ -653,7 +655,7 @@ public Q_SLOTS:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getObjects(const QString& iTable, const QString& iWhereClause, SKGObjectBase::SKGListSKGObjectBase& oListObject) const;
+    virtual SKGError getObjects(const QString& iTable, const QString& iWhereClause, SKGObjectBase::SKGListSKGObjectBase& oListObject);
 
     /**
      * Return the object (@p oObject) corresponding to a where clause (@p iWhereClause ).
@@ -665,7 +667,7 @@ public Q_SLOTS:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getObject(const QString& iTable, const QString& iWhereClause, SKGObjectBase& oObject) const;
+    virtual SKGError getObject(const QString& iTable, const QString& iWhereClause, SKGObjectBase& oObject);
 
     /**
      * Return the object (@p oObject) corresponding to an id (@p iId ).
@@ -677,7 +679,7 @@ public Q_SLOTS:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getObject(const QString& iTable, int iId, SKGObjectBase& oObject) const;
+    virtual SKGError getObject(const QString& iTable, int iId, SKGObjectBase& oObject);
 
     /**
      * Retrieve list of tables
@@ -898,7 +900,7 @@ private:
     static int m_databaseUniqueIdentifier;
 
     int m_lastSavedTransaction;
-    void* m_progressFunction;
+    progressFunction m_progressFunction;
     void* m_progressData;
     QString m_currentFileName;
     QString m_databaseIdentifier;
