@@ -26,16 +26,31 @@
 
 #include <QString>
 #include <QObject>
-#include <QDBusArgument>
-#include <qscriptvalue.h>
-#include <qscriptengine.h>
+
+/**
+ * To facilitate the error management
+ */
+#define IFKO(ERROR) \
+    if (Q_UNLIKELY(ERROR))
+
+/**
+ * To facilitate the error management
+ */
+#define IFOK(ERROR) \
+    if (Q_LIKELY(!ERROR))
+
+/**
+ * To facilitate the error management
+ */
+#define IFOKDO(ERROR, ACTION) \
+    IFOK(ERROR) {ERROR = ACTION;}
+
 /**
 * This class manages errors
 */
 class SKGBASEMODELER_EXPORT SKGError : public QObject
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.skrooge.SKGError")
     /**
      * Return code of the error
      */
@@ -210,48 +225,4 @@ private:
      */
     SKGError* m_previousError;
 };
-/**
- * Declare the class
- */
-Q_DECLARE_TYPEINFO(SKGError, Q_MOVABLE_TYPE);
-
-/**
- * Declare the meta type
- */
-Q_DECLARE_METATYPE(SKGError)
-
-/**
- * Declare the meta type
- */
-Q_DECLARE_METATYPE(SKGError*)
-
-/**
-* Function for scription
-* @param engine the engine
-* @param in the object
-* @return the value
-*/
-SKGBASEMODELER_EXPORT QScriptValue SKGErrorToScriptValue(QScriptEngine* engine, SKGError* const& in);
-
-/**
-* Function for scription
-* @param object the object
-* @param out the object
-*/
-SKGBASEMODELER_EXPORT void SKGErrorFromScriptValue(const QScriptValue& object, SKGError* &out);
-
-/**
-* Operator <<
-* @param iArgument the DBus argument
-* @param iError the error
-*/
-SKGBASEMODELER_EXPORT QDBusArgument& operator<<(QDBusArgument& iArgument, const SKGError& iError);
-
-/**
-* Operator >>
-* @param iArgument the DBus argument
-* @param iError the error
-*/
-SKGBASEMODELER_EXPORT const QDBusArgument& operator>>(const QDBusArgument& iArgument, SKGError& iError);
-
 #endif //SKGERROR_H
