@@ -28,10 +28,8 @@
 #include <kstandarddirs.h>
 #include <grantlee/engine.h>
 #include <grantlee/templateloader.h>
-#ifdef SKGGRANTLEE17ENABLED
 #include <grantlee/qtlocalizer.h>
 #include <grantlee/metatype.h>
-#endif
 #include <kaboutdata.h>
 #include <kcomponentdata.h>
 #include <kcolorscheme.h>
@@ -44,12 +42,10 @@
 #include <QFont>
 
 
-#ifdef SKGGRANTLEE17ENABLED
 GRANTLEE_BEGIN_LOOKUP(SKGObjectBase)
 Q_UNUSED(object);
 Q_UNUSED(property);
 GRANTLEE_END_LOOKUP
-#endif
 
 SKGReport::SKGReport(SKGDocument* iDocument)
     : QObject(), m_document(iDocument)
@@ -57,10 +53,8 @@ SKGReport::SKGReport(SKGDocument* iDocument)
     SKGTRACEIN(1, "SKGReport::SKGReport");
 
     //Grantlee initialization
-#ifdef SKGGRANTLEE17ENABLED
     Grantlee::MetaType::init();
     Grantlee::registerMetaType<SKGObjectBase>();
-#endif
 }
 
 SKGReport::~SKGReport()
