@@ -42,6 +42,7 @@
 #include <QTemporaryFile>
 #include <QtCrypto>
 #include <QDomDocument>
+#include <QScriptEngine>
 
 int SKGServices::SKGSqlTraces = (SKGServices::getenv("SKGTRACESQL").isEmpty() ? -1 : SKGServices::stringToInt(SKGServices::getenv("SKGTRACESQL")));
 
@@ -66,7 +67,7 @@ QList< SKGServices::SKGSearchCriteria > SKGServices::stringToSearchCriterias(con
             if (word.count() > 1) nextChar = word[1];
             if (nextChar < '0' || nextChar > '9') {
                 word = word.right(word.length() - 1);
-                if (i != 0) {
+                if (Q_LIKELY(i != 0)) {
                     if (criteria.mode == '-') output.push_back(criteria);
                     else {
                         output.push_front(criteria);
@@ -87,10 +88,10 @@ QList< SKGServices::SKGSearchCriteria > SKGServices::stringToSearchCriterias(con
 
     if (!atLeastOnePlus) {
         //Add a '+' always true
-        SKGServices::SKGSearchCriteria criteria;
-        criteria.mode = '+';
-        criteria.words.push_back("");
-        output.push_front(criteria);
+        SKGServices::SKGSearchCriteria criteria2;
+        criteria2.mode = '+';
+        criteria2.words.push_back("");
+        output.push_front(criteria2);
     }
 
     return output;
@@ -110,11 +111,11 @@ QString SKGServices::intToString(qlonglong iNumber)
 
 qlonglong SKGServices::stringToInt(const QString& iNumber)
 {
-    if (iNumber.isEmpty()) return 0;
+    if (Q_UNLIKELY(iNumber.isEmpty())) return 0;
 
     bool ok;
     qlonglong output = iNumber.toLongLong(&ok);
-    if (!ok) {
+    if (Q_LIKELY(!ok)) {
         SKGTRACE << "WARNING: SKGServices::stringToInt(" << iNumber << ") failed" << endl;
     }
 
@@ -156,7 +157,7 @@ QString SKGServices::stringsToCsv(const QStringList& iList, const QChar& iSepara
     int nb = iList.count();
     for (int i = 0; i < nb; ++i) {
         output.append(SKGServices::stringToCsv(iList[i]));
-        if (i < nb - 1) output.append(iSeparator);
+        if (Q_LIKELY(i < nb - 1)) output.append(iSeparator);
     }
 
     return output;
@@ -173,9 +174,9 @@ QString SKGServices::stringToCsv(const QString& iNumber)
 
 double SKGServices::stringToDouble(const QString& iNumber)
 {
-    if (iNumber.isEmpty() || iNumber == "nan") return 0;
-    else if (iNumber == "inf") return 1e300;
-    else if (iNumber == "-inf") return -1e300;
+    if (Q_UNLIKELY(iNumber.isEmpty() || iNumber == "nan")) return 0;
+    else if (Q_UNLIKELY(iNumber == "inf")) return 1e300;
+    else if (Q_UNLIKELY(iNumber == "-inf")) return -1e300;
     QString number = iNumber;
     number.remove(QRegExp("[^0-9-+/eE,.]"));
     if (number.contains("/")) {
@@ -187,24 +188,24 @@ double SKGServices::stringToDouble(const QString& iNumber)
 
     bool ok;
     double output = number.toDouble(&ok);
-    if (!ok) {
+    if (Q_LIKELY(!ok)) {
         QString tmp = number;
         tmp.replace(',', '.');
         if (tmp.count('.') > 1) tmp.remove(tmp.indexOf('.'), 1);
         output = tmp.toDouble(&ok);
-        if (!ok) {
-            QString tmp = number;
-            tmp.replace('.', ',');
-            if (tmp.count(',') > 1) tmp.remove(tmp.indexOf(','), 1);
-            output = tmp.toDouble(&ok);
+        if (Q_LIKELY(!ok)) {
+            QString tmp2 = number;
+            tmp2.replace('.', ',');
+            if (tmp2.count(',') > 1) tmp2.remove(tmp2.indexOf(','), 1);
+            output = tmp2.toDouble(&ok);
             if (!ok) {
-                QString tmp = number;
-                tmp.remove(',');
-                output = tmp.toDouble(&ok);
+                QString tmp3 = number;
+                tmp3.remove(',');
+                output = tmp3.toDouble(&ok);
             }
         }
     }
-    if (!ok) {
+    if (Q_LIKELY(!ok)) {
         SKGTRACE << "WARNING: SKGServices::stringToDouble(" << iNumber << ") failed" << endl;
     }
     return output;
@@ -220,14 +221,14 @@ QString SKGServices::doubleToString(double iNumber)
 QString SKGServices::timeToString(const QDateTime& iDateTime)
 {
     QDateTime d = iDateTime;
-    if (!d.isValid()) d = QDateTime::currentDateTime();
+    if (Q_UNLIKELY(!d.isValid())) d = QDateTime::currentDateTime();
     return d.toString("yyyy-MM-dd HH:mm:ss");
 }
 
 QString SKGServices::dateToSqlString(const QDateTime& iDateTime)
 {
     QDateTime d = iDateTime;
-    if (!d.isValid()) d = QDateTime::currentDateTime();
+    if (Q_UNLIKELY(!d.isValid())) d = QDateTime::currentDateTime();
     return d.toString("yyyy-MM-dd");
 }
 
@@ -248,7 +249,7 @@ int SKGServices::nbWorkingDays(const QDate& iFrom, const QDate& iTo)
 QDateTime SKGServices::stringToTime(const QString& iDateString)
 {
     QDateTime output = QDateTime::fromString(iDateString, "yyyy-MM-dd HH:mm:ss");
-    if (!output.isValid()) {
+    if (Q_UNLIKELY(!output.isValid())) {
         output = QDateTime::fromString(iDateString, "yyyy-MM-dd");
     }
 
@@ -436,18 +437,18 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     else if (f_MMDDYYYY) return "MMDDYYYY";
     else if (f_DDMMYYYY) return "DDMMYYYY";
     else if (f_DD_MM_YY && f_MM_DD_YY) {
-        KLocale* locale = KGlobal::locale();
-        if (locale) {
-            QString sFormat = locale->dateFormatShort();
+        KLocale* loc = KGlobal::locale();
+        if (loc) {
+            QString sFormat = loc->dateFormatShort();
             if (sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YY";
         }
         return "DD-MM-YY";
     } else if (f_MM_DD_YY) return "MM-DD-YY";
     else if (f_DD_MM_YY) return "DD-MM-YY";
     else if (f_DD_MM_YYYY && f_MM_DD_YYYY) {
-        KLocale* locale = KGlobal::locale();
-        if (locale) {
-            QString sFormat = locale->dateFormatShort();
+        KLocale* loc = KGlobal::locale();
+        if (loc) {
+            QString sFormat = loc->dateFormatShort();
             if (sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YYYY";
         }
         return "DD-MM-YYYY";
@@ -619,10 +620,10 @@ SKGError SKGServices::downloadToStream(const KUrl& iSourceUrl, QByteArray& oStre
     SKGTRACEINRC(10, "SKGServices::downloadToStream", err);
     QString tmpFile;
     err = download(iSourceUrl, tmpFile);
-    if (!err) {
+    IFOK(err) {
         //Open file
         QFile file(tmpFile);
-        if (!file.open(QIODevice::ReadOnly)) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
+        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
         else {
             oStream = file.readAll();
 
@@ -642,7 +643,7 @@ SKGError SKGServices::download(const KUrl& iSourceUrl, QString& oTemporaryFile)
     tmpFile.setAutoRemove(false);
     if (tmpFile.open()) {
         err = upload(iSourceUrl, KUrl::fromLocalFile(tmpFile.fileName()));
-        if (!err) oTemporaryFile = tmpFile.fileName();
+        IFOK(err) oTemporaryFile = tmpFile.fileName();
     }
     return err;
 }
@@ -692,7 +693,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
 
         QByteArray input;
         err = downloadToStream(KUrl(iFileSource), input);
-        if (!err) {
+        IFOK(err) {
             //Read document
             QByteArray h = (iHeaderFile % (!cipher ? "_DECRYPTED-" : "_ENCRYPTED-")).toLatin1();
             //BUG 249955 vvv
@@ -713,7 +714,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
             }
 
             // output the results of that stage
-            if (!err) {
+            IFOK(err) {
                 KSaveFile fileOutput(iFileTarget);
                 if (!fileOutput.open()) err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
                 else {
@@ -805,7 +806,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         // Copy the tables
         SKGStringListList listTables;
         int nb = 0;
-        if (!err) {
+        IFOK(err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYTABLES", err);
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
                     "SELECT sql, tbl_name FROM sqlite_master WHERE type='table' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
@@ -818,16 +819,16 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
             }
         }
         //Attach db
-        if (!err) {
+        IFOK(err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-ATTACH", err);
             err = SKGServices::executeSqliteOrder(iMemoryDb, "ATTACH DATABASE '" % dbFileName % "' as source");
         }
 
         //Copy records
-        if (!err) {
+        IFOK(err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPY", err);
             err = SKGServices::executeSqliteOrder(iMemoryDb, "BEGIN");
-            if (!err) {
+            IFOK(err) {
                 for (int i = 1; !err && i < nb; ++i) { //Forget header
                     QString val = listTables.at(i).at(1);
                     if (iFromFileToMemory)  err = SKGServices::executeSqliteOrder(iMemoryDb, "insert into main." % val % " select * from source." % val);
@@ -846,7 +847,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         }
 
         //Optimization
-        if (!err) {
+        IFOK(err) {
 
             QStringList optimization;
             optimization << "PRAGMA case_sensitive_like=true"
@@ -860,45 +861,45 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         }
 
         // Copy the indexes
-        if (!err) {
+        IFOK(err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYINDEX", err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
                     "SELECT sql FROM sqlite_master WHERE type='index' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
                     listSqlOrder);
 
-            int nb = listSqlOrder.count();
-            for (int i = 1; !err && i < nb; ++i) { //Forget header
+            int nb2 = listSqlOrder.count();
+            for (int i = 1; !err && i < nb2; ++i) { //Forget header
                 QString val = listSqlOrder.at(i).at(0);
                 err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
             }
         }
 
         // Copy the views
-        if (!err) {
+        IFOK(err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYVIEW", err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
                     "SELECT sql FROM sqlite_master WHERE type='view' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
                     listSqlOrder);
 
-            int nb = listSqlOrder.count();
-            for (int i = 1; !err && i < nb; ++i) { //Forget header
+            int nb2 = listSqlOrder.count();
+            for (int i = 1; !err && i < nb2; ++i) { //Forget header
                 QString val = listSqlOrder.at(i).at(0);
                 err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
             }
         }
 
         // Copy the triggers, must be done after the views
-        if (!err) {
+        IFOK(err) {
             SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYTRIGGER", err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
                     "SELECT sql FROM sqlite_master WHERE type='trigger' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
                     listSqlOrder);
 
-            int nb = listSqlOrder.count();
-            for (int i = 1; !err && i < nb; ++i) { //Forget header
+            int nb2 = listSqlOrder.count();
+            for (int i = 1; !err && i < nb2; ++i) { //Forget header
                 QString val = listSqlOrder.at(i).at(0);
                 err = SKGServices::executeSqliteOrder((iFromFileToMemory ? iMemoryDb : iFileDb), val);
             }
@@ -907,7 +908,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         //Check if created file exists
         if (!err && !iFromFileToMemory && !QFile(dbFileName).exists()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message: creating a file failed", "Creation file '%1' failed", dbFileName));
     }
-    if (err) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("SKGServices::copySqliteDatabase()")));
+    IFKO(err) err.addError(SQLLITEERROR + ERR_FAIL, i18nc("Error message: something failed", "%1 failed", QString("SKGServices::copySqliteDatabase()")));
     return err;
 }
 
@@ -985,7 +986,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
     //initialisation
     QStringList oResult;
     err = SKGServices::dumpSelectSqliteOrder(iDb, iSqlOrder, oResult, iMode);
-    if (!err) {
+    IFOK(err) {
         //dump
         int nb = oResult.size();
         for (int i = 0; i < nb; ++i) {
@@ -1005,7 +1006,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
 
     QStringList oResultTmp;
     err = SKGServices::dumpSelectSqliteOrder(iDb, iSqlOrder, oResultTmp, iMode);
-    if (!err) {
+    IFOK(err) {
         //dump
         int nb = oResultTmp.size();
         for (int i = 0; i < nb; ++i) {
@@ -1023,7 +1024,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
     //Execution of sql order
     SKGStringListList oResultTmp;
     err = executeSelectSqliteOrder(iDb, iSqlOrder, oResultTmp);
-    if (!err) oResult = tableToDump(oResultTmp, iMode);
+    IFOK(err) oResult = tableToDump(oResultTmp, iMode);
     return err;
 }
 
@@ -1072,18 +1073,18 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
 
             //Addition of rows
             while (query.next()) {
-                QStringList line;
-                int index = 0;
-                while (index != -1) {
-                    QVariant val = query.value(index);
+                QStringList line2;
+                int index2 = 0;
+                while (index2 != -1) {
+                    QVariant val = query.value(index2);
                     if (val.isValid()) {
-                        line.push_back(val.toString());
-                        ++index;
+                        line2.push_back(val.toString());
+                        ++index2;
                     } else {
-                        index = -1;
+                        index2 = -1;
                     }
                 }
-                oResult.push_back(line);
+                oResult.push_back(line2);
             }
             if (SKGServices::SKGSqlTraces != -1) {
                 double elapse1 = SKGServices::getMicroTime() - elapse;
@@ -1150,7 +1151,6 @@ SKGStringListList SKGServices::getBase100Table(const SKGStringListList& iTable)
 
     output.push_back(iTable.at(0));
 
-    QStringList newLine;
     int nblines = iTable.count();
     int nbCols = 0;
     if (nblines) {
@@ -1189,7 +1189,6 @@ SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable,
 
     output.push_back(iTable.at(0));
 
-    QStringList newLine;
     int nblines = iTable.count();
     int nbCols = 0;
     if (nblines) {
@@ -1252,7 +1251,6 @@ SKGStringListList SKGServices::getHistorizedTable(const SKGStringListList& iTabl
 
     output.push_back(iTable.at(0));
 
-    QStringList newLine;
     int nblines = iTable.count();
     int nbCols = 0;
     if (nblines) {
