@@ -183,7 +183,7 @@ QStringList SKGTraces::getProfilingStatistics()
             SKGPerfoMapIterator max;
             SKGPerfoMapIterator it2;
             for (it2 = SKGPerfoMethodeCopy.begin() ; it2 != SKGPerfoMethodeCopy.end(); ++it2) {
-                if (it2.value().TimePropre > maxtime) {
+                if (it2.value().TimePropre > maxtime || maxtime == -1) {
                     maxtime = it2.value().TimePropre;
                     max = it2;
                 }
