@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -26,12 +26,13 @@
 SKGTransactionMng::SKGTransactionMng(SKGDocument* iDocument,
                                      const QString& iName,
                                      SKGError* iError,
-                                     int iNbStep)
+                                     int iNbStep,
+                                     bool iRefreshViews)
 {
     m_parentDocument = iDocument;
     m_error = iError;
-    if(m_parentDocument && m_error) {
-        *m_error = m_parentDocument->beginTransaction(iName, iNbStep);
+    if (m_parentDocument && m_error) {
+        *m_error = m_parentDocument->beginTransaction(iName, iNbStep, QDateTime::currentDateTime(), iRefreshViews);
         m_errorInBeginTransaction = (m_error->isFailed());
     }
 
@@ -39,11 +40,14 @@ SKGTransactionMng::SKGTransactionMng(SKGDocument* iDocument,
 
 SKGTransactionMng::~SKGTransactionMng()
 {
-    if(m_parentDocument && m_error) {
+    if (m_parentDocument && m_error) {
         //close the transaction based on error
-        if(!m_errorInBeginTransaction) {
-            if(m_error->isSucceeded()) *m_error = m_parentDocument->endTransaction(true);
-            else  m_parentDocument->endTransaction(false);
+        if (!m_errorInBeginTransaction) {
+            if (m_error->isSucceeded()) {
+                SKGError opError = *m_error; //In case of the message is not empty
+                *m_error = m_parentDocument->endTransaction(true);
+                if (m_error->isSucceeded()) *m_error = opError;
+            } else  m_parentDocument->endTransaction(false);
         }
         m_parentDocument = NULL;
         m_error = NULL;
