@@ -40,6 +40,23 @@
  */
 #define VER VER_(SKGVERSION)
 
+void SKGMessageOutput(QtMsgType type, const char* msg)
+{
+    switch (type) {
+    case QtDebugMsg:
+        SKGTRACE << "DEBUG: " << msg << endl;
+        break;
+    case QtWarningMsg:
+        SKGTRACE << "WARNING: " << msg << endl;
+        break;
+    case QtCriticalMsg:
+        SKGTRACE << "CRITICAL: " << msg << endl;
+        break;
+    case QtFatalMsg:
+        SKGTRACE << "FATAL: " << msg << endl;
+        abort();
+    }
+}
 
 /**
  * The main of the application
@@ -49,6 +66,8 @@
  */
 int main(int argc, char** argv)
 {
+    qInstallMsgHandler(SKGMessageOutput);
+
     KAboutData about("skrooge",
                      0,
                      ki18nc("The name of the application", "Skrooge"),
@@ -91,6 +110,9 @@ int main(int argc, char** argv)
         SKGDocumentBank doc;
         {
             SKGUniqueApplication kApp(&doc);
+            if (!SKGServices::getenv("SKGTEST").isEmpty()) {
+                QTimer::singleShot(5000, &kApp, SLOT(quit()));
+            }
             rc = kApp.exec(); // krazy:exclude=crashy
         }
     }
